/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(ub){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function sb(tb){var r=tb.a;var s=r.buffer;r.grow=qb;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=tb.abort;var M=NaN;var N=Infinity;var O=tb.b;var P=tb.c;var Q=tb.d;var R=tb.e;var S=tb.f;var T=tb.g;var U=tb.h;var V=tb.i;var W=tb.j;var X=tb.k;var Y=tb.l;var Z=tb.m;var _=tb.n;var $=tb.o;var aa=tb.p;var ba=tb.q;var ca=tb.r;var da=tb.s;var ea=tb.t;var fa=tb.u;var ga=tb.v;var ha=tb.w;var ia=tb.x;var ja=tb.y;var ka=tb.z;var la=tb.A;var ma=tb.B;var na=tb.C;var oa=tb.D;var pa=tb.E;var qa=tb.F;var ra=tb.G;var sa=tb.H;var ta=tb.I;var ua=tb.J;var va=tb.K;var wa=tb.L;var xa=tb.M;var ya=tb.N;var za=tb.O;var Aa=tb.P;var Ba=tb.Q;var Ca=tb.R;var Da=tb.S;var Ea=tb.T;var Fa=tb.U;var Ga=tb.V;var Ha=tb.W;var Ia=tb.X;var Ja=tb.Y;var Ka=tb.Z;var La=tb._;var Ma=tb.$;var Na=tb.aa;var Oa=tb.ba;var Pa=tb.ca;var Qa=tb.da;var Ra=tb.ea;var Sa=tb.fa;var Ta=tb.ga;var Ua=tb.ha;var Va=tb.ia;var Wa=tb.ja;var Xa=tb.ka;var Ya=tb.la;var Za=tb.ma;var _a=tb.na;var $a=tb.oa;var ab=tb.pa;var bb=tb.qa;var cb=tb.ra;var db=tb.sa;var eb=tb.ta;var fb=tb.ua;var gb=5709184;var hb=0;var ib=0;var jb=0;
// EMSCRIPTEN_START_FUNCS
function Dt(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,R=0,T=0,V=0,W=0,X=C(0),Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=C(0),xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=C(0),Qa=0;_=gb-48|0;gb=_;na=_+40|0;v[na>>2]=55644;v[na>>2]=55544;d=gL(_+32|0);e=gL(_+24|0);f=v[d+4>>2];v[_+16>>2]=v[d>>2];v[_+20>>2]=f;d=v[e+4>>2];v[_+8>>2]=v[e>>2];v[_+12>>2]=d;ia=b;pa=c;T=gb-128|0;gb=T;K=a;a:{b:{qa=a+24604|0;a=qa;if(!v[a+16>>2]){break b}b=v[a+20>>2];if(b>>>0>4|!(1<<b&22)){break b}a=v[a+28>>2];if(a>>>0>4){break b}a=23>>>a&1;break a}a=0}if(!a){gP(T+112|0,6308,10390,200,45);b=T+112|0;a=gb-160|0;gb=a;v[a+88>>2]=0;d=au(a+88|0);v[22640]=0;c=Q(2,a+120|0,14815)|0;e=v[22640];v[22640]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){v[22640]=0;U(6,a+104|0,1,14495);e=v[22640];v[22640]=0;if((e|0)==1){break i}v[22640]=0;U(3,a+136|0,c|0,a+104|0);e=v[22640];v[22640]=0;if((e|0)==1){break h}v[22640]=0;ha(33,d|0,b|0,1,10933,a+136|0);b=v[22640];v[22640]=0;if((b|0)==1){break g}vb(a+136|0);vb(a+104|0);vb(c);break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+136|0)}vb(a+104|0)}vb(c)}S(b|0);L()}gb=a+160|0}i=v[K+480208>>2];j:{if(!ia|i&512){break j}ya=K+8204|0;za=K+1074332|0;Aa=K+393352|0;ea=K+12|0;ra=K+1298260|0;Ba=K+1074376|0;a=v[K+1074380>>2];while(1){k:{if(a){break k}R=K;a=i|512;l:{if(i&256){break l}i=0;k=gb-48|0;gb=k;J=gb-32|0;gb=J;p=K;f=p;b=f+1074392|0;a=v[b>>2]+1|0;v[b>>2]=a;m:{n:{n=f+1074376|0;o:{if(sk(n)>>>0>a>>>0){break o}j=f+1074312|0;d=f+1074992|0;a=f+1298224|0;r=f+1074424|0;h=f+484344|0;e=f+484360|0;g=f+1074448|0;o=f+480210|0;while(1){Ez(J+24|0,f,n,(v[f+480208>>2]&524288)>>>19|0);p:{q:{r:{s:{if(!(w[f+480208|0]&32)){c=x[g>>1];b=f;t:{if(sc(Rb(e))>>>0>c>>>0){c=x[rc(Rb(e),x[g>>1])>>1];break t}c=65535}u[b+1074446>>1]=c;u:{if(Oe(h)>>>0<=(c&65535)>>>0){break u}if(hi(_b(h,x[f+1074446>>1]))){break u}u[f+1074446>>1]=65534}if(x[f+1074446>>1]>=Oe(h)>>>0){while(1){v:{w:{x:{y:{if(x[f+1074446>>1]!=65535){b=x[g>>1];if(sc(Rb(e))>>>0>b>>>0){break y}}c=x[Rb(e)+28>>1];if(c){break w}b=x[g>>1];if(sc(Rb(e))>>>0<b>>>0){break x}b=x[g>>1];if(!b){break x}while(1){c=b;b=b-1|0;if(!b){break x}if(x[rc(Rb(e),b)>>1]!=65535){continue}break}break w}b=x[g>>1]+1|0;u[g>>1]=b;break v}c=0}u[f+1074448>>1]=c;v[f+480208>>2]=v[f+480208>>2]&-524289;z:{if(sc(Rb(e))>>>0<=(c&65535)>>>0){break z}while(1){if(x[rc(Rb(e),x[g>>1])>>1]!=65534){break z}b=x[g>>1]+1|0;u[g>>1]=b;if(sc(Rb(e))>>>0>(b&65535)>>>0){continue}break}}b=x[g>>1];if(sc(Rb(e))>>>0<=b>>>0){break s}if(!Mo(Rb(e),x[g>>1])){break s}b=x[g>>1]}c=f;A:{if(sc(Rb(e))>>>0>(b&65535)>>>0){b=x[rc(Rb(e),x[g>>1])>>1];break A}b=65535}u[c+1074446>>1]=b;B:{if(Oe(h)>>>0<=(b&65535)>>>0){break B}if(hi(_b(h,x[f+1074446>>1]))){break B}u[f+1074446>>1]=65534}if(x[f+1074446>>1]>=Oe(h)>>>0){continue}break}}u[f+1074450>>1]=x[f+1074448>>1]}if(!ke(h,x[f+1074446>>1])){break n}if(y[f+1074424>>2]>=y[_b(h,x[f+1074446>>1])+12>>2]){v[r>>2]=0}if(v[f+480208>>2]&32?v[f+480272>>2]!=-1:0){break p}if(!tu(a,x[g>>1],v[r>>2],Nq(J+16|0,d),w[J+24|0])){break p}b=v[f+480272>>2];if(b){if((b|0)>=1){v[f+480272>>2]=b-1}Jo(a,1);tu(a,x[g>>1],v[r>>2],Nq(J+16|0,d),w[J+24|0]);break p}if(!(w[o|0]&64)){break s}if(xR(a,g,r,1)){break q}v[f+1074448>>2]=0;v[f+1074424>>2]=0;v[f+1074428>>2]=0;if(w[e+16|0]<(Oi(e)-1|0)){break r}Pi(e,0)}Jo(a,1);break n}Pi(e,w[e+16|0]+1&255);Jo(a,1)}b=0;while(1){$m((f+B(b,872)|0)+1074992|0,7,f,b&65535,134217728);b=b+1|0;if((b|0)!=256){continue}break}ZO(f);v[f+1074416>>2]=v[f+480196>>2];v[f+1074420>>2]=v[f+480204>>2];v[f+1074456>>2]=v[f+480200>>2];u[f+1074450>>1]=x[f+1074448>>1];v[f+1074428>>2]=v[f+1074424>>2];c=a;l=sc(Rb(e));b=x[f+1074448>>1];if(l>>>0>b>>>0){Na=f,Oa=x[rc(Rb(e),x[f+1074448>>1])>>1],u[Na+1074446>>1]=Oa;b=x[f+1074448>>1]}tu(c,b&65535,v[f+1074424>>2],Nq(J+16|0,d),w[J+24|0]);if(!ke(h,x[f+1074446>>1])){break n}}Dz(f,n,(v[f+480208>>2]&32)>>>5|0);c=Tc(_b(h,x[f+1074446>>1]),v[f+1074424>>2],0);b=x[f+480188>>1];if(b){E=(f+B(b,872)|0)+1074992|0;b=d;while(1){Db(J+16|0,j,82);C:{if(!Cb(J+16|0)|w[b+805|0]!=1){break C}l=w[c+3|0];if((l|0)!=3?(l|0)!=2:0){break C}Na=b,Oa=Yg(f,w[b+800|0],u[b+772>>1],v[b+704>>2]),v[Na+700>>2]=Oa}Db(J+16|0,j,91);D:{if(!Cb(J+16|0)){break D}if(ce(c)){break D}if(!ce(b+788|0)|w[b+791|0]!=19){break D}l=w[b+793|0];if((l&240)!=208|y[f+1074416>>2]>(l&15)>>>0){break D}Na=b,Oa=Yg(f,w[b+788|0],u[b+772>>1],0),v[Na+700>>2]=Oa}Db(J+16|0,j,92);E:{if(!Cb(J+16|0)){break E}Db(J+8|0,j,5);if(Cb(J+8|0)|v[f+1074416>>2]!=1|w[b+791|0]!=17){break E}v[f+1074420>>2]=B(w[b+793|0],1e4)}l=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b+788|0]=l;t[b+789|0]=l>>>8;t[b+790|0]=l>>>16;t[b+791|0]=l>>>24;l=w[c+4|0]|w[c+5|0]<<8;t[b+792|0]=l;t[b+793|0]=l>>>8;l=v[b+676>>2];v[b+20>>2]=v[b+672>>2];v[b+24>>2]=l;v[b+88>>2]=v[b+88>>2]&-393217;Db(J+16|0,j,21);if(!Cb(J+16|0)){t[b+831|0]=0}v[b+860>>2]=0;t[b+805|0]=0;c=c+6|0;b=b+872|0;if((E|0)!=(b|0)){continue}break}}b=f;l=b+1074412|0;F:{G:{c=b+484344|0;if($l(c,x[b+1074446>>1])){if(XP(_b(c,x[b+1074446>>1]))){break G}}v[b+1074408>>2]=v[b+480216>>2];b=v[b+480220>>2];break F}Na=b+1074408|0,Oa=v[_b(c,x[b+1074446>>1])+16>>2],v[Na>>2]=Oa;b=v[_b(c,x[b+1074446>>1])+20>>2]}v[l>>2]=b;if(!w[J+24|0]){break o}b=v[f+1074416>>2]+1|0;v[f+1074392>>2]=b;if(sk(n)>>>0<=b>>>0){continue}break}}if(!v[f+1074416>>2]){v[f+1074416>>2]=1}b=v[f+480208>>2];a=f;c=a;H:{I:{if(v[a+1074392>>2]){v[f+480208>>2]=b&-4097;if(v[f+480180>>2]&1048580|(w[f+480210|0]&32?0:v[f+480180>>2]==1)){break H}if(y[f+1074392>>2]>=sk(n)>>>0|y[f+1074392>>2]%(v[f+1074400>>2]+v[f+1074416>>2]>>>0)){break H}a=v[f+480208>>2];break I}a=b&-528385}v[c+480208>>2]=a|4096}F=0;m=gb-16|0;gb=m;u[f+1074444>>1]=65535;a=f+1074436|0;v[a>>2]=-1;v[a+4>>2]=-1;G=f+480208|0;M=f+1074376|0;if(x[f+480188>>1]){ba=f+1075809|0;H=f+1298260|0;A=f+1074312|0;ca=f+480210|0;while(1){q=f+B(F,872)|0;g=q+1075785|0;E=w[g|0];n=q+1075783|0;a=w[n|0];r=q+1075784|0;h=w[r|0];Z=q+1075782|0;e=w[Z|0];W=q+1075781|0;d=w[W|0];c=v[f+1074392>>2];j=v[f+1074400>>2];l=v[f+1074416>>2];I=q+1075780|0;b=nu(I);Y=q+1075843|0;t[Y|0]=v[f+480208>>2]>>>12&1|w[Y|0]&254;s=(c>>>0)%(j+l>>>0)|0;j=w[I|0];if((j|0)==252){c=w[W|0];j=Mq(I);l=Eo(I);J:{if(!c|c-251>>>0<5){break J}c=v[(f+B(c,160)|0)+906140>>2];if(!c){break J}kb[v[v[c>>2]+44>>2]](c,j,C(C(l>>>0)*C(.0010010009864345193)))}j=w[I|0]}K:{if(a&255|z[q+1075852>>2]==C(0)?(j&255)!=251:0){break K}l=v[G>>2]&4096;L:{if(!l){c=w[q+1075862|0];break L}c=w[W|0];t[q+1075862|0]=c}if(!c|c-251>>>0<5){break K}c=(f+B(c,160)|0)+906140|0;if(!v[c>>2]){break K}M:{if(!l){j=x[q+1075860>>1];break M}j=ju(w[Z|0],w[r|0]);u[q+1075860>>1]=j;X=C(C(ju(w[n|0],w[g|0])>>>0)*C(.0010010009864345193));z[q+1075856>>2]=X;g=v[c>>2];Na=q+1075852|0,Pa=C(C(X-C(kb[v[v[g>>2]+48>>2]](g,j)))/C(sk(M)>>>0)),z[Na>>2]=Pa}g=v[f+1074392>>2];n=sk(M);c=v[c>>2];g=(n|0)==(g+1|0);kb[v[v[c>>2]+(g?44:104)>>2]](c,j,z[(g?q+1075856|0:q+1075852|0)>>2]);j=w[I|0]}r=q+1074992|0;N:{O:{P:{Q:{R:{if(!SP(j&255)){if(w[G+1|0]&16){break Q}c=d;break R}a=gb-16|0;gb=a;u[a+12>>1]=0;v[a+8>>2]=0;Zi(a+8|0);b=x[a+12>>1];t[r+792|0]=b;t[r+793|0]=b>>>8;b=v[a+8>>2];t[r+788|0]=b;t[r+789|0]=b>>>8;t[r+790|0]=b>>>16;t[r+791|0]=b>>>24;gb=a+16|0;c=0;e=0;h=0;a=0;E=0;b=0;n=0;g=0;o=0;d=0;j=0;l=0;if(w[G+1|0]&16){break O}}LP(f,r);d=c;break P}if(!d){d=0;break P}v[q+1075752>>2]=0}j=0;c=a&255;S:{T:{U:{if(c-19>>>0>=2){if((c|0)!=33){break U}Db(m+8|0,A,30);j=E>>>4|0;fA(f,F&65535,j+(E&15)|0,Cb(m+8|0));a=33;break T}V:{if(!(!(v[f+480180>>2]&16777250)|E)){E=w[q+1075825|0];break V}t[q+1075825|0]=E}c=E&240;if((c|0)==208){l=E&15;if(!l){if(v[f+480180>>2]&16777248){n=a;g=h;j=1;break S}c=b;n=a;g=h;o=e;l=E;if(v[f+480180>>2]!=2){break O}break N}W:{if(l>>>0<v[f+1074400>>2]+v[f+1074416>>2]>>>0){break W}Db(m+8|0,A,14);if(!Cb(m+8|0)){break W}if(!d){break N}t[q+1075795|0]=d;break N}n=a;g=h;j=l;break S}if(!(w[G+1|0]&16)|(c|0)!=224|(v[f+1074396>>2]?v[f+480180>>2]&16777250:0)){break U}c=E&15;if(c?0:v[f+480180>>2]&2){break U}v[f+1074396>>2]=c+1}}n=a;g=h}c=b;o=e;l=E}$=n&255;b=v[f+480180>>2]==16&($|0)==19&(l&240)==208;V=b?0:j;X:{if(!V|w[I|0]!=255|w[Z|0]!=2){break X}Db(m+8|0,A,74);if(!Cb(m+8|0)){break X}t[Z|0]=0}a=v[f+1074392>>2];Db(m+8|0,A,72);Y:{if(Cb(m+8|0)){E=0;if(V>>>0>=y[f+1074416>>2]){break Y}}Db(m+8|0,A,88);E=(s|0)==(V|0)|(a|0)==(V|0);if(!(!Cb(m+8|0)|!V)){break Y}E=(a|0)==(V|0)}Db(m+8|0,A,44);if(Cb(m+8|0)){t[Y|0]=w[Y|0]&254|(s|0)==(V|0)}aa=l&15;a=b?aa|144:l;Db(m+8|0,A,66);c=(!V|Cb(m+8|0)^-1)&c;Z:{_:{if(!(v[f+1074392>>2]|(!(w[ca|0]&32)|!d))){v[q+1075652>>2]=0;if(E){break _}if(!Ki(r)){break Z}t[q+1075795|0]=d;if(x[f+480190>>1]<d>>>0){break Z}b=f+B(d,104)|0;v[q+1075680>>2]=x[b+484410>>1];u[q+1075764>>1]=t[b+484417|0];break Z}if(!E){break Z}}j=w[I|0];if(d){t[q+1075795|0]=d}$:{aa:{if(!ve(j)){break aa}Db(m+8|0,A,67);if(!Cb(m+8|0)){break aa}b=u[q+1075762>>1];ba:{if(!d|c){break ba}e=Qz(f,j,d);if(!e){break ba}b=t[Sl(f,e)+36|0]}j=(b+j|0)-12>>>0>119?0:j;break $}if(!(v[f+480180>>2]&25165856)|!x[f+480192>>1]){break $}b=j;if(b){b=ve(b)}else{b=1}if(!b){break $}b=d;ca:{if(!b){b=w[q+1075796|0];if(!b){break ca}}if(v[(f+(b<<2)|0)+900380>>2]?x[f+480192>>1]>=b>>>0:0){break $}j=0}d=0}if(!(($|0)!=25|a)){Db(m+8|0,A,55);b=Cb(m+8|0);d=b?0:d;j=b?0:j}Db(m+8|0,A,65);b=(d|0)!=0;e=!j;h=Cb(m+8|0);N=1;da:{if(v[f+480180>>2]&16777248){break da}Db(m+8|0,A,107);if(Cb(m+8|0)){break da}Db(m,A,85);N=0;if(!Cb(m)){break da}if(Ki(r)){break da}N=1;l=v[q+1075096>>2];if(!l){break da}N=Ld(l)^1}l=b&e;s=b&h;ea:{fa:{ga:{ha:{ia:{ja:{if(!(v[f+480180>>2]&1048580)){break ja}ka:{if((j|0)!=255){break ka}if(($|0)!=13?(o&255)==1|d:1){Db(m+8|0,A,55);if(Cb(m+8|0)){break ka}}b=v[q+1075648>>2];if(t[b+60|0]&1?b:0){break ka}v[q+1075680>>2]=0;b=q+1075080|0;v[b>>2]=v[b>>2]|2097152;la:{if(!(v[f+480208>>2]&4096)){break la}Db(m+8|0,A,86);if(!Cb(m+8|0)){break la}v[b>>2]=v[b>>2]|4096}d=0;j=0;e=0;b=0;h=0;l=1;if(s){break fa}break ea}Db(m+8|0,A,59);if(!Cb(m+8|0)|v[G>>2]&4096){break ja}ma:{if(!j){j=w[q+1075789|0]-w[q+1075762|0]|0;break ma}if(j>>>0>250){N=0;s=1;j=0;break ma}na:{if(d){break na}Db(m+8|0,A,98);if(!Cb(m+8|0)){break na}d=0;break ma}N=1;s=1}e=j;c=0;break ia}e=0;h=0;if(!l){break ha}}Db(m+8|0,A,65);if(!Cb(m+8|0)){break ga}j=e;h=1}b=j;e=h;l=1;if(s){break fa}break ea}j=e;e=1;l=s}oa:{pa:{if(!x[f+480192>>1]){if(x[f+480190>>1]<d>>>0){break oa}b=(f+B(d,104)|0)+484380|0;break pa}b=v[q+1075096>>2];if(!b){break oa}}qa:{if(u[b+34>>1]<0){break qa}if(v[f+480180>>2]==2){if(!Ld(b)){break qa}}v[q+1075680>>2]=x[b+30>>1]}if(!l){break oa}Ro(r,x[b+28>>1],f)}b=j;h=e}Db(m+8|0,A,71);if(!(!Cb(m+8|0)|!d)){t[q+1075831|0]=32}ra:{if(!x[f+480192>>1]){break ra}Db(m+8|0,A,100);if(!Cb(m+8|0)|!d){break ra}if(ve(b&255)){break ra}e=v[G>>2];sa:{if(c){if(e&8){break sa}break ra}if(!(e&4)){break ra}}Km(r);v[q+1075688>>2]=65536;e=q+1075080|0;v[e>>2]=v[e>>2]|2097152}if(h){Db(m+8|0,A,11);ta:{if(!(Na=Cb(m+8|0),Oa=1,Qa=v[f+480180>>2]!=268435456,Qa?Na:Oa)){break ta}Db(m+8|0,A,87);j=0;if(Cb(m+8|0)){j=Ki(r)^1}ua:{if(x[f+480192>>1]){if(x[f+480192>>1]<d>>>0){break ta}if(v[q+1075648>>2]!=v[(f+(d<<2)|0)+900380>>2]|j){break ua}break ta}if((v[q+1075096>>2]!=((f+B(d,104)|0)+484380|0)|j)!=1){break ta}}b=w[q+1075789|0]}va:{if(!x[f+480192>>1]|!(v[f+480180>>2]&1048588)){break va}Km(r);t[q+1075810|0]=0;v[q+1075748>>2]=0;v[q+1075688>>2]=65536;e=q+1075080|0;v[e>>2]=v[e>>2]&-2101249|2097152;Db(m+8|0,A,86);if(!Cb(m+8|0)){break va}v[e>>2]=v[e>>2]&-2049}d=N?d:0}j=b&255;wa:{if(j>>>0<251){break wa}Db(m+8|0,A,50);xa:{if(!Cb(m+8|0)|!d){break xa}e=Qz(f,w[q+1075791|0],d);if(!e){break xa}e=f+B(e,104)|0;if(u[e+484414>>1]<0){break xa}v[q+1075680>>2]=x[e+484410>>1]}Db(m+8|0,A,100);if(Na=Cb(m+8|0),Oa=0,Qa=v[G>>2]&4,Qa?Na:Oa){break wa}d=0}ya:{if(!ve(j)){break ya}t[q+1075794|0]=b;t[q+1075791|0]=b;if(!c){OP(f,F&65535,d,j,0)}e=q+1075776|0;b=u[e>>1];if(b){v[q+1075684>>2]=(b&32767)-1;if((b|0)<=-1){b=q+1075080|0;v[b>>2]=v[b>>2]|256}u[e>>1]=0}b=q+1075787|0;e=w[b|0];if(e){t[q+1075830|0]=e-1;t[b|0]=0}b=q+1075788|0;e=w[b|0];if(!e){break ya}t[q+1075829|0]=e-1;t[b|0]=0}za:{Aa:{Ba:{Ca:{Da:{if(d){e=q+1075096|0;h=v[e>>2];Do(f,r,d,c,1,1);b=v[e>>2];Ea:{if(!b|!(w[b+35|0]&2)){break Ea}if(!Bd(H)){break Ea}wu(v[H>>2],F&65535,v[e>>2]+68|0)}Fa:{Ga:{if(v[f+480180>>2]==1){if(!c){break Ga}Db(m+8|0,A,85);if(!Cb(m+8|0)){break Ga}break Fa}Db(m+8|0,A,50);if(!Cb(m+8|0)){break Ga}if(!ve(j)){break Fa}}t[q+1075795|0]=0}Db(m+8|0,A,42);if(Cb(m+8|0)){if(!ve(j)|(h|0)==v[e>>2]){break Ca}break Da}if(!(!(v[f+480180>>2]&16777248)|(h|0)==v[e>>2])){b=0;if(ve(j)){break Ba}}Db(m+8|0,A,107);Ha:{if(!Cb(m+8|0)|(h|0)==v[e>>2]){break Ha}Ia:{if(!c){if(ve(j)){break Ia}}b=q+1075068|0;if(y[b>>2]>=y[r+4>>2]){break Ha}v[b>>2]=0;break Ca}c=0}Db(m+8|0,A,85);if(!Cb(m+8|0)){break Ca}if(!Ki(r)){break Da}break Ca}if(!j){b=c;break za}e=0;l=q+1075795|0;Ja:{if(!w[l|0]){break Ja}if(!ve(j)){break Ja}Do(f,r,w[l|0],c,!(v[q+1075096>>2]?1:v[q+1075648>>2]),!(v[f+480180>>2]&1048580));t[l|0]=0;e=1}b=c;break Aa}v[r>>2]=0;v[r+4>>2]=0}b=c}e=0;if(!j){break za}}c=q+1075096|0;h=v[c>>2];Ka:{if(!h|!(w[h+35|0]&2)){break Ka}if(!Bd(H)){break Ka}if(!e){if(PP(v[H>>2],F&65535)){break Ka}}wu(v[H>>2],F&65535,v[c>>2]+68|0)}c=F&65535;ku(f,r,j,b,!(v[f+480180>>2]&1048580),0,c);if(!(!b|(!(v[f+480180>>2]&1048580)|!d))){d=q+1075080|0;v[d>>2]=v[d>>2]|2097152;Km(r);t[q+1075810|0]=0;v[q+1075748>>2]=0}if(!(v[q+1075080>>2]&512)){break za}if(!Bd(H)){break za}La:{switch(j-253|0){case 0:Db(m+8|0,A,99);if(Cb(m+8|0)){break za}break;case 1:case 2:break La;default:break za}}Db(m+8|0,A,110);if(Cb(m+8|0)){JA(v[H>>2],c,0,1,0)}uk(v[H>>2],c)}Ma:{Na:{switch((o&255)-1|0){case 0:g=g>>>0<64?g:64;v[q+1075680>>2]=g<<2;c=q+1075080|0;v[c>>2]=v[c>>2]|2097152;break Ma;case 1:break Na;default:break Ma}}Nm(f,r,g,6)}if(x[f+480192>>1]){tO(f,F&65535)}c=b}Db(m+8|0,A,77);if(Na=Cb(m+8|0),Oa=0,Qa=v[(f+(F<<5)|0)+480280>>2]&1024,Qa?Na:Oa){break N}b=v[f+1074392>>2];Db(m+8|0,A,75);e=b>>>0>=V>>>0;Oa:{Pa:{Qa:{Ra:{if(!Cb(m+8|0)|!V){break Ra}d=v[f+1074392>>2];if(!d){break Qa}e=1;if((d|0)!=(V|0)){break Ra}e=!w[W|0]&(o&255)!=11}b=o&255;if(!e|b>>>0<3){break Qa}if((b|0)==11){nA(m+8|0,f,I,V);b=w[Re(m+8|0)|0];zo(f,r,x[m+8>>1]);if(b){break Pa}o=11;break Qa}Db(m+8|0,A,62);Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{if(!(!Cb(m+8|0)|g)){g=0;o=0;Za:{switch(b-8|0){case 0:break Ya;case 1:break Za;default:break Qa}}if(w[G+1|0]&16){break Qa}v[q+1075684>>2]=0;break Qa}Db(m+8|0,A,41);_a:{if(Cb(m+8|0)){break _a}if(g){t[q+1075826|0]=g;break _a}g=w[q+1075826|0]}$a:{switch(b-3|0){case 0:case 1:ab:{bb:{if(g){break bb}Db(m+8|0,A,41);if(!Cb(m+8|0)){break bb}g=w[q+1075826|0];if(g){break ab}g=0;break Qa}t[q+1075826|0]=g}Co(f,r,((b|0)==3?g<<4:g)&255);break Qa;case 2:if((V|0)!=v[f+1074392>>2]){Db(m+8|0,A,41);o=5;if(Cb(m+8|0)){break Qa}}Db(m+8|0,A,41);Lq(f,r,g,Cb(m+8|0));o=5;break Qa;case 3:if((V|0)!=v[f+1074392>>2]){Db(m+8|0,A,41);o=6;if(Cb(m+8|0)){break Qa}}Db(m+8|0,A,41);Kq(f,r,g,Cb(m+8|0));o=6;break Qa;case 11:break Sa;case 12:break Ta;case 10:break Ua;case 9:break Va;case 7:break Wa;case 6:break Xa;case 5:break Ya;case 4:break $a;default:break Qa}}Db(m+8|0,A,53);if(Cb(m+8|0)){t[q+1075815|0]=g&15;o=7;break Qa}Hl(r,g<<4);o=7;break Qa}Hl(r,g);o=8;break Qa}Db(m+8|0,A,62);eA(f,r,g,Cb(m+8|0)^1);o=9;break Qa}Db(m+8|0,A,62);eA(f,r,g<<4&240,Cb(m+8|0)^1);o=10;break Qa}o=12;Db(m+8|0,A,12);KP(f,F&65535,g<<2&252,Cb(m+8|0));break Qa}Db(m+8|0,A,12);JP(f,F&65535,g<<2&252,Cb(m+8|0));o=13;break Qa}o=15;if(!E){break Qa}b=q+1075096|0;if(!v[b>>2]|g>>>0>9){break Qa}cb:{if(!g){d=v[q+1075656>>2];break cb}d=v[(v[b>>2]+(g<<2)|0)- -64>>2];v[q+1075656>>2]=d}Mm(f,r,d);break Qa}o=14;if(g>>>0>1){break Qa}t[Y|0]=w[Y|0]&251|!g<<2}d=a;db:{eb:{fb:{gb:{switch($-1|0){case 12:if(!(w[G+1|0]&16)){break Pa}b=f+B(F,872)|0;v[b+1075680>>2]=a>>>0<64?a<<2:256;b=b+1075080|0;v[b>>2]=v[b>>2]|2097152;break Pa;case 1:if(!a){d=0;if(v[f+480180>>2]&1){break Oa}}KP(f,F&65535,a,0);break Pa;case 2:if(!a){d=0;if(v[f+480180>>2]&1){break Oa}}JP(f,F&65535,a,0);break Pa;case 10:if(!a){d=0;if(v[f+480180>>2]==1){break Oa}}Co(f,r,a);break Pa;case 3:zo(f,r,a);break Pa;case 5:if(v[f+480180>>2]==1?a:1){Co(f,r,a)}zo(f,r,0);break Pa;case 4:Hl(r,a);break Pa;case 6:if(v[f+480180>>2]==1?a:1){Co(f,r,a)}Hl(r,0);break Pa;case 15:if(!(w[G+1|0]&16)){break Pa}break db;case 16:Db(m+8|0,A,5);if(Cb(m+8|0)){if(!(w[G+1|0]&16)){break Pa}if(a){break db}break Pa}d=Om(f,x[f+1074446>>1],v[f+1074424>>2],F&65535,0);hb:{if(!(v[f+480180>>2]&16777250)){break hb}if(d){t[(f+B(F,872)|0)+1075827|0]=d;break hb}d=w[(f+B(F,872)|0)+1075827|0]}v[m+8>>2]=B(d,1e4);tc(m+8|0,B(v[v[f+8>>2]+24>>2],1e4));b=gb-16|0;gb=b;e=v[m+8>>2];v[b+8>>2]=e;a=f;c=v[a+8>>2];ib:{if(e>>>0>=(v[a+480180>>2]&16392?1e4:32e4)>>>0){e=v[a+480208>>2];Db(b,a+1074312|0,92);if((Cb(b)|0)==((e&4096)>>>12|0)){break ib}v[b>>2]=B(v[c+24>>2],1e4);c=a+1074420|0;a=b+8|0;Na=c,Oa=v[(Ed(b,a)?b:a)>>2],v[Na>>2]=Oa;break ib}if(w[a+480209|0]&16){break ib}g=a+1074420|0;e=(e>>>0)/1e4|0;h=B(e&15,1e4);v[g>>2]=v[g>>2]+((e&240)==16?h:0-h|0);e=v[c+20>>2];c=v[c+24>>2];Db(b,a+1074312|0,8);Gp(g,B(e,1e4),Cb(b)?255e4:B(c,1e4))}gb=b+16|0;break Oa;case 9:if(!E|(v[f+480180>>2]==4?c:0)){break Pa}WP(f,r,F&65535,M);break Pa;case 43:if(!E){break Pa}d=mqa(v[(f+B(F,872)|0)+1075068>>2],0,a,0);b=jb;c=b>>>8|0;Mm(f,r,Uc((b&255)<<24|d>>>8,c));break Pa;case 0:if(v[f+1074392>>2]){break Pa}b=f+B(F,872)|0;jb:{if(w[b+1075789|0]?v[b+1075692>>2]:0){break jb}b=v[b+1075648>>2];if(b){if(Fj(b)){break jb}}Db(m+8|0,A,13);if(Cb(m+8|0)){break jb}if(v[f+480180>>2]&16777248){break Pa}}if(!a){d=0;if(v[f+480180>>2]&5){break Oa}t[(f+B(F,872)|0)+1075797|0]=1;break Oa}b=f+B(F,872)|0;t[b+1075798|0]=a;t[b+1075797|0]=1;break Pa;case 14:if(v[f+480180>>2]&1048580){a=a&240?a:w[(f+B(F,872)|0)+1075799|0]&240|a;if(!(a&15)){a=w[(f+B(F,872)|0)+1075799|0]&15|a}a=a|256}d=a;Db(m+8|0,A,23);if(Cb(m+8|0)){b=f;c=F&65535;if(d){t[(f+B(F,872)|0)+1075799|0]=d;a=d}else{a=w[(f+B(F,872)|0)+1075799|0]}dA(b,c,a&255,(o&255)==15?g+1|0:0);break Oa}kb:{if(d){t[(f+B(F,872)|0)+1075799|0]=d;break kb}d=w[(f+B(F,872)|0)+1075799|0]}dA(f,F&65535,d,(o&255)==15?g+1|0:0);break Oa;case 17:if(!(w[G+1|0]&16)){break Pa}Db(m+8|0,A,22);lb:{mb:{if(Cb(m+8|0)){if(!a){a=0;break mb}if(w[G|0]&4){break mb}a=a&240?a-16|0:a;a=a-((a&15)!=0)|0;break mb}Db(m+8|0,A,71);if(!Cb(m+8|0)){break lb}}b=(f+B(F,872)|0)+1075831|0;t[b|0]=w[b|0]|128}b=f+B(F,872)|0;t[b+1075797|0]=18;if(!a){d=0;break Oa}t[b+1075832|0]=a;break Pa;case 22:if(!(w[G+1|0]&16)){break Pa}d=a<<!(v[f+480180>>2]&59593760);if(d>>>0<=128){v[f+1074456>>2]=d<<1;break Oa}if(v[f+480180>>2]&16777250){break Oa}v[f+1074456>>2]=256;break Oa;case 23:Db(m+8|0,A,9);if(Cb(m+8|0)){IP(f,a,(f+B(F,872)|0)+1075809|0);break Pa}IP(f,a,ba);break Pa;case 8:if(!(w[G+1|0]&16)){break Pa}Nm(f,r,a,8);break Pa;case 28:eA(f,r,a,1);break Pa;case 7:ZP(r,a);break Pa;case 25:_P(f,r,a);break Pa;case 18:b=f;j=b+1074376|0;e=F&65535;h=B(e,872);g=(j+h|0)+616|0;c=a;d=a&15;nb:{ob:{switch(a>>>4|0){case 0:if(!x[b+480188>>1]){break nb}d=(c&1)<<14;c=0;while(1){e=(b+B(c,872)|0)+1075080|0;v[e>>2]=(d|v[e>>2]&-16385)^16384;c=c+1|0;if(c>>>0<x[b+480188>>1]){continue}break};break nb;case 1:if(!(v[b+480180>>2]&1048580?1:d)){break nb}AP(b,g,d);break nb;case 2:if(!(v[b+480180>>2]&1048580?1:d)){break nb}zP(b,g,d);break nb;case 3:b=(b+h|0)+1075080|0;v[b>>2]=v[b>>2]&-1048577|((d|0)!=0)<<20;break nb;case 4:t[(b+h|0)+1075814|0]=c&7;break nb;case 5:if(!(w[b+480209|0]&16)){break nb}if(v[b+480180>>2]&69206025){c=b+B(e,872)|0;g=c+1075764|0;u[g>>1]=d<<28>>24;d=c+1075692|0;if(!v[d>>2]){break nb}if(!ce(c+1075780|0)){break nb}c=b;b=b+B(e,872)|0;Na=d,Oa=Yg(c,w[b+1075789|0],u[g>>1],v[b+1075696>>2]),v[Na>>2]=Oa;break nb}h=v[b+480180>>2];g=ce((b+B(e,872)|0)+1075780|0);if((h|0)==16){if(!g){break nb}c=b+B(e,872)|0;g=v[c+1075096>>2];if(!g){break nb}t[g+37|0]=d;u[c+1075764>>1]=d;c=c+1075692|0;if(!v[c>>2]){break nb}h=b;b=b+B(e,872)|0;Na=c,Oa=Yg(h,w[b+1075789|0],d,v[b+1075696>>2]),v[Na>>2]=Oa;break nb}if(!g){break nb}d=b+B(e,872)|0;c=(c<<4^-128)<<24>>24;u[d+1075764>>1]=c;e=d+1075692|0;if(!v[e>>2]){break nb}Na=e,Oa=Yg(b,w[d+1075789|0],c,v[d+1075696>>2]),v[Na>>2]=Oa;break nb;case 6:if(!(w[b+480209|0]&16)){break nb}lu(b,j,g,d);break nb;case 7:t[(b+h|0)+1075817|0]=c&7;break nb;case 8:if(!(w[b+480209|0]&16)){break nb}Nm(b,g,d,4);break nb;case 9:dA(b,e,d,0);break nb;case 10:if(!(v[b+480180>>2]&1048580?1:d)){break nb}Lq(b,g,d,0);break nb;case 11:if(!(v[b+480180>>2]&1048580?1:d)){break nb}Kq(b,g,d,0);break nb;case 12:fA(b,e,d,0);break nb;case 15:break ob;default:break nb}}if(v[b+480180>>2]==1){t[(b+B(e,872)|0)+1075838|0]=d;if(!(w[b+480209|0]&16)){break nb}LP(b,g);break nb}t[(b+B(e,872)|0)+1075836|0]=d}break Pa;case 19:Db(m+8|0,A,78);b=f;c=F&65535;d=a;pb:{if(!Cb(m+8|0)){break pb}d=a;if(a){break pb}d=w[(f+B(F,872)|0)+1075798|0]}HP(b,c,d);break Oa;case 24:Db(m+8|0,A,55);if(Cb(m+8|0)){if(v[f+1074392>>2]!=(a|0)){break Pa}b=v[(f+B(F,872)|0)+1075648>>2];if(t[b+60|0]&1?b:0){break eb}if(!(!(w[Z|0]?1:w[W|0])|a)){b=(f+B(F,872)|0)+1075080|0;v[b>>2]=v[b>>2]|4096;break eb}b=f+B(F,872)|0;v[b+1075680>>2]=0;b=b+1075080|0;v[b>>2]=v[b>>2]|2097152;break eb}if(w[G+1|0]&16){break eb}break Pa;case 27:b=(a&240)-16>>>4|0;if(b>>>0>9){break Pa}if(!(1<<b&880)){if(!b){break fb}if((b|0)!=1){break Pa}GP(f,r,a&15);break Pa}Db(m+8|0,A,58);if(Cb(m+8|0)){break Pa}HP(f,F&65535,a);break Pa;case 34:case 35:if(!((n&255)!=36?w[G+1|0]&16:1)){break Pa}b=F&65535;VP(f,b,M,(n&255)==36);c=gu(f,b);if(!c){break Pa}kb[v[v[c>>2]+80>>2]](c,x[r+774>>1]>>>2^8192,b);break Pa;case 20:if(!(w[G+1|0]&16)|a>>>0>64){break Pa}b=f+B(F,872)|0;v[b+1075740>>2]=a;b=b+1075080|0;v[b>>2]=v[b>>2]|2097152;break Pa;case 21:d=f;c=r;b=a;qb:{if(a){t[c+816|0]=b;break qb}b=w[c+816|0]}h=b&255;e=c;j=b&240;g=b&15;rb:{sb:{if(!(!j|(g|0)!=15)){if(!(w[d+480209|0]&16)){break rb}b=h>>>4|0;break sb}n=v[d+480208>>2]&4096;if(!(!g|(j|0)!=240)){if(!n){break rb}b=0-g|0;break sb}if(n){break rb}if(g){b=0-g|0;if(!(v[d+480180>>2]&25690144)|!j){break sb}break rb}if((b&255)>>>0<16){break rb}b=h>>>4|0}Na=e,Oa=Lb(b+v[c+748>>2]|0,0,64),v[Na+748>>2]=Oa}break Pa;case 26:YP(r,a);break Pa;case 29:if(!(w[G+1|0]&16)){break Pa}b=f+B(F,872)|0;v[b+1075716>>2]=a;Db(m+8|0,A,60);if(Na=0,Oa=Cb(m+8|0),Qa=w[b+1075722|0]&4,Qa?Na:Oa){break Pa}b=f+B(F,872)|0;v[b+1075732>>2]=a;v[b+1075724>>2]=a;break Pa;case 11:mA(f,M,F&65535);break Pa;case 13:b=kA(f,M,F&65535,a);if((b|0)==-1){break Pa}v[f+1074436>>2]=b;if(!(w[f+480208|0]&32)){break Pa}u[f+1074444>>1]=x[f+1074448>>1];break Pa;case 37:case 38:case 39:case 40:b=r;c=a;d=n&255;e=(d|0)==38|(d|0)==40;g=(n&254)==40;d=f;tb:{if(w[d+480209|0]&16){d=w[b+848|0];e=c&240;if(e){d=e|d&15;t[b+848|0]=d}c=c&15;if(c){d=c|d&-16;t[b+848|0]=d}t[b+849|0]=(d&240)>>>4;break tb}c=w[b+849|0]-1|0;t[b+849|0]=c;ub:{if(c&255){break ub}c=w[b+848|0];t[b+849|0]=c>>>4;c=c&15;c=e?c:0-c|0;vb:{if(Hj(b)){v[b+852>>2]=v[b+852>>2]+B(c,v[v[v[b+656>>2]+44>>2]+36>>2]);break vb}Na=b,Oa=Yg(d,fu(d,v[b+700>>2],0,0)+c|0,8363,0),v[Na+700>>2]=Oa}if(!g){break ub}v[b>>2]=0;v[b+4>>2]=0}}break Pa;case 41:jA(r,a);break Pa;case 42:break gb;default:break Oa}}if(v[f+1074392>>2]|aa>>>0>2|a>>>0>31){break Pa}b=(a&240)==16;d=b?0:F;c=(b?x[f+480188>>1]-1|0:F)&65535;if((d&65535)>>>0>c>>>0){break Pa}b=((aa|0)==1)<<26;while(1){e=d&65535;g=(f+(e<<5)|0)+480280|0;v[g>>2]=b|v[g>>2]&-67108865;e=(f+B(e,872)|0)+1075080|0;v[e>>2]=b|v[e>>2]&-67108865;d=d+1|0;if(c>>>0>=(d&65535)>>>0){continue}break}break Pa}FP(f,r,a&15);break Pa}Bo(f,r);break Pa}$P(f,M,a)}d=a}Db(m+8|0,A,78);if(!(!Cb(m+8|0)|!d)){a=d&255;t[r+840|0]=a;t[r+812|0]=a;t[r+811|0]=a;t[r+809|0]=a;t[r+807|0]=a;t[r+806|0]=a;t[r+826|0]=a>>>4;t[r+827|0]=a<<2&60}a=w[W|0];if(!a){break N}t[q+1075796|0]=a}F=F+1|0;if(F>>>0<x[f+480188>>1]){continue}break}}wb:{if(!(w[G+1|0]&16)){break wb}if(!UP(f,M,1)){break wb}v[G>>2]=v[G>>2]|524288}gb=m+16|0;a=1;break m}a=0}gb=J+32|0;xb:{if(!a|!v[p+1074420>>2]){break xb}a=UO(p,p+1074376|0);v[p+1074380>>2]=a;v[p+1074404>>2]=a;b=Jd(x[p+480188>>1],1,31);J=p+1074332|0;yb:{if(w[J+34|0]){a=v[p+24628>>2];if((a|0)>=129){a=((B(a-128|0,b+4|0)|0)/16|0)+128|0}r=((B(v[p+480228>>2],a)<<1&-128)>>>0)/w[(b>>>1|0)+38784|0]|0;break yb}r=v[p+480228>>2]}u[p+480212>>1]=0;q=p+1298260|0;m=p+1074312|0;F=p+480210|0;M=p+480209|0;E=0;while(1){l=p+B(E,872)|0;s=l+1075080|0;zb:{if(!(v[s>>2]&4096)|(v[l+1075016>>2]|(v[l+1075012>>2]|v[l+1075688>>2]))){break zb}Db(k+16|0,m,64);if(Cb(k+16|0)){break zb}v[l+1075068>>2]=0;a=l+1075084|0;v[a>>2]=0;v[a+4>>2]=0}b=x[p+480188>>1];Ab:{Bb:{a=v[s>>2];if(!(a&1024)){c=b>>>0>E>>>0;if(c|v[l+1075068>>2]){break Bb}}if(b>>>0>E>>>0){BO(p,E&65535)}u[l+1075834>>1]=0;break Ab}h=0;I=l+1075712|0;v[I>>2]=0;A=l+1075672|0;v[A>>2]=0;G=l+1075e3|0;b=G;v[b>>2]=0;v[b+4>>2]=0;v[l+1075092>>2]=0;v[k+44>>2]=1065353216;u[k+42>>1]=0;H=l+1075648|0;V=v[H>>2];v[k+36>>2]=0;o=l+1075692|0;h=v[o>>2]?v[l+1075068>>2]!=0:h;b=l+1074992|0;Cb:{Db:{Eb:{Fb:{if(!c){break Fb}if(w[(p+(E<<5)|0)+480288|0]){break Db}if(!V){break Fb}c=w[V+34|0]!=0|h;break Eb}c=0-h|0}if(!(c&1)){break Cb}}v[k+8>>2]=v[l+1075680>>2];v[k+32>>2]=v[l+1075744>>2];Db(k+16|0,m,28);a=b;c=Cb(k+16|0)?k+32|0:k+8|0;d=gb-16|0;gb=d;e=p+1074312|0;Db(d+8|0,e,28);Gb:{if(Cb(d+8|0)){v[c>>2]=v[c>>2]+u[a+776>>1];Qd(c,0,64);break Gb}Db(d+8|0,e,1);f=Cb(d+8|0);e=u[a+776>>1];if(f){v[c>>2]=e+v[c>>2];Qd(c,0,256);break Gb}v[a+688>>2]=e+v[a+688>>2];Qd(a+688|0,0,256);v[c>>2]=v[a+688>>2];u[a+776>>1]=0}gb=d+16|0;c=gb-16|0;gb=c;d=p+1074312|0;Db(c+8|0,d,28);Hb:{Ib:{if(!Cb(c+8|0)){Db(c,d,1);if(!Cb(c)){break Ib}}v[a+684>>2]=v[a+692>>2]+u[a+778>>1];Qd(a+684|0,0,256);break Hb}v[a+692>>2]=v[a+692>>2]+u[a+778>>1];Qd(a+692|0,0,256);u[a+778>>1]=0;v[a+684>>2]=v[a+692>>2]}gb=c+16|0;f=gb-16|0;gb=f;c=p;Jb:{if(!(w[b+90|0]&4)|(v[c+480208>>2]&2101248)==2101248){break Jb}Kb:{if(v[k+8>>2]<=0){Db(f+8|0,c+1074312|0,21);if(!Cb(f+8|0)){break Kb}}n=5;if(!(v[c+480180>>2]&5)){Db(f+8|0,c+1074312|0,21);n=Cb(f+8|0)?5:6}e=Cz(c,w[a+825|0],w[a+820|0]);Lb:{if((w[a+825|0]&3)!=1){break Lb}Db(f+8|0,c+1074312|0,89);if(!Cb(f+8|0)){break Lb}e=w[a+819|0];g=w[a+820|0];d=g<<2&124;d=(!(w[a+90|0]&2)|w[c+480209|0]&16?e:w[a+823|0]+e|0)&32?d^127:d;e=g&32?0-d|0:d}d=k;if(v[c+480180>>2]!=131072){e=v[k+8>>2]+((B(w[a+827|0],e)|0)/(1<<n)|0)|0}else{i=64-e|0;e=v[k+8>>2];e=((B(w[a+827|0],B(i,e))|0)/-8192|0)+e|0}v[d+8>>2]=e}if(!(v[c+480180>>2]&16777248)|w[c+480208|0]&4?w[c+480209|0]&16:0){break Jb}Db(f+8|0,c+1074312|0,21);c=Cb(f+8|0);e=a;d=w[a+826|0];a=w[a+820|0];t[e+820|0]=(c?d<<2:a)+(c?a:d)}gb=f+16|0;f=E&65535;d=f;g=gb-16|0;gb=g;a=p;c=a+1074312|0;Db(g+8|0,c,71);Mb:{if(Cb(g+8|0)){c=(a+B(d,872)|0)+1075831|0;e=t[c|0];if((e|0)>-1){break Mb}if(!(w[a+480209|0]&16|w[(a+B(d,872)|0)+1075797|0]!=18)){j=e&-33;t[c|0]=j;Nb:{Ob:{if((j|0)!=-64){e=e&223;if((e|0)!=128){break Ob}e=w[(a+B(d,872)|0)+1075832|0]>>>4|-64;break Nb}e=w[(a+B(d,872)|0)+1075832|0]&15|-128;break Nb}e=e-1|0}t[c|0]=e;c=(a+B(d,872)|0)+1075080|0;v[c>>2]=v[c>>2]|2097152}if((e&224)!=128){break Mb}v[k+8>>2]=0;break Mb}if(w[(a+B(d,872)|0)+1075797|0]!=18){break Mb}Db(g+8|0,c,22);Pb:{if(Cb(g+8|0)){i=a+B(d,872)|0;c=i+1075831|0;j=w[c|0];e=j<<24>>24;if(!((e|0)>-1|!v[i+1075068>>2])){Qb:{Rb:{if((j|0)!=192){if((j|0)!=128){break Rb}e=w[(a+B(d,872)|0)+1075832|0]>>>4|-64;break Qb}e=w[(a+B(d,872)|0)+1075832|0]&15|-128;break Qb}e=e-1|0}t[c|0]=e}if((e&192)!=128){break Pb}v[k+8>>2]=0;break Pb}c=w[(a+B(d,872)|0)+1075832|0];n=c>>>4|0;i=n+(c&15)|0;if(!(w[a+480208|0]&4?0:v[a+480180>>2]&16777248)){n=n+1|0;i=i+2|0}c=(a+B(d,872)|0)+1075831|0;e=w[c|0];if(!(v[a+480180>>2]&4)){e=(e&255)>>>0<i>>>0?e:0;if((e&255)>>>0>=n>>>0){v[k+8>>2]=0}t[c|0]=e+1;break Pb}Sb:{if(w[a+480209|0]&16){e=e&255?e-1|0:0;break Sb}t[c|0]=e+1}if(((e&255)>>>0)%(i>>>0)>>>0<n>>>0){break Pb}v[k+8>>2]=0}c=(a+B(d,872)|0)+1075080|0;v[c>>2]=v[c>>2]|2097152}c=a+B(d,872)|0;Tb:{if(w[c+1075797|0]!=18){break Tb}j=c+1075648|0;c=v[j>>2];if(!c|!w[c+34|0]|w[c+15|0]&2){break Tb}c=a+B(d,872)|0;if(v[c+1075080>>2]&134218752){break Tb}e=c+1075791|0;if(!ve(w[e|0])){break Tb}j=v[j>>2];c=v[(a+B(w[j+34|0],160)|0)+906140>>2];if(!c){break Tb}i=kb[v[v[c>>2]+100>>2]](c,w[e|0],d)|0;n=v[k+8>>2];if(!(!i|n)){kb[v[v[c>>2]+92>>2]](c,j,w[e|0]+255|0,0,d);break Tb}if(i|!n){break Tb}kb[v[v[c>>2]+92>>2]](c,j,w[e|0],x[(a+B(d,872)|0)+1075680>>1],d)}gb=g+16|0;Qd(k+8|0,0,256);v[k+8>>2]=v[k+8>>2]<<6;Ub:{if(V){Db(k+16|0,m,31);if(Cb(k+16|0)){Yt(p,b)}d=gb-16|0;gb=d;c=b;Vb:{if(!Bz(p,b,0)){break Vb}e=v[c+656>>2];a=a+1074312|0;Db(d+8|0,a,31);Wb:{if(Cb(d+8|0)){g=v[c+724>>2];if(g){break Wb}break Vb}g=v[c+724>>2]}Db(d+8|0,a,31);j=e+48|0;n=g-Cb(d+8|0)|0;g=Zq(j,n,256,64);i=w[e+65|0];Xb:{if((i|0)==255){break Xb}c=u[c+728>>1];if((c|0)==-1){break Xb}i=w[Mb(j,i)+2|0];e=x[Mb(j,w[e+65|0])>>1];Db(d+8|0,a,94);a=i<<2;e=(e|0)==(n|0)?a:g;if(Cb(d+8|0)){g=c+(e-a<<1)|0;break Xb}if(!i){g=0;break Xb}g=(B(c,e)|0)/(a|0)|0}Na=k,Oa=(B(v[k+8>>2],Lb(g,0,512))|0)/256|0,v[Na+8>>2]=Oa}gb=d+16|0;AO(b,k+8|0);d=gb-16|0;gb=d;c=p;a=b;Yb:{if(!Bz(c,a,1)){break Yb}e=v[a+656>>2];c=c+1074312|0;Db(d+8|0,c,31);Zb:{if(Cb(d+8|0)){n=v[a+732>>2];if(n){break Zb}break Yb}n=v[a+732>>2]}Db(d+8|0,c,31);c=a;e=Zq(e+68|0,n-Cb(d+8|0)|0,64,64)-32|0;a=v[a+684>>2];Na=c,Oa=Lb(((B(e,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),v[Na+684>>2]=Oa}gb=d+16|0;a=b;c=v[a+656>>2];d=t[c+26|0];_b:{if(!d){break _b}e=w[a+797|0];if(!e){break _b}Na=a,Oa=Lb(v[a+684>>2]+((B(d,e+(w[c+27|0]^-1)|0)|0)/2|0)|0,0,256),v[Na+684>>2]=Oa}break Ub}if(!(w[s+1|0]&16)){break Ub}v[l+1075688>>2]=0;v[k+8>>2]=0}$b:{if(w[l+1075843|0]&4){v[k+8>>2]=0;break $b}a=v[k+8>>2];if(!a){break $b}if(w[s+3|0]&8){v[A>>2]=0;break $b}if(w[J+33|0]){c=B(v[k+32>>2],v[l+1075740>>2]);a=a<<8;Na=A,Oa=zc(nqa(mqa(c,c>>31,a,a>>31),jb,1048576,0),jb),v[Na>>2]=Oa;break $b}c=B(v[k+32>>2],v[l+1075740>>2]);a=B(a,v[p+1074456>>2]);Na=A,Oa=zc(nqa(mqa(c,c>>31,a,a>>31),jb,1048576,0),jb),v[Na>>2]=Oa}v[I>>2]=v[k+8>>2];ac:{if(v[p+480180>>2]==2|v[o>>2]>=v[p+480260>>2]){break ac}if(qk(p)){break ac}v[o>>2]=v[p+480260>>2]}Db(k+16|0,m,73);if(Cb(k+16|0)){Lb(v[o>>2],1,31999)}i=v[o>>2];v[k+36>>2]=i;bc:{if((v[s>>2]&1572864)!=1572864){break bc}if(w[F|0]&32){if(!nu(l+1075780|0)|w[M|0]&16){break bc}i=v[k+36>>2]}a=l+1075704|0;cc:{if(v[a>>2]==(i|0)){i=v[l+1075708>>2];break cc}v[a>>2]=i;a=l+1075764|0;c=l+1075696|0;i=Yg(p,fu(p,i,u[a>>1],v[c>>2]),u[a>>1],v[c>>2]);v[l+1075708>>2]=i}v[k+36>>2]=i}n=gb-16|0;gb=n;d=p;j=d+B(f,872)|0;a=v[j+1075648>>2];dc:{if(!a){break dc}c=w[a+34|0];if(!c|w[a+15|0]&2|(!v[(d+B(c,160)|0)+906140>>2]|v[(d+B(f,872)|0)+1075080>>2]&134218752)){break dc}c=d+B(f,872)|0;W=c+1075783|0;N=w[W|0];i=0;e=c+1075791|0;if(ve(w[e|0])){i=w[lc(a+108|0,w[e|0]-1|0)|0]}e=c+1075780|0;ec:{fc:{if((N|0)==1){g=0;gc:{hc:{switch((y[d+1074392>>2]%3|0)-1|0){case 0:g=w[(d+B(f,872)|0)+1075798|0]>>>4|0;break gc;case 1:break hc;default:break gc}}g=w[(d+B(f,872)|0)+1075798|0]&15}a=d+B(f,872)|0;t[a+1075793|0]=i;if(w[a+1075792|0]==(g+i|0)){break ec}if(!(w[d+480209|0]&16)){break fc}if(!ce(e)){break fc}break ec}g=0;if(w[e|0]|!w[(d+B(f,872)|0)+1075792|0]){break ec}}a=d+B(f,872)|0;Jm(d,f,w[a+1075793|0]+g|0,x[a+1075680>>1])}c=(d+B(f,872)|0)+1075792|0;a=w[c|0];ic:{if(!a){if(!(w[d+480209|0]&16)|(N|0)!=1){break ic}if(ce(e)){break ic}a=i;if(!ve(a)){break ic}}Jm(d,f,(a&255)+255|0,0)}t[c|0]=w[W|0]==1?w[(d+B(f,872)|0)+1075793|0]+g|0:0}jc:{if(w[j+1075797|0]!=1){break jc}if(Hj(j+1074992|0)){i=0;kc:{lc:{mc:{switch(y[d+1074392>>2]%3|0){case 1:i=w[(d+B(f,872)|0)+1075798|0]>>>4|0;break lc;case 0:break lc;case 2:break mc;default:break kc}}i=w[(d+B(f,872)|0)+1075798|0]&15}u[k+42>>1]=i}a=(d+B(f,872)|0)+1075843|0;t[a|0]=w[a|0]|48;break jc}if(!(!(w[d+480209|0]&16)|v[d+480180>>2]!=1048576)){a=d+B(f,872)|0;c=Yg(d,w[a+1075789|0],u[a+1075764>>1],v[a+1075696>>2]);v[k+36>>2]=c;v[a+1075692>>2]=c}e=d+1074312|0;Db(n+8|0,e,13);if(Cb(n+8|0)){i=w[(d+B(f,872)|0)+1075798|0];if(!i){break jc}c=65536;nc:{switch(((y[d+1074392>>2]%(v[d+1074400>>2]+v[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:i=i<<4;case 0:c=v[((i&240)<<2)+43952>>2];break;default:break nc}}f=qk(d);a=v[k+36>>2];d=a;a=a>>31;e=k;if(f){c=mqa(d,a,c,c>>31)+32768|0;a=jb;a=nqa(c,c>>>0<32768?a+1|0:a,65536,0)}else{f=(c|0)/2|0;g=f;j=f>>31;f=d;d=a<<16|d>>>16;f=f<<16;a=f+g|0;j=d+j|0;a=nqa(a,a>>>0<f>>>0?j+1|0:j,c,c>>31)}c=jb;Na=e,Oa=zc(a,c),v[Na+36>>2]=Oa;break jc}Db(n+8|0,e,51);if(Cb(n+8|0)){if(w[d+480209|0]&16){break jc}oc:{pc:{a=v[d+1074416>>2];a=a-(y[d+1074392>>2]%(a>>>0)|0)|0;if((a|0)>16){break pc}if((a|0)==16){break jc}g=0;qc:{switch((a|0)%3|0){case 0:break jc;case 2:break pc;case 1:break qc;default:break oc}}g=w[(d+B(f,872)|0)+1075798|0]>>>4|0;break oc}g=w[(d+B(f,872)|0)+1075798|0]&15}a=d+B(f,872)|0;c=a+1075764|0;a=a+1075696|0;e=fu(d,v[k+36>>2],u[c>>1],v[a>>2])+g|0;c=Yg(d,e,u[c>>1],v[a>>2]);v[k+36>>2]=c;if(e>>>0<109){break jc}v[n+8>>2]=c;Na=n,Oa=Yg(d,109,0,v[a>>2]),v[Na+4>>2]=Oa;Na=k,Oa=v[Jc(n+8|0,n+4|0)>>2],v[Na+36>>2]=Oa;break jc}a=v[d+1074392>>2];if(v[d+480180>>2]!=1){g=w[(d+B(f,872)|0)+1075789|0]}else{c=d+B(f,872)|0;g=fu(d,v[k+36>>2],u[c+1075764>>1],v[c+1075696>>2])}rc:{sc:{switch((((v[d+480180>>2]&67633152?a+2|0:a)>>>0)%3|0)-1|0){case 0:g=(w[(d+B(f,872)|0)+1075798|0]>>>4|0)+g|0;break rc;case 1:break sc;default:break rc}}g=(w[(d+B(f,872)|0)+1075798|0]&15)+g|0}if(!(v[d+480180>>2]&67633408|w[(d+B(f,872)|0)+1075789|0]!=(g&255))){Db(n+8|0,e,82);if(!Cb(n+8|0)){break jc}}i=k;c=d;W=c;if(w[c+480210|0]&32){j=g&255;if((j|0)==85){v[k+36>>2]=2147483647;break jc}g=j>>>0>85?g-37|0:g}a=d+B(f,872)|0;Na=i,Oa=Yg(W,g&255,u[a+1075764>>1],v[a+1075696>>2]),v[Na+36>>2]=Oa;if(v[d+480180>>2]&71827712){v[a+1075692>>2]=v[k+36>>2];break jc}Db(n+8|0,e,82);if(!Cb(n+8|0)){break jc}t[(d+B(f,872)|0)+1075792|0]=g}gb=n+16|0;if(!(!(w[F|0]&33)|v[k+36>>2]==2147483647)){tc:{if(v[p+480180>>2]==2){a=452;c=3424;break tc}c=B(x[l+1075764>>1]>>>4&15,24);a=x[c+39686>>1];a=a>>>0<904?452:a>>>1|0;c=x[c+39664>>1]<<1}Qd(k+36|0,a,c);Qd(o,a,c)}Gz(p,b);a=v[s>>2]}uc:{if(!(a&256)|w[M|0]&64){break uc}Db(k+16|0,m,37);if(!Cb(k+16|0)){break uc}v[l+1075676>>2]=128}j=E&65535;BO(p,j);vc:{if(!h){break vc}a=zO(p,b,k+36|0);if((a|0)<0|!(w[s+1|0]&2)){break vc}if(!Bd(q)){break vc}Vq(v[q>>2],j,a>>>2&255,1)}wc:{if(w[l+1075782|0]!=8){break wc}xc:{yc:{a=w[l+1075783|0];switch(a-5|0){case 1:break wc;case 0:case 2:break xc;default:break yc}}if((a|0)!=26){break wc}}if(v[p+480180>>2]==4){if(w[M|0]&16){break wc}a=l+1075811|0;t[a|0]=w[a|0]+w[l+1075815|0];break wc}if(!(v[p+480180>>2]&16777248)){break wc}Hl(b,w[l+1075784|0]);yO(p,j,k+36|0,k+44|0)}yO(p,j,k+36|0,k+44|0);zc:{if(!h){break zc}v[k+32>>2]=0;c=p;d=k+36|0;o=gb-16|0;gb=o;a=b;h=v[a+104>>2];Ac:{if(!h|!w[h+40|0]){break Ac}N=Hj(a);g=qk(c);Db(o+8|0,c+1074312|0,21);i=g?44976:43952;f=g?43952:44976;if(!(N|!Cb(o+8|0)|v[c+480180>>2]==1048576)){if(!w[h+41|0]){break Ac}e=w[a+818|0];v[o+4>>2]=v[a+756>>2]+w[h+39|0];Zj(o+4|0,w[h+40|0]<<8);n=v[o+4>>2];v[a+756>>2]=n;n=(n|0)/256|0;v[o+4>>2]=n;t[a+818|0]=w[a+818|0]+w[h+41|0];Bc:{Cc:{switch(w[h+38|0]-1|0){case 3:c=vO(Ao(c))+-64|0;n=v[o+4>>2];break Bc;case 2:c=64-(e+1>>>1|0)|0;break Bc;case 1:c=(e+1>>>1|0)+-64|0;break Bc;case 0:c=(e>>>1^-1)&64;break Bc;default:break Cc}}c=t[e+40256|0]}Zj(d,8388607);e=v[d>>2]<<8;v[d>>2]=e;n=B(c,n);c=(n|0)/64|0;a=c>>31;h=a^a+c;c=h>>>2|0;a=d;Dc:{if((n|0)<=-64){c=v[(c<<2)+i>>2];f=zc(nqa(mqa(c,c>>31,e,e>>31),jb,65536,0),jb);c=v[d>>2];f=f-c|0;h=h&3;e=f;if(!h){break Dc}e=v[(h<<2)+(g?43888:43824)>>2];f=zc(nqa(mqa(e,e>>31,c,c>>31),jb,65536,0),jb)+f|0;c=v[d>>2];e=f-c|0;break Dc}c=v[f+(c<<2)>>2];f=zc(nqa(mqa(c,c>>31,e,e>>31),jb,65536,0),jb);c=v[d>>2];f=f-c|0;h=h&3;e=f;if(!h){break Dc}e=v[(h<<2)+(g?43824:43888)>>2];f=zc(nqa(mqa(e,e>>31,c,c>>31),jb,65536,0),jb)+f|0;c=v[d>>2];e=f-c|0}v[a>>2]=(c+e|0)/256;v[k+32>>2]=e&255;break Ac}Ec:{if(!(w[h+39|0]|v[c+480180>>2]&16777248)){v[a+756>>2]=w[h+40|0]<<8;break Ec}Fc:{Gc:{if(v[c+480180>>2]&16777248){n=w[h+39|0]<<1;g=v[a+756>>2];e=a+756|0;break Gc}if(w[a+89|0]&8){break Fc}g=((w[h+40|0]<<8&65280)>>>0)/w[h+39|0]|0;n=v[a+756>>2];e=a+756|0}v[e>>2]=g+n}Zj(a+756|0,w[h+40|0]<<8)}e=w[a+818|0]+w[h+41|0]|0;t[a+818|0]=e;e=e<<24>>24;Hc:{Ic:{switch(w[h+38|0]-1|0){case 3:t[a+818|0]=e+1;g=t[(e&63)+40192|0];break Hc;case 2:g=(64-(e>>>1|0)&127)+-64|0;break Hc;case 1:g=((e>>>1|0)- -64&127)+-64|0;break Hc;case 0:g=(e|0)>-1?-64:64;break Hc;default:break Ic}}e=w[a+818|0];g=0-t[e+40256|0]|0;if(v[c+480180>>2]!=1048576){break Hc}g=(64-t[(e+-64&255)+40256|0]|0)/2<<16>>16}e=g;n=B(e,v[a+756>>2]);g=(n|0)/256|0;if(N){z[k+44>>2]=C(C(C(e|0)*C(1220703143189894e-20))*C(w[h+40|0]))+z[k+44>>2];t[a+851|0]=w[a+851|0]|32;break Ac}if(v[c+480180>>2]!=4){Jc:{if((n|0)<=-256){g=0-g|0;c=0-n>>>16|0;a=(c<<2)+i|0;break Jc}i=f;c=(n|0)/65536|0;a=f+(c<<2)|0}e=v[d>>2];a=v[a>>2];a=((B(v[((c<<2)+i|0)+4>>2]-a|0,(g|0)/4&63)|0)/64|0)+a|0;a=zc(nqa(mqa(e,e>>31,a,a>>31),jb,256,0),jb);v[d>>2]=a;v[k+32>>2]=a&255;v[d>>2]=v[d>>2]/256;break Ac}v[d>>2]=v[d>>2]+((n|0)/16384|0)}gb=o+16|0;if(v[k+36>>2]<=v[p+480260>>2]){Db(k+16|0,m,81);if(Cb(k+16|0)){v[l+1075068>>2]=0}v[k+36>>2]=v[p+480260>>2]}Kc:{if(!Hj(b)){break Kc}a=l+1075843|0;c=w[a|0];if(!(v[p+1074392>>2]|!(c&16)?c&32:1)){break Kc}OS(b,z[k+44>>2],u[k+42>>1],p);c=a;a=w[a|0];t[c|0]=(a&32?-33:-17)&a}Fz(k+16|0,p,b,v[k+36>>2],v[k+32>>2]);d=mqa(v[k+16>>2],v[k+20>>2],v[p+480240>>2],0);c=jb;e=nqa(d,c,65536,0);f=jb;a=k;d=d+65535|0;c=d>>>0<65535?c+1|0:c;c=!c&d>>>0<131071;d=c?1:e;v[a+16>>2]=d;a=c?0:f;v[k+20>>2]=a;v[G>>2]=d;v[G+4>>2]=a;if((v[s>>2]&134219264)!=512){break zc}if(!Bd(q)){break zc}Db(k+8|0,m,99);if(Na=Cb(k+8|0)|!(w[s+1|0]&16),Oa=1,Qa=v[p+480180>>2]!=2,Qa?Na:Oa){Lc:{if(w[s+1|0]&8?v[p+480180>>2]==2:0){break Lc}a=mqa(v[k+24>>2],0,261625,0)+66904|0;c=jb;c=Uc(pqa(a,a>>>0<66904?c+1|0:c,133808,0),jb);d=v[s>>2];a=1;Mc:{if(d&2048){break Mc}a=0;if(!(d&4096)){break Mc}a=!v[l+1075688>>2]}Db(k+8|0,m,110);if(Na=Cb(k+8|0),Oa=0,Qa=a,Qa?Na:Oa){break Lc}d=v[q>>2];Db(k+8|0,m,95);JA(d,j,c,a,Cb(k+8|0))}d=v[q>>2];a=mqa(B(v[l+1075744>>2],B(v[l+1075740>>2],v[I>>2])),0,63,0)+33554432|0;c=jb;c=a>>>0<33554432?c+1|0:c;Vq(d,j,Uc((c&67108863)<<6|a>>>26,c>>>26|0)&255,0);a=l+1075676|0;f=a;d=v[a>>2];a=0;c=v[q>>2];e=Nl(c,j);Nc:{if((e|0)==255){break Nc}if(vk(c)){break Nc}a=lc(ln(c+314|0,e),10);c=v[c>>2];e=xu(e)|192;a=w[a|0]&-49;a=(d|0)<171?a|16:a;a=((d|0)>84?a|32:a)&255;Yh(c,e,a);a=(a>>>5&1)+(a<<27>>31)|0}v[f>>2]=(a<<7)+128}Oc:{a=v[H>>2];if(!a|(w[a+60|0]&7)!=1){break Oc}a=a+48|0;if($c(a)){break Oc}c=v[wO(b,0)>>2];a=uo(a);if(c>>>0<x[a>>1]|w[a+2|0]){break Oc}Mi(v[q>>2],j,1);Db(k+8|0,m,109);a=Cb(k+8|0);h=v[s>>2];if(!a){h=h&-513;v[s>>2]=h}v[s>>2]=h|4096;v[l+1075688>>2]=0;break zc}Db(k+8|0,m,99);if(!Cb(k+8|0)|!(w[s+1|0]&16)|v[l+1075688>>2]){break zc}Mi(v[q>>2],j,1);v[s>>2]=v[s>>2]&-513}Pc:{if(!V){break Pc}Db(k+16|0,m,31);if(Cb(k+16|0)){break Pc}Yt(p,b)}c=v[s>>2];a=c&-65537;h=l+1075012|0;j=l+1075016|0;v[s>>2]=v[h>>2]|(v[j>>2]|v[A>>2])?(a|c<<7&65536)^65536:a;c=l+1075664|0;a=c;v[a>>2]=0;v[a+4>>2]=0;f=l+1075834|0;d=w[f|0];a=d-4|0;t[f|0]=a>>>0>d>>>0?0:a;g=l+1075835|0;d=w[g|0];a=d-4|0;t[g|0]=a>>>0>d>>>0?0:a;Qc:{Rc:{Sc:{Tc:{Uc:{Vc:{a=l+1075096|0;d=v[a>>2];Wc:{if(!d){break Wc}if(!Ld(d)|!v[l+1075068>>2]){break Wc}if(Ki(b)){break Vc}}d=l+1075008|0;v[d>>2]=0;break Uc}d=l+1075008|0;a=v[v[a>>2]+20>>2];v[d>>2]=a;if(a){break Tc}}if(!rk(b)|w[s+1|0]&24){break Sc}}n=v[A>>2];i=v[l+1075676>>2];a=(B(n,256-i|0)|0)/16384|0;e=a>>>0<127?a:127;a=t[f|0];if((a|0)<=-1){t[f|0]=e;o=e}else{o=a}a=e>>>1|0;if((o&255)>>>0<a>>>0){t[f|0]=a}a=(B(i,n)|0)/16384|0;a=a>>>0<127?a:127;i=t[g|0];if((i|0)<=-1){t[g|0]=a;i=a}a=a>>>1|0;if(a>>>0>(i&255)>>>0){break Rc}break Qc}if(w[f|0]>=129){t[f|0]=0}a=0;if(w[g|0]<129){break Qc}}t[g|0]=a}Xc:{Yc:{if(v[d>>2]){a=l+1075668|0;Zc:{if(y[p+24624>>2]>=2){v[k+16>>2]=v[l+1075676>>2];Qd(k+16|0,0,256);f=B(r,v[A>>2])>>>(w[J+34|0]?7:8)|0;d=a;_c:{$c:{ad:{switch(w[J+32|0]){case 0:if(!(w[p+24616|0]&16)){break $c}case 1:e=v[k+16>>2];if((e|0)<=127){v[c>>2]=f>>>1;f=(B(f,e)|0)/256|0;break _c}v[c>>2]=(B(f,256-e|0)|0)/256;f=f>>>1|0;break _c;case 3:break ad;default:break $c}}Zj(k+16|0,255);e=c;g=v[k+16>>2];if((g|0)<=0){h=f<<16}else{h=B(f,x[(0-g<<1)+46512>>1])}v[e>>2]=h>>>16;f=B(f,x[(g<<1)+46e3>>1])>>>16|0;break _c}e=v[k+16>>2];v[c>>2]=(B(f,256-e|0)|0)/256;f=(B(f,e)|0)/256|0}v[d>>2]=f;break Zc}d=B(r,v[A>>2])>>>8|0;v[c>>2]=d;v[a>>2]=d}g=l+1075786|0;f=g;bd:{cd:{d=v[H>>2];if(!d){break cd}if(!wp(w[d+14|0])){break cd}d=w[v[H>>2]+14|0];break bd}if(wp(w[p+480268|0])){d=w[p+480268|0];break bd}d=w[p+24648|0];d=w[F|0]&128?v[p+24668>>2]?-1:d:d}t[f|0]=d;f=v[s>>2];e=v[G>>2];h=v[G+4>>2];if(!(f&131072|((e|0)!=0|(h|0)!=1)|(v[l+1075748>>2]|(d&255)==255))){t[g|0]=0}d=c;i=v[c>>2];c=1<<v[J+28>>2];v[d>>2]=(i|0)/(c|0);c=v[a>>2]/(c|0)|0;v[a>>2]=c;if(!(!(f&256)|v[p+24624>>2]!=2)){v[a>>2]=0-c}if(f&128){v[G>>2]=0-e;v[G+4>>2]=0-(((e|0)!=0)+h|0)}f=p;h=0;e=gb-16|0;gb=e;c=b;v[b+28>>2]=0;v[b+32>>2]=0;g=b;dd:{ed:{j=v[b+88>>2];if(!(j&65536)){a=v[c+676>>2];b=v[c+672>>2];break ed}b=v[c+20>>2];n=v[c+672>>2];fd:{if((b|0)!=(n|0)){a=v[c+24>>2];d=v[c+676>>2];break fd}a=v[c+24>>2];d=v[c+676>>2];if((a|0)==(d|0)){break ed}}i=f+24604|0;j=e;d=(a|0)<(d|0)|(b|0)<(n|0);gd:{if(d){a=RS(i);break gd}a=QS(i)}v[j+12>>2]=a;Db(e,f+1074312|0,4);if(!(!Cb(e)|!(v[f+480180>>2]&4))){a=v[f+24620>>2];a=mqa(a,a>>31,5,0)+500|0;j=jb;a=zc(nqa(a,a>>>0<500?j+1|0:j,1e3,0),jb)}j=v[c+656>>2];hd:{if(!j){b=a;break hd}b=a;if(!d){break hd}d=x[j+12>>1];if(d){b=(B(d,v[f+24620>>2])>>>0)/1e5|0}h=(d|0)!=0}o=b?b:1;i=v[c+676>>2];b=v[c+24>>2];j=i-b<<12;d=v[c+672>>2];n=v[c+20>>2];A=d-n<<12;if(!(w[c+90|0]&32|(!(d|i)|(!(b|n)|h)))){v[e+12>>2]=v[f+1074380>>2];Qd(e+12|0,a,2048);i=v[c+676>>2];o=v[e+12>>2];d=v[c+672>>2]}f=(j|0)/(o|0)|0;v[c+32>>2]=f;h=(A|0)/(o|0)|0;v[c+28>>2]=h;a=((B(f,o)|0)/-4096|0)+i|0;v[c+24>>2]=a;b=((B(h,o)|0)/-4096|0)+d|0;v[c+20>>2]=b;if(f|h){v[c+100>>2]=o;d=v[c+88>>2];break dd}v[c+24>>2]=i;v[c+20>>2]=d;a=i;b=d;d=v[c+88>>2]&-65537;break dd}v[c+24>>2]=a;v[c+20>>2]=b;d=j&-65537}v[g+88>>2]=d&-2097153;v[c+40>>2]=a<<12;v[c+36>>2]=b<<12;gb=e+16|0;if(!(w[s+1|0]&2)){break Yc}break Xc}v[h>>2]=0;v[j>>2]=0;v[l+1075068>>2]=0;if(v[l+1075088>>2]){break Yc}if(!v[l+1075084>>2]){break Xc}}a=x[p+480212>>1];u[p+480212>>1]=a+1;u[(p+(a<<1)|0)+1074478>>1]=E}v[l+1075660>>2]=v[s>>2]}E=E+1|0;if((E|0)!=256){continue}break}i=1;if(y[p+24608>>2]>x[p+480212>>1]){break xb}a=p+1074478|0;c=a;b=a+(v[p+24608>>2]<<1)|0;g=a+(x[p+480212>>1]<<1)|0;d=gb-16|0;gb=d;v[d+8>>2]=p;f=d+8|0;h=f;e=b-a|0;if((e|0)>=3){j=e>>1;e=(j-2|0)/2|0;while(1){yz(a,h,j,a+(e<<1)|0);n=(e|0)>0;e=e-1|0;if(n){continue}break}}if((b|0)!=(g|0)){e=b-c>>1;a=b;while(1){if(Aq(f,x[a>>1],x[c>>1])){zz(a,c);yz(c,f,e,c)}a=a+2|0;if((g|0)!=(a|0)){continue}break}}a=b-c|0;if((a|0)>=3){h=a>>>1|0;while(1){zz(c,b-2|0);yz(c,f,h-1|0,c);b=b-2|0;a=(h|0)>2;h=h-1|0;if(a){continue}break}}gb=d+16|0}gb=k+48|0;if(i){i=v[K+480208>>2];break k}a=v[K+480208>>2]|512;if(w[K+1298380|0]){break l}i=0;a=v[K+24620>>2]/10|0;b=zc(a,a>>31);id:{if(!b){break id}c=b>>>0<1048576?b:1048576;v[p+1074380>>2]=c;e=x[p+480212>>1];if(!e){break id}d=p+1074376|0;while(1){a=d+B(x[(d+(i<<1)|0)+102>>1],872)|0;f=a+1288|0;v[f>>2]=0;v[f+4>>2]=0;v[a+716>>2]=c;f=v[a+640>>2]<<12;v[a+656>>2]=f;g=v[a+636>>2]<<12;v[a+652>>2]=g;v[a+704>>2]=v[a+704>>2]|65536;v[a+644>>2]=(0-g|0)/(c|0);v[a+648>>2]=(0-f|0)/(c|0);i=i+1|0;if((e|0)!=(i|0)){continue}break}}c=v[K+480208>>2];a=c|256;if(b){break l}a=c|512}i=a;v[R+480208>>2]=i}if(i&512){Na=K+1074392|0,Oa=sk(Ba),v[Na>>2]=Oa;break j}v[T+112>>2]=512;a=v[K+1074380>>2];v[T+108>>2]=3;v[T+120>>2]=ia;v[T+116>>2]=a;v[T+104>>2]=T+112;a=v[T+108>>2];v[T+48>>2]=v[T+104>>2];v[T+52>>2]=a;f=OX(T+48|0);if(v[K+24632>>2]){a=K;b=na;i=0;d=gb-48|0;gb=d;c=f;g=c<<2;while(1){v[d+32>>2]=0;e=(a+(i<<11)|0)+16396|0;j=e;h=(e+g|0)-e>>2;if((h|0)>=1){while(1){v[j>>2]=v[d+32>>2];j=j+4|0;e=(h|0)>1;h=h-1|0;if(e){continue}break}}i=i+1|0;if((i|0)!=4){continue}break}i=0;while(1){v[(d+32|0)+(i<<2)>>2]=(a+(i<<11)|0)+16396;i=i+1|0;if((i|0)!=4){continue}break}a=ig(d+16|0,d+32|0,v[a+24632>>2],c);c=v[v[b>>2]+8>>2];v[d+8>>2]=v[a+8>>2];e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;kb[c|0](b,d);gb=d+48|0}if(w[_+12|0]){i=0;while(1){v[(T+112|0)+(i<<2)>>2]=((i<<11)+K|0)+16396;i=i+1|0;if((i|0)!=4){continue}break}b=v[_+8>>2];a=ig(T+88|0,T+112|0,v[K+24632>>2],f);c=v[v[b>>2]+8>>2];v[T+40>>2]=v[a+8>>2];d=v[a+4>>2];v[T+32>>2]=v[a>>2];v[T+36>>2]=d;kb[c|0](b,T+32|0)}l=K;M=0;b=gb-112|0;gb=b;r=f;if(f){R=l+12|0;m=l+24592|0;q=l+24588|0;So(R,r,m,q);if(y[l+24624>>2]>=3){So(l+8204|0,r,l+24600|0,l+24596|0)}u[b+30>>1]=0;oa=l+1074312|0;Db(b+8|0,oa,33);a=Cb(b+8|0);if(x[l+480212>>1]){Ca=a?2:1;Da=l+24648|0;A=l+24596|0;Ea=l+24600|0;Fa=l+8204|0;G=l+397460|0;J=l+397456|0;V=l+393352|0;sa=l+1074376|0;while(1){p=sa+(M<<1)|0;a=B(x[p+102>>1],872);n=a+sa|0;W=n;jd:{kd:{if(v[n+632>>2]){break kd}c=a+l|0;if(v[c+1075088>>2]){break kd}if(!v[c+1075084>>2]){break jd}}i=a+l|0;a=w[i+1075786|0]+1|0;ld:{if((a&255)>>>0<=5){j=v[(a<<24>>24<<2)+34448>>2];break ld}j=0}e=A;H=i+1075080|0;d=v[H>>2];md:{if(!(!(d&16777216)&w[l+24612|0]>>>5)){k=R;c=q;h=d;a=m;if(!(d&8388608)){break md}}c=r;a=V;if(!v[a+4116>>2]){So(a+8|0,c,a+4104|0,a+4108|0)}v[a+4116>>2]=1;k=a+8|0;h=v[H>>2];c=G;a=J}g=c;c=h>>>8&y[l+24624>>2]>2;F=c?e:g;Y=c?Ea:a;g=c?Fa:k;ba=Im(l,x[p+102>>1],2,1);nd:{if((!ba|0)==(ba>>>0<251|0)){break nd}c=v[(l+B(ba,160)|0)+906140>>2];if(!c){break nd}a=v[c+24>>2];if(!a){break nd}F=c+36|0;Y=c+40|0;if(!(t[c+28|0]&1)){So(a,r,Y,F);v[c+28>>2]=v[c+28>>2]|1}g=a}e=n+616|0;if(w[i+1075843|0]&4){SS(e,g,r);a=i+1075084|0;v[Y>>2]=v[Y>>2]+v[a>>2];v[F>>2]=v[F>>2]+v[i+1075088>>2];v[a>>2]=0;v[a+4>>2]=0;break jd}fa=0;ka=b+8|0;a=ka;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;a=e;if(v[a+16>>2]){cF(ka,a);h=v[a+12>>2];p=h;c=h>>31;k=h>>31;h=k+v[a+8>>2]|0;a=c;c=a+p|0;c=h>>>0<k>>>0?c+1|0:c;a=a^c;v[ka+12>>2]=a>>>0>8191?2:16384/(a+1>>>0)|0}E=d>>>12&8|(d>>>5&2|(j|d&1));ta=i+1075795|0;Ga=i+1075778|0;Ha=i+1075688|0;Ia=i+1075024|0;Ja=i+1075020|0;Ka=i+1075668|0;La=i+1075664|0;N=i+1075e3|0;Z=i+1075088|0;$=i+1075084|0;ua=i+1075016|0;va=i+1075012|0;ga=i+1075096|0;ca=i+1075076|0;I=i+1075068|0;la=i+1075072|0;aa=i+1075092|0;a=r;while(1){od:{c=v[aa>>2];ma=c?a>>>0>c>>>0?c:a:a;v[b+68>>2]=ma;s=v[la>>2];c=v[H>>2];n=v[N+4>>2];h=v[N>>2];v[b+56>>2]=h;v[b+60>>2]=n;pd:{qd:{if(!ma|!(h|n)){break qd}k=v[I>>2];if(!k){break qd}d=v[b+8>>2];if(!d){break qd}v[W+632>>2]=d;d=v[e+4>>2];i=d;rd:{sd:{j=v[e>>2];o=s&c<<30>>31;da=d;td:{if((o|0)>(d|0)){if((n|0)<-1?1:(n|0)<=-1){v[b+104>>2]=0;d=o;v[b+108>>2]=d<<1;j=Mg(b+104|0,e);c=jb;i=c;v[e>>2]=j;v[e+4>>2]=c;if(!(c>>>0<d+v[I>>2]>>>1>>>0?(c|0)>=(d|0):0)){j=0;v[e>>2]=j;i=d;v[e+4>>2]=d}c=h;d=0-(((c|0)!=0)+n|0)|0;p=0-c|0;v[b+56>>2]=p;v[b+60>>2]=d;v[N>>2]=p;v[N+4>>2]=d;c=v[H>>2];ud:{if(c&4){k=c&-129;v[H>>2]=k;break ud}k=c|128;v[H>>2]=k;c=v[I>>2]-1|0;i=c;v[e>>2]=j;v[e+4>>2]=c;v[N>>2]=h;v[N+4>>2]=n}vd:{if(!(k&2)){k=v[I>>2];break vd}k=v[I>>2];if(i>>>0<k>>>0){break rd}}d=e;v[d>>2]=0;v[d+4>>2]=k;break qd}if((i|0)>-1){break td}c=0;i=c;v[e>>2]=j;v[e+4>>2]=c;break td}if(k>>>0<=da>>>0){break sd}}p=h;d=n;break rd}if(!(c&2)){break qd}if(c&4){wd:{if((n|0)<0?1:(n|0)<=0?h>>>0<1:0){p=h;d=n;break wd}p=0-h|0;v[b+56>>2]=p;d=0-(((h|0)!=0)+n|0)|0;v[b+60>>2]=d;v[N>>2]=p;v[N+4>>2]=d}v[H>>2]=c|128;c=1-((j|0)!=0)|0;j=0-j|0;n=(k<<1)-(c+da|0)|0;c=n;i=c;v[e>>2]=j;v[e+4>>2]=c;if(k>>>0>c>>>0?c>>>0>s>>>0:0){break rd}v[b+104>>2]=Ca;c=k-v[Fb(I,b+104|0)>>2]|0;j=v[e>>2];v[e>>2]=j;i=c;v[e+4>>2]=c;break rd}xd:{if((n|0)>-1){p=h;d=n;break xd}p=0-h|0;v[b+56>>2]=p;d=0-(((h|0)!=0)+n|0)|0;v[b+60>>2]=d;v[N>>2]=p;v[N+4>>2]=d}v[b+104>>2]=0;v[b+108>>2]=o-k;Ub(e,b+104|0);v[H>>2]=v[H>>2]|8192;j=v[e>>2];i=v[e+4>>2]}v[b+48>>2]=j;c=i;v[b+52>>2]=c;yd:{zd:{s=c;if((c|0)<(o|0)){c=0;if((i|0)<0|(d|0)<0){break yd}break zd}if((i|0)>0?1:(i|0)>=0){break zd}c=0;break yd}c=0;if(s>>>0>=y[I>>2]){break yd}v[b+44>>2]=ma;tc(b+68|0,v[b+20>>2]);Na=b,Oa=sw(b+56|0,v[b+68>>2]-1|0),v[Na+32>>2]=Oa;v[b+36>>2]=jb;k=d>>31;h=p+k|0;c=d;d=d>>31;c=c+d|0;Ma=h;h=h>>>0<k>>>0?c+1|0:c;p=v[la>>2];da=p+16|0;c=v[b+36>>2]+v[b+52>>2]|0;ja=v[b+48>>2];n=ja+v[b+32>>2]|0;c=n>>>0<ja>>>0?c+1|0:c;ja=p>>>0>s>>>0;if(s>>>0<da>>>0?ja:1){v[H>>2]=v[H>>2]&-8193}n=k^Ma;k=d^h;h=c;Ad:{Bd:{Cd:{if(!v[b+12>>2]){d=v[b+60>>2];break Cd}c=v[b+16>>2];if(c>>>0<=s>>>0){h=b;d=v[b+60>>2];Dd:{if((d|0)<-1?1:(d|0)<=-1){v[b+96>>2]=j;v[b+100>>2]=i;v[b+104>>2]=0;v[b+108>>2]=c;Na=b,Oa=Mg(b+96|0,b+104|0),v[Na+80>>2]=Oa;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Na=b,Oa=Mg(b+80|0,b+72|0),v[Na+88>>2]=Oa;v[b+92>>2]=jb;c=Hn(b+88|0,n,k);break Dd}d=v[ca>>2];v[b+104>>2]=j;v[b+108>>2]=i;v[b+96>>2]=0;v[b+100>>2]=d;Na=b,Oa=Mg(b+96|0,b+104|0),v[Na+80>>2]=Oa;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Na=b,Oa=Mg(b+80|0,b+72|0),v[Na+88>>2]=Oa;v[b+92>>2]=jb;c=Hn(b+88|0,n,k)}v[h+44>>2]=c+1;v[W+632>>2]=v[b+12>>2];break Ad}if(!(!(w[H+1|0]&32)|ja|s>>>0>=da>>>0)){v[b+104>>2]=j;v[b+108>>2]=i;v[b+96>>2]=0;v[b+100>>2]=o+16;Na=b,Oa=Mg(b+96|0,b+104|0),v[Na+80>>2]=Oa;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Na=b,Oa=Mg(b+80|0,b+72|0),v[Na+88>>2]=Oa;v[b+92>>2]=jb;Na=b,Oa=Hn(b+88|0,n,k)+1|0,v[Na+44>>2]=Oa;Na=W,Oa=v[b+12>>2]+B(v[ca>>2]-o|0,fj(v[ga>>2]))|0,v[Na+632>>2]=Oa;break Ad}d=v[b+60>>2];if((d|0)<0?1:(d|0)<=0?y[b+56>>2]<1:0){break Cd}if(ma>>>0<2|c>>>0>h>>>0){break Bd}v[b+104>>2]=j;v[b+108>>2]=i;v[b+96>>2]=0;v[b+100>>2]=c;Na=b,Oa=Mg(b+96|0,b+104|0),v[Na+80>>2]=Oa;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Na=b,Oa=Mg(b+80|0,b+72|0),v[Na+88>>2]=Oa;v[b+92>>2]=jb;Na=b,Oa=Hn(b+88|0,n,k)+1|0,v[Na+44>>2]=Oa;break Ad}if((d|0)>-1){break Bd}if((h|0)>=(o|0)){break Ad}v[b+96>>2]=j;v[b+100>>2]=i;v[b+104>>2]=0;v[b+108>>2]=p;Na=b,Oa=Mg(b+96|0,b+104|0),v[Na+80>>2]=Oa;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Na=b,Oa=Mg(b+80|0,b+72|0),v[Na+88>>2]=Oa;v[b+92>>2]=jb;Na=b,Oa=Hn(b+88|0,n,k)+1|0,v[Na+44>>2]=Oa;break Ad}c=v[I>>2];if((c|0)>(h|0)){break Ad}v[b+104>>2]=j;v[b+108>>2]=i;v[b+96>>2]=0;v[b+100>>2]=c;Na=b,Oa=Mg(b+96|0,b+104|0),v[Na+80>>2]=Oa;v[b+84>>2]=jb;v[b+72>>2]=1;v[b+76>>2]=0;Na=b,Oa=Mg(b+80|0,b+72|0),v[Na+88>>2]=Oa;v[b+92>>2]=jb;Na=b,Oa=Hn(b+88|0,n,k)+1|0,v[Na+44>>2]=Oa}Gp(b+44|0,1,v[b+68>>2]);c=v[b+44>>2]}if((c|0)>0){break pd}}v[W+632>>2]=0;v[I>>2]=0;v[e>>2]=0;v[e+4>>2]=0;v[aa>>2]=0;SS(e,g,a);v[Y>>2]=v[Y>>2]+v[$>>2];v[F>>2]=v[F>>2]+v[Z>>2];v[Z>>2]=0;v[$>>2]=0;v[H>>2]=v[H>>2]&-129;j=x[b+30>>1];break od}Ed:{Fd:{j=x[b+30>>1];if(j>>>0>=y[l+24608>>2]){break Fd}if(v[aa>>2]){d=E|4}else{if(!(v[ua>>2]|v[va>>2])){break Fd}d=E}h=(c<<3)+g|0;i=h-8|0;v[$>>2]=0-v[i>>2];p=h-4|0;v[Z>>2]=0-v[p>>2];kb[v[(d<<2)+34064>>2]](e,Da,g,c);v[$>>2]=v[$>>2]+v[i>>2];v[Z>>2]=v[Z>>2]+v[p>>2];fa=1;break Ed}Na=b,Oa=mqa(v[N>>2],v[N+4>>2],c,c>>31),v[Na+104>>2]=Oa;v[b+108>>2]=jb;Ub(e,b+104|0);fa=0;v[Z>>2]=0;v[$>>2]=0;h=(c<<3)+g|0}g=h;d=v[aa>>2];Gd:{if(!d){break Gd}if(c>>>0>=d>>>0){v[aa>>2]=0;v[va>>2]=v[La>>2];v[ua>>2]=v[Ka>>2];v[Ja>>2]=0;v[Ia>>2]=0;if(v[Ha>>2]|!(w[H+1|0]&16)){break Gd}v[I>>2]=0;v[W+632>>2]=0;break Gd}v[aa>>2]=d-c}k=0;h=0;d=v[e+4>>2];h=d>>>0>=y[ca>>2]?(w[H|0]&2)>>>1|0:h;i=d;d=v[I>>2];k=i>>>0<d>>>0|(!d|w[H|0]&2)?k:!x[Ga>>1];a=a-c|0;Db(b+104|0,oa,85);Hd:{Id:{Jd:{Kd:{if(!Cb(b+104|0)){break Kd}c=w[ta|0];if(!c|c>>>0>x[l+480190>>1]){break Kd}c=l+B(w[ta|0],104)|0;d=c+484380|0;i=v[ga>>2];if(!(h|k)|(d|0)==(i|0)){break Jd}v[ga>>2]=d;v[W+632>>2]=v[c+484400>>2];d=x[c+484414>>1];v[H>>2]=d|v[H>>2]&-768;h=d<<30>>31;d=v[c+484388>>2];v[I>>2]=h&d;c=v[c+484384>>2];v[la>>2]=c;v[ca>>2]=d;v[e+4>>2]=c;cF(ka,e);if(!v[W+632>>2]){break od}if((a|0)>0){continue}break od}if(h){break Id}break Hd}if(!h|(d|0)!=(i|0)){break Hd}}Db(b+104|0,oa,83);if(!Cb(b+104|0)|v[la>>2]){break Hd}v[e>>2]=v[e>>2];v[e+4>>2]=0;c=v[v[ga>>2]+8>>2];v[I>>2]=c;v[ca>>2]=c}if((a|0)>0){continue}}break}v[W+632>>2]=v[b+8>>2];u[b+30>>1]=j+fa;if(!fa|!ba|ba>>>0>250){break jd}a=v[(l+B(ba,160)|0)+906140>>2];if(!a){break jd}kb[v[v[a>>2]+148>>2]](a)}M=M+1|0;if(M>>>0<x[l+480212>>1]){continue}break}}Na=l,Oa=x[Ie(l+480214|0,b+30|0)>>1],u[Na+480214>>1]=Oa}gb=b+112|0;if(Bd(ra)){i=ea;a=f;b=(B(v[K+480232>>2],v[K+480236>>2])>>>0)/48|0;o=gb-16|0;gb=o;G=v[ra>>2];Ld:{if(!w[G+530|0]){break Ld}d=mqa(b,0,6169,0);b=jb;c=b>>>16|0;q=Uc((b&65535)<<16|d>>>16,c);if(!a){break Ld}while(1){b=v[G>>2];c=v[b>>2];h=v[b+4>>2];if((c|0)<=(h|0)){e=b+14|0;g=b+12|0;while(1){v[b+8>>2]=v[b+12>>2];c=b;h=g;j=e;E=0;r=0;n=0;d=gb-16|0;gb=d;while(1){k=c+B(n,44)|0;Md:{if(!w[k+56|0]){u[d+12>>1]=0;u[d+14>>1]=0;break Md}l=v[k+32>>2];p=x[l+3840>>1];if(p&3){l=(x[k+36>>1]>>>7&7)>>>(w[l+3844|0]^1)>>>(p&1)|0;p=(p&4?0-l|0:l)&65535}else{p=0}l=p<<x[k+38>>1];p=d;s=v[k+52>>2];Nd:{if(s){J=x[s+32>>1];A=x[k+48>>1];s=fg(v[k+16>>2],v[k+40>>2],l<<16>>16,0,u[k+46>>1]);R=v[k+40>>2];m=v[k+20>>2];if(!J){if(!A){l=l<<16>>16;s=fg(m,R,l,s,0);s=fg(v[k+24>>2],v[k+40>>2],l,s,0);l=fg(v[k+28>>2],v[k+40>>2],l,s,0);break Nd}l=l<<16>>16;R=fg(m,R,l,0,0);R=fg(v[k+24>>2],v[k+40>>2],l,R,0);l=fg(v[k+28>>2],v[k+40>>2],l,R,0)+s|0;break Nd}if(!A){l=l<<16>>16;s=fg(m,R,l,s,0);R=fg(v[k+24>>2],v[k+40>>2],l,0,0);l=fg(v[k+28>>2],v[k+40>>2],l,R,0)+s|0;break Nd}l=l<<16>>16;R=fg(m,R,l,0,0);l=(fg(v[k+24>>2],v[k+40>>2],l,R,0)+s|0)+fg(v[k+28>>2],v[k+40>>2],l,0,0)|0;break Nd}A=x[k+48>>1];l=l<<16>>16;s=fg(v[k+16>>2],v[k+40>>2],l,0,u[k+46>>1]);R=v[k+40>>2];m=v[k+20>>2];if(!A){l=fg(m,R,l,s,0);break Nd}l=fg(m,R,l,0,0)+s|0}u[p+14>>1]=w[k+57|0]?l:0;u[d+12>>1]=w[k+58|0]?l:0}E=u[d+12>>1]+E|0;r=u[d+14>>1]+r|0;n=n+1|0;if((n|0)!=18){continue}break}p=h;h=(r|0)<32767?r:32767;u[p>>1]=(h|0)>-32768?h:-32768;h=(E|0)<32767?E:32767;u[j>>1]=(h|0)>-32768?h:-32768;u[c+3832>>1]=x[c+3832>>1]+1;h=(x[c+3834>>1]+1>>>0)%13440|0;u[c+3834>>1]=h;h=h>>>0<6720?h:13440-h|0;u[c+3836>>1]=h>>>8;if(!w[c+3843|0]){u[c+3836>>1]=h>>>10}h=x[c+3838>>1]+1|0;u[c+3838>>1]=h;if((h&65535)>>>0>=1024){u[c+3838>>1]=0;u[c+3840>>1]=x[c+3840>>1]+1&7}gb=d+16|0;c=v[b>>2];h=v[b+4>>2]-c|0;v[b+4>>2]=h;if((c|0)<=(h|0)){continue}break}}d=c-h|0;u[o+14>>1]=(B(u[b+12>>1],h)+B(d,u[b+8>>1])|0)/(c|0);u[o+12>>1]=(B(u[b+14>>1],h)+B(d,u[b+10>>1])|0)/(c|0);v[b+4>>2]=h+49716;v[i>>2]=v[i>>2]+B(q,u[o+14>>1]);v[i+4>>2]=v[i+4>>2]+B(q,u[o+12>>1]);i=i+8|0;a=a-1|0;if(a){continue}break}}gb=o+16|0}e=ea;b=f;j=Aa;Od:{if(!v[j+4116>>2]){if(!v[j+4120>>2]){break Od}So(j+8|0,b,j+4104|0,j+4108|0)}d=v[j>>2];g=v[j+4184>>2];a=B(d,g)>>>4|0;a=a>>>0<32767?a:32767;u[j+4202>>1]=a;u[j+4200>>1]=a;h=v[j+54052>>2];a=B(h,d)>>>4|0;a=a>>>0<65536?a:65536;c=a+127>>>3|0;u[j+54050>>1]=c;a=a+255>>>4|0;u[j+54048>>1]=a;u[j+54046>>1]=a;u[j+54044>>1]=c;c=e;a=j+8|0;i=a;g=(g|0)>(h|0)?g:h;d=36-d>>>1|0;d=d>>>0>8?d:8;g=16-(B((g|0)<32768?g:32768,(d|0)<16?16-d|0:0)>>15)|0;k=0;d=b;if(b){while(1){h=k<<3;p=h+c|0;v[p>>2]=v[p>>2]+B(g,v[h+i>>2]>>4);h=h|4;p=h+c|0;v[p>>2]=v[p>>2]+B(g,v[h+i>>2]>>4);k=k+1|0;if((d|0)!=(k|0)){continue}break}}i=j+4172|0;d=a;h=0;c=j;g=v[c+4144>>2];o=v[c+4140>>2];if(b){p=u[c+4188>>1];while(1){n=h<<3;k=(n|4)+d|0;r=v[k>>2];n=d+n|0;l=v[n>>2]>>12;o=(B(p,l-o|0)>>15)+l|0;v[n>>2]=o;n=r>>12;g=(B(p,n-g|0)>>15)+n|0;v[k>>2]=g;h=h+1|0;if((b|0)!=(h|0)){continue}break}}v[c+4144>>2]=g;v[c+4140>>2]=o;Pd:{if(!b){d=v[i>>2];break Pd}n=j+53996|0;c=b;h=i;o=v[h>>2]-1|0;M=x[h+22>>1];p=u[h+26>>1];R=u[h+18>>1];g=v[h+4>>2];k=x[h+20>>1];r=u[h+24>>1];m=u[h+16>>1];l=h+32928|0;while(1){E=Lb(v[d>>2],-32768,32767);s=Lb(v[d+4>>2],-32768,32767);k=Lb((k<<16>>16)-E|0,-32768,32767);q=Lb((M<<16>>16)-s|0,-32768,32767);k=Sc(Lb((B(k,m)|0)/65536<<1,-32768,32767)+E|0);M=Sc(Lb((B(q,R)|0)/65536<<1,-32768,32767)+s|0);s=l+(g<<2)|0;E=u[s+2>>1];q=u[s>>1];s=Sc(((B(q,r)|0)/-65536|0)+k|0);g=g+1&127;A=l+(g<<2)|0;G=Sc(((B(p,E)|0)/-65536|0)+M|0);u[A+2>>1]=G;u[A>>1]=s;o=o+1&8191;A=h+(o<<2)|0;Na=A,Oa=Sc(q+((B(r,s)|0)/65536|0)|0),u[Na+160>>1]=Oa;Na=A,Oa=Sc(E+((B(p,G)|0)/65536|0)|0),u[Na+162>>1]=Oa;d=d+8|0;c=c-1|0;if(c){continue}break}u[h+22>>1]=M;u[h+20>>1]=k;v[h+4>>2]=g;h=v[j+4180>>2];A=j+37612|0;c=a;k=b;while(1){p=h&4095;g=A+(p<<2)|0;d=c;R=h-v[j+53996>>2]&4095;h=4096-(p>>>0>R>>>0?p:R)|0;h=h>>>0<k>>>0?h:k;p=h>>>0<64?h:64;o=p;r=0;l=gb-32|0;gb=l;h=i;E=v[h>>2];while(1){v[l+(r<<2)>>2]=E+(v[(h+(r<<4)|0)+32>>2]^-1);r=r+1|0;if((r|0)!=7){continue}break}r=u[h+28>>1]/8|0;if(o){m=r<<16>>16;while(1){M=0;E=0;r=0;while(1){s=l+(r<<2)|0;q=v[s>>2]+1&8191;v[s>>2]=q;J=E;E=h+(q<<2)|0;q=u[E+160>>1];s=h+(r<<4)|0;G=u[E+162>>1];E=(J+B(q,u[s+44>>1])|0)+B(G,u[s+46>>1])|0;M=(B(q,u[s+40>>1])+M|0)+B(G,u[s+42>>1])|0;r=r+1|0;if((r|0)!=4){continue}break}F=0;r=4;q=Sc((M|0)/32768|0);G=Sc((E|0)/32768|0);M=0;while(1){E=l+(r<<2)|0;s=v[E>>2]+1&8191;v[E>>2]=s;s=h+(s<<2)|0;J=u[s+160>>1];E=h+(r<<4)|0;s=u[s+162>>1];M=(B(J,u[E+44>>1])+M|0)+B(s,u[E+46>>1])|0;F=(B(J,u[E+40>>1])+F|0)+B(s,u[E+42>>1])|0;r=r+1|0;if((r|0)!=7){continue}break}r=Sc(q+((F|0)/32768|0)|0);u[g>>1]=r;v[d>>2]=B(m,r);r=Sc(G+((M|0)/32768|0)|0);u[g+2>>1]=r;v[d+4>>2]=B(m,r);d=d+8|0;g=g+4|0;o=o-1|0;if(o){continue}break}}gb=l+32|0;E=A+(R<<2)|0;h=c;g=n;o=v[g+4>>2];M=o&2047;d=p;if(d){r=g+8256|0;l=g- -64|0;s=g+24640|0;R=g+16448|0;while(1){G=u[(r+((o+754&2047)<<2)|0)+2>>1];J=u[r+((o+1206&2047)<<2)>>1];q=u[(l+((o+1602&2047)<<2)|0)+2>>1];V=u[l+((o+1750&2047)<<2)>>1];F=s+((o+22&2047)<<2)|0;m=u[F+2>>1];F=u[F>>1];I=s+((o+502&2047)<<2)|0;H=u[I+2>>1];N=u[E>>1];W=u[E+2>>1];I=u[I>>1];Y=Lb(u[g+32>>1]-I|0,-32768,32767);Z=u[g+24>>1];$=Lb(u[g+34>>1]-H|0,-32768,32767);aa=u[g+26>>1];ba=Lb(u[g+36>>1]-F|0,-32768,32767);ca=u[g+28>>1];fa=Lb(u[g+38>>1]-m|0,-32768,32767);ga=u[g+30>>1];Na=g,Oa=Sc(Lb((B(Y,Z)|0)/65536<<1,-32768,32767)+I|0),u[Na+32>>1]=Oa;Na=g,Oa=Sc(Lb((B($,aa)|0)/65536<<1,-32768,32767)+H|0),u[Na+34>>1]=Oa;Na=g,Oa=Sc(Lb((B(ba,ca)|0)/65536<<1,-32768,32767)+F|0),u[Na+36>>1]=Oa;Na=g,Oa=Sc(Lb((B(fa,ga)|0)/65536<<1,-32768,32767)+m|0),u[Na+38>>1]=Oa;m=Lb((B(u[g+32>>1],u[g+16>>1])|0)/32768|0,-32768,32767);H=Lb((B(u[g+38>>1],u[g+22>>1])|0)/32768|0,-32768,32767);F=Lb(m+((N|0)/4<<16>>16)|0,-32768,32767);H=Lb(H+((W|0)/4<<16>>16)|0,-32768,32767);I=Lb(F+((B(V,u[g+8>>1])|0)/-65536|0)|0,-32768,32767);m=M<<2;N=m+l|0;W=Lb(H+((B(q,u[g+10>>1])|0)/-65536|0)|0,-32768,32767);u[N+2>>1]=W;u[N>>1]=I;V=Lb(V+((B(I,u[g+8>>1])|0)/65536|0)|0,-32768,32767);I=m+R|0;q=Lb(q+((B(W,u[g+10>>1])|0)/65536|0)|0,-32768,32767);u[I+2>>1]=q;u[I>>1]=V;V=Lb(F+V|0,-32768,32767);F=Lb(q+H|0,-32768,32767);q=R+((o+426&2047)<<2)|0;H=u[q+2>>1];I=u[q>>1];o=R+((o+682&2047)<<2)|0;N=u[o+2>>1];W=u[o>>1];o=Lb((B(N,u[g+42>>1])+B(W,u[g+40>>1])|0)/32768|0,-32768,32767);q=Lb((B(H,u[g+46>>1])+B(I,u[g+44>>1])|0)/32768|0,-32768,32767);W=Lb(Lb(V+W|0,-32768,32767)-o|0,-32768,32767);N=Lb(Lb(F+N|0,-32768,32767)-q|0,-32768,32767);V=Lb(Lb(I+V|0,-32768,32767)-o|0,-32768,32767);F=Lb(Lb(F+H|0,-32768,32767)-q|0,-32768,32767);o=Lb(o+((B(J,u[g+8>>1])|0)/-65536|0)|0,-32768,32767);H=u[g+8>>1];I=u[g+10>>1];Y=m+r|0;q=Lb(q+((B(G,u[g+10>>1])|0)/-65536|0)|0,-32768,32767);u[Y+2>>1]=q;u[Y>>1]=o;da=J;J=(B(o,H)|0)/65536|0;o=Lb(da+J|0,-32768,32767);m=m+s|0;q=(B(q,I)|0)/65536|0;G=Lb(q+G|0,-32768,32767);u[m+2>>1]=G;u[m>>1]=o;o=Lb(o+W|0,-32768,32767);Na=h,Oa=(v[h>>2]+B(o,u[g+48>>1])|0)+B(Lb(G+N|0,-32768,32767),u[g+50>>1])|0,v[Na>>2]=Oa;o=Lb(Lb(J,-32768,32767)+V|0,-32768,32767);m=u[g+52>>1];q=Lb(q,-32768,32767);Na=h,Oa=(v[h+4>>2]+B(m,o)|0)+B(Lb(q+F|0,-32768,32767),u[g+54>>1])|0,v[Na+4>>2]=Oa;h=h+8|0;E=E+4|0;o=M+1|0;M=o&2047;d=d-1|0;if(d){continue}break}}v[g+4>>2]=M;h=p+v[j+4180>>2]&4095;v[j+4180>>2]=h;d=p+v[j+4172>>2]&8191;v[j+4172>>2]=d;c=(p<<3)+c|0;k=k-p|0;if(k){continue}break}}v[j+4172>>2]=d&8191;d=a;h=e;e=0;n=0;g=j;k=v[g+4160>>2];o=v[g+4156>>2];c=b;if(b){a=v[g+4164>>2];i=v[g+4168>>2];while(1){e=v[d>>2];n=v[d+4>>2];i=i-n|0;i=(((i|0)/1024|0)-i|0)+k|0;v[h+4>>2]=i+v[h+4>>2];a=a-e|0;a=(((a|0)/1024|0)-a|0)+o|0;v[h>>2]=a+v[h>>2];k=i+((i|0)/-512|0)|0;o=a+((a|0)/-512|0)|0;h=h+8|0;d=d+8|0;i=n;a=e;c=c-1|0;if(c){continue}break}}v[g+4168>>2]=n;v[g+4164>>2]=e;v[g+4160>>2]=k;v[g+4156>>2]=o;Qd:{if(v[j+4116>>2]){v[j+4120>>2]=v[j+4124>>2];break Qd}a=v[j+4120>>2];if(a>>>0>b>>>0){v[j+4120>>2]=a-b;break Qd}SL(j);v[j+4120>>2]=0}v[j+4116>>2]=0}if(v[K+946300>>2]){o=0;E=0;e=f;d=f<<2;g=K;r=x[g+480214>>1]!=0;a=g+1074332|0;X=z[a>>2];wa=z[a+4>>2];while(1){h=(g+B(o,160)|0)+906300|0;a=v[h>>2];Rd:{if(!a|!v[a+24>>2]){break Rd}if(!ki(a+44|0)){break Rd}a=v[h>>2];if(!(kb[v[v[a>>2]+112>>2]](a)|0)){kb[v[v[a>>2]+108>>2]](a,1);kb[v[v[a>>2]+120>>2]](a)}c=a+44|0;b=Md(c,0);c=Md(c,1);Sd:{if(t[a+28|0]&1){$A(v[a+24>>2],b,c,e,X);break Sd}j=a+40|0;if(v[a+36>>2]?1:v[j>>2]){So(v[a+24>>2],e,j,a+36|0);$A(v[a+24>>2],b,c,e,X);break Sd}Qb(b,0,d);Qb(c,0,d)}v[a+28>>2]=v[a+28>>2]&-2;if(rw(h)){break Rd}r=!(w[a+28|0]&4)|r}o=o+1|0;if((o|0)!=250){continue}break}n=g+12|0;h=g+12300|0;j=g+14348|0;$A(n,h,j,e,X);a=g+1074476|0;m=w[a|0];t[a|0]=0;a=h;c=j;while(1){i=(g+B(E,160)|0)+906300|0;b=v[i>>2];Td:{if(!b|!v[b+24>>2]){break Td}if(!ki(b+44|0)){break Td}k=v[i>>2];Ud:{if(rw(i)){break Ud}b=v[i>>2];if(kb[v[v[b>>2]+144>>2]](b)|w[v[i>>2]+28|0]&2){break Ud}o=0;if(!E){break Td}while(1){if((Sk((g+B(o,160)|0)+906300|0)|0)==(E|0)){break Ud}o=o+1|0;if((E|0)!=(o|0)){continue}break}break Td}b=k+44|0;l=Md(b,0);R=Md(b,1);p=v[i>>2];s=(a|0)==(l|0);a=s?h:a;b=a;c=s?j:c;d=c;Vd:{if(!(w[i+28|0]|w[i+29|0]<<8|(w[i+30|0]<<16|w[i+31|0]<<24))){break Vd}b=a;o=Sk(i);d=c;if((o|0)==255){break Vd}d=c;if(o>>>0<=E>>>0){break Vd}o=v[(g+B(o,160)|0)+906300>>2];d=c;if(!o){break Vd}if(!(w[p+28|0]&4)){kb[v[v[o>>2]+148>>2]](o)}o=o+44|0;d=c;if(!ki(o)){break Vd}b=Md(o,0);d=Md(o,1)}Wd:{if(!rw(i)){break Wd}Xd:{if(s){break Xd}o=0;if(!e){break Xd}while(1){s=o<<2;q=s+l|0;G=q;X=z[q>>2];q=a+s|0;z[G>>2]=X+z[q>>2];A=s+R|0;s=c+s|0;z[A>>2]=z[A>>2]+z[s>>2];v[q>>2]=0;v[s>>2]=0;o=o+1|0;if((e|0)!=(o|0)){continue}break}}c=d;a=b;if(!(r&1)){break Wd}a=v[i>>2];if(a){kb[v[v[a>>2]+148>>2]](a)}a=b;o=Sk(i);if(o>>>0>249|o>>>0<=E>>>0){break Wd}while(1){c=o&255;a=(g+B(c,160)|0)+906300|0;o=Sk(a);a=v[a>>2];if(a){kb[v[v[a>>2]+148>>2]](a)}if(c>>>0<o>>>0?o>>>0<=249:0){continue}break}c=d;a=b}Yd:{Zd:{if(!((w[i+24|0]&2)>>>1|0)){if(!aF(i)|!(w[p+28|0]&4)){break Zd}}o=0;if(!e){break Yd}while(1){i=o<<2;k=i+b|0;z[k>>2]=z[k>>2]+z[i+l>>2];k=d+i|0;z[k>>2]=z[k>>2]+z[i+R>>2];o=o+1|0;if((e|0)!=(o|0)){continue}break}break Yd}if(m){kb[v[v[k>>2]+128>>2]](k)}kb[v[v[k>>2]+60>>2]](k,b,d,e);v[p+32>>2]=e+v[p+32>>2];if(!aF(i)){break Yd}if((kb[v[v[k>>2]+156>>2]](k)|0)<1|y[p+32>>2]<v[g+24620>>2]<<2>>>0){break Yd}o=0;_d:{if(!e){break _d}while(1){$d:{i=o<<2;X=z[i+b>>2];if(X>=C(1.1920928955078125e-7)|X<=C(-1.1920928955078125e-7)){break $d}X=z[d+i>>2];if(X>=C(1.1920928955078125e-7)|!(X>C(-1.1920928955078125e-7))){break $d}o=o+1|0;if((e|0)!=(o|0)){continue}break _d}break}v[p+32>>2]=0;break Yd}v[p+28>>2]=v[p+28>>2]|4}v[p+28>>2]=v[p+28>>2]&-3}E=E+1|0;if((E|0)!=250){continue}break}ae:{if(!e){break ae}b=1;while(1){d=n;X=C(z[a>>2]*wa);be:{if(C(D(X))<C(2147483648)){h=~~X;break be}h=-2147483648}v[d>>2]=h;d=n;X=C(z[c>>2]*wa);ce:{if(C(D(X))<C(2147483648)){h=~~X;break ce}h=-2147483648}v[d+4>>2]=h;if((b|0)==(e|0)){break ae}n=n+8|0;c=c+4|0;a=a+4|0;b=b+1|0;continue}}}if(v[K+24624>>2]==1){a=ea;g=0;b=f;if(b){while(1){c=g<<3;v[a+(g<<2)>>2]=(v[a+(c|4)>>2]+v[a+c>>2]|0)/2;g=g+1|0;if((b|0)!=(g|0)){continue}break}}}if(w[za+33|0]){b=f;h=gb-16|0;gb=h;de:{ee:{a=K;fe:{if(!v[a+1074376>>2]){d=a+1074460|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074468>>2]=v[a+1074456>>2];break fe}e=v[a+1074468>>2];c=v[a+1074456>>2];ge:{if((e|0)==(c|0)){g=v[a+1074460>>2];break ge}v[a+1074468>>2]=c;d=a+24604|0;i=a+1074460|0;he:{if((c|0)>(e|0)){g=RS(d);break he}g=QS(d)}v[i>>2]=g;v[a+1074464>>2]=g}d=a+1074460|0;if((g|0)>=1){break ee}}k=0;break de}e=(v[a+1074468>>2]<<12)-v[a+1074472>>2]|0;k=(e|0)/(g|0)|0;if(w[a+1074368|0]!=2){break de}v[h+12>>2]=50;c=a+1074464|0;v[h+8>>2]=1e4/(v[c>>2]+1|0);j=v[Nf(h+12|0,h+8|0)>>2];g=k>>31;if((j|0)>=(g+k^g)){break de}i=v[c>>2];g=v[d>>2];while(1){g=g+i|0;k=(e|0)/(g|0)|0;c=k>>31;if((j|0)<(c^c+k)){continue}break}v[d>>2]=g}ie:{je:{switch(v[a+24624>>2]-1|0){case 0:if((b|0)<1){break ie}c=v[a+1074456>>2];i=c<<12;e=c;p=c>>31;g=a+12|0;c=0;while(1){ke:{if(v[d>>2]>=1){j=v[a+1074472>>2]+k|0;v[a+1074472>>2]=j;n=v[g>>2];Na=g,Oa=zc(nqa(mqa(n,n>>31,j,j>>31),jb,1048576,0),jb),v[Na>>2]=Oa;v[a+1074460>>2]=v[a+1074460>>2]-1;break ke}j=v[g>>2];Na=g,Oa=zc(nqa(mqa(j,j>>31,e,p),jb,256,0),jb),v[Na>>2]=Oa;v[a+1074472>>2]=i}g=g+4|0;c=c+1|0;if((b|0)!=(c|0)){continue}break};break ie;case 1:if((b|0)<1){break ie}c=v[a+1074456>>2];p=c<<12;e=c;j=c>>31;g=a+12|0;c=0;while(1){le:{if(v[d>>2]>=1){i=v[a+1074472>>2]+k|0;v[a+1074472>>2]=i;n=v[g>>2];Na=g,Oa=zc(nqa(mqa(n,n>>31,i,i>>31),jb,1048576,0),jb),v[Na>>2]=Oa;i=v[a+1074472>>2];n=i;r=i>>31;i=v[g+4>>2];Na=g,Oa=zc(nqa(mqa(n,r,i,i>>31),jb,1048576,0),jb),v[Na+4>>2]=Oa;v[a+1074460>>2]=v[a+1074460>>2]-1;break le}i=v[g>>2];Na=g,Oa=zc(nqa(mqa(i,i>>31,e,j),jb,256,0),jb),v[Na>>2]=Oa;i=v[g+4>>2];Na=g,Oa=zc(nqa(mqa(i,i>>31,e,j),jb,256,0),jb),v[Na+4>>2]=Oa;v[a+1074472>>2]=p}g=g+8|0;c=c+1|0;if((b|0)!=(c|0)){continue}break};break ie;case 3:break je;default:break ie}}if((b|0)<1){break ie}c=v[a+1074456>>2];p=c<<12;e=c;j=c>>31;g=a+12|0;c=a+8204|0;E=0;while(1){me:{if(v[d>>2]>=1){i=v[a+1074472>>2]+k|0;v[a+1074472>>2]=i;n=v[g>>2];Na=g,Oa=zc(nqa(mqa(n,n>>31,i,i>>31),jb,1048576,0),jb),v[Na>>2]=Oa;i=v[a+1074472>>2];n=i;r=i>>31;i=v[g+4>>2];Na=g,Oa=zc(nqa(mqa(n,r,i,i>>31),jb,1048576,0),jb),v[Na+4>>2]=Oa;i=v[a+1074472>>2];n=i;r=i>>31;i=v[c>>2];Na=c,Oa=zc(nqa(mqa(n,r,i,i>>31),jb,1048576,0),jb),v[Na>>2]=Oa;i=v[a+1074472>>2];n=i;r=i>>31;i=v[c+4>>2];Na=c,Oa=zc(nqa(mqa(n,r,i,i>>31),jb,1048576,0),jb),v[Na+4>>2]=Oa;v[a+1074460>>2]=v[a+1074460>>2]-1;break me}i=v[g>>2];Na=g,Oa=zc(nqa(mqa(i,i>>31,e,j),jb,256,0),jb),v[Na>>2]=Oa;i=v[g+4>>2];Na=g,Oa=zc(nqa(mqa(i,i>>31,e,j),jb,256,0),jb),v[Na+4>>2]=Oa;i=v[c>>2];Na=c,Oa=zc(nqa(mqa(i,i>>31,e,j),jb,256,0),jb),v[Na>>2]=Oa;i=v[c+4>>2];Na=c,Oa=zc(nqa(mqa(i,i>>31,e,j),jb,256,0),jb),v[Na+4>>2]=Oa;v[a+1074472>>2]=p}c=c+8|0;g=g+8|0;E=E+1|0;if((b|0)!=(E|0)){continue}break}}gb=h+16|0}if(v[qa>>2]!=128){c=K+12|0;d=K+8204|0;a=f;b=v[K+24604>>2];e=v[K+24624>>2];ne:{if((b|0)==128|e>>>0<2){break ne}rO(c,a,b);if(e>>>0<4){break ne}rO(d,a,b)}}if(v[K+24624>>2]==4){a=ea;b=ya;g=f-1|0;if((g|0)>-1){while(1){c=g<<4;d=g<<3;e=d|4;v[a+(c|12)>>2]=v[e+b>>2];v[a+(c|8)>>2]=v[b+d>>2];v[a+(c|4)>>2]=v[a+e>>2];v[a+c>>2]=v[a+d>>2];c=(g|0)>0;g=g-1|0;if(c){continue}break}}}if(w[_+20|0]){b=v[_+16>>2];a=ig(T+72|0,ea,v[K+24624>>2],f);c=v[v[b>>2]+8>>2];v[T+24>>2]=v[a+8>>2];d=v[a+4>>2];v[T+16>>2]=v[a>>2];v[T+20>>2]=d;kb[c|0](b,T+16|0)}a=ig(T+56|0,ea,v[K+24624>>2],f);b=v[v[pa>>2]+8>>2];v[T+8>>2]=v[a+8>>2];c=v[a+4>>2];v[T>>2]=v[a>>2];v[T+4>>2]=c;kb[b|0](pa,T);a=v[K+1074380>>2]-f|0;v[K+1074380>>2]=a;v[K+1074376>>2]=f+v[K+1074376>>2];xa=f+xa|0;i=v[K+480208>>2];if(i&512){break j}ia=ia-f|0;if(ia){continue}break}}gb=T+128|0;gb=_+48|0;return xa}function Ioa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;d=gb-480|0;gb=d;vc(b);f=gb-32|0;gb=f;h=d+288|0;Jr(f+24|0,h);j=xb(f+24|0);e=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=e;v[f>>2]=i;v[f+4>>2]=e;e=b;fc(f+16|0,e,f);i=xb(f+16|0);if((i|0)==(j|0)){Yb(e,xb(f+24|0))}gb=f+32|0;e=(i|0)==(j|0);if(!e){SW(h)}a:{b:{c:{if(!e){break c}if(!mX(d+288|0)){break c}if(!Pb(b,Uc(lX(d+288|0),jb))){break c}if(!c){g=1;break c}Gd(a,32);t[d+287|0]=0;j=Kb(d+272|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{if(v[d+288>>2]==778924148){v[22640]=0;R(578,a|0,16777216);e=v[22640];v[22640]=0;if((e|0)==1){break b}v[22640]=0;e=T(232,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}v[22640]=0;Q(227,b|0,e-4|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}v[22640]=0;s=T(229,b|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){break G}break b}H:{I:{J:{K:{L:{M:{if((w[d+328|0]|w[d+329|0]<<8)>>>0<2185|(w[d+328|0]|w[d+329|0]<<8)>>>0>4095){break M}v[22640]=0;e=T(232,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}v[22640]=0;Q(227,b|0,e-4|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}v[22640]=0;s=T(229,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}if(s>>>0<256){break M}v[22640]=0;e=T(232,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}if(e>>>0<=s>>>0){break M}v[22640]=0;e=Q(227,b|0,s|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}if(!e){break M}v[22640]=0;e=T(579,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}if(!e){break M}v[22640]=0;R(578,a|0,16777216);e=v[22640];v[22640]=0;if((e|0)==1){break b}if((w[d+328|0]|w[d+329|0]<<8)>>>0>=4096){v[22640]=0;b=Q(2,d+88|0,13627)|0;c=v[22640];v[22640]=0;if((c|0)==1){break F}v[22640]=0;U(580,a|0,1,b|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(b);break d}a=P()|0;O()|0;vb(b);break a}if((w[d+328|0]|w[d+329|0]<<8)>>>0<2194){break M}v[22640]=0;e=Q(2,d+88|0,13156)|0;f=v[22640];v[22640]=0;if((f|0)==1){break L}v[22640]=0;U(580,a|0,4,e|0);f=v[22640];v[22640]=0;if((f|0)==1){break K}vb(e)}if(v[a+480180>>2]!=32){break G}if(((w[d+328|0]|w[d+329|0]<<8)&61440)!=20480){break H}e=(w[d+328|0]|w[d+329|0]<<8)&4095;g=e<<16;if(v[d+348>>2]!=1414548815){break J}t[d+287|0]=1;break I}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e);break a}if(e>>>0<297){break I}g=w[d+348|0]|w[d+349|0]<<8|g}v[a+1074308>>2]=g;break G}if(!((w[d+328|0]|w[d+329|0]<<8)!=2184?(w[d+330|0]|w[d+331|0]<<8)!=2184:0)){t[d+287|0]=1;v[a+1074308>>2]=18284544;break G}if(!((w[d+328|0]|w[d+329|0]<<8)!=535|(w[d+330|0]|w[d+331|0]<<8)!=512|(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)))){v[22640]=0;e=qv(d+352|0,255,64);f=v[22640];v[22640]=0;if((f|0)==1){break b}N:{if(e){v[a+1074308>>2]=18219008;v[22640]=0;g=Q(2,d+88|0,12035)|0;e=v[22640];v[22640]=0;if((e|0)!=1){break N}a=P()|0;O()|0;break a}v[a+1074308>>2]=18284544;v[22640]=0;g=Q(2,d+88|0,13961)|0;e=v[22640];v[22640]=0;if((e|0)==1){break E}}Eb(j,g);vb(g);t[d+287|0]=1;break G}if(!((w[d+328|0]|w[d+329|0]<<8)!=532|(w[d+330|0]|w[d+331|0]<<8)!=514|(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)))){v[a+1074308>>2]=17367040;v[22640]=0;e=Q(2,d+88|0,11958)|0;f=v[22640];v[22640]=0;if((f|0)!=1){Eb(j,e);vb(e);t[d+287|0]=1;break G}a=P()|0;O()|0;break a}if((w[d+328|0]|w[d+329|0]<<8)!=768|(w[d+330|0]|w[d+331|0]<<8)!=768|(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)|(w[d+320|0]|w[d+321|0]<<8)!=256)){break G}if(w[d+341|0]|w[d+340|0]!=128){break G}v[a+1074308>>2]=18285088;t[d+287|0]=1}v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+332|0]|w[d+333|0]<<8)<<1&16;v[a+480208>>2]=v[a+480208>>2]&-5|(w[d+332|0]|w[d+333|0]<<8)>>>2&4;v[a+480208>>2]=v[a+480208>>2]&-9|(w[d+332|0]|w[d+333|0]<<8)>>>2&8;v[a+480208>>2]=v[a+480208>>2]&-32769|(w[d+332|0]|w[d+333|0]<<8)<<3&32768;v[22640]=0;Cp(d+200|0,3,d+288|4);e=v[22640];v[22640]=0;if((e|0)==1){break D}v[22640]=0;R(377,d+88|0,d+200|0);e=v[22640];v[22640]=0;if((e|0)==1){break D}Eb(a+1298268|0,d+88|0);vb(d+88|0);if(!(!(w[d+334|0]&4)|v[a+1074308>>2]-1>>>0<18285313)){v[a+480216>>2]=w[d+318|0];v[a+480220>>2]=w[d+319|0]}e=w[d+336|0];v[a+480200>>2]=e>>>0>128?256:e<<1;if(w[d+338|0]){v[a+480196>>2]=w[d+338|0]}t[d+88|0]=31;e=w[d+339|0];v[22640]=0;t[d+200|0]=e;e=Bf(d+88|0,d+200|0);f=v[22640];v[22640]=0;if((f|0)==1){break e}v[a+480204>>2]=B(w[e|0],1e4);t[d+88|0]=w[d+337|0];v[22640]=0;t[d+200|0]=128;e=ac(d+88|0,d+200|0);f=v[22640];v[22640]=0;if((f|0)==1){break f}v[a+480228>>2]=w[e|0];g=0;while(1){i=(d+288|0)+g|0;f=i- -64|0;O:{if(w[f|0]==255){break O}v[22640]=0;h=(g<<5)+a|0;e=h+480280|0;Se(e);k=v[22640];v[22640]=0;if((k|0)==1){break C}C=h+480286|0,D=Jd(w[i+128|0],0,64),u[C>>1]=D;if(t[f|0]<=-1){v[e>>2]=v[e>>2]|1024}f=w[f|0]&127;if(f>>>0<=64){u[h+480284>>1]=f<<2;break O}if((f|0)!=100){break O}v[e>>2]=v[e>>2]|256}g=g+1|0;if((g|0)!=64){continue}break}v[22640]=0;Q(227,b|0,192)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}P:{if(!(v[a+480180>>2]!=16777216|(w[d+328|0]|w[d+329|0]<<8)>>>0<2187|(w[d+328|0]|w[d+329|0]<<8)>>>0>2189)){g=0;v[22640]=0;e=T(319,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break B}if(e){break d}v[22640]=0;e=T(229,b|0)|0;f=v[22640];v[22640]=0;Q:{if((f|0)==1){break Q}if(e>>>0>4e3){break d}f=Rb(a+484360|0);v[22640]=0;e=W(583,f|0,b|0,e|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break Q}if(!e){break d}break P}a=P()|0;O()|0;break a}e=Rb(a+484360|0);f=w[d+320|0]|w[d+321|0]<<8;v[22640]=0;ga(540,e|0,b|0,f|0,255,254)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}}q=nc(d+256|0);o=nc(d+240|0);m=nc(d+224|0);e=w[d+322|0]|w[d+323|0]<<8;g=0;v[22640]=0;e=W(584,b|0,q|0,e|0)|0;f=v[22640];v[22640]=0;R:{if((f|0)==1){break R}if(!e){break z}e=w[d+324|0]|w[d+325|0]<<8;v[22640]=0;e=W(584,b|0,o|0,e|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break R}if(!e){break z}e=w[d+326|0]|w[d+327|0]<<8;v[22640]=0;e=W(584,b|0,m|0,e|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break R}if(!e){break z}v[d+220>>2]=-1;C=d,D=Sb(q),v[C+88>>2]=D;C=d,D=Wb(q),v[C+200>>2]=D;if(!Gb(d+88|0,d+200|0)){break A}while(1){e=v[d+88>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+220>>2])){v[d+220>>2]=e}Fg(d+88|0);if(Gb(d+88|0,d+200|0)){continue}break}break A}a=P()|0;O()|0;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}C=d,D=Sb(o),v[C+88>>2]=D;C=d,D=Wb(o),v[C+200>>2]=D;if(Gb(d+88|0,d+200|0)){while(1){e=v[d+88>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+220>>2])){v[d+220>>2]=e}Fg(d+88|0);if(Gb(d+88|0,d+200|0)){continue}break}}C=d,D=Sb(m),v[C+88>>2]=D;C=d,D=Wb(m),v[C+200>>2]=D;if(Gb(d+88|0,d+200|0)){while(1){e=v[d+88>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+220>>2])){v[d+220>>2]=e}Fg(d+88|0);if(Gb(d+88|0,d+200|0)){continue}break}}S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{if(t[d+334|0]&1){e=w[d+344|0]|w[d+345|0]<<8|(w[d+346|0]<<16|w[d+347|0]<<24);v[22640]=0;v[d+88>>2]=e;e=Fb(d+220|0,d+88|0);f=v[22640];v[22640]=0;if((f|0)==1){break ba}v[d+220>>2]=v[e>>2]}e=0;ca:{if((w[d+330|0]|w[d+331|0]<<8)!=532|(w[d+328|0]|w[d+329|0]<<8?(w[d+328|0]|w[d+329|0]<<8)!=532:0)|(w[d+319|0]|w[d+318|0])){break ca}if(w[d+332|0]&192|(w[d+341|0]|(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)))){break ca}da:{if(!(w[d+324|0]|w[d+325|0]<<8)|(w[d+322|0]|w[d+323|0]<<8)){break da}if((v[b+8>>2]+(Nb(o)<<2)|0)+2>>>0>y[d+220>>2]){break da}if(w[d+324|0]|w[d+325|0]<<8){while(1){v[22640]=0;f=T(229,b|0)|0;g=v[22640];v[22640]=0;ea:{if((g|0)!=1){if(!f){break ea}lg(b,((e&65535)<<2)+4|0);break da}a=P()|0;O()|0;break g}e=e+1|0;if((e&65535)>>>0<(w[d+324|0]|w[d+325|0]<<8)>>>0){continue}break}}v[22640]=0;e=Q(2,d+88|0,12179)|0;f=v[22640];v[22640]=0;if((f|0)==1){break $}Eb(j,e);vb(e)}e=1;if(w[d+328|0]|w[d+329|0]<<8){break ca}v[22640]=0;f=Q(2,d+88|0,12576)|0;g=v[22640];v[22640]=0;if((g|0)==1){break _}Eb(j,f);vb(f)}fa:{if(w[d+334|0]&2){v[22640]=0;f=T(319,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break Z}v[22640]=0;g=f<<3;h=Q(228,b|0,g|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break Z}if(!(!h|y[d+220>>2]<g+v[b+8>>2]>>>0)){v[22640]=0;g=a+1298368|0;R(585,g|0,f|0);h=v[22640];v[22640]=0;if((h|0)==1){break Z}C=d,D=Sb(g),v[C+200>>2]=D;C=d,D=Wb(g),v[C+176>>2]=D;if(Gb(d+200|0,d+176|0)){while(1){g=v[d+200>>2];v[22640]=0;R(586,b|0,d+88|0);h=v[22640];v[22640]=0;if((h|0)==1){break Y}v[22640]=0;KE(d+88|0,g);g=v[22640];v[22640]=0;if((g|0)==1){break Y}v[d+200>>2]=v[d+200>>2]+48;if(Gb(d+200|0,d+176|0)){continue}break}}if(!(!f&e)){break fa}if(w[d+334|0]&4){v[22640]=0;e=Q(2,d+88|0,12609)|0;f=v[22640];v[22640]=0;if((f|0)!=1){Eb(j,e);vb(e);break fa}a=P()|0;O()|0;break g}v[22640]=0;e=Q(2,d+88|0,12201)|0;f=v[22640];v[22640]=0;if((f|0)!=1){Eb(j,e);vb(e);break fa}a=P()|0;O()|0;break g}lg(b,2);break fa}if(!e|(w[d+334|0]|w[d+335|0]<<8)>>>0>1){break fa}v[22640]=0;e=T(319,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break aa}if(!e){v[22640]=0;e=Q(2,d+88|0,12179)|0;f=v[22640];v[22640]=0;if((f|0)!=1){Eb(j,e);vb(e);break fa}a=P()|0;O()|0;break g}lg(b,2)}ga:{if(!(w[d+334|0]&8?1:w[d+332|0]&128)){break ga}v[22640]=0;e=a+901404|0;f=Q(588,b|0,e|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break h}if(!f){break ga}v[22640]=0;Bu(e);e=v[22640];v[22640]=0;if((e|0)==1){break h}}if((w[d+328|0]|w[d+329|0]<<8)>>>0<=531){v[22640]=0;To(a+901404|0);e=v[22640];v[22640]=0;if((e|0)==1){break h}}v[22640]=0;z=T(251,d+200|0)|0;e=v[22640];v[22640]=0;ha:{ia:{ja:{ka:{la:{ma:{if((e|0)!=1){v[22640]=0;e=Q(575,b|0,11215)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ma}if(e){v[22640]=0;e=T(229,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break la}v[22640]=0;U(320,d+88|0,b|0,e|0);e=v[22640];v[22640]=0;if((e|0)==1){break la}od(z,d+88|0);yb(d+88|0)}u[a+480188>>1]=1;v[22640]=0;e=Q(575,b|0,11220)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ma}if(e){v[22640]=0;e=T(229,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ka}v[22640]=0;U(320,d+88|0,b|0,e|0);e=v[22640];v[22640]=0;if((e|0)==1){break ka}v[22640]=0;e=T(232,d+88|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ja}v[22640]=0;u[d+176>>1]=(e>>>0)/20;e=Oc(29236,d+176|0);f=v[22640];v[22640]=0;if((f|0)==1){break ja}e=x[e>>1];u[a+480188>>1]=e;if(e){g=0;while(1){v[22640]=0;W(591,d+88|0,((g<<5)+a|0)+480289|0,20)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ja}g=g+1|0;if((e|0)!=(g|0)){continue}break}}yb(d+88|0)}if(y[b+8>>2]>y[d+220>>2]){break ia}g=v[d+220>>2]-v[b+8>>2]|0;break ha}a=P()|0;O()|0;break g}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;yb(d+88|0);break i}v[22640]=0;g=T(492,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break X}}v[22640]=0;U(320,d+176|0,b|0,g|0);e=v[22640];v[22640]=0;if((e|0)==1){break X}v[22640]=0;A=Q(592,a|0,d+176|0)|0;e=v[22640];v[22640]=0;na:{oa:{if((e|0)==1){break oa}if(!(t[d+334|0]&1)|!(w[d+342|0]|w[d+343|0]<<8)){break na}e=w[d+344|0]|w[d+345|0]<<8|(w[d+346|0]<<16|w[d+347|0]<<24);v[22640]=0;e=Q(227,b|0,e|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break oa}if(!e){break na}e=w[d+342|0]|w[d+343|0]<<8;v[22640]=0;ca(532,a+1298292|0,b|0,e|0,4)|0;e=v[22640];v[22640]=0;if((e|0)!=1){break na}}a=P()|0;O()|0;break j}g=0;u[a+480192>>1]=0;if(w[d+332|0]&4){u[d+88>>1]=w[d+322|0]|w[d+323|0]<<8;v[22640]=0;u[d+72>>1]=255;e=Oc(d+88|0,d+72|0);f=v[22640];v[22640]=0;if((f|0)==1){break W}u[a+480192>>1]=x[e>>1]}pa:{qa:{ra:{sa:{if(x[a+480192>>1]){while(1){e=Mb(q,g);ta:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break ta}e=Mb(q,g);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[22640]=0;e=Q(227,b|0,e|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break sa}if(!e){break ta}v[22640]=0;e=Q(228,b|0,554)|0;f=v[22640];v[22640]=0;if((f|0)==1){break sa}if(!e){break ta}v[22640]=0;e=W(415,a|0,g+1&65535,0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ra}if(!e){break ta}f=w[d+330|0]|w[d+331|0]<<8;v[22640]=0;ca(593,a|0,b|0,e|0,f|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ra}t[e+33|0]=w[d+341|0]}g=g+1|0;if(g>>>0<x[a+480192>>1]){continue}break}}v[d+172>>2]=0;if(w[d+324|0]|w[d+325|0]<<8){e=Mb(o,(w[d+324|0]|w[d+325|0]<<8)-1|0);v[d+172>>2]=(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+80}u[d+88>>1]=w[d+324|0]|w[d+325|0]<<8;v[22640]=0;u[d+72>>1]=3999;e=Oc(d+88|0,d+72|0);f=v[22640];v[22640]=0;if((f|0)==1){break qa}u[a+480190>>1]=x[e>>1];g=0;if(x[a+480190>>1]){break pa}f=0;h=0;break S}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}k=c&2;p=d+108|0;h=0;f=0;while(1){e=Mb(o,g);ua:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break ua}e=Mb(o,g);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[22640]=0;e=Q(227,b|0,e|0)|0;i=v[22640];v[22640]=0;va:{wa:{xa:{ya:{za:{Aa:{Ba:{if((i|0)==1){break Ba}if(!e){break ua}v[22640]=0;e=Q(594,b|0,d+88|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break Ba}if(!e){break ua}v[22640]=0;l=g+1|0;e=B(l,104)+a|0;i=e+484380|0;r=Q(595,d+88|0,i|0)|0;n=v[22640];v[22640]=0;if((n|0)==1){break Aa}v[22640]=0;Cp(d+56|0,3,p);n=v[22640];v[22640]=0;if((n|0)==1){break za}v[22640]=0;R(377,d+72|0,d+56|0);n=v[22640];v[22640]=0;if((n|0)==1){break za}v[22640]=0;Q(333,((l<<5)+a|0)+946304|0,d+72|0)|0;n=v[22640];v[22640]=0;if((n|0)==1){break ya}vb(d+72|0);v[22640]=0;r=Q(227,b|0,r|0)|0;n=v[22640];v[22640]=0;if((n|0)==1){break Aa}if(!r){break ua}e=x[e+484414>>1];if(!(e&512)){break xa}v[22640]=0;e=Q(596,b|0,d+72|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){if(!e){break wa}v[d+8>>2]=v[d+80>>2];v[22640]=0;e=v[d+76>>2];v[d>>2]=v[d+72>>2];v[d+4>>2]=e;U(597,i|0,1,d|0);e=v[22640];v[22640]=0;if((e|0)!=1){break wa}}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(d+72|0);break j}if(!(e&16384)){e=w[d+328|0]|w[d+329|0]<<8;v[22640]=0;LE(d+72|0,d+88|0,e);e=v[22640];v[22640]=0;if((e|0)==1){break T}Ca:{if(k){e=0;v[22640]=0;W(363,d+72|0,i|0,b|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){break Ca}break T}e=1;f=w[d+75|0];if(f>>>0>18){break Ca}f=1<<f;Da:{if(!(f&126991)){if(f&396800){break Da}break Ca}if(!w[d+72|0]){break Ca}}e=v[i>>2];v[22640]=0;f=pv(d+72|0,e);e=v[22640];v[22640]=0;if((e|0)==1){break T}e=0;v[22640]=0;Q(350,b|0,f|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break T}}if(w[d+75|0]!=1){break va}h=v[i>>2]!=0|h;break va}v[22640]=0;Q(600,b|0,d+52|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break U}e=v[d+52>>2];if(!(!k|!e)){e=Kb(d+72|0);v[22640]=0;W(441,b|0,e|0,v[d+52>>2])|0;f=v[22640];v[22640]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((f|0)!=1){v[22640]=0;R(601,d+40|0,13549);f=v[22640];v[22640]=0;if((f|0)==1){break Ka}v[d+36>>2]=l;v[22640]=0;U(13,d+24|0,0,e|0);f=v[22640];v[22640]=0;if((f|0)==1){break Ja}v[22640]=0;Y(602,d+56|0,d+40|0,d+36|0,d+24|0);f=v[22640];v[22640]=0;if((f|0)==1){break Ia}v[22640]=0;U(580,a|0,2,d+56|0);f=v[22640];v[22640]=0;if((f|0)==1){break Ha}vb(d+56|0);vb(d+24|0);Hb(d+40|0);vb(e);break wa}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;break Fa}a=P()|0;O()|0;break Ga}a=P()|0;O()|0;vb(d+56|0)}vb(d+24|0)}Hb(d+40|0)}vb(e);break j}v[22640]=0;Q(350,b|0,e|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break U}}e=0}f=v[b+8>>2];v[22640]=0;v[d+72>>2]=f;f=Jc(d+172|0,d+72|0);i=v[22640];v[22640]=0;if((i|0)==1){break V}v[d+172>>2]=v[f>>2];f=(e|0)!=0}g=g+1|0;if(g>>>0<x[a+480190>>1]){continue}break}break S}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}u[d+88>>1]=1;e=x[a+480190>>1];v[22640]=0;u[d+72>>1]=e;e=Ie(d+88|0,d+72|0);g=v[22640];v[22640]=0;La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((g|0)!=1){u[a+480190>>1]=x[e>>1];Va:{if(!(h&1)|(w[d+328|0]|w[d+329|0]<<8)!=516|(w[d+334|0]|w[d+335|0]<<8|(w[d+330|0]|w[d+331|0]<<8)!=512)){break Va}if(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)|((w[d+332|0]|w[d+333|0]<<8)&65527)!=21|(w[d+336|0]!=128|w[d+337|0]!=48)){break Va}if(w[d+341|0]|w[d+340|0]!=128|(w[d+342|0]|w[d+343|0]<<8)){break Va}h=d+416|0;e=d+352|0;g=1;while(1){g=(w[e|0]|128)!=160?0:g;e=e+1|0;if((h|0)!=(e|0)){continue}break}h=d+480|0;e=d+416|0;while(1){g=w[e|0]==64&g;e=e+1|0;if((h|0)!=(e|0)){continue}break}e=20;while(1){g=!w[(d+e|0)+292|0]&g;e=e+1|0;if((e|0)!=26){continue}break}if(!g){break Va}v[22640]=0;e=Q(2,d+88|0,7181)|0;g=v[22640];v[22640]=0;if((g|0)==1){break Ma}Eb(j,e);vb(e)}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;C=d,D=Nb(m),u[C+88>>1]=D;e=v[a+8>>2];v[22640]=0;e=Oc(d+88|0,e+10|0);g=v[22640];v[22640]=0;if((g|0)==1){break Ua}e=x[e>>1];u[d+52>>1]=e;if((Nb(m)|0)!=(e|0)){v[22640]=0;_(604,d+72|0);e=v[22640];v[22640]=0;if((e|0)==1){break Ta}e=Nb(m);v[22640]=0;v[d+56>>2]=e;Y(605,d+88|0,d+72|0,d+56|0,d+52|0);e=v[22640];v[22640]=0;if((e|0)==1){break Sa}v[22640]=0;U(580,a|0,2,d+88|0);e=v[22640];v[22640]=0;if((e|0)==1){break Ra}vb(d+88|0);Hb(d+72|0)}if(c&1){break Pa}u[d+52>>1]=0;break Oa}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Qa}a=P()|0;O()|0;vb(d+88|0)}Hb(d+72|0);break j}if(!x[d+52>>1]){break Oa}e=0;while(1){c=Mb(m,e);Wa:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break Wa}c=Mb(m,e);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22640]=0;c=Q(227,b|0,c|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break Na}if(!c){break Wa}v[22640]=0;c=T(319,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break k}v[22640]=0;i=T(319,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break l}if((i-1&65535)>>>0>1023){break Wa}v[22640]=0;g=Q(350,b|0,4)|0;h=v[22640];v[22640]=0;if((h|0)==1){break l}if(!g){break Wa}v[22640]=0;U(320,d+88|0,b|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break m}h=0;c=x[a+480188>>1];v[22640]=0;c=Q(606,d+72|0,c|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break o}while(1){Xa:{v[22640]=0;g=Q(228,d+88|0,1)|0;k=v[22640];v[22640]=0;Ya:{Za:{if((k|0)!=1){if(!g){break Xa}v[22640]=0;g=T(353,d+88|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break p}k=g<<24>>24;if(k){break Za}h=h+1|0;break Ya}break p}_a:{g=k&127;l=g?g-1|0:0;g=l&65535;if(pc(c)>>>0>g>>>0){break _a}v[22640]=0;t[d+56|0]=0;U(607,c|0,g+1|0,d+56|0);p=v[22640];v[22640]=0;if((p|0)!=1){break _a}break p}if((k|0)<=-1){v[22640]=0;k=T(353,d+88|0)|0;p=v[22640];v[22640]=0;if((p|0)==1){break p}C=kc(c,g),D=k,t[C|0]=D}if(!(!(w[kc(c,g)|0]&15)|g>>>0<x[a+480188>>1])){u[a+480188>>1]=l+1}if(t[kc(c,g)|0]&1){v[22640]=0;Q(350,d+88|0,1)|0;k=v[22640];v[22640]=0;if((k|0)==1){break p}}if(w[kc(c,g)|0]&2){v[22640]=0;Q(350,d+88|0,1)|0;k=v[22640];v[22640]=0;if((k|0)==1){break p}}if(w[kc(c,g)|0]&4){v[22640]=0;Q(350,d+88|0,1)|0;k=v[22640];v[22640]=0;if((k|0)==1){break p}}if(!(w[kc(c,g)|0]&8)){break Ya}v[22640]=0;Q(350,d+88|0,2)|0;g=v[22640];v[22640]=0;if((g|0)==1){break p}}if(h>>>0<i>>>0){continue}}break}g=v[b+8>>2];v[22640]=0;v[d+56>>2]=g;g=Jc(d+172|0,d+56|0);h=v[22640];v[22640]=0;if((h|0)==1){break p}v[d+172>>2]=v[g>>2];gc(c);yb(d+88|0)}e=e+1|0;if(e>>>0<x[d+52>>1]){continue}break}}c=v[d+172>>2];if(!c){break La}v[22640]=0;Q(227,b|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break q}if(!(f&1)){break La}while(1){$a:{v[22640]=0;c=Q(228,b|0,4)|0;e=v[22640];v[22640]=0;if((e|0)==1){break $a}if(!c){break La}v[22640]=0;c=Q(575,b|0,11194)|0;e=v[22640];v[22640]=0;if((e|0)==1){break $a}ab:{if(!c){v[22640]=0;c=Q(575,b|0,11199)|0;e=v[22640];v[22640]=0;if((e|0)==1){break $a}if(!c){break ab}}v[22640]=0;c=T(229,b|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){lg(b,8);if(!(c&1616928864)|c&-2139062144){break ab}break La}a=P()|0;O()|0;break j}v[22640]=0;c=T(319,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break $a}v[22640]=0;Q(350,b|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}v[22640]=0;c=Q(608,a|0,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break q}c=c|w[d+287|0];t[d+287|0]=c;if(!(!c|A)){ov(a+1074312|0);t[a+1074368|0]=0}v[22640]=0;Y(609,a|0,b|0,0,d+287|0);c=v[22640];v[22640]=0;if((c|0)==1){break q}v[22640]=0;l=a+484344|0;R(364,l|0,x[d+52>>1]);c=v[22640];v[22640]=0;if((c|0)==1){break q}u[d+36>>1]=0;bb:{if(!x[d+52>>1]){break bb}g=0;while(1){cb:{db:{c=Mb(m,g);eb:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){c=Mb(m,x[d+36>>1]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22640]=0;c=Q(227,b|0,c|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break eb}if(c){break db}}v[22640]=0;c=W(365,l|0,x[d+36>>1],64)|0;e=v[22640];v[22640]=0;if((e|0)==1){break eb}if(!c){v[22640]=0;_(610,d+72|0);c=v[22640];v[22640]=0;fb:{gb:{hb:{if((c|0)!=1){v[22640]=0;U(611,d+88|0,d+72|0,d+36|0);c=v[22640];v[22640]=0;if((c|0)==1){break hb}v[22640]=0;U(580,a|0,2,d+88|0);c=v[22640];v[22640]=0;if((c|0)==1){break gb}vb(d+88|0);Hb(d+72|0);break bb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break fb}a=P()|0;O()|0;vb(d+88|0)}Hb(d+72|0);break j}c=_b(l,x[d+36>>1]);v[22640]=0;R(612,c|0,z|0);c=v[22640];v[22640]=0;if((c|0)!=1){break cb}}a=P()|0;O()|0;break j}v[22640]=0;c=T(319,b|0)|0;e=v[22640];v[22640]=0;ib:{jb:{if((e|0)!=1){v[22640]=0;p=T(319,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break jb}v[22640]=0;e=Q(350,b|0,4)|0;f=v[22640];v[22640]=0;if((f|0)==1){break jb}if(!e){break cb}v[22640]=0;e=W(365,l|0,x[d+36>>1],p|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break jb}if(e){break ib}break cb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}v[22640]=0;U(320,d+88|0,b|0,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){c=_b(l,x[d+36>>1]);v[22640]=0;R(612,c|0,z|0);c=v[22640];v[22640]=0;kb:{if((c|0)!=1){c=x[a+480188>>1];v[22640]=0;k=Q(606,d+72|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){c=x[a+480188>>1];gi(d+40|0);v[22640]=0;i=W(613,d+56|0,c|0,d+40|0)|0;c=v[22640];v[22640]=0;lb:{if((c|0)!=1){C=d,D=Sb(_b(l,x[d+36>>1])),v[C+24>>2]=D;r=0;mb:{if(!p){break mb}while(1){v[22640]=0;c=Q(228,d+88|0,1)|0;e=v[22640];v[22640]=0;nb:{if((e|0)!=1){ob:{if(!c){break mb}v[22640]=0;c=T(353,d+88|0)|0;e=v[22640];v[22640]=0;pb:{if((e|0)!=1){c=c<<24>>24;if(c){break pb}xX(d+24|0,x[a+480188>>1]);r=r+1|0;break nb}break ob}qb:{e=c&127;h=e?e-1&65535:0;if(pc(k)>>>0>h>>>0){break qb}v[22640]=0;t[d+40|0]=0;e=h+1|0;U(607,k|0,e|0,d+40|0);f=v[22640];v[22640]=0;if((f|0)==1){break ob}gi(d+40|0);v[22640]=0;U(614,i|0,e|0,d+40|0);e=v[22640];v[22640]=0;if((e|0)!=1){break qb}break ob}if((c|0)<=-1){v[22640]=0;c=T(353,d+88|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break ob}C=kc(k,h),D=c,t[C|0]=D}gi(d+40|0);e=d+40|0;if(h>>>0<x[a+480188>>1]){e=_c(d+24|0,h)}if(w[kc(k,h)|0]&16){C=e,D=w[_c(i,h)|0],t[C|0]=D}if(w[kc(k,h)|0]&32){C=e,D=w[_c(i,h)+1|0],t[C+1|0]=D}if(w[kc(k,h)|0]&64){C=e,D=w[_c(i,h)+2|0],t[C+2|0]=D;C=e,D=w[_c(i,h)+4|0],t[C+4|0]=D}if(t[kc(k,h)|0]<=-1){C=e,D=w[_c(i,h)+3|0],t[C+3|0]=D;C=e,D=w[_c(i,h)+5|0],t[C+5|0]=D}if(t[kc(k,h)|0]&1){v[22640]=0;c=T(353,d+88|0)|0;f=v[22640];v[22640]=0;g=e;rb:{sb:{if((f|0)!=1){c=c+(((c^-1)&128)>>>7|0)|0;if(!(v[a+480180>>2]&16777216)){break sb}f=c;break rb}break ob}f=253;if((c-121&255)>>>0<132){break rb}f=(c&255)==253?0:c}t[g|0]=f;C=_c(i,h),D=f,t[C|0]=D}if(w[kc(k,h)|0]&2){v[22640]=0;c=T(353,d+88|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ob}t[e+1|0]=c;C=_c(i,h),D=c,t[C+1|0]=D}if(w[kc(k,h)|0]&4){v[22640]=0;g=T(353,d+88|0)|0;f=v[22640];v[22640]=0;c=e;tb:{ub:{vb:{if((f|0)!=1){if(g>>>0>64){break vb}t[e+4|0]=g;f=1;break ub}break ob}if(!(g<<24>>24>-1|g>>>0>192)){f=2;t[e+2|0]=2;t[e+4|0]=g^128;break tb}if(g>>>0<=74){f=5;t[e+2|0]=5;t[e+4|0]=g-65;break tb}if(g>>>0<=84){f=6;t[e+2|0]=6;t[e+4|0]=g-75;break tb}if(g>>>0<=94){f=3;t[e+2|0]=3;t[e+4|0]=g-85;break tb}if(g>>>0<=104){f=4;t[e+2|0]=4;t[e+4|0]=g-95;break tb}if(g>>>0<=114){f=13;t[e+2|0]=13;t[e+4|0]=g-105;break tb}if(g>>>0<=124){f=12;t[e+2|0]=12;t[e+4|0]=g-115;break tb}f=g+63|0;if((f&255)>>>0<=9){t[e+4|0]=f;f=11;break ub}f=g+53|0;n=f&255;if(n>>>0<=9){t[e+4|0]=f;f=8;t[e+2|0]=8;if(!n|v[a+1074308>>2]-1>>>0>18285139){break tb}f=7;break ub}f=g+33|0;if((f&255)>>>0>=10){f=w[e+2|0];break tb}t[e+4|0]=f;f=15}t[c+2|0]=f}C=_c(i,h),D=f,t[C+2|0]=D;c=w[e+4|0];C=_c(i,h),D=c,t[C+4|0]=D}if(!(w[kc(k,h)|0]&8)){break nb}v[22640]=0;R(431,d+16|0,d+88|0);c=v[22640];v[22640]=0;if((c|0)!=1){wb:{c=md(d+16|0);t[e+3|0]=w[d+16|0];t[e+5|0]=w[c|0];v[22640]=0;Pu(e,1);c=v[22640];v[22640]=0;if((c|0)==1){break wb}c=w[e+3|0];C=_c(i,h),D=c,t[C+3|0]=D;c=w[e+5|0];C=_c(i,h),D=c,t[C+5|0]=D;break nb}}}}a=P()|0;O()|0;kn(i);break lb}if(p>>>0>r>>>0){continue}break}}kn(i);gc(k);yb(d+88|0);break cb}a=P()|0;O()|0}gc(k);break kb}a=P()|0;O()|0;break kb}a=P()|0;O()|0}yb(d+88|0);break j}a=P()|0;O()|0;break j}c=x[d+36>>1]+1|0;u[d+36>>1]=c;g=c&65535;if(g>>>0<x[d+52>>1]){continue}break}}c=a+1074308|0;xb:{yb:{zb:{if(v[a+1074308>>2]){break zb}if((w[d+328|0]|w[d+329|0]<<8)==2184){v[a+1074308>>2]=18284544;break zb}if(!v[c>>2]){break yb}}if(!dd(j)){break yb}v[22640]=0;e=Q(2,d+72|0,14686)|0;f=v[22640];v[22640]=0;Ab:{Bb:{Cb:{Db:{Eb:{Fb:{if((f|0)!=1){v[22640]=0;R(199,d+56|0,c|0);f=v[22640];v[22640]=0;if((f|0)==1){break Fb}v[22640]=0;U(3,d+88|0,e|0,d+56|0);f=v[22640];v[22640]=0;if((f|0)==1){break Eb}Eb(j,d+88|0);vb(d+88|0);vb(d+56|0);vb(e);if(v[d+348>>2]==1414548815|((w[d+328|0]|w[d+329|0]<<8)&61440)!=20480){break Ab}v[22640]=0;c=Q(2,d+88|0,13973)|0;e=v[22640];v[22640]=0;if((e|0)==1){break Cb}v[22640]=0;Q(155,j|0,c|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break Bb}vb(c);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Db}a=P()|0;O()|0;vb(d+56|0)}vb(e);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}if(!mG(c)){break xb}v[22640]=0;c=Q(2,d+88|0,14209)|0;e=v[22640];v[22640]=0;Gb:{if((e|0)!=1){v[22640]=0;Q(155,j|0,c|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break Gb}vb(c);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}if((w[d+328|0]|w[d+329|0]<<8)==8191){c=w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)}else{c=(w[d+328|0]|w[d+329|0]<<8)-4176|0}Hb:{switch((w[d+328|0]|w[d+329|0]<<8)>>>12|0){case 0:if(A){v[22640]=0;c=Q(2,d+88|0,5553)|0;e=v[22640];v[22640]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}Ib:{if((w[d+328|0]|w[d+329|0]<<8)!=532|(w[d+330|0]|w[d+331|0]<<8)!=512|(w[d+334|0]|w[d+335|0]<<8|(w[d+332|0]|w[d+333|0]<<8)!=9)){break Ib}if(w[d+319|0]|w[d+318|0]|(w[d+322|0]|w[d+323|0]<<8|((w[d+326|0]|w[d+327|0]<<8)+1|0)!=(w[d+320|0]|w[d+321|0]<<8))){break Ib}if(w[d+336|0]!=128|w[d+337|0]!=100|(w[d+338|0]!=1|w[d+340|0]!=128)){break Ib}if(w[d+341|0]|(w[d+342|0]|w[d+343|0]<<8)|(w[d+344|0]|w[d+345|0]<<8|(w[d+346|0]<<16|w[d+347|0]<<24)|(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)))){break Ib}v[22640]=0;c=Q(2,d+88|0,7162)|0;e=v[22640];v[22640]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}Jb:{if((w[d+328|0]|w[d+329|0]<<8)!=532|(w[d+330|0]|w[d+331|0]<<8)!=512|(w[d+319|0]|w[d+318|0])){break Jb}if(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)){break Jb}v[a+1074308>>2]=16777381;v[22640]=0;c=Q(2,d+88|0,12116)|0;e=v[22640];v[22640]=0;if((e|0)!=1){Eb(j,c);vb(c);t[d+287|0]=1;break xb}a=P()|0;O()|0;break j}if(!((w[d+328|0]|w[d+329|0]<<8)!=532|(w[d+330|0]|w[d+331|0]<<8)!=532|v[d+348>>2]!=1229080643)){v[22640]=0;c=Q(2,d+88|0,5605)|0;e=v[22640];v[22640]=0;if((e|0)!=1){Eb(j,c);vb(c);v[22640]=0;Q(438,a+1074312|0,38)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break xb}break r}a=P()|0;O()|0;break j}Kb:{if((w[d+328|0]|w[d+329|0]<<8)!=532|(w[d+330|0]|w[d+331|0]<<8)!=532|(w[d+341|0]|(w[d+334|0]|w[d+335|0]<<8)>>>0>1)){break Kb}if(!x[a+480190>>1]|(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24)|((w[d+332|0]|w[d+333|0]<<8)&4294)!=4)){break Kb}v[22640]=0;c=Q(112,d+88|0,10846)|0;e=v[22640];v[22640]=0;Lb:{Mb:{if((e|0)!=1){v[22640]=0;e=Q(616,a+484527|0,c|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break Mb}vb(c);if(!e){break Kb}v[22640]=0;c=Q(2,d+88|0,5631)|0;e=v[22640];v[22640]=0;if((e|0)==1){break Lb}Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}a=P()|0;O()|0;break j}Nb:{if(w[d+328|0]|w[d+329|0]<<8){break Nb}if(!dd(j)){break Nb}v[22640]=0;c=Q(2,d+88|0,6910)|0;e=v[22640];v[22640]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}if((w[d+330|0]|w[d+331|0]<<8)>>>0>767){break xb}if(!dd(j)){break xb}Ob:{Pb:{Qb:{Rb:{Sb:{if((w[d+330|0]|w[d+331|0]<<8)>>>0>=533){v[22640]=0;c=Q(2,d+88|0,12149)|0;e=v[22640];v[22640]=0;if((e|0)!=1){Eb(j,c);vb(c);break Sb}a=P()|0;O()|0;break j}if((w[d+328|0]|w[d+329|0]<<8)>>>0>=533){v[22640]=0;R(617,d+72|0,1124);c=v[22640];v[22640]=0;Tb:{if((c|0)!=1){c=w[d+328|0]|w[d+329|0]<<8;v[22640]=0;v[d+56>>2]=c-532;U(618,d+88|0,d+72|0,d+56|0);c=v[22640];v[22640]=0;if((c|0)==1){break Tb}Eb(j,d+88|0);vb(d+88|0);Hb(d+72|0);break Sb}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(d+72|0);break j}v[22640]=0;R(439,d+72|0,1423);c=v[22640];v[22640]=0;if((c|0)==1){break Rb}v[d+40>>2]=w[d+329|0]&15;c=w[d+328|0];v[22640]=0;v[d+24>>2]=c;R(619,d+56|0,d+24|0);c=v[22640];v[22640]=0;if((c|0)==1){break Qb}v[22640]=0;Y(602,d+88|0,d+72|0,d+40|0,d+56|0);c=v[22640];v[22640]=0;if((c|0)==1){break Pb}Eb(j,d+88|0);vb(d+88|0);vb(d+56|0);Hb(d+72|0)}c=a+1298368|0;if(!$c(c)|!(w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24))){break xb}e=w[d+328|0]|w[d+329|0]<<8;f=w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24);v[22640]=0;e=kw(e,f);f=v[22640];v[22640]=0;if((f|0)==1){break u}f=Er(d+88|0);v[f+44>>2]=e;v[22640]=0;R(621,c|0,f|0);c=v[22640];v[22640]=0;if((c|0)!=1){break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Ob}a=P()|0;O()|0;vb(d+56|0)}Hb(d+72|0);break j;case 1:e=w[d+328|0]|w[d+329|0]<<8;f=w[d+348|0]|w[d+349|0]<<8|(w[d+350|0]<<16|w[d+351|0]<<24);v[22640]=0;U(622,d+88|0,e|0,f|0);e=v[22640];v[22640]=0;Ub:{Vb:{Wb:{Xb:{if((e|0)!=1){Eb(j,d+88|0);vb(d+88|0);if((c|0)>1915){break Xb}e=v[a+480208>>2];if(!(e&16)){break Wb}v[22640]=0;Q(438,a+1074312|0,7)|0;c=v[22640];v[22640]=0;if((c|0)==1){break r}break Vb}a=P()|0;O()|0;break j}if((c|0)>4200){break xb}e=v[a+480208>>2]}if(!(e&16)){v[22640]=0;Q(438,a+1074312|0,7)|0;e=v[22640];v[22640]=0;if((e|0)==1){break r}}if((c|0)>2385){break Ub}}v[22640]=0;Q(438,a+1074312|0,38)|0;c=v[22640];v[22640]=0;if((c|0)==1){break r}}v[22640]=0;c=a+1074312|0;Q(438,c|0,102)|0;e=v[22640];v[22640]=0;if((e|0)==1){break r}v[22640]=0;Q(438,c|0,48)|0;c=v[22640];v[22640]=0;if((c|0)==1){break r}break xb;case 4:v[22640]=0;R(623,d+72|0,1487);c=v[22640];v[22640]=0;Yb:{Zb:{_b:{if((c|0)!=1){v[d+40>>2]=w[d+329|0]&15;c=w[d+328|0];v[22640]=0;v[d+24>>2]=c;R(619,d+56|0,d+24|0);c=v[22640];v[22640]=0;if((c|0)==1){break _b}v[22640]=0;Y(602,d+88|0,d+72|0,d+40|0,d+56|0);c=v[22640];v[22640]=0;if((c|0)==1){break Zb}Eb(j,d+88|0);vb(d+88|0);vb(d+56|0);Hb(d+72|0);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;break Yb}a=P()|0;O()|0;vb(d+56|0)}Hb(d+72|0);break j;case 6:v[22640]=0;c=Q(2,d+88|0,5553)|0;e=v[22640];v[22640]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j;case 7:if(!((w[d+328|0]|w[d+329|0]<<8)!=32767|(w[d+330|0]|w[d+331|0]<<8)!=533)){v[22640]=0;c=Q(2,d+88|0,2138)|0;e=v[22640];v[22640]=0;if((e|0)!=1){Eb(j,c);vb(c);break xb}a=P()|0;O()|0;break j}v[22640]=0;R(195,d+72|0,1259);c=v[22640];v[22640]=0;$b:{if((c|0)!=1){v[d+56>>2]=w[d+329|0]&15;v[d+40>>2]=(w[d+328|0]|w[d+329|0]<<8)>>>4&15;c=w[d+328|0]|w[d+329|0]<<8;v[22640]=0;v[d+24>>2]=c&15;ha(196,d+88|0,d+72|0,d+56|0,d+40|0,d+24|0);c=v[22640];v[22640]=0;if((c|0)==1){break $b}Eb(j,d+88|0);vb(d+88|0);Hb(d+72|0);break xb}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(d+72|0);break j;case 13:break Hb;default:break xb}}v[22640]=0;c=Q(2,d+88|0,3177)|0;e=v[22640];v[22640]=0;if((e|0)==1){break t}Eb(j,c);vb(c)}ac:{if(v[a+480180>>2]!=16777216|(w[d+328|0]|w[d+329|0]<<8)>>>0<2186){break ac}v[22640]=0;c=Q(227,b|0,s|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break q}if(!c){break ac}c=w[d+328|0]|w[d+329|0]<<8;v[22640]=0;U(624,a|0,b|0,c|0);b=v[22640];v[22640]=0;if((b|0)==1){break q}}b=v[a+480180>>2];bc:{if((b|0)==16777216){v[22640]=0;Q(2,d+88|0,11177)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break bc}a=P()|0;O()|0;break j}v[22640]=0;R(439,d+72|0,1423);c=v[22640];v[22640]=0;if((c|0)==1){break y}v[d+40>>2]=w[d+331|0];c=w[d+330|0];v[22640]=0;v[d+24>>2]=c;R(619,d+56|0,d+24|0);c=v[22640];v[22640]=0;if((c|0)==1){break x}v[22640]=0;Y(602,d+88|0,d+72|0,d+40|0,d+56|0);c=v[22640];v[22640]=0;if((c|0)==1){break w}}Eb(a+1298304|0,d+88|0);vb(d+88|0);if((b|0)!=16777216){vb(d+56|0);Hb(d+72|0)}cc:{if(v[a+480180>>2]==16777216){v[22640]=0;Q(2,d+88|0,7450)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break cc}break s}v[22640]=0;Q(2,d+88|0,3181)|0;b=v[22640];v[22640]=0;if((b|0)==1){break s}}Eb(a+1298316|0,d+88|0);vb(d+88|0);Eb(a+1298328|0,j);v[a+1298364>>2]=v[a+1074308>>2]?8:5;yb(d+176|0);yb(z);g=1}bi(m);bi(o);bi(q);break d}a=P()|0;O()|0;break j}a=P()|0;O()|0;break v}a=P()|0;O()|0;vb(d+56|0)}Hb(d+72|0);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;gc(c);break n}a=P()|0;O()|0}yb(d+88|0);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0}yb(d+176|0)}yb(z);break g}a=P()|0;O()|0}bi(m);bi(o);bi(q);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}vb(j)}gb=d+480|0;return g|0}a=P()|0;O()|0}vb(j);S(a|0);L()}function _ma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;d=gb-1680|0;gb=d;vc(b);a:{if(!Hh(b,d+1672|0)){break a}if(!QV(d+1672|0)){break a}if(!c){f=1;break a}g=w[d+1672|3];t[d+1671|0]=g;v[d+1664>>2]=-1;v[d+1660>>2]=1048576;if(g>>>0>=5){g=og(b);v[d+1664>>2]=g;if(!Pb(b,g)){break a}v[d+272>>2]=134217727;J=d,K=v[Fb(d+272|0,d+1664|0)>>2]<<5,v[J+1660>>2]=K}C=nc(d+1648|0);f=d+1672|4;g=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[22640]=0;v[d+272>>2]=g;g=Fb(d+1660|0,d+272|0);e=v[22640];v[22640]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((e|0)==1){break x}g=v[g>>2];v[22640]=0;R(746,C|0,g|0);g=v[22640];v[22640]=0;if((g|0)==1){break x}g=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);f=0;v[22640]=0;g=W(747,b|0,C|0,g|0)|0;e=v[22640];v[22640]=0;y:{if((e|0)==1){break y}if(!g){break t}if(w[d+1671|0]>=5){v[22640]=0;Q(227,b|0,v[d+1664>>2]+12|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break y}}v[22640]=0;R(407,a|0,0);g=v[22640];v[22640]=0;if((g|0)==1){break y}v[22640]=0;wg(a);g=v[22640];v[22640]=0;if((g|0)==1){break y}v[22640]=0;be(d+1616|0,C);e=v[22640];v[22640]=0;g=a;z:{A:{B:{C:{if((e|0)==1){break C}e=Sd(d+1608|0);v[22640]=0;k=v[d+1620>>2];v[d+88>>2]=v[d+1616>>2];v[d+92>>2]=k;k=v[e+4>>2];v[d+80>>2]=v[e>>2];v[d+84>>2]=k;k=W(749,d+1624|0,d+88|0,d+80|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break C}v[22640]=0;W(552,k|0,a+1298268|0,-1)|0;e=v[22640];v[22640]=0;if((e|0)==1){break B}v[22640]=0;W(552,k|0,a+1298292|0,-1)|0;e=v[22640];v[22640]=0;if((e|0)==1){break B}v[22640]=0;e=Q(750,k|0,d+1184|0)|0;l=v[22640];v[22640]=0;if((l|0)==1){break d}if(!e|!w[d+1184|0]|t[d+1184|0]<0){break u}e=d+1193|0;if((w[e|0]|w[e+1|0]<<8)>>>0>255){break u}l=d+1195|0;if((w[l|0]|w[l+1|0]<<8)>>>0>3999){break u}u[a+480188>>1]=w[d+1184|0];j=a+484360|0;i=d+1184|3;af(Rb(j),w[i|0]|w[i+1|0]<<8);u[a+480192>>1]=w[e|0]|w[e+1|0]<<8;u[a+480190>>1]=w[l|0]|w[l+1|0]<<8;e=d+1197|0;if(w[e|0]){break A}e=6;break z}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=w[e|0]}v[g+480196>>2]=e;g=a;e=d+1198|0;if(w[e|0]){e=B(w[e|0],1e4)}else{e=125e4}v[g+480204>>2]=e;l=d+1199|0;D:{if(t[l+1|0]&1){v[22640]=0;R(578,a|0,32);g=v[22640];v[22640]=0;if((g|0)!=1){break D}break d}if(w[l|0]&2){v[22640]=0;R(578,a|0,2);g=v[22640];v[22640]=0;if((g|0)==1){break d}break D}if(w[l|0]&128){v[22640]=0;R(578,a|0,1);g=v[22640];v[22640]=0;if((g|0)==1){break d}break D}if(w[l|0]&8){v[22640]=0;R(578,a|0,16);g=v[22640];v[22640]=0;if((g|0)==1){break d}break D}v[22640]=0;R(578,a|0,4);g=v[22640];v[22640]=0;if((g|0)==1){break d}}v[a+480208>>2]=v[a+480208>>2]|16777216;if(t[l|0]&1){v[a+480208>>2]=v[a+480208>>2]|16}if(!(!(w[l|0]&16)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|65536}if(!(!(w[l|0]&4)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|2}if(!(w[l+1|0]&8|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|4}if(!(w[l+1|0]&4|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|8}if(w[l+2|0]&32){v[a+480208>>2]=v[a+480208>>2]|32768}if(w[l+2|0]&8){v[22640]=0;W(437,a+1074312|0,5,1)|0;g=v[22640];v[22640]=0;if((g|0)==1){break d}}E:{g=v[a+480180>>2];F:{if((g|0)!=2){if((g|0)!=32){break F}t[d+272|0]=w[d+1203|0];v[22640]=0;t[d+192|0]=128;g=ac(d+272|0,d+192|0);e=v[22640];v[22640]=0;if((e|0)==1){break w}v[a+480200>>2]=w[g|0]<<1;break F}t[d+272|0]=w[d+1203|0];v[22640]=0;t[d+192|0]=64;g=ac(d+272|0,d+192|0);e=v[22640];v[22640]=0;if((e|0)==1){break E}v[a+480200>>2]=w[g|0]<<2}F=a+480188|0;i=d+1205|0;e=t[i|0];g=a;if(t[i|0]<=-1){e=e+52|0}else{E=Ow(+(e|0)*.15500000000000003);G:{if(E<4294967296&E>=0){e=~~E>>>0;break G}e=0}e=e+51|0}v[g+480228>>2]=e;v[22640]=0;u[d+272>>1]=64;g=Oc(F,d+272|0);e=v[22640];v[22640]=0;if((e|0)!=1){H:{e=x[g>>1];if(e){while(1){g=v[a+480180>>2];if((g|0)==32){t[d+272|0]=w[(d+f|0)+1206|0];v[22640]=0;t[d+192|0]=64;g=ac(d+272|0,d+192|0);i=v[22640];v[22640]=0;if((i|0)==1){break H}u[((f<<5)+a|0)+480286>>1]=w[g|0];g=v[a+480180>>2]}I:{if((g|0)==4){break I}g=(d+f|0)+1270|0;if(w[g|0]==127){v[((f<<5)+a|0)+480280>>2]=256;break I}if(w[g|0]==255){u[((f<<5)+a|0)+480284>>1]=256;break I}u[((f<<5)+a|0)+480284>>1]=w[g|0]}f=f+1|0;if((e|0)!=(f|0)){continue}break}}i=0;f=0;e=0;while(1){f=w[(d+e|0)+1334|0]!=0|f;e=e+1|0;if((e|0)!=16){continue}break}while(1){f=w[((i<<1)+d|0)+1351|0]!=0|f;i=i+1|0;if((i|0)!=128){continue}break}if(f&1){f=0;while(1){J:{g=(d+f|0)+1334|0;if(w[g|0]){v[22640]=0;_(751,d+192|0);e=v[22640];v[22640]=0;K:{L:{M:{N:{O:{if((e|0)!=1){g=w[g|0];v[22640]=0;v[d+216>>2]=g-1;R(752,d+1160|0,d+216|0);g=v[22640];v[22640]=0;if((g|0)==1){break O}v[22640]=0;U(470,d+272|0,d+192|0,d+1160|0);g=v[22640];v[22640]=0;if((g|0)==1){break N}v[22640]=0;R(471,d+1136|0,((f<<5)+a|0)+901692|0);g=v[22640];v[22640]=0;if((g|0)==1){break M}v[22640]=0;Q(429,d+1136|0,d+272|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break M}vb(d+272|0);vb(d+1160|0);Hb(d+192|0);break J}e=P()|0;O()|0;break c}e=P()|0;O()|0;break K}e=P()|0;O()|0;break L}e=P()|0;O()|0;vb(d+272|0)}vb(d+1160|0)}Hb(d+192|0);break c}v[22640]=0;g=Q(112,d+272|0,18693)|0;e=v[22640];v[22640]=0;P:{if((e|0)!=1){v[22640]=0;R(471,d+192|0,((f<<5)+a|0)+901692|0);e=v[22640];v[22640]=0;if((e|0)==1){break P}v[22640]=0;Q(429,d+192|0,g|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break P}vb(g);break J}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(g);break c}f=f+1|0;if((f|0)!=16){continue}break}f=0;while(1){g=(d+1184|0)+(f<<1)|0;e=g;Q:{if(w[e+167|0]){v[22640]=0;_(753,d+192|0);i=v[22640];v[22640]=0;R:{S:{T:{U:{V:{W:{X:{if((i|0)!=1){e=w[e+167|0];v[22640]=0;v[d+160>>2]=e-1;R(752,d+1160|0,d+160|0);e=v[22640];v[22640]=0;if((e|0)==1){break X}g=w[g+166|0];v[22640]=0;t[d+1120|0]=g;R(754,d+1136|0,d+1120|0);g=v[22640];v[22640]=0;if((g|0)==1){break W}v[22640]=0;Y(755,d+272|0,d+192|0,d+1160|0,d+1136|0);g=v[22640];v[22640]=0;if((g|0)==1){break V}v[22640]=0;R(471,d+216|0,((f<<5)+a|0)+902204|0);g=v[22640];v[22640]=0;if((g|0)==1){break U}v[22640]=0;Q(429,d+216|0,d+272|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break U}vb(d+272|0);vb(d+1136|0);vb(d+1160|0);Hb(d+192|0);break Q}e=P()|0;O()|0;break c}e=P()|0;O()|0;break R}e=P()|0;O()|0;break S}e=P()|0;O()|0;break T}e=P()|0;O()|0;vb(d+272|0)}vb(d+1136|0)}vb(d+1160|0)}Hb(d+192|0);break c}v[22640]=0;g=Q(112,d+272|0,18693)|0;e=v[22640];v[22640]=0;Y:{if((e|0)!=1){v[22640]=0;R(471,d+192|0,((f<<5)+a|0)+902204|0);e=v[22640];v[22640]=0;if((e|0)==1){break Y}v[22640]=0;Q(429,d+192|0,g|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break Y}vb(g);break Q}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(g);break c}f=f+1|0;if((f|0)!=128){continue}break}}f=Rb(j);g=d+1184|1;g=w[g|0]|w[g+1|0]<<8;v[22640]=0;ga(540,f|0,k|0,g|0,255,254)|0;f=v[22640];v[22640]=0;Z:{_:{$:{aa:{ba:{ca:{if((f|0)!=1){j=d+1184|5;f=w[j|0]|w[j+1|0]<<8;g=w[d+1184|0];v[22640]=0;U(320,d+1160|0,k|0,B(f,g)<<1);f=v[22640];v[22640]=0;if((f|0)==1){break ca}f=w[j|0]|w[j+1|0]<<8;v[22640]=0;U(320,d+1136|0,k|0,f<<1);f=v[22640];v[22640]=0;if((f|0)==1){break ba}f=d+1184|7;f=w[f|0]|w[f+1|0]<<8;v[22640]=0;A=Q(359,d+1120|0,f|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break aa}J=d,K=Sb(A),v[J+192>>2]=K;J=d,K=Wb(A),v[J+216>>2]=K;if(Gb(d+192|0,d+216|0)){while(1){f=v[d+192>>2];v[22640]=0;g=T(229,k|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break $}v[22640]=0;U(320,d+272|0,k|0,g|0);g=v[22640];v[22640]=0;if((g|0)==1){break _}od(f,d+272|0);yb(d+272|0);Ah(d+192|0);if(Gb(d+192|0,d+216|0)){continue}break}}f=v[a+480180>>2];h=1;p=c&1;if(!p){break Z}g=w[j|0]|w[j+1|0]<<8;v[22640]=0;R(364,a+484344|0,g|0);g=v[22640];v[22640]=0;if((g|0)!=1){break Z}e=P()|0;O()|0;break g}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break e}e=P()|0;O()|0;break f}e=P()|0;O()|0;break g}e=P()|0;O()|0;break g}D=a+484344|0;da:{ea:{fa:{ga:{ha:{ia:{if(w[j|0]|w[j+1|0]<<8){z=(f|0)==16?14:(f|0)==32?1:13;while(1){v[22640]=0;f=T(319,d+1136|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break da}v[d+192>>2]=f;ja:{if(!p){break ja}v[22640]=0;f=W(365,D|0,q&65535,f|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break da}if(!f){break ja}m=0;if(!w[d+1184|0]){break ja}while(1){v[22640]=0;f=T(319,d+1160|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break ea}ka:{if(Ze(A)>>>0<=f>>>0){break ka}n=Hg(A,f);vc(n);f=_b(D,q);v[22640]=0;f=Tc(f,0,m&65535);g=v[22640];v[22640]=0;if((g|0)==1){break h}g=0;if(!v[d+192>>2]){break ka}while(1){v[22640]=0;s=T(353,n|0)|0;e=v[22640];v[22640]=0;la:{ma:{if((e|0)!=1){if(!s){break ka}gi(d+272|0);i=0;r=s&15;if(r){break ma}break la}e=P()|0;O()|0;break g}while(1){na:{v[22640]=0;R(756,n|0,d+216|0);e=v[22640];v[22640]=0;if((e|0)==1){break na}oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{e=w[d+216|0];switch(e-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break qa;case 33:break ua;case 30:case 31:break va;case 29:break wa;case 28:break xa;case 26:break ya;case 19:case 20:break za;case 17:break Aa;case 15:break Ba;case 14:break Ca;case 10:break Da;case 6:break Ea;case 5:break Fa;case 1:break Ga;case 0:break Ha;default:break Ia}}switch(e-48|0){case 4:break ra;case 1:case 2:break sa;case 0:break ta;default:break qa}}e=w[d+217|0];Ja:{if(e>>>0<=119){t[d+272|0]=e+z;break Ja}Ka:{switch(e-254|0){case 1:t[d+272|0]=255;break Ja;case 0:t[d+272|0]=254;break Ja;default:break Ka}}t[d+272|0]=253}v[22640]=0;e=rv(d+272|0);o=v[22640];v[22640]=0;if((o|0)==1){break na}h=e&h;break oa}t[d+273|0]=w[d+217|0]+1;break oa}La:{if(w[d+274|0]){break La}e=v[a+480180>>2];if((e|0)!=32){if((e|0)!=4){break La}e=w[d+217|0];if(e&15){break La}t[d+274|0]=11;t[d+276|0]=e>>>4;break oa}e=0;o=w[d+217|0];while(1){if((o|0)==w[e+39472|0]){t[d+276|0]=e;t[d+274|0]=11;break oa}e=e+1|0;if((e|0)!=10){continue}break}}t[d+275|0]=4;t[d+277|0]=w[d+217|0];break oa}e=w[d+217|0];if(!(w[d+274|0]|e>>>0>9|v[a+480180>>2]!=32)){t[d+276|0]=e;t[d+274|0]=8;break oa}t[d+277|0]=e;t[d+275|0]=5;break oa}Ma:{if(w[d+274|0]){break Ma}Na:{e=v[a+480180>>2];if((e|0)!=4){if((e|0)!=32){break Ma}e=w[d+217|0];if((e|0)!=255){break Na}t[d+276|0]=64;t[d+274|0]=2;break oa}e=w[d+217|0];if(e&15){break Ma}break pa}if(!(e&3)){break pa}}t[d+275|0]=9;t[d+277|0]=w[d+217|0];break oa}e=w[d+217|0];if(!(w[d+274|0]|e>>>0>64|v[a+480180>>2]==1)){t[d+276|0]=e;t[d+274|0]=1;break oa}t[d+277|0]=e;t[d+275|0]=13;break oa}t[d+275|0]=14;e=w[d+217|0];t[d+277|0]=e;if(v[a+480180>>2]==32){break oa}t[d+277|0]=B((e&240)>>>4|0,10)+(e&15);break oa}e=w[d+217|0];t[d+277|0]=e;if(e>>>0<=31){t[d+275|0]=16;break oa}t[d+275|0]=17;break oa}o=w[d+217|0];if(o>>>0>=16){t[d+276|0]=o>>>4;t[d+274|0]=(e|0)==20?3:5;break oa}t[d+276|0]=o;t[d+274|0]=(e|0)==20?4:6;break oa}e=w[d+217|0];if(e>>>0>=16){t[d+274|0]=10;t[d+276|0]=e>>>4;break oa}t[d+276|0]=e;t[d+274|0]=9;break oa}t[d+275|0]=28;t[d+277|0]=w[d+217|0]|16;break oa}t[d+275|0]=28;t[d+277|0]=w[d+217|0]|32;break oa}t[d+276|0]=w[d+217|0];t[d+274|0]=w[e+33504|0];break oa}t[d+277|0]=w[d+217|0];e=w[d+275|0];t[d+275|0]=(e|0)==4?6:(e|0)==5?7:11;break oa}e=w[d+217|0];t[d+276|0]=(e>>>0)%10;if(e>>>0<=9){t[d+274|0]=5;break oa}if(e>>>0<=19){t[d+274|0]=6;break oa}if(e>>>0<=29){t[d+274|0]=3;break oa}if(e>>>0>39){break oa}t[d+274|0]=4;break oa}t[d+276|0]=w[d+217|0];t[d+274|0]=w[e+33504|0];break oa}e=w[d+217|0]+33|0;if((e&255)>>>0>9){break oa}t[d+276|0]=e;t[d+274|0]=15;break oa}if(e>>>0>=56){break oa}t[d+277|0]=w[d+217|0];t[d+275|0]=w[w[d+216|0]+33504|0];break oa}t[d+274|0]=2;t[d+276|0]=e>>>2}i=i+1|0;if(r>>>0>(i&255)>>>0){continue}break la}break}e=P()|0;O()|0;break g}v[22640]=0;v[d+216>>2]=(s>>>4|0)+g;e=Fb(d+216|0,d+192|0);i=v[22640];v[22640]=0;if((i|0)==1){break ia}e=v[e>>2];if(e>>>0>g>>>0){while(1){i=v[d+272>>2];t[f|0]=i;t[f+1|0]=i>>>8;t[f+2|0]=i>>>16;t[f+3|0]=i>>>24;i=x[d+276>>1];t[f+4|0]=i;t[f+5|0]=i>>>8;f=B(w[d+1184|0],6)+f|0;g=g+1|0;if((e|0)!=(g|0)){continue}break}g=e}if(y[d+192>>2]>g>>>0){continue}break}}m=m+1|0;if(w[d+1184|0]>(m&65535)>>>0){continue}break}}q=q+1|0;if(q>>>0<(w[j|0]|w[j+1|0]<<8)>>>0){continue}break}}if(!((h^1)&1|x[a+480188>>1]!=4|v[a+480180>>2]!=1)){v[a+480208>>2]=v[a+480208>>2]|8454144}if(v[a+480180>>2]!=4){break ha}j=0;break ga}e=P()|0;O()|0;break g}j=!((w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24))&512);f=0;if(v[a+480180>>2]!=4){break fa}}f=x[a+480192>>1]}v[22640]=0;q=Q(757,d+1104|0,f|0)|0;f=v[22640];v[22640]=0;g=1;if((f|0)!=1){Oa:{Pa:{Qa:{if(x[a+480192>>1]){e=1;while(1){Ra:{Sa:{Ta:{if(!j){v[22640]=0;i=W(415,a|0,e&65535,0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break Ta}if(i){break Sa}}while(1){v[22640]=0;f=T(353,k|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break j}if(f){continue}break}if(w[d+1671|0]>=5){while(1){v[22640]=0;f=T(353,k|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){e=P()|0;O()|0;break i}if(f){continue}break}}v[22640]=0;Q(350,k|0,826)|0;f=v[22640];v[22640]=0;if((f|0)!=1){break Ra}}e=P()|0;O()|0;break i}f=Kb(d+192|0);v[22640]=0;W(552,k|0,f|0,-1)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Qa}v[22640]=0;Q(333,i+492|0,f|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Qa}Ua:{if(w[d+1671|0]<5){break Ua}v[22640]=0;W(552,k|0,f|0,-1)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Qa}v[22640]=0;Q(333,i+524|0,f|0)|0;h=v[22640];v[22640]=0;if((h|0)!=1){break Ua}break Qa}v[22640]=0;h=Q(758,k|0,d+272|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break Qa}if(!h){break Pa}h=v[a+480180>>2];v[22640]=0;U(759,d+272|0,i|0,h|0);i=v[22640];v[22640]=0;if((i|0)==1){break Qa}if(v[a+480180>>2]==4){g=Mb(q,g-1|0);i=x[d+1074>>1]|x[d+1076>>1]<<16;t[g|0]=i;t[g+1|0]=i>>>8;t[g+2|0]=i>>>16;t[g+3|0]=i>>>24}vb(f)}e=e+1|0;g=e&65535;if(g>>>0<=x[a+480192>>1]){continue}break}}if(!j){break Oa}u[a+480192>>1]=0;break Oa}e=P()|0;O()|0;vb(f);break i}vb(f)}f=x[a+480190>>1];v[22640]=0;s=Q(760,d+256|0,f|0)|0;f=v[22640];v[22640]=0;z=1;if((f|0)!=1){z=w[d+1671|0]<=4?!(t[l|0]&1):z;r=c&2;c=0;Va:{if(!x[a+480190>>1]){break Va}i=1;g=1;while(1){f=c;m=Kb(d+240|0);v[22640]=0;W(552,k|0,m|0,-1)|0;c=v[22640];v[22640]=0;Wa:{Xa:{Ya:{Za:{_a:{if((c|0)==1){break _a}v[22640]=0;Q(333,((i<<5)+a|0)+946304|0,m|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break _a}h=B(i,104)+a|0;if(w[d+1671|0]<5){break Za}v[22640]=0;W(552,k|0,m|0,-1)|0;c=v[22640];v[22640]=0;if((c|0)==1){break _a}v[22640]=0;Q(335,h+484423|0,m|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break Za}}e=P()|0;O()|0;break Ya}v[22640]=0;c=Q(761,k|0,d+272|0)|0;e=v[22640];v[22640]=0;$a:{ab:{bb:{cb:{db:{eb:{fb:{if((e|0)==1){break fb}if(!c){break eb}c=v[a+480180>>2];v[22640]=0;e=h+484380|0;Y(762,d+272|0,e|0,c|0,z|0);c=v[22640];v[22640]=0;if((c|0)==1){break fb}j=0;gb:{if(((w[d+292|0]|w[d+293|0]<<8)&61440)!=28672|w[d+1671|0]<5){break gb}v[22640]=0;j=T(763,k|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break gb}e=P()|0;O()|0;break Ya}if(!r){break Xa}G=w[d+292|0]|w[d+293|0]<<8;n=G&61440;if(!(n|(w[d+307|0]|w[d+308|0]<<8|(w[d+309|0]<<16|w[d+310|0]<<24)))){c=Pc(d+192|0,(w[d+292|0]|w[d+293|0]<<8)&1?16:8,(w[d+292|0]|w[d+293|0]<<8)&1024?3:1,0,0);v[22640]=0;W(363,c|0,e|0,b|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break Xa}e=P()|0;O()|0;break Ya}if(!(((w[d+307|0]|w[d+308|0]<<8|(w[d+309|0]<<16|w[d+310|0]<<24))+i|0)<1|(w[d+307|0]|w[d+308|0]<<8|(w[d+309|0]<<16|w[d+310|0]<<24))>-1)){c=w[d+307|0]|w[d+308|0]<<8|(w[d+309|0]<<16|w[d+310|0]<<24);v[22640]=0;Q(764,e|0,(B(c+i|0,104)+a|0)+484380|0)|0;e=v[22640];v[22640]=0;c=f;if((e|0)!=1){break Wa}e=P()|0;O()|0;break Ya}if((w[d+307|0]|w[d+308|0]<<8|(w[d+309|0]<<16|w[d+310|0]<<24))<1){break Xa}if(t[d+292|0]&1){c=h+484414|0;u[c>>1]=x[c>>1]|1}if(w[d+293|0]&4){c=h+484414|0;u[c>>1]=x[c>>1]|64}c=w[d+307|0]|w[d+308|0]<<8|(w[d+309|0]<<16|w[d+310|0]<<24);v[22640]=0;U(320,d+216|0,b|0,c|0);o=v[22640];v[22640]=0;hb:{ib:{I=d;jb:{kb:{if((o|0)!=1){o=bd(e);H=(n|0)==16384;if(!((n|0)!=8192?H:1)){break ib}v[22640]=0;p=T(232,d+216|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break hb}v[d+192>>2]=p;c=v[d+192>>2];p=4/(o>>>0)|0;if(c>>>0>4294967295/(p>>>0)>>>0){break kb}c=B(c,p);break jb}e=P()|0;O()|0;break Ya}c=-1}p=c;v[I+192>>2]=p;tc(e,p);if(!H){if((n|0)!=8192){break ib}v[22640]=0;c=T(424,e|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break ab}if(!c){break cb}if(t[d+292|0]&1){c=v[h+484400>>2];e=v[e>>2];v[22640]=0;Y(765,d+216|0,c|0,e|0,o|0);e=v[22640];v[22640]=0;c=f;if((e|0)!=1){break bb}break ab}c=v[h+484400>>2];e=v[e>>2];v[22640]=0;Y(766,d+216|0,c|0,e|0,o|0);e=v[22640];v[22640]=0;c=f;if((e|0)==1){break ab}break bb}v[22640]=0;c=T(424,e|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break ab}if(!c){break cb}if(t[d+292|0]&1){c=v[h+484400>>2];e=v[e>>2];v[22640]=0;Y(767,d+216|0,c|0,e|0,o|0);e=v[22640];v[22640]=0;c=f;if((e|0)==1){break ab}break bb}c=v[h+484400>>2];e=v[e>>2];v[22640]=0;Y(768,d+216|0,c|0,e|0,o|0);e=v[22640];v[22640]=0;c=f;if((e|0)==1){break ab}break bb}if((G&45056)==12288){c=OV(d+192|0,d+216|0,w[d+311|0]|w[d+312|0]<<8,j);e=Ul(s,i-1|0);od(e,c);v[e+20>>2]=v[c+20>>2];yb(c);break cb}if((n|0)!=32768){c=1;if((n|0)!=4096){break bb}i=Je(d+192|0,d+216|0);v[22640]=0;Q(769,d+184|0,d+216|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){lb:{if(!w[d+189|0]){break lb}c=x[d+186>>1]<<1;if((c&65535)>>>0>(w[d+311|0]|w[d+312|0]<<8)>>>0){break lb}c=(w[d+311|0]|w[d+312|0]<<8)-c|0;t[d+311|0]=c;t[d+312|0]=c>>>8;v[22640]=0;Q(227,d+216|0,x[d+184>>1])|0;c=v[22640];v[22640]=0;if((c|0)==1){break db}v[22640]=0;c=T(492,d+216|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break db}v[22640]=0;U(320,d+160|0,d+216|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break db}od(i,d+160|0);yb(d+160|0)}v[22640]=0;c=ga(770,a|0,g&65535,i|0,1,1)|0;j=v[22640];v[22640]=0;if((j|0)==1){break db}mb:{if(!c){v[22640]=0;c=v[22640];v[22640]=0;if((c|0)==1){break db}c=1;break mb}nb:{if(!(w[d+311|0]|w[d+312|0]<<8)){break nb}c=w[d+311|0]|w[d+312|0]<<8;if(Yi(e)>>>0<=c>>>0){break nb}c=w[d+311|0]|w[d+312|0]<<8;j=fj(e);h=h+484400|0;sh(zb(v[h>>2]),zb(v[h>>2])+(w[d+311|0]|w[d+312|0]<<8)|0,Yi(e)-(w[d+311|0]|w[d+312|0]<<8)|0);v[e>>2]=v[e>>2]-((c>>>0)/(j>>>0)|0)}c=v[d+280>>2];v[d+156>>2]=c;v[d+60>>2]=c;if(y[e>>2]>(w[d+60|0]|w[d+61|0]<<8|(w[d+62|0]<<16|w[d+63|0]<<24))>>>0){v[e>>2]=w[d+60|0]|w[d+61|0]<<8|(w[d+62|0]<<16|w[d+63|0]<<24)}c=f}yb(i);break bb}break db}v[22640]=0;c=Q(596,d+216|0,d+192|0)|0;i=v[22640];v[22640]=0;if((i|0)!=1){if(!c){break cb}v[d+72>>2]=v[d+200>>2];v[22640]=0;c=v[d+196>>2];v[d+64>>2]=v[d+192>>2];v[d+68>>2]=c;U(597,e|0,1,d- -64|0);c=v[22640];v[22640]=0;if((c|0)!=1){break cb}}e=P()|0;O()|0;break $a}e=P()|0;O()|0;break $a}e=P()|0;O()|0;break Ya}vb(m);c=f;break Va}e=P()|0;O()|0;yb(i);break $a}c=f}yb(d+216|0);break Wa}e=P()|0;O()|0}yb(d+216|0)}vb(m);break k}c=f}vb(m);g=g+1|0;i=g&65535;if(i>>>0<=x[a+480190>>1]){continue}break}}if(!(!r|!x[a+480190>>1])){f=1;m=1;while(1){i=Ul(s,f-1|0);v[22640]=0;b=T(307,i|0)|0;g=v[22640];v[22640]=0;ob:{pb:{qb:{if((g|0)!=1){if(!b){break ob}g=x[i+22>>1];b=g+m&65535;rb:{sb:{h=(g|0)!=0&(b|0)!=0&b>>>0<=x[a+480190>>1];if(!h){v[22640]=0;T(232,i|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break sb}break l}e=x[i+20>>1];g=Ul(s,b-1|0);vc(g);b=x[i+20>>1];v[22640]=0;b=Q(228,g|0,b|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break l}if(!b){break ob}v[d+192>>2]=0;v[d+216>>2]=0;v[22640]=0;U(772,d+272|0,g|0,e|0);b=v[22640];v[22640]=0;tb:{if((b|0)!=1){v[22640]=0;b=Rd(d+272|0);e=v[22640];v[22640]=0;if((e|0)==1){break tb}b=zb(b);e=Si(v[d+272>>2]);v[22640]=0;b=ga(773,b|0,e|0,d+192|0,d+216|0,0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break tb}v[22640]=0;Q(350,g|0,v[d+192>>2])|0;g=v[22640];v[22640]=0;if((g|0)==1){break tb}xc(d+272|0);break rb}e=P()|0;O()|0;break k}e=P()|0;O()|0;xc(d+272|0);break k}vc(i);b=0;v[d+192>>2]=0;v[d+216>>2]=0}v[22640]=0;R(774,d+272|0,i|0);g=v[22640];v[22640]=0;ub:{vb:{if((g|0)!=1){v[22640]=0;j=Rd(d+272|0);g=v[22640];v[22640]=0;if((g|0)==1){break ub}e=v[d+272>>2];if(!h){b=zb(j);g=Si(e);v[22640]=0;b=ga(773,b|0,g|0,d+192|0,d+216|0,0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break qb}v[22640]=0;Q(350,i|0,v[d+192>>2])|0;g=v[22640];v[22640]=0;if((g|0)==1){break qb}g=v[d+192>>2];e=e-g|0;j=g+j|0}if(b){break vb}c=1;break pb}e=P()|0;O()|0;break k}v[22640]=0;f=B(f,104)+a|0;h=f+484380|0;T(424,h|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break qb}o=f+484400|0;z=f+484414|0;f=0;g=v[d+216>>2];while(1){wb:{if(y[h>>2]<=f>>>0|(!e|(g|0)!=1?g:0)){break wb}if(!Ld(h)){break wb}v[d+160>>2]=0;v[d+240>>2]=0;g=zb(j);n=Si(e);v[22640]=0;g=la(775,b|0,g|0,n|0,d+160|0,d+184|0,d+240|0)|0;n=v[22640];v[22640]=0;if((n|0)==1){break qb}v[22640]=0;v[d+192>>2]=g;Q(350,i|0,g|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break qb}p=v[d+192>>2];Zj(d+240|0,Si(v[h>>2]-f|0));xb:{if(v[d+240>>2]<1){break xb}if(v[d+160>>2]!=(bd(h)|0)){break xb}if(t[z|0]&1){g=ig(d+144|0,v[o>>2]+(B(bd(h),f)<<1)|0,bd(h),v[d+240>>2]);n=ig(d+128|0,v[d+184>>2],v[d+160>>2],v[d+240>>2]);v[22640]=0;v[d+56>>2]=v[g+8>>2];r=v[g+4>>2];v[d+48>>2]=v[g>>2];v[d+52>>2]=r;v[d+40>>2]=v[n+8>>2];g=v[n+4>>2];v[d+32>>2]=v[n>>2];v[d+36>>2]=g;R(776,d+48|0,d+32|0);g=v[22640];v[22640]=0;if((g|0)!=1){break xb}break qb}g=ig(d+112|0,v[o>>2]+B(bd(h),f)|0,bd(h),v[d+240>>2]);n=ig(d+96|0,v[d+184>>2],v[d+160>>2],v[d+240>>2]);v[22640]=0;v[d+24>>2]=v[g+8>>2];r=v[g+4>>2];v[d+16>>2]=v[g>>2];v[d+20>>2]=r;v[d+8>>2]=v[n+8>>2];g=v[n+4>>2];v[d>>2]=v[n>>2];v[d+4>>2]=g;R(777,d+16|0,d|0);g=v[22640];v[22640]=0;if((g|0)==1){break qb}}v[22640]=0;n=v[d+240>>2];g=ey(b);r=v[22640];v[22640]=0;if((r|0)==1){break qb}e=e-p|0;j=j+p|0;v[d+216>>2]=g;f=f+n|0;continue}break}v[22640]=0;fy(b);b=v[22640];v[22640]=0;if((b|0)!=1){break pb}break qb}break qb}e=P()|0;O()|0;break k}e=P()|0;O()|0;xc(d+272|0);break k}xc(d+272|0)}m=m+1|0;f=m&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}yb:{if(v[a+480180>>2]!=4){break yb}f=0;while(1){if(x[a+480192>>1]<=f>>>0){break yb}b=w[Mb(q,f)|0];g=w[Mb(q,f)+1|0];e=w[Mb(q,f)+2|0];i=w[Mb(q,f)+3|0];v[22640]=0;f=f+1|0;ka(780,a|0,f&65535,b|0,g|0,e|0,i|0);b=v[22640];v[22640]=0;if((b|0)!=1){continue}break}e=P()|0;O()|0;break k}zb:{Ab:{Bb:{Cb:{if(!(w[l+2|0]&16)){break Cb}v[22640]=0;b=Q(228,k|0,1)|0;f=v[22640];v[22640]=0;if((f|0)==1){break m}if(!b){break Cb}f=0;v[22640]=0;b=T(353,k|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break n}if(!(!(b&1)|!x[F>>1])){while(1){v[22640]=0;b=T(229,k|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break Bb}t[((f<<5)+a|0)+480288|0]=b;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}while(1){v[22640]=0;b=Q(228,k|0,1)|0;f=v[22640];v[22640]=0;Db:{if((f|0)!=1){if(!b){break Cb}v[22640]=0;b=T(353,k|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break Ab}if(!b){break Cb}v[22640]=0;f=T(229,k|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break zb}v[22640]=0;U(320,d+272|0,k|0,f|0);f=v[22640];v[22640]=0;if((f|0)==1){break zb}if(b>>>0>250){break Db}v[22640]=0;R(625,d+272|0,(B(b,160)+a|0)+906140|0);b=v[22640];v[22640]=0;if((b|0)!=1){break Db}e=P()|0;O()|0;yb(d+272|0);break k}e=P()|0;O()|0;break k}yb(d+272|0);continue}}e=a+901404|0;j=a+1074308|0;i=Kb(d+160|0);g=0;b=0;Eb:{Fb:{while(1){v[22640]=0;f=Q(228,k|0,8)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Eb}if(!f){break Fb}v[22640]=0;f=T(229,k|0)|0;h=v[22640];v[22640]=0;Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{if((h|0)!=1){v[22640]=0;h=T(229,k|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break Wb}v[22640]=0;U(320,d+192|0,k|0,h|0);h=v[22640];v[22640]=0;if((h|0)==1){break Vb}if((f|0)<=1397900629){if((f|0)==1229211981){break Tb}if((f|0)!=1229476432){break Hb}v[22640]=0;f=T(353,d+192|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break q}v[a+480216>>2]=f;v[22640]=0;f=T(353,d+192|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break q}v[a+480220>>2]=f;break Hb}if((f|0)==1397900630){break Ub}if((f|0)!=1414548815){break Hb}v[22640]=0;f=Q(575,d+192|0,11215)|0;h=v[22640];v[22640]=0;if((h|0)==1){break q}if(!f){break Rb}v[22640]=0;f=T(229,d+192|0)|0;h=v[22640];v[22640]=0;if((h|0)!=1){v[22640]=0;U(320,d+216|0,d+192|0,f|0);f=v[22640];v[22640]=0;if((f|0)!=1){break Sb}}e=P()|0;O()|0;break p}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}Xb:{Yb:{Zb:{f=v[a+480180>>2];switch(f-2|0){case 1:break Hb;case 0:break Ib;case 2:break Yb;default:break Zb}}if((f|0)==16){break Xb}if((f|0)!=32){break Hb}v[22640]=0;g=T(319,d+192|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break q}v[22640]=0;b=T(319,d+192|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){break Hb}break q}v[d+272>>2]=32;v[22640]=0;f=T(232,d+192|0)|0;h=v[22640];v[22640]=0;_b:{if((h|0)==1){break _b}v[22640]=0;v[d+216>>2]=f;f=Fb(d+272|0,d+216|0);h=v[22640];v[22640]=0;if((h|0)==1){break _b}f=v[f>>2];v[22640]=0;U(781,d+192|0,i|0,f|0);f=v[22640];v[22640]=0;if((f|0)!=1){break Hb}}e=P()|0;O()|0;break p}v[22640]=0;f=T(353,d+192|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Gb}v[22640]=0;R(782,d+216|0,1320);h=v[22640];v[22640]=0;$b:{if((h|0)!=1){v[d+240>>2]=f>>>4;v[22640]=0;v[d+184>>2]=f&15;Y(485,d+272|0,d+216|0,d+240|0,d+184|0);f=v[22640];v[22640]=0;if((f|0)==1){break $b}Eb(i,d+272|0);vb(d+272|0);Hb(d+216|0);break Hb}e=P()|0;O()|0;break p}e=P()|0;O()|0;Hb(d+216|0);break p}v[22640]=0;Q(588,d+192|0,e|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break q}v[22640]=0;Bu(e);f=v[22640];v[22640]=0;if((f|0)==1){break q}break Hb}v[22640]=0;f=T(232,d+216|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Qb}u[d+272>>1]=f>>>5;f=Oe(D);v[22640]=0;u[d+240>>1]=f;f=Oc(d+272|0,d+240|0);h=v[22640];v[22640]=0;if((h|0)==1){break Qb}h=x[f>>1];if(h){f=0;while(1){v[22640]=0;W(783,d+216|0,d+272|0,32)|0;m=v[22640];v[22640]=0;if((m|0)==1){break Qb}m=_b(D,f);v[22640]=0;Q(784,m|0,d+272|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break Qb}f=f+1|0;if((h|0)!=(f|0)){continue}break}}yb(d+216|0)}v[22640]=0;f=Q(575,d+192|0,11220)|0;h=v[22640];v[22640]=0;if((h|0)==1){break q}if(!f){break Ob}v[22640]=0;f=T(229,d+192|0)|0;h=v[22640];v[22640]=0;if((h|0)!=1){v[22640]=0;U(320,d+272|0,d+192|0,f|0);f=v[22640];v[22640]=0;if((f|0)!=1){break Pb}}e=P()|0;O()|0;break p}e=P()|0;O()|0;yb(d+216|0);break p}v[22640]=0;f=T(232,d+272|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Nb}u[d+216>>1]=(f>>>0)/20;f=x[a+480188>>1];v[22640]=0;u[d+240>>1]=f;f=Oc(d+216|0,d+240|0);h=v[22640];v[22640]=0;if((h|0)==1){break Nb}h=x[f>>1];if(h){f=0;while(1){v[22640]=0;W(591,d+272|0,((f<<5)+a|0)+480289|0,20)|0;m=v[22640];v[22640]=0;if((m|0)==1){break Nb}f=f+1|0;if((h|0)!=(f|0)){continue}break}}yb(d+272|0)}v[22640]=0;Q(608,a|0,d+192|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break q}v[22640]=0;Y(609,a|0,d+192|0,1,0);f=v[22640];v[22640]=0;if((f|0)==1){break q}if((g-2186&65535)>>>0<=117){v[a+480180>>2]=16777216;v[22640]=0;U(624,a|0,d+192|0,g&65535);f=v[22640];v[22640]=0;if((f|0)==1){break q}}if(!v[j>>2]){break Hb}v[22640]=0;f=Q(2,d+216|0,14686)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Mb}v[22640]=0;R(199,d+240|0,j|0);h=v[22640];v[22640]=0;if((h|0)==1){break Lb}v[22640]=0;U(3,d+272|0,f|0,d+240|0);h=v[22640];v[22640]=0;if((h|0)==1){break Kb}Eb(i,d+272|0);vb(d+272|0);vb(d+240|0);vb(f);break Hb}e=P()|0;O()|0;yb(d+272|0);break p}e=P()|0;O()|0;break p}e=P()|0;O()|0;break Jb}e=P()|0;O()|0;vb(d+240|0)}vb(f);break p}v[22640]=0;g=T(319,d+192|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break q}}yb(d+192|0);continue}break}e=P()|0;O()|0;break p}ac:{bc:{cc:{dc:{ec:{fc:{gc:{if(v[a+480180>>2]!=32){break gc}f=g&65535;if(f>>>0<256){break gc}if(f>>>0<532){break fc}}hc:{if(v[a+480180>>2]!=2){break hc}f=g&65535;if(f>>>0<12544){break hc}if(f>>>0<12820){break fc}}if(v[a+480180>>2]!=2){break ec}f=g&65535;if(f>>>0<4864|f>>>0>4895){break ec}}v[22640]=0;To(e);f=v[22640];v[22640]=0;if((f|0)==1){break dc}}if(!(t[l+2|0]&1)){break ac}f=v[a+1074308>>2];if(!f){if(x[a+480192>>1]){f=1;while(1){g=v[(((f&65535)<<2)+a|0)+900380>>2];if(g){v[22640]=0;e=ii(g,2);l=v[22640];v[22640]=0;if((l|0)==1){break cc}l=v[a+480180>>2];v[22640]=0;U(785,e|0,4,l|0);e=v[22640];v[22640]=0;if((e|0)==1){break bc}t[g+19|0]=w[g+19|0]+3>>>2}f=f+1|0;if(x[a+480192>>1]>=(f&65535)>>>0){continue}break}}f=v[a+1074308>>2]}if(f>>>0<=18350079){v[22640]=0;f=a+1074312|0;Q(438,f|0,27)|0;g=v[22640];v[22640]=0;if((g|0)==1){break dc}v[22640]=0;Q(438,f|0,57)|0;f=v[22640];v[22640]=0;if((f|0)==1){break dc}f=v[a+1074308>>2]}if(f>>>0<=19070975){v[22640]=0;Q(438,a+1074312|0,73)|0;f=v[22640];v[22640]=0;if((f|0)==1){break dc}f=v[a+1074308>>2]}if(f>>>0>19267583){break ac}v[22640]=0;Q(438,a+1074312|0,50)|0;f=v[22640];v[22640]=0;if((f|0)!=1){break ac}}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}ic:{jc:{kc:{lc:{mc:{nc:{oc:{pc:{qc:{rc:{sc:{tc:{uc:{vc:{if(dd(i)){v[22640]=0;_(786,d+192|0);f=v[22640];v[22640]=0;wc:{if((f|0)!=1){v[22640]=0;U(743,d+272|0,d+192|0,d+1671|0);f=v[22640];v[22640]=0;if((f|0)==1){break wc}break vc}e=P()|0;O()|0;break o}e=P()|0;O()|0;Hb(d+192|0);break o}v[22640]=0;_(787,d+192|0);f=v[22640];v[22640]=0;if((f|0)==1){break uc}v[22640]=0;Y(788,d+272|0,d+192|0,d+1671|0,i|0);f=v[22640];v[22640]=0;if((f|0)==1){break tc}}Eb(i,d+272|0);vb(d+272|0);Hb(d+192|0);v[22640]=0;R(742,d+192|0,1108);f=v[22640];v[22640]=0;if((f|0)==1){break rc}v[22640]=0;U(743,d+272|0,d+192|0,d+1671|0);f=v[22640];v[22640]=0;if((f|0)==1){break qc}Eb(a+1298304|0,d+272|0);vb(d+272|0);Hb(d+192|0);v[22640]=0;f=Q(2,d+272|0,12197)|0;g=v[22640];v[22640]=0;if((g|0)==1){break pc}Eb(a+1298316|0,f);vb(f);f=v[a+480180>>2];if((f|0)>15){break sc}switch(f-1|0){case 1:break lc;case 3:break mc;case 0:break nc;default:break v}}e=P()|0;O()|0;break o}e=P()|0;O()|0;Hb(d+192|0);break o}if((f|0)==16){break oc}if((f|0)==32){break kc}if((f|0)!=16777216){break v}v[22640]=0;b=Q(2,d+272|0,7450)|0;f=v[22640];v[22640]=0;if((f|0)==1){break jc}Eb(a+1298352|0,b);vb(b);v[22640]=0;b=Q(2,d+272|0,11177)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ic}Eb(a+1298340|0,b);vb(b);break v}e=P()|0;O()|0;break o}e=P()|0;O()|0;Hb(d+192|0);break o}e=P()|0;O()|0;break o}v[22640]=0;b=Q(2,d+272|0,7455)|0;f=v[22640];v[22640]=0;xc:{if((f|0)!=1){Eb(a+1298352|0,b);vb(b);v[22640]=0;b=Q(2,d+272|0,5592)|0;f=v[22640];v[22640]=0;if((f|0)==1){break xc}Eb(a+1298340|0,b);vb(b);break v}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}v[22640]=0;b=Q(2,d+272|0,9606)|0;f=v[22640];v[22640]=0;yc:{if((f|0)!=1){Eb(a+1298352|0,b);vb(b);v[22640]=0;b=Q(2,d+272|0,11522)|0;f=v[22640];v[22640]=0;if((f|0)==1){break yc}Eb(a+1298340|0,b);vb(b);break v}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}v[22640]=0;b=Q(2,d+272|0,7428)|0;f=v[22640];v[22640]=0;zc:{if((f|0)!=1){Eb(a+1298352|0,b);vb(b);v[22640]=0;b=Q(2,d+272|0,12446)|0;f=v[22640];v[22640]=0;if((f|0)==1){break zc}Eb(a+1298340|0,b);vb(b);break v}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}v[22640]=0;b=Q(2,d+272|0,7800)|0;f=v[22640];v[22640]=0;Ac:{if((f|0)!=1){Eb(a+1298352|0,b);vb(b);v[22640]=0;b=Q(2,d+272|0,12246)|0;f=v[22640];v[22640]=0;if((f|0)==1){break Ac}Eb(a+1298340|0,b);vb(b);break v}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}v[22640]=0;f=Q(2,d+272|0,3181)|0;g=v[22640];v[22640]=0;Bc:{Cc:{Dc:{Ec:{Fc:{if((g|0)!=1){Eb(a+1298352|0,f);vb(f);if(!(b&65535)){break Bc}v[22640]=0;R(439,d+192|0,1423);f=v[22640];v[22640]=0;if((f|0)==1){break Fc}v[d+240>>2]=(b&65280)>>>8;v[22640]=0;v[d+184>>2]=b&255;R(619,d+216|0,d+184|0);b=v[22640];v[22640]=0;if((b|0)==1){break Ec}v[22640]=0;Y(602,d+272|0,d+192|0,d+240|0,d+216|0);b=v[22640];v[22640]=0;if((b|0)==1){break Dc}Eb(a+1298340|0,d+272|0);vb(d+272|0);vb(d+216|0);Hb(d+192|0);break v}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break Cc}e=P()|0;O()|0;vb(d+216|0)}Hb(d+192|0);break o}v[22640]=0;b=Q(2,d+272|0,5768)|0;f=v[22640];v[22640]=0;if((f|0)!=1){Eb(a+1298340|0,b);vb(b);break v}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break i}e=P()|0;O()|0;break g}e=P()|0;O()|0;break g}e=P()|0;O()|0;break g}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}Eb(a+1298328|0,i);Gc:{if(v[a+1074308>>2]){v[a+1298364>>2]=8;break Gc}if(v[a+480180>>2]==1){v[a+1298364>>2]=2;break Gc}v[a+1298364>>2]=5}f=1;if(c&1){v[22640]=0;b=Q(2,d+272|0,13761)|0;c=v[22640];v[22640]=0;if((c|0)==1){break s}v[22640]=0;U(580,a|0,2,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break r}vb(b)}vb(i);UB(s);ai(q);fd(A);yb(d+1136|0);yb(d+1160|0)}yb(k)}gc(C);break a}e=P()|0;O()|0;break o}e=P()|0;O()|0;vb(b);break o}e=P()|0;O()|0}yb(d+192|0)}vb(i);break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0}UB(s);break i}e=P()|0;O()|0}ai(q);break g}e=P()|0;O()|0}fd(A)}yb(d+1136|0)}yb(d+1160|0);break c}e=P()|0;O()|0}yb(k)}gc(C);S(e|0);L()}gb=d+1680|0;return f|0}function zka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,A=C(0),D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Z=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ha=0,ia=C(0),ja=0,ka=0,la=0,ma=C(0);e=gb-464|0;gb=e;vc(b);a:{b:{c:{if(!Hh(b,e+456|0)){break c}if(!TT(e+456|0)){break c}if((PT(b)|0)>-1){break c}if(!c){f=1;break c}Gd(a,16777216);v[a+480208>>2]=v[a+480208>>2]|1681e4;Yz(e+216|0,32);f=v[e+228>>2];d=a+1074320|0;v[d>>2]=v[e+224>>2];v[d+4>>2]=f;d=v[e+220>>2];v[a+1074312>>2]=v[e+216>>2];v[a+1074316>>2]=d;Yf(a+1074312|0,38);D=ad(e+440|0);G=ad(e+424|0);E=ad(e+408|0);n=ad(e+392|0);lg(b,4);o=a+480190|0;I=c&1;h=a+1298292|0;y=2500;k=!(c&2);d:{e:{f:{g:{h:{i:{while(1){v[22640]=0;c=Q(228,b|0,4)|0;d=v[22640];v[22640]=0;j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((d|0)!=1){t:{if(c){v[22640]=0;j=T(917,b|0)|0;c=v[22640];v[22640]=0;u:{if((c|0)==1){break u}f=0;v:{switch(j+21|0){case 20:v[22640]=0;c=T(453,b|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){if(x[a+480188>>1]){continue}d=c&65535;if(!d|d>>>0>127){continue}u[a+480188>>1]=c;ka=a,la=Lb(512/(d>>>0)|0,16,128),v[ka+480228>>2]=la;continue}a=P()|0;O()|0;break a;case 19:v[22640]=0;K=T(453,b|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break u}if(K>>>0<=1024){continue}break q;case 16:v[22640]=0;c=T(453,b|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){if((c&65535)==4){continue}break q}a=P()|0;O()|0;break a;case 15:v[22640]=0;c=T(453,b|0)|0;d=v[22640];v[22640]=0;w:{if((d|0)!=1){v[e+216>>2]=c;v[22640]=0;v[e+112>>2]=800;c=Fb(e+216|0,e+112|0);d=v[22640];v[22640]=0;if((d|0)==1){break w}v[a+480204>>2]=B(v[c>>2],12400);continue}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a;case 17:case 18:v[22640]=0;Q(350,b|0,4)|0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}break u;case 31:v[22640]=0;c=T(453,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break u}Z=1;y=Jd(c,0,1e4);continue;case 32:case 33:v[22640]=0;c=T(453,b|0)|0;d=v[22640];v[22640]=0;x:{y:{if((d|0)!=1){Z=1;if(!c){continue}v[22640]=0;c=Q(2,e+216|0,9866)|0;d=v[22640];v[22640]=0;if((d|0)==1){break y}v[22640]=0;U(580,a|0,2,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break x}vb(c);continue}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a;case 14:v[22640]=0;Q(350,b|0,4)|0;c=v[22640];v[22640]=0;if((c|0)==1){break u}p=!x[o>>1]|p;continue;case 11:z:{if(!I){break z}if(!$c(D)){break z}v[22640]=0;R(918,e+216|0,b|0);c=v[22640];v[22640]=0;if((c|0)!=1){c=D;d=c;if(v[c>>2]){Nd(d);tB(v[d>>2],$h(d));ka=wb(d),la=0,v[ka>>2]=la;v[d>>2]=0;v[d+4>>2]=0}d=e+216|0;v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];f=wb(d);ka=wb(c),la=v[f>>2],v[ka>>2]=la;v[f>>2]=0;v[d>>2]=0;v[d+4>>2]=0;Ku(e+216|0);continue}a=P()|0;O()|0;break a}v[22640]=0;c=T(453,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break u}v[22640]=0;Q(350,b|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}break u;case 3:case 4:case 10:if(ah(n)>>>0<=x[o>>1]){continue}A:{if((k|p)&1){break A}if(!ei(a)){break A}m=x[o>>1]+1|0;u[o>>1]=m;d=nc(e+376|0);v[22640]=0;c=T(251,e+216|0)|0;f=v[22640];v[22640]=0;B:{C:{D:{if((f|0)!=1){if((j|0)==-17){break D}if((j|0)!=-11){break C}v[22640]=0;f=T(453,b|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break B}v[22640]=0;U(320,e+112|0,b|0,f|0);f=v[22640];v[22640]=0;if((f|0)==1){break B}od(c,e+112|0);yb(e+112|0);break j}a=P()|0;O()|0;break d}v[22640]=0;R(919,e+112|0,b|0);f=v[22640];v[22640]=0;E:{if((f|0)!=1){lp(d,e+112|0);gc(e+112|0);v[22640]=0;be(e+368|0,d);f=v[22640];v[22640]=0;if((f|0)==1){break E}f=Sd(e+360|0);v[22640]=0;j=v[e+372>>2];v[e+24>>2]=v[e+368>>2];v[e+28>>2]=j;j=v[f+4>>2];v[e+16>>2]=v[f>>2];v[e+20>>2]=j;f=W(530,e+112|0,e+24|0,e+16|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break E}od(c,f);yb(f);break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}v[22640]=0;R(920,e+112|0,b|0);f=v[22640];v[22640]=0;F:{if((f|0)!=1){lp(d,e+112|0);gc(e+112|0);v[22640]=0;be(e+352|0,d);f=v[22640];v[22640]=0;if((f|0)==1){break F}f=Sd(e+344|0);v[22640]=0;j=v[e+356>>2];v[e+8>>2]=v[e+352>>2];v[e+12>>2]=j;j=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=j;f=W(530,e+112|0,e+8|0,e|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break F}od(c,f);yb(f);break j}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}v[22640]=0;c=T(453,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break u}v[22640]=0;Q(350,b|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}break u;case 9:if(!ei(a)){continue}u[o>>1]=x[o>>1]+1;continue;case 8:G:{if(!I){break G}if(!$c(E)){break G}v[22640]=0;R(921,e+216|0,b|0);c=v[22640];v[22640]=0;if((c|0)!=1){c=E;d=c;if(v[c>>2]){Nd(d);eC(v[d>>2],ye(d));ka=wb(d),la=0,v[ka>>2]=la;v[d>>2]=0;v[d+4>>2]=0}d=e+216|0;v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];f=wb(d);ka=wb(c),la=v[f>>2],v[ka>>2]=la;v[f>>2]=0;v[d>>2]=0;v[d+4>>2]=0;ai(e+216|0);continue}a=P()|0;O()|0;break a}v[22640]=0;c=T(453,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break u}v[22640]=0;Q(350,b|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}break u;case 7:if($c(n)){v[22640]=0;R(922,e+216|0,b|0);c=v[22640];v[22640]=0;if((c|0)!=1){c=n;d=c;if(v[c>>2]){Nd(d);qB(v[d>>2],rB(d));ka=wb(d),la=0,v[ka>>2]=la;v[d>>2]=0;v[d+4>>2]=0}d=e+216|0;v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];f=wb(d);ka=wb(c),la=v[f>>2],v[ka>>2]=la;v[f>>2]=0;v[d>>2]=0;v[d+4>>2]=0;Iu(e+216|0);continue}a=P()|0;O()|0;break a}v[22640]=0;c=T(453,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break u}v[22640]=0;Q(350,b|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}break u;case 6:H:{if(!I){break H}if(!$c(G)){break H}v[22640]=0;R(923,e+216|0,b|0);c=v[22640];v[22640]=0;if((c|0)!=1){c=G;d=c;if(v[c>>2]){Nd(d);sB(v[d>>2],si(d));ka=wb(d),la=0,v[ka>>2]=la;v[d>>2]=0;v[d+4>>2]=0}d=e+216|0;v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];f=wb(d);ka=wb(c),la=v[f>>2],v[ka>>2]=la;v[f>>2]=0;v[d>>2]=0;v[d+4>>2]=0;Hu(e+216|0);continue}a=P()|0;O()|0;break a}v[22640]=0;c=T(453,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break u}v[22640]=0;Q(350,b|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}break u;case 5:v[22640]=0;R(924,e+216|0,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break t}I:{if($c(e+216|0)){break I}c=v[e+216>>2];d=pc(e+216|0);v[22640]=0;ca(925,h|0,c|0,d|0,1)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break I}a=P()|0;O()|0;gc(e+216|0);break a}gc(e+216|0);continue;case 0:case 1:case 2:break v;default:break q}}v[22640]=0;c=T(453,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break u}v[22640]=0;Q(350,b|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}}a=P()|0;O()|0;break a}f=0;if(!x[a+480188>>1]|!K){break q}if($c(n)){break q}if(I){if($c(D)){break q}if($c(E)){break q}if($c(G)){break q}}if(ah(n)>>>0>=256){v[22640]=0;R(926,n|0,255);b=v[22640];v[22640]=0;if((b|0)==1){break b}}ka=a,la=ah(n),u[ka+480192>>1]=la;v[22640]=0;k=a+480192|0;b=Ie(o,k);c=v[22640];v[22640]=0;if((c|0)==1){break b}u[o>>1]=x[b>>1];if(p&1){v[22640]=0;b=Q(2,e+216|0,13591)|0;c=v[22640];v[22640]=0;if((c|0)==1){break k}v[22640]=0;U(580,a|0,2,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break l}vb(b)}f=x[k>>1];p=1;while(1){d=f;f=0;c=1;b=1;J:{if(!d){break J}while(1){K:{h=Ql(n,c-1|0);d=h;if(w[d|0]){d=t[d+128|0]<0}else{d=1}L:{if(d){break L}if((Gu(h)|0)==(p&1)){break L}j=0;d=h;M:{if(!Gu(d)){break M}if(Ib(w[d+6|0]|w[d+7|0]<<8)){break M}if(Ib(w[d+14|0]|w[d+15|0]<<8)>>>0>20){break M}j=(Ib(w[d+18|0]|w[d+19|0]<<8)|0)==4}N:{O:{if(j){f=w[h+23|0];d=w[h+140|0];v[22640]=0;d=ga(927,h|0,a|0,(d&2)>>>1|0,(B(c,104)+a|0)+484380|0,y&65535)|0;j=v[22640];v[22640]=0;P:{Q:{R:{if((j|0)!=1){if(!d){break P}v[22640]=0;d=Q(112,e+216|0,8069)|0;j=v[22640];v[22640]=0;if((j|0)==1){break R}v[22640]=0;Q(333,((c<<5)+a|0)+946304|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break Q}vb(d);d=b;if(ah(n)>>>0<=f>>>0){break N}ka=h,la=w[Ql(n,f)+143|0]+w[h+143|0]|0,t[ka+143|0]=la;break O}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}d=f+1|0;break N}j=0;S:{if(!Gu(h)){break S}if((Ib(w[d+6|0]|w[d+7|0]<<8)|0)!=1){break S}if((Ib(w[d+14|0]|w[d+15|0]<<8)|0)!=2){break S}j=(Ib(w[d+18|0]|w[d+19|0]<<8)|0)==10}d=b;if(!j){break N}hc(e+216|0,h,128);if(Ib(w[e+236|0]|w[e+237|0]<<8)>>>0>=x[o>>1]){break O}v[22640]=0;f=Q(912,e+112|0,0)|0;d=v[22640];v[22640]=0;T:{U:{V:{if((d|0)!=1){d=(B(Ib(w[e+236|0]|w[e+237|0]<<8),104)+a|0)+484484|0;if(Ib(w[e+252|0]|w[e+253|0]<<8)>>>0<x[a+480190>>1]){f=(B(Ib(w[e+252|0]|w[e+253|0]<<8),104)+a|0)+484484|0}v[22640]=0;d=ca(928,e+216|0,d|0,f|0,(B(c,104)+a|0)+484380|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break V}if(!d){break O}v[22640]=0;d=Q(112,e+376|0,8593)|0;f=v[22640];v[22640]=0;if((f|0)==1){break U}v[22640]=0;Q(333,((c<<5)+a|0)+946304|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break T}vb(d);t[h+139|0]=w[h+139|0]+12;break O}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}d=b}v[22640]=0;c=d&65535;d=W(415,a|0,b&65535,c|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break K}if(!d|c>>>0>x[o>>1]){break L}v[22640]=0;Y(929,h|0,d|0,(B(c,104)+a|0)+484380|0,a|0);c=v[22640];v[22640]=0;if((c|0)==1){break K}}b=b+1|0;c=b&65535;f=x[k>>1];if(c>>>0<=f>>>0){continue}break J}break}a=P()|0;O()|0;break a}b=p&1;p=0;if(b){continue}break}F=Ck(e+112|0);o=Ck(e+376|0);b=Nb(E);$=B(x[a+480188>>1],K);aa=Ev((b>>>0)/($>>>0)|0);v[22640]=0;M=a+484344|0;R(364,M|0,aa|0);b=v[22640];v[22640]=0;if((b|0)==1){a=P()|0;O()|0;break m}ba=a+484360|0;sn(Rb(ba));b=x[a+480188>>1];v[22640]=0;r=Q(930,e+96|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){ka=e,la=Sb(G),v[ka+88>>2]=la;ka=e,la=Wb(G),v[ka+80>>2]=la;if(!Gb(e+88|0,e+80|0)){break s}W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{while(1){da:{q=v[e+88>>2];b=q;ea:{if((Ib(w[b+6|0]|w[b+7|0]<<8)|0)==1){break ea}if((Ib(w[b+6|0]|w[b+7|0]<<8)|0)==65535){break da}b=Ib(w[q|0]|w[q+1|0]<<8);if(Ae(D)>>>0<=b>>>0){break ea}b=Ib(w[q+2|0]|w[q+3|0]<<8);if(Ae(D)>>>0<b>>>0){break ea}if(!Ib(w[q+2|0]|w[q+3|0]<<8)){break ea}if(Ae(D)-Ib(w[q+2|0]|w[q+3|0]<<8)>>>0<Ib(w[q|0]|w[q+1|0]<<8)>>>0){break ea}b=v[D>>2];pd(e+216|0,b,b+(Ae(D)<<5)|0);c=Ib(w[q|0]|w[q+1|0]<<8);b=Ib(w[q+2|0]|w[q+3|0]<<8);d=v[e+216>>2]+(c<<5)|0;b=(b|0)==-1?(v[e+220>>2]-v[e+216>>2]>>5)-c|0:b;v[e+72>>2]=d;v[e+76>>2]=d+(b<<5);fa:{N=Rb(ba);if($c(N)){break fa}v[22640]=0;R(729,N|0,65534);b=v[22640];v[22640]=0;if((b|0)!=1){break fa}a=P()|0;O()|0;break n}b=v[e+72>>2];da=v[e+76>>2];if((b|0)==(da|0)){break ea}while(1){m=b;c=Ib(Ib(w[q+8|0]|w[q+9|0]<<8)+Ib(w[b+16|0]|w[b+17|0]<<8)&65535);t[b+16|0]=c;t[b+17|0]=c>>>8;ga:{ha:{ia:{d=b;f=F;c=Vd(f);ja:{if(c){wb(f);while(1){j=c+14|0;if(!Eu(d,j)){f=1;if(!Eu(j,d)){break ja}c=c+4|0}c=v[c>>2];if(c){continue}break}}f=0}if(f){v[22640]=0;c=Q(931,F|0,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break ia}H=x[c>>1];break ha}H=0;if(!I){break ha}c=Ib(w[b+12|0]|w[b+13|0]<<8);v[22640]=0;H=W(564,M|0,c|0,0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break ia}if((H|0)==65535){break ea}v[22640]=0;c=Q(931,F|0,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break ia}u[c>>1]=H;c=b;if(Ib(w[c+8|0]|w[c+9|0]<<8)>>>0>=aa>>>0){break ga}d=b;if(Ib(w[d+10|0]|w[d+11|0]<<8)>>>0>=K>>>0){break ga}ea=b;j=Ib(w[b+14|0]|w[b+15|0]<<8);ka=e,la=Sb(E),v[ka+48>>2]=la;ka=e,la=Xo(e+48|0,B(Ib(w[c+8|0]|w[c+9|0]<<8),$)),v[ka+216>>2]=la;ka=e,la=Xo(e+216|0,B(Ib(w[d+10|0]|w[d+11|0]<<8),x[a+480188>>1])),v[ka+64>>2]=la;v[e+60>>2]=0;Zi(e+48|0);fa=b;if(Ib(w[b+12|0]|w[b+13|0]<<8)){V=0;while(1){c=_b(M,H);v[22640]=0;X=Tc(c,V,0);c=v[22640];v[22640]=0;ka:{la:{if((c|0)!=1){s=0;p=0;if(x[a+480188>>1]){break la}break ka}a=P()|0;O()|0;break n}while(1){ka=e,la=Wb(E),v[ka+216>>2]=la;c=e+60|0;if(Gb(e- -64|0,e+216|0)){c=v[e- -64>>2]}ka=e,la=Wb(E),v[ka+216>>2]=la;if(Gb(e- -64|0,e+216|0)){Fg(e- -64|0)}d=B(s,6);h=c;if(t[c+1|0]<0|t[c+1|0]>84){f=255}else{f=w[h+1|0]+25|0}d=d+X|0;y=0;l=ah(n);k=c;J=w[c+3|0];ma:{if(l>>>0<=J>>>0){break ma}y=J+1|0;if(t[Ql(n,J)+142|0]&1|f<<24>>24<0){break ma}f=pn(Ib(w[m+16|0]|w[m+17|0]<<8)+f<<24>>24)}na:{if(!w[d|0]){break na}if(!(w[k+3|0]|(w[c|0]|w[h+1|0]!=255))){if(!w[c+2|0]){break na}}l=w[d+1|0];if(!l){break na}if(ah(n)>>>0<l>>>0){break na}if(w[Ql(n,l-1|0)+132|0]!=2){break na}Yo(d)}g=Lj(r,s);oa:{if(p&1){l=v[e+48>>2];t[d|0]=l;t[d+1|0]=l>>>8;t[d+2|0]=l>>>16;t[d+3|0]=l>>>24;l=x[e+52>>1];t[d+4|0]=l;t[d+5|0]=l>>>8;pa:{if(w[d+3|0]){break pa}l=s-1|0;if(w[g+21|0]==w[Lj(r,l)+21|0]){break pa}t[d+3|0]=21;l=w[Lj(r,l)+21|0];t[g+21|0]=l;t[d+5|0]=l}p=0;l=1;qa:{if(w[c|0]==9){break qa}if(w[c|0]==24|w[c|0]==25|!(w[c+2|0]==249|w[c+2|0]==250?w[c|0]:1)){break qa}l=0}if(!l){break oa}}l=d;ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{switch(w[c|0]){case 5:h=w[g+17|0];break xa;case 0:za:{if(w[c+2|0]>=201){p=0;Aa:{switch(w[c+2|0]-242|0){case 11:t[d+4|0]=1;t[d+2|0]=14;t[g+16|0]=0;break sa;case 9:t[d+4|0]=1;t[d+2|0]=15;break sa;case 8:if((j&255)>>>0<2){break sa}j=j-1|0;break ta;case 7:if((j&255)==255){j=255;break sa}j=j+1|0;break ta;case 6:t[g+17|0]=f;if(w[g+18|0]!=(y&255)){break sa}t[d|0]=f;t[d+5|0]=255;t[d+3|0]=4;u[g+32>>1]=0;v[g+8>>2]=0;break sa;case 5:t[d+5|0]=242;t[d+3|0]=2;break sa;case 4:t[d+5|0]=242;t[d+3|0]=3;break sa;case 3:t[d+5|0]=244;t[d+3|0]=2;break sa;case 2:t[d+5|0]=244;t[d+3|0]=3;break sa;case 1:t[d+5|0]=248;t[d+3|0]=2;break sa;case 12:break za;case 0:break Aa;default:break sa}}t[d+5|0]=248;t[d+3|0]=3;break sa}if(t[h+1|0]<=-1){p=0;if(w[c+2|0]>99){break sa}}if(t[h+1|0]>=0){t[g+17|0]=f;t[d|0]=f;t[g+18|0]=y;t[d+1|0]=y;u[g+32>>1]=0;v[g+8>>2]=0}if(!w[c+2|0]){p=0;break sa}c=w[c+2|0];v[22640]=0;c=fn(+(c>>>0)*.64);f=v[22640];v[22640]=0;if((f|0)==1){break ua}t[g+19|0]=c;i=z[g>>2];v[g>>2]=0;p=i!=C(0);break sa}t[d+4|0]=0;t[d+2|0]=14;t[g+16|0]=1;break sa;case 1:v[g+4>>2]=0;z[g>>2]=C(w[c+2|0])*C(.0333000011742115);break ra;case 2:v[g+4>>2]=0;z[g>>2]=C(w[c+2|0])*C(-.0333000011742115);break ra;case 12:t[e+216|0]=15;f=w[k+3|0];v[22640]=0;t[e+44|0]=f>>>3;f=ac(e+216|0,e+44|0);h=v[22640];v[22640]=0;Ba:{if((h|0)!=1){f=w[f|0];t[e+216|0]=15;c=w[c+2|0];v[22640]=0;t[e+44|0]=c>>>3;c=ac(e+216|0,e+44|0);h=v[22640];v[22640]=0;if((h|0)==1){break Ba}t[g+24|0]=w[c|0]|f<<4;break ra}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 3:v[g+12>>2]=0;c=w[c+2|0];u[g+32>>1]=0;z[g+8>>2]=C(c>>>0)*C(.0333000011742115);break ra;case 4:v[g+12>>2]=0;c=w[c+2|0];u[g+32>>1]=0;z[g+8>>2]=C(c>>>0)*C(-.0333000011742115);break ra;case 15:h=f<<24>>24;if(!w[c+2|0]|(h|0)<0){break ra}k=h-w[g+17|0]|0;h=k>>31;h=h^h+(k<<5);v[e+216>>2]=h;t[g+17|0]=f;v[g+8>>2]=0;t[d|0]=f;t[d+3|0]=4;c=di((h>>>0)/(w[c+2|0]<<1>>>0)|0);t[d+5|0]=c;t[g+27|0]=c;v[22640]=0;f=v[e+216>>2];v[e+44>>2]=B(c,(j&255)-1|0);c=ld(e+216|0,e+44|0);h=v[22640];v[22640]=0;if((h|0)!=1){u[g+32>>1]=f-v[c>>2];break ra}a=P()|0;O()|0;break n;case 10:case 11:t[d+3|0]=0;t[d+5|0]=0;break ra;case 13:t[e+216|0]=15;f=w[k+3|0];v[22640]=0;t[e+44|0]=f>>>3;f=ac(e+216|0,e+44|0);h=v[22640];v[22640]=0;Ca:{if((h|0)!=1){f=w[f|0];t[e+216|0]=15;c=w[c+2|0];v[22640]=0;t[e+44|0]=c;c=ac(e+216|0,e+44|0);h=v[22640];v[22640]=0;if((h|0)==1){break Ca}t[g+23|0]=w[c|0]|f<<4;break ra}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 23:case 24:case 25:k=o;f=Vd(k);Da:{if(f){wb(k);while(1){l=f+13|0;if(!Du(h,l)){k=1;if(!Du(l,h)){break Da}f=f+4|0}f=v[f>>2];if(f){continue}break}}k=0}if(k){t[d+3|0]=31;v[22640]=0;c=Q(932,o|0,c|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ua}t[d+5|0]=w[c|0];break ra}if(QT(o)>>>0>127){break ra}f=QT(o);h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22640]=0;v[e+40>>2]=h;v[e+32>>2]=h;h=W(933,e+32|0,(((f&255)<<5)+a|0)+902204|0,a|0)|0;k=v[22640];v[22640]=0;Ea:{if((k|0)==1){break Ea}if(!h){break ra}t[d+3|0]=31;v[22640]=0;h=Q(932,o|0,c|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break Ea}f=f|-128;t[h|0]=f;t[d+5|0]=f;if(w[c|0]!=25?w[c|0]!=24:0){break ra}ja=1;break ra}a=P()|0;O()|0;break n;case 16:if(!w[c+2|0]){break ra}t[d+3|0]=15;v[e+216>>2]=15;f=w[k+3|0];v[22640]=0;v[e+44>>2]=f+1;f=ld(e+216|0,e+44|0);h=v[22640];v[22640]=0;if((h|0)!=1){t[d+5|0]=v[f>>2];u[g+30>>1]=B(w[c+2|0],w[k+3|0]+1|0);break ra}a=P()|0;O()|0;break n;case 9:t[d+3|0]=16;j=w[c+2|0]?w[c+2|0]:4;t[d+5|0]=j;break ra;case 19:if(w[h+1|0]!=4?w[h+1|0]:0){break ra}t[e+39|0]=w[h+1|0]==4?w[k+3|0]:128;t[e+216|0]=w[c+2|0];v[22640]=0;t[e+44|0]=100;c=ac(e+216|0,e+44|0);f=v[22640];v[22640]=0;Fa:{Ga:{if((f|0)!=1){c=w[c|0];v[e+216>>2]=128;v[22640]=0;v[e+44>>2]=256-w[e+39|0];f=ld(e+216|0,e+44|0);k=v[22640];v[22640]=0;if((k|0)==1){break Ga}f=v[f>>2];v[22640]=0;t[e+216|0]=128;k=ac(e+216|0,e+39|0);l=v[22640];v[22640]=0;if((l|0)==1){break Fa}k=w[k|0];f=(B(c,f)|0)/128|0;l=f&255;if((l|0)!=w[g+20|0]){t[g+20|0]=f;t[d+3|0]=21;f=Uc(((B(l,w[g+19|0])+50&65535)>>>0)/100|0,0);t[g+21|0]=f;t[d+5|0]=f}if(w[h+1|0]!=4|(x[a+480188>>1]-1|0)<=(s|0)){break ra}f=s+1|0;h=Lj(r,f);c=B(c,k)>>>7|0;if(w[h+20|0]==(c&255)){break ra}t[h+20|0]=c;c=B(f,6)+X|0;t[c+3|0]=21;f=Uc(((B(w[g+20|0],w[g+19|0])+50&65535)>>>0)/100|0,0);t[g+21|0]=f;t[c+5|0]=f;break ra}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n;case 17:case 20:t[d+3|0]=0;break ra;case 7:c=w[c+2|0];t[g+25|0]=0;t[g+26|0]=0;t[g+22|0]=c;break ra;case 8:t[g+22|0]=w[g+22|0]+w[c+2|0];break ra;case 14:t[g+25|0]=w[k+3|0];t[g+26|0]=w[c+2|0];break ra;case 18:break wa;case 6:break ya;default:break ra}}t[g+18|0]=y;t[g+17|0]=f;t[d+1|0]=y;h=f}t[l|0]=h;if(f<<24>>24>=0){t[g+18|0]=y;t[d+1|0]=y}if(w[c|0]==5){t[d+4|0]=1;t[d+2|0]=11}if(!(w[g+26|0]?1:w[c+2|0]|w[g+22|0])){break va}f=w[g+26|0];if(f){ha=+(f>>>0)*.25*(pi(+x[g+28>>1]*.006135923151542565+4.71238898038469)+-1)}else{ha=0}t[d+3|0]=44;f=w[g+22|0];c=w[c+2|0];v[22640]=0;c=fn(ha+ +(c+f|0));f=v[22640];v[22640]=0;if((f|0)!=1){t[d+5|0]=c;break va}a=P()|0;O()|0;break n}c=w[g+17|0]+w[c+2|0]&255;c=c?c>>>0<120?c:120:1;t[g+17|0]=c;t[d|0]=c;t[d+5|0]=255;t[d+3|0]=4}u[g+32>>1]=0;break ra}a=P()|0;O()|0;break n}t[d+5|0]=j;t[d+3|0]=16}c=Uc(((B(w[g+20|0],w[g+19|0])+50&65535)>>>0)/100|0,0);if(w[g+21|0]==(c&255)?p:1){t[g+21|0]=c;t[d+5|0]=c;t[d+3|0]=21}if(s&1|t[h+1|0]<1|(x[a+480188>>1]-1|0)<=(s|0)){break ra}if(ah(n)>>>0<=J>>>0){break ra}if(w[Ql(n,J)+132|0]!=1){break ra}f=s+1|0;c=B(f,6)+X|0;h=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[c|0]=h;t[c+1|0]=h>>>8;t[c+2|0]=h>>>16;t[c+3|0]=h>>>24;h=w[d+4|0]|w[d+5|0]<<8;t[c+4|0]=h;t[c+5|0]=h>>>8;t[c+1|0]=w[c+1|0]+1;ka=Lj(r,f),la=w[g+19|0],t[ka+19|0]=la;ka=Lj(r,f),ma=z[g>>2],z[ka>>2]=ma;ka=Lj(r,f),ma=z[g+4>>2],z[ka+4>>2]=ma;ka=Lj(r,f),ma=z[g+8>>2],z[ka+8>>2]=ma;ka=Lj(r,f),ma=z[g+12>>2],z[ka+12>>2]=ma;ka=Lj(r,f),la=x[g+30>>1],u[ka+30>>1]=la}Ha:{if(w[d|0]){t[g+16|0]=0;break Ha}p=0;if(w[g+16|0]){break oa}}Ia:{Ja:{Ka:{La:{Ma:{Na:{if(!x[g+30>>1]){break Na}v[22640]=0;c=j&255;u[e+216>>1]=c;f=Ie(g+30|0,e+216|0);h=v[22640];v[22640]=0;if((h|0)==1){break Ma}u[g+30>>1]=x[f>>1]-c;if(w[d+3|0]){break Na}t[d+3|0]=15;t[d+5|0]=0}i=z[g>>2];if(i==C(0)){break Ia}c=j&255;i=C(z[g+4>>2]+C(i*C(c>>>0)));z[g+4>>2]=i;if(w[d+3|0]){break Ia}Oa:{Pa:{if(c>>>0>=2){f=c-1|0;A=C(f|0);if(A>i){break Pa}t[e+216|0]=15;v[22640]=0;c=e;i=C(i/A);Qa:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break Qa}h=0}t[c+44|0]=h;c=ac(e+216|0,e+44|0);h=v[22640];v[22640]=0;if((h|0)!=1){c=w[c|0];z[g+4>>2]=z[g+4>>2]-C(B(c,f)|0);t[d+3|0]=22;c=c<<4;break Ja}a=P()|0;O()|0;break n}if(i<C(1)){break Oa}break Ka}if(!(i<C(1))){break Ka}if(i>C(1-c|0)){break Oa}t[e+216|0]=15;v[22640]=0;c=e;i=C(C(-i)/A);Ra:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break Ra}h=0}t[c+44|0]=h;c=ac(e+216|0,e+44|0);h=v[22640];v[22640]=0;if((h|0)!=1){c=w[c|0];z[g+4>>2]=z[g+4>>2]+C(B(f,c)|0);t[d+3|0]=22;break Ja}a=P()|0;O()|0;break n}if(i>C(-1)){break Ia}t[e+216|0]=14;v[22640]=0;c=e;i=C(-i);Sa:{if(i<C(4294967296)&i>=C(0)){f=~~i>>>0;break Sa}f=0}t[c+44|0]=f;c=ac(e+216|0,e+44|0);f=v[22640];v[22640]=0;if((f|0)==1){break La}c=w[c|0];z[g+4>>2]=z[g+4>>2]+C(c>>>0);t[d+3|0]=22;c=c|-16;break Ja}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}t[e+216|0]=15;v[22640]=0;c=e;if(i<C(4294967296)&i>=C(0)){f=~~i>>>0}else{f=0}t[c+44|0]=f;c=ac(e+216|0,e+44|0);f=v[22640];v[22640]=0;if((f|0)!=1){c=w[c|0];z[g+4>>2]=z[g+4>>2]-C(c>>>0);t[d+3|0]=22;c=c<<4|15;break Ja}a=P()|0;O()|0;break n}t[d+5|0]=c}Ta:{i=z[g+8>>2];if(i==C(0)){break Ta}c=j&255;i=C(z[g+12>>2]+C(i*C(c>>>0)));z[g+12>>2]=i;Ua:{if(!w[d+3|0]){Va:{Wa:{if(c>>>0>=2){f=c-1|0;A=C(f|0);if(A>i){break Wa}t[e+216|0]=223;v[22640]=0;c=e;i=C(i/A);Xa:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break Xa}h=0}t[c+44|0]=h;c=ac(e+216|0,e+44|0);h=v[22640];v[22640]=0;if((h|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(B(c,f)|0);t[d+3|0]=2;t[d+5|0]=c;break Ta}a=P()|0;O()|0;break n}if(i<C(1)){break Va}break Ua}if(!(i<C(1))){break Ua}if(i>C(1-c|0)){break Va}t[e+216|0]=223;v[22640]=0;c=e;i=C(C(-i)/A);Ya:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break Ya}h=0}t[c+44|0]=h;c=ac(e+216|0,e+44|0);h=v[22640];v[22640]=0;if((h|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(B(c,f)|0);t[d+3|0]=3;t[d+5|0]=c;break Ta}a=P()|0;O()|0;break n}if(i>C(-1)){break Ta}t[e+216|0]=14;v[22640]=0;c=e;i=C(-i);Za:{if(i<C(4294967296)&i>=C(0)){f=~~i>>>0;break Za}f=0}t[c+44|0]=f;c=ac(e+216|0,e+44|0);f=v[22640];v[22640]=0;if((f|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(c>>>0);t[d+3|0]=3;t[d+5|0]=c|240;break Ta}a=P()|0;O()|0;break n}if(w[d+2|0]|c>>>0<2){break Ta}ia=C(i*C(.25));f=c-1|0;A=C(f|0);if(!(ia<A)){t[e+216|0]=9;v[22640]=0;c=e;i=C(i/A);_a:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break _a}h=0}t[c+44|0]=h>>>2;c=ac(e+216|0,e+44|0);h=v[22640];v[22640]=0;if((h|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(B(c,f)<<2);t[d+2|0]=12;t[d+4|0]=c;break Ta}a=P()|0;O()|0;break n}if(C(1-c|0)<ia){break Ta}t[e+216|0]=9;v[22640]=0;c=e;i=C(C(-i)/A);$a:{if(i<C(4294967296)&i>=C(0)){h=~~i>>>0;break $a}h=0}t[c+44|0]=h>>>2;c=ac(e+216|0,e+44|0);h=v[22640];v[22640]=0;if((h|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]+C(B(c,f)<<2);t[d+2|0]=13;t[d+4|0]=c;break Ta}a=P()|0;O()|0;break n}t[e+216|0]=15;v[22640]=0;c=e;if(i<C(4294967296)&i>=C(0)){f=~~i>>>0}else{f=0}t[c+44|0]=f;c=ac(e+216|0,e+44|0);f=v[22640];v[22640]=0;if((f|0)!=1){c=w[c|0];z[g+12>>2]=z[g+12>>2]-C(c>>>0);t[d+3|0]=2;t[d+5|0]=c|240;break Ta}a=P()|0;O()|0;break n}ab:{bb:{cb:{db:{eb:{fb:{gb:{h=w[d+3|0];switch(h|0){case 4:break ab;case 0:break gb;default:break fb}}hb:{c=w[g+23|0];if(!c){c=w[g+24|0];if(c){break hb}if(!x[g+32>>1]){break ab}c=g+32|0;break eb}t[d+3|0]=5;t[d+5|0]=c;if(!x[g+32>>1]){break ab}break db}t[d+3|0]=8;t[d+5|0]=c;if(x[g+32>>1]){break db}break ab}if(!x[g+32>>1]){break ab}c=g+32|0;f=c;if(h){break cb}}t[d+3|0]=4;break bb}f=g+32|0}c=f;t[d+2|0]=11}f=w[g+27|0];v[22640]=0;u[e+216>>1]=B(f,(j&255)-1|0);f=Oc(c,e+216|0);h=v[22640];v[22640]=0;if((h|0)!=1){u[c>>1]=x[c>>1]-x[f>>1];break ab}a=P()|0;O()|0;break n}u[g+28>>1]=x[g+28>>1]+B(w[g+25|0],j&255)&1023;p=0;if(s&1){break oa}c=w[g+18|0];if(!c){break oa}if(ah(n)>>>0<c>>>0){break oa}if(!(w[Ql(n,c-1|0)+142|0]&4)){break oa}v[e+48>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[e+52>>1]=w[d+4|0]|w[d+5|0]<<8;if(!w[e+49|0]){p=1;break oa}p=1;if(w[Ql(n,w[g+18|0]-1|0)+132|0]!=1){break oa}t[e+49|0]=w[e+49|0]+1}s=s+1|0;if(s>>>0<x[a+480188>>1]){continue}break}}V=V+1|0;if(Ib(w[fa+12|0]|w[fa+13|0]<<8)>>>0>V>>>0){continue}break}}c=_b(M,H);d=Ib(w[ea+14|0]|w[ea+15|0]<<8);v[22640]=0;d=Be(e+216|0,16,d&255);f=v[22640];v[22640]=0;if((f|0)!=1){d=Eh(Qe(d,0));v[22640]=0;Q(458,c|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break ha}}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}c=Yl(N);ka=e,la=Ib(w[b+4|0]|w[b+5|0]<<8),u[ka+216>>1]=la;v[22640]=0;u[e+48>>1]=1;d=Ie(e+216|0,e+48|0);f=v[22640];v[22640]=0;if((f|0)==1){break ca}d=x[d>>1];v[22640]=0;ca(934,N|0,c|0,d|0,H&65535)|0;c=v[22640];v[22640]=0;if((c|0)==1){break ca}c=Ib(w[q+8|0]|w[q+9|0]<<8);c=Ib(Ib(w[m+16|0]|w[m+17|0]<<8)-c&65535);t[m+16|0]=c;t[m+17|0]=c>>>8}b=b+32|0;if((da|0)!=(b|0)){continue}break}}Wo(e+88|0);if(Gb(e+88|0,e+80|0)){continue}}break}c=0;if(!ja){break r}v[22640]=0;_(463,a+906300|0);b=v[22640];v[22640]=0;if((b|0)==1){break ba}b=a+906316|0;v[b>>2]=1299020115;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[22640]=0;v[e+216>>2]=0;b=a+906332|0;mD(b,b+16|0,e+216|0);b=v[22640];v[22640]=0;if((b|0)==1){break aa}v[22640]=0;b=Q(112,e+216|0,6731)|0;c=v[22640];v[22640]=0;if((c|0)==1){break $}v[22640]=0;Hv(a+906348|0,b);c=v[22640];v[22640]=0;if((c|0)==1){break _}vb(b);v[22640]=0;b=Q(112,e+216|0,6724)|0;c=v[22640];v[22640]=0;if((c|0)==1){break Z}v[22640]=0;Gv(a+906380|0,b);c=v[22640];v[22640]=0;if((c|0)==1){break Y}vb(b);v[22640]=0;b=Q(112,e+216|0,6716)|0;c=v[22640];v[22640]=0;if((c|0)==1){break X}v[22640]=0;Hv(a+906508|0,b);d=v[22640];v[22640]=0;c=1;if((d|0)==1){break W}vb(b);break r}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(b);break n}a=P()|0;O()|0;break m}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}c=0}if(x[a+480188>>1]){b=0;while(1){v[22640]=0;Zt(a,b&65535);d=v[22640];v[22640]=0;if((d|0)==1){break p}d=(b<<5)+a|0;u[d+480284>>1]=b<<8&256;if(c){t[d+480288|0]=1}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}v[22640]=0;b=Q(2,e+216|0,9401)|0;c=v[22640];v[22640]=0;ib:{jb:{kb:{lb:{if((c|0)!=1){Eb(a+1298304|0,b);vb(b);v[22640]=0;b=Q(2,e+216|0,9603)|0;c=v[22640];v[22640]=0;if((c|0)==1){break lb}Eb(a+1298316|0,b);vb(b);if(Z){break jb}v[22640]=0;b=Q(2,e+216|0,9401)|0;c=v[22640];v[22640]=0;if((c|0)==1){break kb}break ib}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}if(ah(n)>>>0<=128){v[22640]=0;b=Q(2,e+216|0,6473)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break ib}a=P()|0;O()|0;break n}v[22640]=0;b=Q(2,e+216|0,12007)|0;c=v[22640];v[22640]=0;if((c|0)==1){break o}}Eb(a+1298328|0,b);vb(b);v[a+1298364>>2]=2;xB(r);JT(o);IT(F);f=1}Iu(n);ai(E);Hu(G);Ku(D);break c}a=P()|0;O()|0;break n}a=P()|0;O()|0}xB(r)}JT(o);IT(F);break a}a=P()|0;O()|0;vb(b);break a}a=P()|0;O()|0;break a}v[22640]=0;f=m&65535;j=W(936,a|0,f|0,c|0)|0;m=v[22640];v[22640]=0;mb:{nb:{ob:{pb:{if((m|0)==1){break pb}if(j){break mb}v[22640]=0;j=ga(937,a|0,f|0,c|0,0,0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break pb}if(j){break mb}v[22640]=0;j=ca(938,a|0,f|0,c|0,0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break pb}if(j){break mb}v[22640]=0;j=Q(939,(B(f,104)+a|0)+484380|0,c|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break pb}if(j){break mb}v[22640]=0;j=Q(2,e+112|0,13302)|0;m=v[22640];v[22640]=0;if((m|0)==1){break ob}v[22640]=0;U(580,a|0,2,j|0);m=v[22640];v[22640]=0;if((m|0)==1){break nb}vb(j);break mb}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(j);break e}qb:{rb:{sb:{j=B(f,104)+a|0;if(w[j+484414|0]&64){if(ei(a)){break sb}}if(ah(n)>>>0<=f>>>0){break rb}if(w[Ql(n,f)+132|0]!=2){break rb}if(!ei(a)){break rb}u[o>>1]=x[o>>1]+1;break rb}f=x[a+480190>>1]+1|0;u[a+480190>>1]=f;v[22640]=0;m=j+484380|0;F=B(f&65535,104)+a|0;ca(940,m|0,F+484380|0,m|0,a|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break qb}v[22640]=0;f=Q(112,e+112|0,3383)|0;m=v[22640];v[22640]=0;if((m|0)==1){break i}v[22640]=0;Q(335,F+484423|0,f|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break h}vb(f);v[22640]=0;f=Q(112,e+112|0,3286)|0;m=v[22640];v[22640]=0;if((m|0)==1){break g}v[22640]=0;Q(335,j+484423|0,f|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break f}vb(f)}yb(c);gc(d);p=0;continue}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(f);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(f)}yb(c)}gc(d);break a}gb=e+464|0;return f|0}a=P()|0;O()|0}Iu(n);ai(E);Hu(G);Ku(D);S(a|0);L()}function ona(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Z=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ga=0,ia=0,ja=0,ka=0,la=0;d=gb-896|0;gb=d;vc(b);a:{if(!lW(b,d+840|0)){break a}if(!nW(d+840|0)){break a}if(!Pb(b,Uc(mW(d+840|0),jb))){break a}if(!c){e=1;break a}Gd(a,8);wg(a);h=w[d+840|3]-48|0;t[d+839|0]=h;Xc(b,Xb(w[d+848|0]|w[d+849|0]<<8|(w[d+850|0]<<16|w[d+851|0]<<24)));rd(d+816|0,b,504);v[22640]=0;R(708,b|0,d+528|0);f=v[22640];v[22640]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((f|0)!=1){if(w[d+811|0]>63){break b}if(Ib(w[d+528|0]|w[d+529|0]<<8)<<16>>16<0){break b}Qb(d+448|0,0,80);n:{if(!Xb(w[d+872|0]|w[d+873|0]<<8|(w[d+874|0]<<16|w[d+875|0]<<24))){break n}f=Xb(w[d+872|0]|w[d+873|0]<<8|(w[d+874|0]<<16|w[d+875|0]<<24));v[22640]=0;f=Q(227,b|0,f|0)|0;l=v[22640];v[22640]=0;if((l|0)!=1){if(!f){break n}v[22640]=0;R(709,b|0,d+448|0);f=v[22640];v[22640]=0;if((f|0)!=1){break n}}g=P()|0;O()|0;break e}v[22640]=0;U(710,d+440|0,b|0,h&255);f=v[22640];v[22640]=0;if((f|0)!=1){N=Re(d+440|0);f=x[d+440>>1];if((f-1&65535)>>>0>126){break b}u[a+480188>>1]=f;J=ad(d+424|0);o:{if(Xb(w[d+864|0]|w[d+865|0]<<8|(w[d+866|0]<<16|w[d+867|0]<<24))){f=Xb(w[d+864|0]|w[d+865|0]<<8|(w[d+866|0]<<16|w[d+867|0]<<24));v[22640]=0;Q(227,b|0,f|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){f=w[d+811|0];v[22640]=0;U(711,b|0,J|0,f|0);f=v[22640];v[22640]=0;if((f|0)!=1){break o}}g=P()|0;O()|0;break f}e=0;if(w[d+811|0]){break c}}f=w[d+811|0];u[a+480192>>1]=f;u[a+480190>>1]=f;e=1;V=1;if((h&255)>>>0>=2){V=t[d+792|0]>-1;f=x[a+480192>>1]}if(f&65535){G=c&2;H=!V;r=d- -64|2;I=d- -64|7;K=d- -64|6;z=d- -64|5;C=d- -64|4;m=d+32|4;o=1;p=1;while(1){v[22640]=0;l=p&65535;f=W(415,a|0,o&65535,l|0)|0;h=v[22640];v[22640]=0;p:{q:{r:{s:{if((h|0)!=1){if(!f){break d}g=v[((e<<2)+a|0)+900380>>2];u[d+36>>1]=0;v[d+32>>2]=0;v[22640]=0;q=T(251,d+136|0)|0;f=v[22640];v[22640]=0;t:{u:{v:{w:{if((f|0)!=1){e=e-1|0;f=Mb(J,e);x:{if(!Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break x}f=Mb(J,e);f=Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));v[22640]=0;f=Q(227,b|0,f|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break q}if(!f){break x}v[22640]=0;R(712,b|0,d+32|0);f=v[22640];v[22640]=0;if((f|0)==1){break q}f=Xb(w[d+32|0]|w[d+33|0]<<8|(w[d+34|0]<<16|w[d+35|0]<<24));v[22640]=0;U(320,d- -64|0,b|0,f|0);f=v[22640];v[22640]=0;if((f|0)==1){break q}od(q,d- -64|0);yb(d- -64|0)}e=Ib(w[m|0]|w[m+1|0]<<8);f=Ib(w[m|0]|w[m+1|0]<<8)&15;j=e<<16>>16;if((j|0)>-1){break w}v[22640]=0;pr(g,0);e=v[22640];v[22640]=0;ba=1;if((e|0)!=1){break v}break q}g=P()|0;O()|0;break f}if(f>>>0>6){break v}h=w[f+29286|0];if(!f){f=h;break s}u[a+480190>>1]=(x[a+480190>>1]+h|0)-1;f=g+108|0;n=g+236|0;E=h-2|0;i=4;while(1){k=B(i,12);e=(E<<3)+i|0;A=e+29340|0;s=w[e+29292|0]+p|0;e=0;while(1){D=e+k|0;ka=sd(n,D),la=s,u[ka>>1]=la;D=lc(f,D);t[D|0]=w[D|0]+w[A|0];e=e+1|0;if((e|0)!=12){continue}break}k=1;i=i+1|0;if((i|0)!=10){continue}break}f=h;break u}h=1;if((f|0)!=7){f=1;break s}k=0;v[22640]=0;IS(g,-24);e=v[22640];v[22640]=0;f=1;if((e|0)==1){break t}}E=1;break r}break q}g=P()|0;O()|0;break f}k=0;if(H|(j|0)<0){break r}k=g+108|0;i=7;while(1){n=B(i,12);A=B(i,-12)+72|0;e=0;while(1){s=lc(k,e+n|0);t[s|0]=A+w[s|0];e=e+1|0;if((e|0)!=12){continue}break}i=i+1|0;if((i|0)!=10){continue}break}k=0}v[22640]=0;R(715,d+816|0,d- -64|0);e=v[22640];v[22640]=0;if((e|0)!=1){y:{if(!(!w[C|0]|w[C|0]>16)){t[g+31|0]=w[C|0];E=1}if(!(!w[z|0]|w[z|0]>128)){t[g+30|0]=w[z|0]}z:{if(!f){break z}g=0;e=l;while(1){v[22640]=0;e=B(e,104)+a|0;R(352,e+484380|0,8);i=v[22640];v[22640]=0;if((i|0)==1){break q}t[d+392|0]=w[K|0];v[22640]=0;t[d+120|0]=64;i=ac(d+392|0,d+120|0);n=v[22640];v[22640]=0;if((n|0)==1){break q}u[e+484410>>1]=w[i|0]<<2;t[e+484416|0]=w[I|0];g=g+1|0;e=g&65535;if(e>>>0>=f>>>0){break z}e=e+l|0;continue}}if(!G|(j|0)<0){break p}n=Pc(d+392|0,8,1,1,0);A=Ib(w[r|0]|w[r+1|0]<<8);e=d- -64|0;g=Ib(w[e|0]|w[e+1|0]<<8);i=Ib(w[r|0]|w[r+1|0]<<8);v[22640]=0;e=T(232,q|0)|0;j=v[22640];v[22640]=0;if((j|0)!=1){if(Ib(w[m|0]|w[m+1|0]<<8)&16){Vi(n,16);e=e>>>1|0}if(Ib(w[m|0]|w[m+1|0]<<8)&32){Bp(n,3);e=e>>>1|0}if(Ib(w[m|0]|w[m+1|0]<<8)&64){zf(n,2)}e=k?(e>>>0)/((-1<<f^-1)>>>0)|0:e;if(!f){break p}j=g+i|0;k=0;i=l;while(1){i=B(i,104)+a|0;s=i+484380|0;v[s>>2]=e;v[22640]=0;W(363,n|0,s|0,q|0)|0;s=v[22640];v[22640]=0;if((s|0)==1){break y}g=g<<1;j=j<<1;if(A>>>0>=2){v[i+484388>>2]=j;v[i+484384>>2]=g;i=i+484414|0;u[i>>1]=x[i>>1]|2}k=k+1|0;i=k&65535;if(i>>>0>=f>>>0){break p}e=e<<1;i=i+l|0;continue}}}}}g=P()|0;O()|0;yb(q);break f}yb(q);p=h+p|0;o=o+1|0;e=o&65535;if(e>>>0<=x[a+480192>>1]){continue}break}}f=d+448|4;A:{if(!Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break A}if(!Ib(w[d+456|0]|w[d+457|0]<<8)){break A}f=Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));v[22640]=0;f=Q(227,b|0,f|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break g}if(!f){break A}ka=d,la=Ib(w[d+456|0]|w[d+457|0]<<8),u[ka+136>>1]=la;f=w[d+811|0];v[22640]=0;u[d+64>>1]=f;f=Oc(d+136|0,d- -64|0);e=v[22640];v[22640]=0;if((e|0)==1){break h}m=x[f>>1];i=Ib(w[d+458|0]|w[d+459|0]<<8);if(!m){break A}k=d+136|5;o=d+136|3;j=d+136|1;h=d+72|0;p=d- -64|4;q=i>>>0<19;r=i>>>0<21;n=i>>>0<15;g=0;while(1){v[22640]=0;U(716,b|0,d+136|0,i|0);f=v[22640];v[22640]=0;B:{C:{D:{if((f|0)!=1){g=g+1|0;f=v[((g<<2)+a|0)+900380>>2];if(!w[d+136|0]){break B}z=qr(d- -64|0,0,64);qr(p,w[d+136|0]-1&65535,64);e=w[d+136|0];l=h;if(w[j|0]){e=e+(64/w[j|0]|0)|0}qr(l,e,0);v[d+420>>2]=3;v[d+416>>2]=z;v[22640]=0;e=v[d+420>>2];v[d>>2]=v[d+416>>2];v[d+4>>2]=e;e=f+48|0;R(717,e|0,d|0);l=v[22640];v[22640]=0;if((l|0)==1){break D}if(w[d+136|0]!=1){break C}ka=d,la=Sb(e),v[ka+64>>2]=la;Fd(d+408|0,d- -64|0);v[22640]=0;R(718,e|0,v[d+408>>2]);e=v[22640];v[22640]=0;if((e|0)!=1){break C}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}v[f>>2]=w[j|0]?w[j|0]<<9:32767;E=1;t[f+60|0]=w[f+60|0]|1}E:{if(q){break E}v[f+4>>2]=w[d+154|0]+1>>>1;if(r){break E}u[f+28>>1]=w[d+156|0]|w[d+157|0]<<8}f=B(x[sd(f+236|0,61)>>1],104)+a|0;t[f+484417|0]=w[o|0]<<4;F:{G:{if(!n){ka=f+484384|0,la=Xb(w[d+146|0]|w[d+147|0]<<8|(w[d+148|0]<<16|w[d+149|0]<<24)),v[ka>>2]=la;ka=f+484388|0,la=Xb(w[d+146|0]|w[d+147|0]<<8|(w[d+148|0]<<16|w[d+149|0]<<24))+Xb(w[d+150|0]|w[d+151|0]<<8|(w[d+152|0]<<16|w[d+153|0]<<24))|0,v[ka>>2]=la;break G}if(i>>>0<6){break F}}if(t[k|0]&1){e=f+484414|0;u[e>>1]=x[e>>1]|2}if(w[k|0]&8){e=f+484414|0;u[e>>1]=x[e>>1]|6}if(!(w[k|0]&4)){break F}u[f+484412>>1]=0}if((g|0)!=(m|0)){continue}break}}if(!Xb(w[d+468|0]|w[d+469|0]<<8|(w[d+470|0]<<16|w[d+471|0]<<24))){break i}if(!Ib(w[d+472|0]|w[d+473|0]<<8)){break i}f=Xb(w[d+468|0]|w[d+469|0]<<8|(w[d+470|0]<<16|w[d+471|0]<<24));v[22640]=0;f=Q(227,b|0,f|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break g}if(!f){break i}ka=d,la=Ib(w[d+472|0]|w[d+473|0]<<8),u[ka+136>>1]=la;f=w[d+811|0];v[22640]=0;u[d+64>>1]=f;f=Oc(d+136|0,d- -64|0);e=v[22640];v[22640]=0;if((e|0)!=1){h=x[f>>1];g=Ib(w[d+474|0]|w[d+475|0]<<8);if(!h){break i}i=0;H:while(1){I:{v[22640]=0;U(719,b|0,d+136|0,g|0);f=v[22640];v[22640]=0;if((f|0)==1){break j}v[22640]=0;PC(d+32|0,2,d+136|0);f=v[22640];v[22640]=0;if((f|0)==1){break k}v[22640]=0;R(377,d- -64|0,d+32|0);f=v[22640];v[22640]=0;if((f|0)==1){break k}i=i+1|0;l=((i<<2)+a|0)+900380|0;f=v[l>>2];v[22640]=0;Q(333,f+492|0,d- -64|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break l}vb(d- -64|0);f=v[l>>2];v[22640]=0;R(721,d- -64|0,f|0);f=v[22640];v[22640]=0;if((f|0)==1){break m}ka=d,la=or(d- -64|0),v[ka+32>>2]=la;ka=d,la=zh(d- -64|0),v[ka+392>>2]=la;while(1){v[22640]=0;f=Xl(d+32|0,d+392|0);e=v[22640];v[22640]=0;J:{if((e|0)!=1){if(f){break J}nr(d- -64|0);if((h|0)!=(i|0)){continue H}break i}break I}v[22640]=0;f=Vl(d+32|0);e=v[22640];v[22640]=0;if((e|0)!=1){e=(x[f>>1]<<5)+a|0;j=e+946328|0;f=v[l>>2];k=v[f+520>>2];v[j>>2]=v[f+516>>2];v[j+4>>2]=k;k=v[f+512>>2];j=e+946320|0;v[j>>2]=v[f+508>>2];v[j+4>>2]=k;k=v[f+504>>2];j=e+946312|0;v[j>>2]=v[f+500>>2];v[j+4>>2]=k;j=v[f+496>>2];e=e+946304|0;v[e>>2]=v[f+492>>2];v[e+4>>2]=j;Oj(d+32|0);continue}break}}break}g=P()|0;O()|0;nr(d- -64|0);break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}g=P()|0;O()|0;break f}g=P()|0;O()|0;vb(d- -64|0);break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}f=0;v[22640]=0;To(a+901404|0);e=v[22640];v[22640]=0;if((e|0)==1){break g}t[a+901696|0]=w[2040];e=a+901692|0;h=w[2036]|w[2037]<<8|(w[2038]<<16|w[2039]<<24);t[e|0]=h;t[e+1|0]=h>>>8;t[e+2|0]=h>>>16;t[e+3|0]=h>>>24;vc(b);K=a+484360|0;K:{L:{M:{N:{O:{P:{Q:{R:{S:{if(!w[N|0]){break S}da=c&1;z=a+484344|0;C=a+1298292|0;D=a+1298268|0;ea=d+136|1;l=d+136|4;q=d+8|4;Z=d+8|2;_=d+56|2;fa=d+56|3;r=d+528|2;A=0;while(1){T:{v[22640]=0;Y(724,b|0,d+840|0,d+448|0,d+528|0);c=v[22640];v[22640]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{if((c|0)==1){break ea}c=A&255;if(c){v[22640]=0;e=T(445,K|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break ea}if((e|0)==255){break d}}m=Nj(K,c);n=Ck(d+392|0);sn(m);g=w[d+839|0];if(g>>>0>1){break ca}if(Ib(w[r|0]|w[r+1|0]<<8)>>>0>256|x[a+480188>>1]>16){break ba}jW(d+136|0,d+528|0);c=Ib(w[r|0]|w[r+1|0]<<8);v[22640]=0;U(725,m|0,d+136|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break aa}ka=d,la=Sb(m),v[ka+136>>2]=la;ka=d,la=Wb(m),v[ka+64>>2]=la;if(Gb(d+136|0,d- -64|0)){break da}break W}g=P()|0;O()|0;break f}while(1){c=v[d+136>>2];u[c>>1]=x[c>>1]+f;mf(d+136|0);if(Gb(d+136|0,d- -64|0)){continue}break}break W}jW(d+136|0,d+528|0);if(!Ib(w[d+148|0]|w[d+149|0]<<8)){break ba}if(Ib(w[d+148|0]|w[d+149|0]<<8)>>>0>64|x[a+480188>>1]>64){break ba}k=Xb(w[d+156|0]|w[d+157|0]<<8|(w[d+158|0]<<16|w[d+159|0]<<24));fa:{if(Ib(w[d+160|0]|w[d+161|0]<<8)){ka=d,la=Ib(w[d+160|0]|w[d+161|0]<<8),u[ka+64>>1]=la;v[22640]=0;u[d+32>>1]=800;c=Oc(d- -64|0,d+32|0);e=v[22640];v[22640]=0;if((e|0)==1){break fa}c=Uc(((x[c>>1]<<5)+50>>>0)/100|0,0)}else{c=32}e=Xb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24));v[22640]=0;h=Q(227,b|0,e|0)|0;e=v[22640];v[22640]=0;ga:{if((e|0)==1){break ga}e=0;ha:{ia:{ja:{ka:{la:{if(h&x[a+480188>>1]!=0){while(1){v[22640]=0;h=T(353,b|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break la}t[d+64|0]=h;v[22640]=0;t[d+32|0]=64;h=ac(d- -64|0,d+32|0);i=v[22640];v[22640]=0;if((i|0)==1){break ka}u[((e<<5)+a|0)+480286>>1]=w[h|0];e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}if(!Xb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24))){break ia}e=Xb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24));v[22640]=0;e=Q(227,b|0,e|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break ga}if(!e){break ia}e=0;if(!x[a+480188>>1]){break ha}while(1){v[22640]=0;h=T(726,b|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break ja}ka=((e<<5)+a|0)+480284|0,la=(Lb(h,-16,16)<<3)+128|0,u[ka>>1]=la;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break ha}g=P()|0;O()|0;break K}g=P()|0;O()|0;break K}g=P()|0;O()|0;break K}v[22640]=0;rh(a,1);e=v[22640];v[22640]=0;if((e|0)==1){break ga}}h=ad(d+120|0);e=Xb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));v[22640]=0;i=Q(227,b|0,e|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break $}j=1;e=0;if(!i){break X}i=Ib(w[r|0]|w[r+1|0]<<8);v[22640]=0;i=Q(228,b|0,i<<1)|0;o=v[22640];v[22640]=0;if((o|0)==1){break $}if(!i){break X}i=Ib(w[r|0]|w[r+1|0]<<8);v[22640]=0;i=W(727,b|0,h|0,i|0)|0;o=v[22640];v[22640]=0;if((o|0)==1){break $}if(!i){break X}ka=d,la=Sb(h),v[ka+8>>2]=la;ka=d,la=Wb(h),v[ka+112>>2]=la;if(!Gb(d+8|0,d+112|0)){break Y}while(1){e=v[d+8>>2];e=Ib(w[e|0]|w[e+1|0]<<8);ma:{if(Ib(w[d+150|0]|w[d+151|0]<<8)>>>0<e>>>0){break ma}i=Xb(w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24));v[22640]=0;Q(227,b|0,i+(e<<2)|0)|0;e=v[22640];v[22640]=0;na:{oa:{pa:{qa:{ra:{if((e|0)==1){break ra}v[22640]=0;e=T(453,b|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break ra}v[22640]=0;e=Q(227,b|0,e|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break ra}if(!e){break ma}v[22640]=0;e=Q(228,b|0,42)|0;i=v[22640];v[22640]=0;if((i|0)==1){break ra}if(!e){break ma}v[22640]=0;R(728,b|0,d- -64|0);e=v[22640];v[22640]=0;sa:{if((e|0)!=1){if($c(m)){break sa}v[22640]=0;R(729,m|0,65534);e=v[22640];v[22640]=0;if((e|0)!=1){break sa}}g=P()|0;O()|0;break Z}e=Ib(w[d+104|0]|w[d+105|0]<<8);v[22640]=0;v[d+60>>2]=e;e=Q(228,b|0,e|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break qa}if(!e){v[22640]=0;e=T(492,b|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break qa}tc(d+60|0,e)}tc(d+60|0,65534);i=sc(m);v[22640]=0;R(730,m|0,i+v[d+60>>2]|0);e=v[22640];v[22640]=0;if((e|0)==1){break oa}e=0;if(!v[d+60>>2]){break pa}while(1){ta:{v[22640]=0;j=T(444,b|0)|0;o=v[22640];v[22640]=0;if((o|0)==1){break ta}j=j<<16>>16;if((j|0)>=0){v[22640]=0;R(729,m|0,f+j&65535);j=v[22640];v[22640]=0;if((j|0)==1){break ta}}e=e+1|0;if(e>>>0<y[d+60>>2]){continue}break pa}break}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}ua:{if(!w[d+64|0]){break ua}v[22640]=0;U(6,d+32|0,2,d- -64|0);e=v[22640];v[22640]=0;va:{if((e|0)!=1){v[22640]=0;R(446,m|0,d+32|0);e=v[22640];v[22640]=0;if((e|0)==1){break va}vb(d+32|0);break ua}g=P()|0;O()|0;break Z}g=P()|0;O()|0;vb(d+32|0);break Z}if(!Xb(w[d+96|0]|w[d+97|0]<<8|(w[d+98|0]<<16|w[d+99|0]<<24))){break ma}e=Xb(w[d+96|0]|w[d+97|0]<<8|(w[d+98|0]<<16|w[d+99|0]<<24));v[22640]=0;e=Q(227,b|0,e|0)|0;j=v[22640];v[22640]=0;if((j|0)!=1){break na}}g=P()|0;O()|0;break Z}if(!e){break ma}while(1){wa:{v[22640]=0;e=Q(731,b|0,d+56|0)|0;j=v[22640];v[22640]=0;xa:{ya:{if((j|0)!=1){if(!e){break ma}e=w[fa|0];v[22640]=0;U(320,d+32|0,b|0,e|0);e=v[22640];v[22640]=0;if((e|0)==1){break ya}ka=d,la=Ev(Ib(w[d+56|0]|w[d+57|0]<<8)+i|0),u[ka+30>>1]=la;if((Ib(w[d+56|0]|w[d+57|0]<<8)|0)==65535){break wa}e=x[d+30>>1];if(sc(m)>>>0>e>>>0){break xa}yb(d+32|0);break ma}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}za:{if(w[_|0]==1){e=65535}else{if(w[_|0]!=2){break za}v[22640]=0;e=T(444,d+32|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break _}v[22640]=0;j=Q(732,n|0,d+30|0)|0;o=v[22640];v[22640]=0;if((o|0)==1){break _}u[j>>1]=e;e=65534}ka=rc(m,x[d+30>>1]),la=e,u[ka>>1]=la}yb(d+32|0);continue}break}yb(d+32|0)}nD(d+8|0);if(Gb(d+8|0,d+112|0)){continue}break}break Y}g=P()|0;O()|0;break K}g=P()|0;O()|0;break K}mr(n);break d}g=P()|0;O()|0;break K}g=P()|0;O()|0;break Z}g=P()|0;O()|0;yb(d+32|0)}Fv(h);break K}j=0;e=1}Fv(h);if(e){i=c>>>(k>>>1&1)|0;break V}mr(n);if(!j){break d}break U}v[22640]=0;rh(a,1);c=v[22640];v[22640]=0;Aa:{if((c|0)!=1){e=0;i=32;if(!x[a+480188>>1]){break V}while(1){t[d+136|0]=w[(d+e|0)+794|0];v[22640]=0;t[d+64|0]=64;c=ac(d+136|0,d- -64|0);h=v[22640];v[22640]=0;if((h|0)==1){break Aa}u[((e<<5)+a|0)+480286>>1]=w[c|0];e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break V}g=P()|0;O()|0;break K}g=P()|0;O()|0;break K}e=w[d+791|0];$=w[d+791|0]&64;s=w[d+792|0]&32;G=(w[d+792|0]&31)+1|0;ka=a,la=gW(Ib(w[d+788|0]|w[d+789|0]<<8),$>>>6|0,s>>>5|0,G),v[ka+480204>>2]=la;ka=a,la=Jd(w[d+793|0],1,32),v[ka+480196>>2]=la;if(s){v[a+480216>>2]=G;v[a+480220>>2]=G<<2}Ba:{Ca:{if(w[d+810|0]){t[d+136|0]=w[d+810|0];v[22640]=0;t[d+64|0]=64;c=ac(d+136|0,d- -64|0);h=v[22640];v[22640]=0;if((h|0)==1){break Ca}v[a+480200>>2]=w[c|0]<<2}v[a+480228>>2]=i;v[a+480232>>2]=i;v[a+480208>>2]=v[a+480208>>2]&-3|(w[d+791|0]>>>4^-1)&2;Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{if(!Xb(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24))){break Oa}c=Xb(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24));v[22640]=0;c=Q(227,b|0,c|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Na}if(!c){break Oa}c=Xb(w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24));v[22640]=0;W(441,b|0,D|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break Na}if(w[N|0]<2){break Oa}v[22640]=0;U(13,d+136|0,2,D|0);c=v[22640];v[22640]=0;if((c|0)==1){break Ma}v[22640]=0;R(446,m|0,d+136|0);c=v[22640];v[22640]=0;if((c|0)==1){break La}vb(d+136|0)}Pa:{if(Xb(w[d+464|0]|w[d+465|0]<<8|(w[d+466|0]<<16|w[d+467|0]<<24))>>>0<2){break Pa}c=Xb(w[d+460|0]|w[d+461|0]<<8|(w[d+462|0]<<16|w[d+463|0]<<24));v[22640]=0;c=Q(227,b|0,c|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Na}if(!c){break Pa}c=Xb(w[d+464|0]|w[d+465|0]<<8|(w[d+466|0]<<16|w[d+467|0]<<24));v[22640]=0;ca(532,C|0,b|0,c-1|0,4)|0;c=v[22640];v[22640]=0;if((c|0)==1){break Na}}if(!Xb(w[d+504|0]|w[d+505|0]<<8|(w[d+506|0]<<16|w[d+507|0]<<24))){break Ba}c=Xb(w[d+504|0]|w[d+505|0]<<8|(w[d+506|0]<<16|w[d+507|0]<<24));v[22640]=0;c=Q(227,b|0,c|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Na}if(!c){break Ba}v[22640]=0;c=Q(228,b|0,12)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Na}if(!c){break Ba}v[22640]=0;Q(350,b|0,6)|0;c=v[22640];v[22640]=0;if((c|0)==1){break Na}v[22640]=0;c=T(444,b|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Na}if((c|0)!=1){break Ba}v[22640]=0;c=T(453,b|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Ja}if(!c){break Ba}v[22640]=0;h=Q(228,b|0,c|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break Ja}if(h){break Ka}break Ba}g=P()|0;O()|0;break K}g=P()|0;O()|0;break K}g=P()|0;O()|0;vb(d+136|0);break K}Dc(d+136|0,C);v[22640]=0;ca(532,C|0,b|0,c|0,4)|0;c=v[22640];v[22640]=0;if((c|0)==1){break Ea}if(!dd(d+136|0)){v[22640]=0;c=W(733,d+32|0,2,13)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Ia}v[22640]=0;U(734,d- -64|0,d+136|0,c|0);h=v[22640];v[22640]=0;if((h|0)==1){break Ha}v[22640]=0;U(735,d+16|0,d- -64|0,C|0);h=v[22640];v[22640]=0;if((h|0)==1){break Ga}Eb(C,d+16|0);vb(d+16|0);vb(d- -64|0);vb(c)}vb(d+136|0);break Ba}g=P()|0;O()|0;break K}g=P()|0;O()|0;break Da}g=P()|0;O()|0;break Fa}g=P()|0;O()|0;vb(d- -64|0)}vb(c);break Da}g=P()|0;O()|0}vb(d+136|0);break K}g=P()|0;O()|0;break K}Qa:{if(g>>>0<2){break Qa}if(!Xb(w[d+516|0]|w[d+517|0]<<8|(w[d+518|0]<<16|w[d+519|0]<<24))){break Qa}j=0;if(!x[a+480188>>1]){break Qa}while(1){c=Xb(w[d+516|0]|w[d+517|0]<<8|(w[d+518|0]<<16|w[d+519|0]<<24));v[22640]=0;c=Q(227,b|0,c+(j<<2)|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break L}Ra:{if(!c){break Ra}v[22640]=0;c=T(453,b|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break L}v[22640]=0;c=Q(227,b|0,c|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break L}i=0;k=0;if(!c){break Ra}while(1){Sa:{v[22640]=0;c=Q(228,b|0,8)|0;h=v[22640];v[22640]=0;Ta:{Ua:{Va:{if((h|0)!=1){if(!c){break Sa}v[22640]=0;R(736,b|0,d+136|0);c=v[22640];v[22640]=0;if((c|0)==1){break Va}if(!Xb(w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))){break Sa}switch((Xb(w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))&536870911)-1|0){case 1:break Ta;case 0:break Ua;default:continue}}g=P()|0;O()|0;break K}g=P()|0;O()|0;break K}i=Xb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));continue}k=Xb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));continue}break}if(!i|!k){break Ra}v[22640]=0;c=Q(227,b|0,i|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break M}if(!c){break Ra}v[22640]=0;W(591,b|0,((j<<5)+a|0)+480289|0,k|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break M}}j=j+1|0;if(j>>>0<x[a+480188>>1]){continue}break}}i=Ib(w[d+528|0]|w[d+529|0]<<8);v[22640]=0;c=f+i|0;R(364,z|0,c&65535);h=v[22640];v[22640]=0;if((h|0)==1){break R}if(i){ga=e&16;ia=f&65535;k=0;while(1){Wa:{if(!da){break Wa}e=Xb(w[d+856|0]|w[d+857|0]<<8|(w[d+858|0]<<16|w[d+859|0]<<24));v[22640]=0;e=Q(227,b|0,e+(k<<2)|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break P}if(!e){break Wa}v[22640]=0;e=T(453,b|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break P}v[22640]=0;e=Q(227,b|0,e|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break P}if(!e){break Wa}H=Kb(d+120|0);v[22640]=0;I=T(251,d- -64|0)|0;e=v[22640];v[22640]=0;Xa:{Ya:{if((e|0)!=1){e=w[d+839|0];if(e){break Ya}v[22640]=0;R(737,b|0,d+136|0);e=v[22640];v[22640]=0;if((e|0)==1){break O}u[d+112>>1]=w[d+136|0];o=w[ea|0]+1|0;e=48;break Xa}g=P()|0;O()|0;break N}h=t[d+790|0];v[22640]=0;R(738,b|0,d+8|0);g=v[22640];v[22640]=0;Za:{_a:{if((g|0)!=1){ka=d,la=Ib(w[d+8|0]|w[d+9|0]<<8),u[ka+112>>1]=la;o=Ib(w[Z|0]|w[Z+1|0]<<8)+1|0;if(!Xb(w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24))){break Za}g=v[b+8>>2];j=Xb(w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24));v[22640]=0;Q(227,b|0,j|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break O}v[22640]=0;R(739,b|0,d+136|0);j=v[22640];v[22640]=0;if((j|0)==1){break O}j=Xb(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24));v[22640]=0;j=Q(227,b|0,j|0)|0;p=v[22640];v[22640]=0;if((p|0)==1){break O}if(!j){break _a}j=Xb(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24));v[22640]=0;W(441,b|0,H|0,j|0)|0;j=v[22640];v[22640]=0;if((j|0)!=1){break _a}break O}break O}$a:{if(!Xb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24))){break $a}j=Xb(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24));v[22640]=0;j=Q(227,b|0,j|0)|0;p=v[22640];v[22640]=0;if((p|0)==1){break O}if(!j){break $a}v[22640]=0;j=T(453,b|0)|0;p=v[22640];v[22640]=0;if((p|0)==1){break O}v[22640]=0;j=Q(227,b|0,j|0)|0;p=v[22640];v[22640]=0;if((p|0)==1){break O}if(!j){break $a}v[22640]=0;U(320,d+32|0,b|0,B(x[d+112>>1],o)|0);j=v[22640];v[22640]=0;if((j|0)==1){break O}od(I,d+32|0);yb(d+32|0)}v[22640]=0;Q(227,b|0,g|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break O}}e=h+(e>>>0<3?48:24)|0}v[22640]=0;g=k+ia|0;j=W(365,z|0,g&65535,o|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break O}h=e;if(j){aa=_b(z,g);v[22640]=0;Q(455,aa|0,H|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break O}sg(d+112|0,x[a+480188>>1]);p=0;while(1){v[22640]=0;e=Tc(aa,p,0);g=v[22640];v[22640]=0;ab:{bb:{if((g|0)!=1){j=0;if(x[d+112>>1]){break bb}break ab}break O}while(1){cb:{if(!w[d+839|0]){v[22640]=0;R(740,d+136|0,b|0);g=v[22640];v[22640]=0;if((g|0)!=1){g=md(d+136|0);X=Re(d+136|0);F=w[d+136|0];t[e+1|0]=F>>>3&16|w[g|0]>>>4|F>>>1&32;t[e+3|0]=w[g|0]&15;t[e+5|0]=w[X|0];g=F&63;g=g?g+h|0:0;break cb}break O}v[22640]=0;R(550,d+136|0,b|0);g=v[22640];v[22640]=0;db:{eb:{if((g|0)!=1){F=md(d+136|0);X=Re(d+136|0);ja=aj(d+136|0);v[22640]=0;g=T(353,I|0)|0;M=v[22640];v[22640]=0;if((M|0)==1){break O}t[e+4|0]=g;M=w[d+136|0];g=M&127;if(!g){break eb}g=g+h|0;break db}break O}g=0;if((M|0)!=128){break db}t[e|0]=254}t[e+1|0]=w[F|0]&63;t[e+3|0]=w[X|0];t[e+5|0]=w[ja|0]}if(g-1>>>0<=119){t[e|0]=g}v[22640]=0;ha(741,e|0,($|0)!=0|0,(s|0)!=0|0,G|0,(ga|0)!=0|0);F=v[22640];v[22640]=0;if((F|0)!=1){E=(g|0)>84&V|E;e=e+6|0;j=j+1|0;if(x[d+112>>1]<=(j&65535)>>>0){break ab}continue}break}break O}p=p+1|0;if((o|0)!=(p|0)){continue}break}}yb(I);vb(H)}k=k+1|0;if((k|0)!=(i|0)){continue}break}}ka=d,la=or(n),v[ka+64>>2]=la;ka=d,la=zh(n),v[ka+32>>2]=la;fb:{gb:{if(kg(d- -64|0,d+32|0)){while(1){c=Vl(d- -64|0);h=c;g=Re(c);hb:{ib:{jb:{c=x[c>>1];if(!c){e=0;break jb}v[22640]=0;c=Q(497,m|0,c-1&65535)|0;e=v[22640];v[22640]=0;if((e|0)==1){break gb}e=x[h>>1];if(!c){break jb}v[22640]=0;e=Q(565,m|0,e-1&65535)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break ib}break gb}if(x[g>>1]==(e+1|0)){break hb}v[22640]=0;e=W(564,z|0,1,0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break gb}if((e|0)==65535){break hb}ka=rc(m,x[h>>1]),la=e,u[ka>>1]=la}c=_b(z,e);h=wv(x[g>>1]);v[22640]=0;h=Be(d+136|0,12,h);g=v[22640];v[22640]=0;if((g|0)==1){break fb}h=op(Qe(h,v[_b(z,e)+12>>2]-1|0));v[22640]=0;Q(458,c|0,h|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break fb}i=(i&65535)>>>0>e>>>0?i:e+1|0}Oj(d- -64|0);if(kg(d- -64|0,d+32|0)){continue}break}c=f+i|0}if(!Xb(w[d+448|0]|w[d+449|0]<<8|(w[d+450|0]<<16|w[d+451|0]<<24))){break T}f=Xb(w[d+448|0]|w[d+449|0]<<8|(w[d+450|0]<<16|w[d+451|0]<<24));v[22640]=0;f=Q(227,b|0,f|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break R}if(!f){break T}mr(n);f=c;break U}g=P()|0;O()|0;break K}g=P()|0;O()|0;break K}A=A+1|0;if(w[N|0]>(A&255)>>>0){continue}break S}break}mr(n)}v[22640]=0;Pi(K,0);b=v[22640];v[22640]=0;if((b|0)==1){break Q}if(!(E&1)){j=x[a+480192>>1];if(j){e=1;while(1){b=(((e&65535)<<2)+a|0)+900380|0;c=v[b>>2];if(c){Zb(hv(c));j=x[a+480192>>1]}v[b>>2]=0;e=e+1|0;if((e&65535)>>>0<=(j&65535)>>>0){continue}break}}u[a+480192>>1]=0}kb:{lb:{mb:{nb:{ob:{pb:{qb:{if(ba){v[22640]=0;b=Q(2,d+136|0,13502)|0;c=v[22640];v[22640]=0;if((c|0)==1){break qb}v[22640]=0;U(580,a|0,2,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break pb}vb(b)}g=18693;switch(w[d+839|0]){case 3:break lb;case 2:break mb;case 1:break nb;case 0:break ob;default:break kb}}g=P()|0;O()|0;break f}g=P()|0;O()|0;vb(b);break f}g=x[a+480188>>1]>4?14344:14330;break kb}g=14312;break kb}g=14294;break kb}g=14267}v[22640]=0;R(742,d- -64|0,13912);b=v[22640];v[22640]=0;rb:{sb:{tb:{if((b|0)!=1){v[22640]=0;U(743,d+136|0,d- -64|0,d+839|0);b=v[22640];v[22640]=0;if((b|0)==1){break tb}Eb(a+1298304|0,d+136|0);vb(d+136|0);Hb(d- -64|0);v[22640]=0;b=Q(2,d+136|0,9997)|0;c=v[22640];v[22640]=0;if((c|0)==1){break sb}Eb(a+1298316|0,b);vb(b);v[22640]=0;Q(194,a+1298328|0,g|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break rb}v[a+1298364>>2]=2;e=1;break c}g=P()|0;O()|0;break f}g=P()|0;O()|0;Hb(d- -64|0);break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break K}g=P()|0;O()|0;break f}g=P()|0;O()|0;break K}g=P()|0;O()|0;yb(I)}vb(H);break K}g=P()|0;O()|0;break K}g=P()|0;O()|0}mr(n);break f}g=P()|0;O()|0;break f}g=P()|0;O()|0}ai(J)}yb(d+816|0);S(g|0);L()}e=0}ai(J)}yb(d+816|0)}gb=d+896|0;return e|0}function jma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=gb-1728|0;gb=e;vc(b);l=gb-32|0;gb=l;i=e+1600|0;cV(l+24|0,i);k=xb(l+24|0);g=v[l+28>>2];d=v[l+24>>2];v[l+8>>2]=d;v[l+12>>2]=g;v[l>>2]=d;v[l+4>>2]=g;d=b;fc(l+16|0,d,l);g=xb(l+16|0);if((g|0)==(k|0)){Yb(d,xb(l+24|0))}gb=l+32|0;d=(g|0)==(k|0);if(!d){bV(i)}a:{if(!d){break a}if(!gV(e+1600|0)){break a}if(!Pb(b,Uc(256,0))){break a}b:{if(!c){break b}Gd(a,1048576);wg(a);f=gb-16|0;gb=f;d=Tb(f,1339);Dc(e+1344|0,d);vb(d);gb=f+16|0;C=e+1608|0;v[e+160>>2]=w[C+1|0];d=w[C|0];v[22640]=0;v[e+16>>2]=d;R(619,e+88|0,e+16|0);d=v[22640];v[22640]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((d|0)!=1){v[22640]=0;Y(602,e+240|0,e+1344|0,e+160|0,e+88|0);d=v[22640];v[22640]=0;if((d|0)==1){break o}Eb(a+1298304|0,e+240|0);vb(e+240|0);vb(e+88|0);Hb(e+1344|0);d=Tb(e+240|0,12334);Eb(a+1298316|0,d);vb(d);_e(e+88|0,2,e+1610|0);Bc(e+1344|0,e+88|0);v[22640]=0;U(13,e+240|0,8,e+1344|0);d=v[22640];v[22640]=0;if((d|0)==1){break j}Eb(a+1298328|0,e+240|0);vb(e+240|0);vb(e+1344|0);v[a+1298364>>2]=8;Hr(e+1344|0,2,e+1642|0);Bc(e+240|0,e+1344|0);Eb(a+1298268|0,e+240|0);vb(e+240|0);d=e+1712|0;u[a+480188>>1]=w[d|0]|w[d+1|0]<<8;d=Jd(w[e+1716|0],1,31);v[a+480204>>2]=125e4;v[a+480208>>2]=32792;v[a+480196>>2]=d;F=e+1722|0;u[a+480192>>1]=w[F|0]|w[F+1|0]<<8;G=e+1724|0;u[a+480190>>1]=w[G|0]|w[G+1|0]<<8;d=Jd(w[e+1717|0],1,32);v[a+480216>>2]=d;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=d<<2;cw(b,e+1344|0);z=a+484360|0;o=e+1706|0;Or(Rb(z),e+1344|0,w[o|0]|w[o+1|0]<<8,65535,65535);d=e+1708|0;af(Rb(z),w[d|0]|w[d+1|0]<<8);rd(e+1320|0,b,Kg(b));v[22640]=0;f=T(229,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break m}v[22640]=0;U(320,e+1296|0,b|0,f|0);d=v[22640];v[22640]=0;if((d|0)==1){break m}D=x[a+480188>>1];v[22640]=0;A=Q(228,e+1320|0,274)|0;d=v[22640];v[22640]=0;if((d|0)==1){break l}if(A){u[a+480188>>1]=x[a+480188>>1]+8}l=c&1;if(!l){break k}d=e+1710|0;d=w[d|0]|w[d+1|0]<<8;v[22640]=0;R(364,a+484344|0,d|0);d=v[22640];v[22640]=0;if((d|0)!=1){break k}h=P()|0;O()|0;break e}h=P()|0;O()|0;break n}h=P()|0;O()|0;vb(e+88|0)}Hb(e+1344|0);break c}h=P()|0;O()|0;break d}h=P()|0;O()|0;break e}q=a+484344|0;r=e+1718|0;j=e+1710|0;if(!(w[j|0]|w[j+1|0]<<8)){break f}while(1){v[22640]=0;f=T(319,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break g}v[e+160>>2]=f;v[22640]=0;f=T(229,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break h}v[22640]=0;U(320,e+240|0,b|0,f+1&-2);d=v[22640];v[22640]=0;if((d|0)==1){break h}tc(e+160|0,1024);d=v[e+160>>2];p:{if(!d|!l){break p}v[22640]=0;f=W(365,q|0,m&65535,d|0)|0;d=v[22640];v[22640]=0;q:{if((d|0)!=1){if(!f){break p}n=0;if(t[r|0]&1){s=0;while(1){v[22640]=0;f=Q(228,e+240|0,1)|0;d=v[22640];v[22640]=0;r:{if((d|0)!=1){if(!f){break p}v[22640]=0;f=T(353,e+240|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break i}k=0;if((f|0)!=255){break r}v[22640]=0;k=T(353,e+240|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;f=T(353,e+240|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break r}}break i}break i}s:{if(!(f&127)){break s}d=_b(q,m);v[22640]=0;d=Tc(d,s,n&65535);g=v[22640];v[22640]=0;if((g|0)==1){break i}Ov(e+88|0);if(f&1){v[22640]=0;i=T(353,e+240|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break i}t[e+88|0]=i}if(f&2){v[22640]=0;i=T(353,e+240|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break i}t[e+89|0]=i}if(f&4){v[22640]=0;i=T(353,e+240|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break i}t[e+90|0]=i}if(f&8){v[22640]=0;i=T(353,e+240|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break i}t[e+91|0]=i}if(f&16){v[22640]=0;i=T(353,e+240|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break i}t[e+92|0]=i}if(f&32){v[22640]=0;i=T(353,e+240|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break i}t[e+93|0]=i}if(f&64){v[22640]=0;g=T(353,e+240|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break i}t[e+94|0]=g}v[22640]=0;i=Q(806,d|0,e+88|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break i}v[e+16>>2]=k;v[22640]=0;v[e+64>>2]=v[e+160>>2]+(s^-1);g=Fb(e+16|0,e- -64|0);f=v[22640];v[22640]=0;if((f|0)==1){break i}h=h|i;i=v[g>>2];if(!i){break s}p=1;f=d;while(1){f=B(x[a+480188>>1],6)+f|0;g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;g=w[d+4|0]|w[d+5|0]<<8;t[f+4|0]=g;t[f+5|0]=g>>>8;if((i|0)==(p|0)){break s}p=p+1|0;continue}}s=(k+s|0)+1|0;d=v[e+160>>2];if(s>>>0>=d>>>0){while(1){n=n+1|0;s=s-d|0;if(d>>>0<=s>>>0){continue}break}}if(D>>>0>(n&65535)>>>0){continue}break}break p}d=0;if(v[e+160>>2]){break q}break p}break i}while(1){f=_b(q,m);v[22640]=0;k=Pf(f,d);f=v[22640];v[22640]=0;t:{u:{if((f|0)!=1){f=0;if(D){break u}break t}break i}while(1){v:{v[22640]=0;R(807,e+240|0,e+88|0);g=v[22640];v[22640]=0;if((g|0)==1){break v}v[22640]=0;i=Q(806,k+B(f,6)|0,e+88|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break v}h=h|i;f=f+1|0;if((D|0)!=(f|0)){continue}break t}break}break i}d=d+1|0;if(d>>>0<y[e+160>>2]){continue}break}}yb(e+240|0);m=m+1|0;if(m>>>0<(w[j|0]|w[j+1|0]<<8)>>>0){continue}break}break f}h=P()|0;O()|0;vb(e+1344|0);break c}h=P()|0;O()|0;yb(e+240|0);break e}h=P()|0;O()|0;break e}h=P()|0;O()|0;break e}d=e+1714|0;if(!((w[d|0]|w[d+1|0]<<8)>>>0<=1|(w[d|0]|w[d+1|0]<<8)>>>0>4999)){w:{if(h&1){p=0;d=w[d|0]|w[d+1|0]<<8;d=zc(((d>>>1|0)+11025e5>>>0)/(d>>>0)|0,0);break w}p=2;E=2646e7/+(B(B(v[a+480216>>2],v[a+480196>>2]),w[d|0]|w[d+1|0]<<8)>>>0);x:{if(E<4294967296&E>=0){d=~~E>>>0;break x}d=0}}t[a+480224|0]=p;v[a+480204>>2]=d}d=x[a+480188>>1];v[22640]=0;t[e+240|0]=0;H=W(808,e+1280|0,d|0,e+240|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){l=a+1298280|0;k=a+1298292|0;i=e+240|3;s=0;y:{z:{A:{B:{C:{while(1){v[22640]=0;f=Q(228,e+1296|0,8)|0;d=v[22640];v[22640]=0;D:{if((d|0)!=1){if(f){break D}if(x[a+480188>>1]){f=0;while(1){d=t[kc(H,f)|0];E:{if((d|0)<=(f|0)|(d|0)>=x[a+480188>>1]){break E}k=((d<<5)+a|0)+480288|0;i=w[k|0];if(!i){break E}g=((f<<5)+a|0)+480288|0;d=w[g|0];if(!d){t[g|0]=i;break E}h=(B(d-1&255,160)+a|0)+906300|0;if((Sk(h)|0)!=255){while(1){h=(B(Sk(h),160)+a|0)+906300|0;if((Sk(h)|0)!=255){continue}break}}g=h+28|0;d=w[k|0]-1&255;d=d>>>0<250?d+128|0:0;t[g|0]=d;t[g+1|0]=d>>>8;t[g+2|0]=d>>>16;t[g+3|0]=d>>>24}f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}v[e+232>>2]=0;v[e+236>>2]=0;v[e+224>>2]=0;v[e+228>>2]=0;v[e+216>>2]=0;v[e+220>>2]=0;v[e+208>>2]=0;v[e+212>>2]=0;F:{G:{H:{I:{J:{K:{if(A){v[22640]=0;R(809,e+1320|0,e+240|0);d=v[22640];v[22640]=0;L:{if((d|0)!=1){h=0;while(1){d=x[a+480192>>1];v[22640]=0;i=SO(a,d+1&65535);d=v[22640];v[22640]=0;M:{N:{O:{P:{Q:{R:{S:{if((d|0)!=1){d=h<<1;f=d+(e+224|0)|0;u[f>>1]=i;k=d+(e+208|0)|0;g=e+d|0;d=g+242|0;u[k>>1]=w[d|0]|w[d+1|0]<<8;if((i|0)==65535){break N}d=w[g+242|0]|w[g+243|0]<<8;v[22640]=0;f=W(415,a|0,i|0,d+1&65535)|0;d=v[22640];v[22640]=0;if((d|0)==1){break S}if(!f){break M}v[22640]=0;R(468,e+160|0,1571);d=v[22640];v[22640]=0;if((d|0)==1){break R}v[22640]=0;v[e+16>>2]=h+1;U(811,e+88|0,e+160|0,e+16|0);d=v[22640];v[22640]=0;if((d|0)==1){break Q}v[22640]=0;Q(333,f+492|0,e+88|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break P}vb(e+88|0);Hb(e+160|0);break M}h=P()|0;O()|0;break y}h=P()|0;O()|0;break y}h=P()|0;O()|0;break y}h=P()|0;O()|0;break O}h=P()|0;O()|0;vb(e+88|0)}Hb(e+160|0);break y}u[f>>1]=0}h=h+1|0;if((h|0)!=8){continue}break}break L}h=P()|0;O()|0;break y}d=w[e+240|0]|w[e+241|0]<<8;f=0;v[22640]=0;l=Q(359,e+160|0,d|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break F}if(w[e+240|0]|w[e+241|0]<<8){while(1){v[22640]=0;g=T(319,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break H}v[22640]=0;U(320,e+88|0,b|0,g<<5);d=v[22640];v[22640]=0;if((d|0)==1){break I}od(Hg(l,f),e+88|0);yb(e+88|0);f=f+1|0;if(f>>>0<(w[e+240|0]|w[e+241|0]<<8)>>>0){continue}break}}d=w[j|0]|w[j+1|0]<<8;m=0;v[22640]=0;A=W(812,e+88|0,d|0,33604)|0;d=v[22640];v[22640]=0;if((d|0)==1){break J}if(w[o|0]|w[o+1|0]<<8){while(1){i=e+m|0;T:{if(w[i+258|0]>=(w[e+240|0]|w[e+241|0]<<8)>>>0){break T}if(x[rc(Rb(z),m)>>1]>=(w[j|0]|w[j+1|0]<<8)>>>0){break T}d=x[rc(Rb(z),m)>>1];U:{if(x[rc(A,d)>>1]==65535){f=w[i+258|0];I=rc(A,d),J=f,u[I>>1]=J;break U}if(x[rc(A,d)>>1]==w[i+258|0]){break U}v[22640]=0;f=W(813,q|0,d|0,0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break K}if((f|0)==65535){break U}I=rc(Rb(z),m),J=f,u[I>>1]=J;d=f}v[22640]=0;g=ke(q,d);f=v[22640];v[22640]=0;if((f|0)==1){break K}if(!g){break T}k=Hg(l,w[i+258|0]);vc(k);v[22640]=0;g=T(232,k|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break K}if(!v[_b(q,d)+12>>2]){break T}i=g>>>5|0;p=0;while(1){g=_b(q,d);f=x[a+480188>>1];v[22640]=0;f=Tc(g,p,f-8&65535);g=v[22640];v[22640]=0;if((g|0)==1){break K}h=0;while(1){gi(e+16|0);g=x[e+20>>1];t[f+4|0]=g;t[f+5|0]=g>>>8;g=v[e+16>>2];t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;V:{if(i>>>0<=p>>>0){break V}v[22640]=0;Q(814,k|0,e+16|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break K}if(t[e+16|0]>-1){break V}t[f|0]=61;t[f+1|0]=w[(e+224|0)+(h<<1)|0];g=w[e+16|0]&31;t[e+64|0]=g;if(g){vf(e- -64|0,15);t[f+3|0]=20;t[f+5|0]=w[e+64|0]|208}t[f+2|0]=1;t[f+4|0]=w[e+17|0]+3>>>2}f=f+6|0;h=h+1|0;if((h|0)!=8){continue}break}p=p+1|0;if(p>>>0<y[_b(q,d)+12>>2]){continue}break}}m=m+1|0;if(m>>>0<(w[o|0]|w[o+1|0]<<8)>>>0){continue}break}}Ue(A);fd(l)}if(!(!(w[r|0]&2)|!(w[j|0]|w[j+1|0]<<8))){n=0;i=((((w[r|0]|w[r+1|0]<<8|(w[r+2|0]<<16|w[r+3|0]<<24))&8?x[a+480188>>1]:D)&65535)+((w[C|0]|w[C+1|0]<<8)>>>0>591?s:0)|0)+((w[r|0]|w[r+1|0]<<8|(w[r+2|0]<<16|w[r+3|0]<<24))>>>4&1)|0;while(1){f=0;W:{if(!i){break W}while(1){X:{v[22640]=0;g=Q(228,b|0,4)|0;d=v[22640];v[22640]=0;if((d|0)==1){break X}if(!g){break W}d=w[C|0]|w[C+1|0]<<8;v[22640]=0;R(815,d|0,b|0);d=v[22640];v[22640]=0;if((d|0)==1){break X}f=f+1|0;if((i|0)!=(f|0)){continue}break W}break}h=P()|0;O()|0;break y}n=n+1|0;if(n>>>0<(w[j|0]|w[j+1|0]<<8)>>>0){continue}break}}v[22640]=0;r=Q(359,e+192|0,255)|0;d=v[22640];v[22640]=0;Y:{Z:{_:{$:{aa:{ba:{if((d|0)!=1){s=e+88|7;D=e+88|1;A=e+88|4;z=e+88|2;l=e+88|3;d=0;while(1){f=d;v[22640]=0;R(816,b|0,e+160|0);d=v[22640];v[22640]=0;ca:{da:{ea:{fa:{if((d|0)!=1){v[22640]=0;g=T(229,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break fa}d=w[C|0]|w[C+1|0]<<8;v[22640]=0;g=(g|0)==32?428:g;g=d>>>0>513?g?g+4|0:g:g;U(320,e+240|0,b|0,g|0);d=v[22640];v[22640]=0;if((d|0)==1){break ea}d=f+1|0;q=Je(e+16|0,od(Hg(r,f),e+240|0));yb(e+240|0);if(f>>>0>=(w[F|0]|w[F+1|0]<<8)>>>0){break ca}v[22640]=0;f=d&65535;j=W(415,a|0,f|0,f|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){break da}h=P()|0;O()|0;break Z}h=P()|0;O()|0;break Y}h=P()|0;O()|0;break Y}h=P()|0;O()|0;break Y}if(!j){break ca}v[22640]=0;_e(e+88|0,2,e+160|0);f=v[22640];v[22640]=0;ga:{ha:{ia:{if((f|0)==1){break ia}v[22640]=0;R(377,e+240|0,e+88|0);f=v[22640];v[22640]=0;if((f|0)==1){break ia}v[22640]=0;Q(333,j+492|0,e+240|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ha}vb(e+240|0);if(!g){break ca}v[22640]=0;R(817,q|0,e+240|0);f=v[22640];v[22640]=0;if((f|0)==1){break $}m=0;if((w[C|0]|w[C+1|0]<<8)>>>0<513){break ga}v[22640]=0;m=T(319,q|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){break ga}h=P()|0;O()|0;break Z}h=P()|0;O()|0;break Z}h=P()|0;O()|0;vb(e+240|0);break Z}n=3;ja:{if((w[C|0]|w[C+1|0]<<8)>>>0<514){break ja}v[22640]=0;n=T(229,q|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){break ja}h=P()|0;O()|0;break Z}v[j>>2]=w[e+342|0]|w[e+343|0]<<8;t[j+16|0]=w[((w[e+344|0]|w[e+345|0]<<8)&3)+33606|0];t[j+17|0]=w[(w[e+345|0]&3)+33606|0];t[j+18|0]=w[((w[e+344|0]|w[e+345|0]<<8)>>>12&3)+33610|0];o=0;ka:{la:{ma:{na:{while(1){oa:{if(!(n&1)){break oa}v[22640]=0;R(818,q|0,e+88|0);f=v[22640];v[22640]=0;if((f|0)==1){break na}v[22640]=0;g=ii(j,w[o+33614|0]);f=v[22640];v[22640]=0;if((f|0)==1){break ma}f=g;if((o|0)!=3){h=w[g+12|0]&-17}else{h=w[g+12|0]&-17|w[e+88|0]<<4&16}t[f+12|0]=h;t[g+12|0]=w[g+12|0]&254|t[e+88|0]&1;t[g+12|0]=w[g+12|0]&251|w[e+88|0]<<1&4;t[g+12|0]=w[g+12|0]&253|w[e+88|0]>>>1&2;t[e+64|0]=w[D|0];v[22640]=0;t[e+48|0]=16;i=ac(e- -64|0,e+48|0);f=v[22640];v[22640]=0;if((f|0)==1){break la}f=w[i|0];v[22640]=0;R(475,g|0,f|0);f=v[22640];v[22640]=0;if((f|0)==1){break la}f=w[z|0];t[g+15|0]=f;t[g+16|0]=f;t[g+13|0]=w[l|0];t[g+14|0]=w[A|0];f=0;if(!Nb(g)){break oa}while(1){k=(e+88|0)+(f<<2)|0;i=w[k+8|0]|w[k+9|0]<<8;I=Mb(g,f),J=i,u[I>>1]=J;i=Jd(w[k+10|0]|w[k+11|0]<<8,0,64);I=Mb(g,f),J=i,t[I+2|0]=J;f=f+1|0;if(Nb(g)>>>0>f>>>0){continue}break}}n=n>>>1|0;o=o+1|0;if((o|0)!=4){continue}break}if(!(t[j+60|0]&1|w[j+16|0]==3)){v[j>>2]=32767}v[22640]=0;fm(j,127,1);f=v[22640];v[22640]=0;if((f|0)==1){break ba}v[22640]=0;em(j,0,1);f=v[22640];v[22640]=0;if((f|0)==1){break ba}if(!m){break ca}v[22640]=0;R(821,q|0,e+88|0);f=v[22640];v[22640]=0;if((f|0)==1){break _}if(!(m&2)){break ka}f=w[z|0]|w[z+1|0]<<8;v[22640]=0;g=pA(a,+(f>>>0));f=v[22640];v[22640]=0;if((f|0)==1){break _}v[22640]=0;fm(j,g,1);f=v[22640];v[22640]=0;if((f|0)==1){break _}f=w[A|0];v[22640]=0;em(j,f,1);f=v[22640];v[22640]=0;if((f|0)!=1){break ka}break _}h=P()|0;O()|0;break Z}h=P()|0;O()|0;break Z}h=P()|0;O()|0;break Z}t[j+25|0]=w[D|0]==1;if(!(m&4)){break ca}t[j+31|0]=w[s|0]+1;t[j+34|0]=w[e+96|0]+1;if(t[e+96|0]<=-1){t[j+30|0]=w[e+103|0]+1}if(w[e+100|0]){f=0;k=j+108|0;while(1){g=f+1|0;v[e+64>>2]=g+t[e+100|0];dV(e- -64|0);i=v[e+64>>2];I=lc(k,f),J=i,t[I|0]=J;f=g;if(f>>>0<128){continue}break}}v[22640]=0;pr(j,0);f=v[22640];v[22640]=0;if((f|0)==1){break _}}yb(q);if((d|0)!=255){continue}break}A=KB(e+88|0);g=e+16|4;s=KB(e+160|0);h=0;pa:{qa:{while(1){v[22640]=0;R(816,b|0,e+240|0);d=v[22640];v[22640]=0;if((d|0)==1){break pa}v[22640]=0;f=T(229,b|0)|0;d=v[22640];v[22640]=0;ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{if((d|0)!=1){v[22640]=0;U(320,e- -64|0,b|0,f|0);d=v[22640];v[22640]=0;if((d|0)==1){break ya}if((w[G|0]|w[G+1|0]<<8)>>>0>h>>>0){v[22640]=0;_e(e+48|0,2,e+240|0);d=v[22640];v[22640]=0;if((d|0)==1){break ra}v[22640]=0;R(377,e+16|0,e+48|0);d=v[22640];v[22640]=0;if((d|0)==1){break ra}v[22640]=0;Q(333,((h<<5)+a|0)+946336|0,e+16|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break xa}vb(e+16|0)}if(!f|(w[G|0]|w[G+1|0]<<8)>>>0<=h>>>0){break sa}v[22640]=0;i=B(h+1|0,104)+a|0;f=i+484380|0;R(352,f|0,32);d=v[22640];v[22640]=0;if((d|0)==1){break wa}v[22640]=0;R(823,e- -64|0,e+16|0);d=v[22640];v[22640]=0;if((d|0)==1){break va}v[f>>2]=w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24);v[i+484404>>2]=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);if(w[e+24|0]>=2){d=i+484414|0;u[d>>1]=x[d>>1]|1;v[f>>2]=v[f>>2]>>>1}if(w[e+25|0]>=2){d=i+484414|0;u[d>>1]=x[d>>1]|64;v[f>>2]=v[f>>2]>>>1}p=2;za:{if(w[e+27|0]!=1){p=6;if(w[e+27|0]!=2){break za}}d=i+484414|0;u[d>>1]=x[d>>1]|p}v[i+484384>>2]=w[e+28|0]|w[e+29|0]<<8|(w[e+30|0]<<16|w[e+31|0]<<24);v[i+484388>>2]=w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24);u[i+484410>>1]=(w[e+36|0]|w[e+37|0]<<8)>>>7;if(w[e+38|0]!=128){break ua}d=i+484414|0;n=x[d>>1]|256;u[d>>1]=n;break ta}h=P()|0;O()|0;break Y}h=P()|0;O()|0;break Y}h=P()|0;O()|0;vb(e+16|0);break qa}h=P()|0;O()|0;break qa}h=P()|0;O()|0;break qa}u[i+484408>>1]=t[e+38|0]+128;n=x[i+484414>>1]}d=i+484414|0;u[d>>1]=n|32;t[i+484416|0]=w[e+39|0];if(w[e+26|0]&2){Db(e+48|0,s,h);er(e+48|0)}if(w[e+26|0]&5){u[d>>1]=x[d>>1]|16384}if(!(w[e+26|0]&8)){break sa}Db(e+48|0,A,h);er(e+48|0);f=0;while(1){d=f<<1;Aa:{if(x[d+(e+208|0)>>1]!=(h|0)){break Aa}d=v[((x[d+(e+224|0)>>1]<<2)+a|0)+900380>>2];if(!d){break Aa}t[d+14|0]=0}f=f+1|0;if((f|0)!=8){continue}break}}yb(e- -64|0);h=h+1|0;if((h|0)==256){break aa}continue}break}h=P()|0;O()|0}yb(e- -64|0);break Y}h=P()|0;O()|0;break Y}h=P()|0;O()|0;break y}h=P()|0;O()|0;break Z}Ba:{if(!(w[F|0]|w[F+1|0]<<8)){break Ba}n=0;Ca:{Da:{while(1){Ea:{d=Hg(r,n);v[22640]=0;f=T(232,d|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break Ea}Fa:{if(!f){n=n+1|0;break Fa}d=Hg(r,n);vc(d);v[22640]=0;R(817,d|0,e+240|0);d=v[22640];v[22640]=0;if((d|0)==1){break Da}z=ad(e+16|0);d=w[e+240|0]|w[e+241|0]<<8;v[22640]=0;U(824,b|0,z|0,d|0);d=v[22640];v[22640]=0;if((d|0)==1){break Ca}n=n+1|0;o=v[((n<<2)+a|0)+900380>>2];if(!(!o|w[o+34|0])){v[o+4>>2]=32;v[22640]=0;pr(o,0);d=v[22640];v[22640]=0;if((d|0)==1){break Ca}k=o+108|0;i=o+236|0;f=0;while(1){d=e+f|0;Ga:{if(w[d+242|0]>=(w[e+240|0]|w[e+241|0]<<8)>>>0){break Ga}l=ze(z,w[d+242|0]);d=w[l|0];D=d+1|0;g=f+12|0;I=sd(i,g),J=D,u[I>>1]=J;if(d>>>0>=x[a+480190>>1]){break Ga}d=B(D,104)+a|0;t[d+484418|0]=w[e+338|0]&3;t[d+484419|0]=w[e+339|0];t[d+484420|0]=w[e+340|0];t[d+484421|0]=w[e+341|0];u[d+484412>>1]=w[l+1|0]<<1;t[d+484417|0]=w[l+2|0];d=D-1|0;Db(e- -64|0,A,d);if(Cb(e- -64|0)){t[o+14|0]=0}Db(e- -64|0,s,d);if(!Cb(e- -64|0)){break Ga}I=lc(k,g),J=61,t[I|0]=J}f=f+1|0;if((f|0)!=96){continue}break}}hs(z)}if((w[F|0]|w[F+1|0]<<8)>>>0>n>>>0){continue}break Ba}break}h=P()|0;O()|0;break Y}h=P()|0;O()|0;break Y}h=P()|0;O()|0;hs(z);break Y}Ha:{Ia:{if(!(c&2)|!x[a+480190>>1]){break Ia}h=1;Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{while(1){k=B(h,104)+a|0;i=k+484416|0;g=t[i|0];f=k+484417|0;c=t[f|0];v[22640]=0;d=k+484380|0;No(d,(+(c|0)*.0078125-+(g-49|0))*.08333333333333333);c=v[22640];v[22640]=0;if((c|0)==1){break Ha}t[f|0]=0;t[i|0]=0;Ra:{c=x[k+484414>>1];Sa:{if(!(c&16384)){c=Pc(e+240|0,c&1?16:8,c&64?3:1,0,12);v[22640]=0;W(363,c|0,d|0,b|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break Sa}h=P()|0;O()|0;break Y}v[22640]=0;d=T(229,b|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break Ra}v[22640]=0;Q(350,b|0,12)|0;c=v[22640];v[22640]=0;if((c|0)==1){break Ra}f=Kb(e+240|0);v[22640]=0;W(441,b|0,f|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break Qa}v[22640]=0;Q(335,k+484423|0,f|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break Qa}v[22640]=0;R(601,e- -64|0,13549);c=v[22640];v[22640]=0;if((c|0)==1){break Pa}v[e+12>>2]=h;c=Dk(a);v[22640]=0;U(13,e+48|0,c|0,f|0);c=v[22640];v[22640]=0;if((c|0)==1){break Oa}v[22640]=0;Y(602,e+16|0,e- -64|0,e+12|0,e+48|0);c=v[22640];v[22640]=0;if((c|0)==1){break Na}v[22640]=0;U(580,a|0,2,e+16|0);c=v[22640];v[22640]=0;if((c|0)==1){break Ma}vb(e+16|0);vb(e+48|0);Hb(e- -64|0);vb(f)}if(x[a+480190>>1]<=h>>>0){break Ia}h=h+1|0;continue}break}h=P()|0;O()|0;break Y}h=P()|0;O()|0;break Ja}h=P()|0;O()|0;break Ja}h=P()|0;O()|0;break Ka}h=P()|0;O()|0;break La}h=P()|0;O()|0;vb(e+16|0)}vb(e+48|0)}Hb(e- -64|0)}vb(f);break Y}fd(r);gc(H);yb(e+1296|0);yb(e+1320|0);break b}h=P()|0;O()|0;break Y}h=P()|0;O()|0;break Z}h=P()|0;O()|0}yb(q)}fd(r);break y}h=P()|0;O()|0;Ue(A);break G}h=P()|0;O()|0;break G}h=P()|0;O()|0;break G}h=P()|0;O()|0}fd(l);break y}h=P()|0;O()|0;break y}h=P()|0;O()|0;break y}v[22640]=0;m=T(229,e+1296|0)|0;f=v[22640];v[22640]=0;d=a;Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{if((f|0)!=1){v[22640]=0;g=T(229,e+1296|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break fb}v[22640]=0;U(320,e+88|0,e+1296|0,g|0);f=v[22640];v[22640]=0;if((f|0)==1){break fb}if((m|0)<=844387157){if((m|0)==4674381){break Xa}if((m|0)==5068115){break Wa}if(h&1|(m|0)!=726487106){break Ua}t[a+480224|0]=2;v[22640]=0;E=+pa(826,e+88|0);f=v[22640];v[22640]=0;if((f|0)==1){break Ta}if(E==0){break Ua}E=2646e7/(E*+(B(v[a+480216>>2],v[a+480196>>2])>>>0));if(!(E<4294967296&E>=0)){break eb}f=~~E>>>0;break db}if((m|0)<=1314144591){if((m|0)==844387158){break Va}if((m|0)!=1280004692){break Ua}p=0;if(!x[a+480188>>1]){break Ua}while(1){v[22640]=0;f=Q(228,e+88|0,1)|0;d=v[22640];v[22640]=0;if((d|0)==1){break B}if(!f){break Ua}g=Kb(e+240|0);v[22640]=0;W(552,e+88|0,g|0,-1)|0;d=v[22640];v[22640]=0;if((d|0)==1){break bb}f=Jb(g);d=Ab(g);v[22640]=0;Te(e+16|0,3,f,d);d=v[22640];v[22640]=0;if((d|0)==1){break ab}v[22640]=0;R(377,e+160|0,e+16|0);d=v[22640];v[22640]=0;if((d|0)==1){break ab}v[22640]=0;Q(427,((p<<5)+a|0)+480289|0,e+160|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break $a}vb(e+160|0);vb(g);p=p+1|0;if(p>>>0<x[a+480188>>1]){continue}break}break Ua}if((m|0)==1397445204){break cb}if((m|0)!=1314144592){break Ua}f=0;if(!(w[j|0]|w[j+1|0]<<8)){break Ua}while(1){v[22640]=0;g=Q(228,e+88|0,1)|0;d=v[22640];v[22640]=0;if((d|0)==1){break Za}if(!g){break Ua}v[22640]=0;g=$l(q,f&65535);d=v[22640];v[22640]=0;if((d|0)==1){break Za}if(!g){break Ua}g=Kb(e+240|0);v[22640]=0;W(552,e+88|0,g|0,-1)|0;d=v[22640];v[22640]=0;if((d|0)==1){break Ya}d=_b(q,f);v[22640]=0;Q(455,d|0,g|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break Ya}vb(g);f=f+1|0;if(f>>>0<(w[j|0]|w[j+1|0]<<8)>>>0){continue}break}break Ua}h=P()|0;O()|0;break y}h=P()|0;O()|0;break y}f=0}v[d+480204>>2]=f;break Ua}v[22640]=0;f=T(319,e+88|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break A}v[a+480232>>2]=f>>>9;v[a+480228>>2]=f>>>8;f=0;if(!x[a+480188>>1]){break Ua}while(1){v[22640]=0;g=Q(828,e+88|0,e+240|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break C}if(g){u[((f<<5)+a|0)+480286>>1]=(w[e+240|0]|w[e+241|0]<<8)>>>10;d=w[i|0];I=kc(H,f),J=d,t[I|0]=J}f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}break Ua}h=P()|0;O()|0;break _a}h=P()|0;O()|0;break _a}h=P()|0;O()|0;vb(e+160|0)}vb(g);break z}h=P()|0;O()|0;break z}h=P()|0;O()|0;vb(g);break z}v[22640]=0;Q(350,e+88|0,1)|0;d=v[22640];v[22640]=0;if((d|0)==1){break A}v[22640]=0;f=T(492,e+88|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break A}v[22640]=0;ca(532,k|0,e+88|0,f|0,2)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break Ua}break A}v[22640]=0;Q(829,e+88|0,e+16|0)|0;d=v[22640];v[22640]=0;gb:{if((d|0)!=1){f=Kb(e+240|0);v[22640]=0;W(552,e+88|0,f|0,-1)|0;d=v[22640];v[22640]=0;if((d|0)==1){break gb}if(xr(f,9933)){v[22640]=0;U(13,e+160|0,8,f|0);d=v[22640];v[22640]=0;if((d|0)==1){break gb}Eb(l,e+160|0);vb(e+160|0)}vb(f);break Ua}h=P()|0;O()|0;break z}h=P()|0;O()|0;vb(f);break z}v[22640]=0;s=T(229,e+88|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break A}}yb(e+88|0);continue}break}h=P()|0;O()|0;break z}h=P()|0;O()|0;break z}h=P()|0;O()|0;break z}h=P()|0;O()|0}yb(e+88|0)}gc(H);break e}h=P()|0;O()|0}yb(e+1296|0)}yb(e+1320|0)}S(h|0);L()}f=1}gb=e+1728|0;return f|0}function zg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=C(0),r=0,s=0,D=0,E=0,F=0;d=gb-2736|0;gb=d;a:{b:{if($r(c)){tc(b,268435456);D=v[c+8>>2];p=d+2712|0;e=p;v[e>>2]=0;v[e+4>>2]=0;nc(e+8|0);v[d+2708>>2]=0;e=d;c:{d:{e:{f:{g:{h:{i:{if(w[a+3|0]-4>>>0<=4){v[22640]=0;f=T(492,c|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break h}v[d+2708>>2]=f;break i}f=w[a+3|0];if(f>>>0>18){break i}f=1<<f;j:{if(!(f&126991)){if(f&396800){break j}break i}if(!w[a|0]){break i}}f=v[b>>2];v[22640]=0;f=pv(a,f);i=v[22640];v[22640]=0;if((i|0)==1){break g}v[22640]=0;U(772,d+544|0,c|0,f|0);f=v[22640];v[22640]=0;if((f|0)==1){break g}f=d+544|0;i=v[f+4>>2];v[p>>2]=v[f>>2];v[p+4>>2]=i;lp(p+8|0,f+8|0);xc(d+544|0);v[22640]=0;g=Rd(p);f=v[22640];v[22640]=0;if((f|0)==1){break h}v[d+2708>>2]=v[p>>2]}k:{f=w[a+3|0];if(f>>>0>18){break k}f=1<<f;l:{if(!(f&126991)){if(!(f&396800)){break k}h=1;break l}h=w[a|0]!=0}if(!h|y[b>>2]<262145){break k}f=v[d+2708>>2];i=w[a+3|0];v[22640]=0;v[d+520>>2]=((i|0)==11)<<4;i=Fb(d+520|0,d+2708|0);h=v[22640];v[22640]=0;if((h|0)!=1){v[d+544>>2]=f-v[i>>2];f=w[a+3|0];if(f>>>0>16){break f}m:{if(!(1<<f&126991)){if((f|0)==11){break m}break f}if(!(w[a|0]&7)){break f}}f=v[d+544>>2];if(f>>>0<=2147483647){f=f<<1;break e}f=-1;break e}a=P()|0;O()|0;break a}n:{if(!(w[a+3|0]==4|w[a+3|0]==5|w[a+3|0]==8)){if(w[a+3|0]!=7){break n}}v[d+544>>2]=v[d+2708>>2];v[22640]=0;f=dp(a);i=v[22640];v[22640]=0;h=d;o:{p:{if((i|0)!=1){i=v[d+544>>2];f=8/(f>>>0)|0;if(i>>>0>4294967295/(f>>>0)>>>0){break p}f=B(f,i);break o}a=P()|0;O()|0;break a}f=-1}v[h+544>>2]=f;tc(b,f);break d}if(w[a+3|0]!=6){break d}e=0;if(y[d+2708>>2]<10){break c}v[22640]=0;Q(350,c|0,4)|0;e=v[22640];v[22640]=0;if((e|0)==1){break h}v[22640]=0;f=T(229,c|0)|0;i=v[22640];v[22640]=0;h=d;q:{r:{s:{if((i|0)!=1){v[d+520>>2]=f;f=v[d+2708>>2];v[22640]=0;v[d+2704>>2]=f;f=Fb(d+520|0,d+2704|0);i=v[22640];v[22640]=0;if((i|0)==1){break s}v[d+544>>2]=v[f>>2];lg(c,8);f=v[d+544>>2];if(f>>>0>50529027){break r}f=B(f,85);break q}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}f=-1}v[h+544>>2]=f;tc(b,(f>>>0)/(w[a|0]>>>3>>>0)|0);break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}v[22640]=0;i=dp(a);f=v[22640];v[22640]=0;t:{u:{if((f|0)!=1){v:{w:{switch(w[a+3|0]){default:h=0;break v;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:h=w[a|0];break v;case 9:h=16;break v;case 11:h=4;break v;case 10:case 17:case 18:break w}}h=8}i=B(h,i)>>>3|0;f=i-1|0;h=v[d+544>>2];if(f>>>0>-1-h>>>0){break u}h=f+h|0;break t}a=P()|0;O()|0;break a}h=-1}f=(h>>>0)/(i>>>0)|0}v[e+544>>2]=f;tc(b,f)}if(!v[b>>2]){e=0;break c}u[b+34>>1]=x[b+34>>1]&65534|w[a|0]>15;u[b+34>>1]=x[b+34>>1]&65471|(w[a+1|0]!=1)<<6;v[22640]=0;e=T(424,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}if(!e){e=0;v[b>>2]=0;break c}x:{y:{if(je(a,Pc(d+544|0,8,1,0,11))){v[22640]=0;a=Q(1192,c|0,d+544|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){e=0;if(!a){break x}a=v[b>>2];v[22640]=0;v[d+520>>2]=a+1>>>1;a=T(492,c|0)|0;e=v[22640];v[22640]=0;z:{if((e|0)!=1){tc(d+520|0,a);a=zb(g);e=v[d+520>>2];if(e){break z}e=16;break x}a=P()|0;O()|0;break a}a=a+16|0;b=v[b+20>>2];g=0;while(1){f=w[d+544|w[a|0]&15]+g|0;t[b|0]=f;g=w[d+544|w[a|0]>>>4]+(f&255)|0;t[b+1|0]=g;e=e-1|0;if(!e){break y}a=a+1|0;b=b+2|0;continue}}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=5?w[a+3|0]!=4:0)){a=w[a+3|0];v[22640]=0;a=ca(1193,d+1616|0,c|0,b|0,(a|0)==5|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break b}yb(a);e=v[c+8>>2]-D|0;break x}if(!(w[a+3|0]!=6|w[a+1|0]!=1)){v[22640]=0;Q(350,c|0,4)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}v[22640]=0;a=T(229,c|0)|0;e=v[22640];v[22640]=0;A:{B:{C:{if((e|0)!=1){v[22640]=0;v[d+520>>2]=a;e=T(353,c|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break C}v[22640]=0;U(1194,d+544|0,c|0,a|0);a=v[22640];v[22640]=0;if((a|0)==1){break A}tc(d+520|0,v[d+544>>2]);v[22640]=0;a=v[d+520>>2];f=Rd(d+544|0);i=v[22640];v[22640]=0;if((i|0)!=1){i=v[d+544>>2];h=v[b+20>>2];b=Yi(b);v[22640]=0;ha(1195,f|0,i|0,h|0,b|0,e<<24>>24);b=v[22640];v[22640]=0;if((b|0)!=1){break B}}a=P()|0;O()|0;xc(d+544|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}e=a+9|0;xc(d+544|0);break x}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=9|w[a+1|0]!=1|w[a|0]!=16)){a=v[d+2708>>2];e=x[Qm(d+1608|0)>>1];v[22640]=0;e=SQ(b,g,a,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}D:{E:{F:{G:{H:{I:{J:{if(!(w[a+3|0]!=8|w[a+1|0]!=1|w[a|0]>16)){e=0;v[22640]=0;f=Q(228,c|0,8)|0;i=v[22640];v[22640]=0;if((i|0)==1){break b}if(!f){break x}v[22640]=0;f=T(229,c|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break b}v[d+2708>>2]=f;if(f>>>0<4){break x}v[22640]=0;U(320,d+520|0,c|0,f|0);f=v[22640];v[22640]=0;if((f|0)==1){break D}f=$k(d+544|0,d+520|0);yb(d+520|0);v[22640]=0;i=T(1197,f|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break F}if(!v[b>>2]){break H}h=w[a|0];n=(h|0)!=16;while(1){K:{if(n){break K}v[22640]=0;o=Q(236,f|0,8)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break K}a=V(27860)|0;break I}v[22640]=0;l=Q(236,f|0,1)|0;a=v[22640];v[22640]=0;if((a|0)==1){break J}v[22640]=0;a=Q(236,f|0,1)|0;g=v[22640];v[22640]=0;if((g|0)==1){break J}L:{M:{N:{if(!a){g=8;while(1){v[22640]=0;a=Q(236,f|0,1)|0;k=v[22640];v[22640]=0;if((k|0)==1){break L}if(a){break N}g=g+16|0;continue}}v[22640]=0;a=Q(236,f|0,3)|0;g=v[22640];v[22640]=0;if((g|0)!=1){break M}break J}v[22640]=0;a=Q(236,f|0,4)|0;k=v[22640];v[22640]=0;if((k|0)==1){break J}a=a+g|0}j=(j&255)+(((l?-1:0)^a)&255)|0;O:{if((h|0)!=16){t[v[b+20>>2]+e|0]=j;break O}u[v[b+20>>2]+(e<<1)>>1]=o&255|j<<8}e=e+1|0;if(e>>>0<y[b>>2]){continue}break H}break}a=V(27860)|0;break I}if(!(w[a+3|0]!=7|w[a+1|0]!=1|w[a|0]>16)){e=0;if(y[d+2708>>2]<5){break x}a=zb(zb(v[b+20>>2]));b=Yi(b);v[22640]=0;e=W(1198,c|0,a|0,b|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=16|(w[a+3|0]!=18?w[a+3|0]!=17:0)|(w[a+1|0]!=2?w[a+1|0]!=1:0))){e=v[b>>2];v[22640]=0;f=dp(a);i=v[22640];v[22640]=0;if((i|0)!=1){v[d+544>>2]=B(e,f);tc(d+544|0,v[d+2708>>2]);b=v[b+20>>2];e=v[d+544>>2];f=w[a+3|0];a=v[d+544>>2];v[d+544>>2]=a-1;if((f|0)!=17){if(!a){break x}while(1){E=b,F=x[sd(37636,zb(w[g|0]))>>1],u[E>>1]=F;a=v[d+544>>2];v[d+544>>2]=a-1;b=b+2|0;g=g+1|0;if(a){continue}break}break x}if(!a){break x}while(1){E=b,F=x[sd(37124,zb(w[g|0]))>>1],u[E>>1]=F;a=v[d+544>>2];v[d+544>>2]=a-1;b=b+2|0;g=g+1|0;if(a){continue}break}break x}a=P()|0;O()|0;break a}if(!(w[a|0]!=8|w[a+1|0]!=1)){P:{Q:{R:{S:{T:{a=w[a+3|0];switch(a|0){case 2:break Q;case 1:break R;case 0:break S;default:break T}}e=0;switch(a-10|0){case 0:break P;case 2:break Q;default:break x}}v[22640]=0;e=RQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[22640]=0;e=QQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}a=v[d+2708>>2];e=w[rA(d+512|0)|0];v[22640]=0;e=PQ(b,g,a,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[22640]=0;e=OQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=8|w[a+1|0]!=3)){U:{V:{W:{X:{f=w[a+3|0];switch(f|0){case 2:break U;case 1:break W;case 0:break X;default:break V}}v[22640]=0;e=NQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[22640]=0;e=MQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}e=0;if((f|0)!=12){break x}}e=v[d+2708>>2];f=w[rA(d+504|0)|0];v[22640]=0;e=LQ(b,g,e,f);f=v[22640];v[22640]=0;if((f|0)==1){break b}if(w[a+3|0]!=12){break x}f=v[b>>2]<<1;if((f|0)<1){break x}a=v[b+20>>2];b=f+a|0;while(1){t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;if(b>>>0>a>>>0){continue}break}break x}if(!(w[a|0]!=8|w[a+1|0]!=2)){e=0;Y:{switch(w[a+3|0]){case 0:v[22640]=0;e=KQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x;case 1:v[22640]=0;e=JQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x;case 2:break Y;default:break x}}a=v[d+2708>>2];e=w[rA(d+496|0)|0];v[22640]=0;e=IQ(b,g,a,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=1))){Z:{_:{$:{aa:{a=w[a+3|0];switch(a|0){case 1:break $;case 0:break aa;case 2:break Z;default:break _}}v[22640]=0;e=HQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[22640]=0;e=GQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}e=0;if((a|0)!=12){break x}}a=v[d+2708>>2];e=x[Qm(d+488|0)>>1];v[22640]=0;e=FQ(b,g,a,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=16|w[a+1|0]!=1|w[a+2|0]!=1)){e=0;ba:{switch(w[a+3|0]){case 0:v[22640]=0;e=EQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x;case 1:v[22640]=0;e=DQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x;case 2:break ba;default:break x}}a=v[d+2708>>2];e=x[Qm(d+480|0)>>1];v[22640]=0;e=CQ(b,g,a,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=3))){ca:{da:{ea:{fa:{f=w[a+3|0];switch(f|0){case 2:break ca;case 1:break ea;case 0:break fa;default:break da}}v[22640]=0;e=BQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[22640]=0;e=AQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}e=0;if((f|0)!=12){break x}}e=v[d+2708>>2];f=x[Qm(d+472|0)>>1];v[22640]=0;e=zQ(b,g,e,f);f=v[22640];v[22640]=0;if((f|0)==1){break b}if(w[a+3|0]!=12){break x}f=v[b>>2];if(f<<1<1){break x}a=v[b+20>>2];b=a+(f<<2)|0;while(1){u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;if(b>>>0>a>>>0){continue}break}break x}if(!(w[a|0]!=16|w[a+1|0]!=3|w[a+2|0]!=1)){e=0;ga:{switch(w[a+3|0]){case 0:v[22640]=0;e=yQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x;case 1:v[22640]=0;e=xQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x;case 2:break ga;default:break x}}a=v[d+2708>>2];e=x[Qm(d+464|0)>>1];v[22640]=0;e=wQ(b,g,a,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=2))){e=0;ha:{switch(w[a+3|0]){case 0:v[22640]=0;e=vQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x;case 1:v[22640]=0;e=uQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x;case 2:break ha;default:break x}}a=v[d+2708>>2];e=x[Qm(d+456|0)>>1];v[22640]=0;e=tQ(b,g,a,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=16|w[a+1|0]!=2|w[a+2|0]!=1)){e=0;ia:{switch(w[a+3|0]){case 0:v[22640]=0;e=sQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x;case 1:v[22640]=0;e=rQ(b,g,v[d+2708>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x;case 2:break ia;default:break x}}a=v[d+2708>>2];e=x[Qm(d+448|0)>>1];v[22640]=0;e=qQ(b,g,a,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=1))){e=v[d+2708>>2];if(!w[a+2|0]){v[22640]=0;e=pQ(b,g,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[22640]=0;e=oQ(b,g,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=2))){e=v[d+2708>>2];if(!w[a+2|0]){v[22640]=0;e=nQ(b,g,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[22640]=0;e=mQ(b,g,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=1))){e=v[d+2708>>2];if(!w[a+2|0]){v[22640]=0;e=lQ(b,g,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[22640]=0;e=kQ(b,g,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=2))){e=v[d+2708>>2];if(!w[a+2|0]){v[22640]=0;e=jQ(b,g,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[22640]=0;e=iQ(b,g,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=1))){e=v[d+2708>>2];if(!w[a+2|0]){v[22640]=0;e=hQ(b,g,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[22640]=0;e=gQ(b,g,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=2))){e=v[d+2708>>2];if(!w[a+2|0]){v[22640]=0;e=fQ(b,g,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[22640]=0;e=eQ(b,g,e);a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=3)){e=v[d+2708>>2];if(!w[a+2|0]){v[22640]=0;e=W(1239,b|0,g|0,e|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[22640]=0;e=W(1240,b|0,g|0,e|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=3)){e=v[d+2708>>2];if(!w[a+2|0]){v[22640]=0;e=W(1241,b|0,g|0,e|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[22640]=0;e=W(1242,b|0,g|0,e|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=64|w[a+1|0]!=1|w[a+3|0]!=3)){e=v[d+2708>>2];if(!w[a+2|0]){v[22640]=0;e=W(1243,b|0,g|0,e|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[22640]=0;e=W(1244,b|0,g|0,e|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=64|w[a+1|0]!=2|w[a+3|0]!=3)){e=v[d+2708>>2];if(!w[a+2|0]){v[22640]=0;e=W(1245,b|0,g|0,e|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[22640]=0;e=W(1246,b|0,g|0,e|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=24|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=16)){v[d+544>>2]=-2147483648;e=v[d+2708>>2];ja:{if(!w[a+2|0]){v[d+8>>2]=v[d+440>>2];v[d+436>>2]=0;a=v[d+436>>2];v[d>>2]=v[d+432>>2];v[d+4>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],bd(b)),v[E+12>>2]=F;tc(k+12|0,(e>>>0)/3|0);e=zb(g);a=v[d+4>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[e|0]);j=zb(w[e+1|0])<<16|f<<8|zb(w[e+2|0])<<24;ka:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break ka}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;e=e+3|0;i=i-1|0;if(i){continue}break}}m=d+544|0;la:{if(!a){break la}j=v[k+12>>2];if(!j){break la}n=a-1|0;s=a>>>1|0;i=a;e=v[h+20>>2];while(1){f=zb(w[g|0]);o=e;f=zb(w[g+1|0])<<16|f<<8|zb(w[g+2|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;ma:{if((f|0)>0?1:(f|0)>=0){f=pqa(h,f,i,0);h=jb;break ma}l=n;h=pqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=ed(zc(f,h),16),u[E>>1]=F;g=g+3|0;e=e+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;e=B(v[k+12>>2],3);break ja}v[d+24>>2]=v[d+424>>2];v[d+420>>2]=0;a=v[d+420>>2];v[d+16>>2]=v[d+416>>2];v[d+20>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],bd(b)),v[E+12>>2]=F;tc(k+12|0,(e>>>0)/3|0);e=zb(g);a=v[d+20>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[e+2|0]);j=zb(w[e+1|0])<<16|f<<8|zb(w[e|0])<<24;na:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break na}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;e=e+3|0;i=i-1|0;if(i){continue}break}}m=d+544|0;oa:{if(!a){break oa}j=v[k+12>>2];if(!j){break oa}n=a-1|0;s=a>>>1|0;i=a;e=v[h+20>>2];while(1){f=zb(w[g+2|0]);o=e;f=zb(w[g+1|0])<<16|f<<8|zb(w[g|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;pa:{if((f|0)>0?1:(f|0)>=0){f=pqa(h,f,i,0);h=jb;break pa}l=n;h=pqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=ed(zc(f,h),16),u[E>>1]=F;g=g+3|0;e=e+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;e=B(v[k+12>>2],3)}if(!e){break x}a=v[d+544>>2];if((a|0)==-2147483648){break x}f=mqa(x[b+32>>1],0,a,0)+1073741824|0;a=jb;a=f>>>0<1073741824?a+1|0:a;E=b,F=Jd(Uc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),u[E+32>>1]=F;u[b+34>>1]=x[b+34>>1]|8192;break x}if(!(w[a|0]!=32|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=16)){v[d+544>>2]=-2147483648;e=v[d+2708>>2];qa:{if(!w[a+2|0]){v[d+40>>2]=v[d+408>>2];v[d+404>>2]=0;a=v[d+404>>2];v[d+32>>2]=v[d+400>>2];v[d+36>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],bd(b)),v[E+12>>2]=F;tc(k+12|0,e>>>2|0);e=zb(g);a=v[d+36>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[e|0]);j=f|zb(w[e+1|0])<<8|zb(w[e+2|0])<<16|zb(w[e+3|0])<<24;ra:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break ra}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;e=e+4|0;i=i-1|0;if(i){continue}break}}m=d+544|0;sa:{if(!a){break sa}j=v[k+12>>2];if(!j){break sa}n=a-1|0;s=a>>>1|0;i=a;e=v[h+20>>2];while(1){f=zb(w[g|0]);o=e;f=f|zb(w[g+1|0])<<8|zb(w[g+2|0])<<16|zb(w[g+3|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;ta:{if((f|0)>0?1:(f|0)>=0){f=pqa(h,f,i,0);h=jb;break ta}l=n;h=pqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=ed(zc(f,h),16),u[E>>1]=F;g=g+4|0;e=e+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;e=v[k+12>>2]<<2;break qa}v[d+56>>2]=v[d+392>>2];v[d+388>>2]=0;a=v[d+388>>2];v[d+48>>2]=v[d+384>>2];v[d+52>>2]=a;k=gb-16|0;gb=k;h=b;E=k,F=B(v[b>>2],bd(b)),v[E+12>>2]=F;tc(k+12|0,e>>>2|0);e=zb(g);a=v[d+52>>2];i=v[k+12>>2];if(i){while(1){f=zb(w[e+3|0]);j=f|zb(w[e+2|0])<<8|zb(w[e+1|0])<<16|zb(w[e|0])<<24;ua:{if((j|0)<=-1){f=-2147483648;if((j|0)==-2147483648){break ua}j=0-j|0}f=a>>>0<j>>>0?j:a}a=f;e=e+4|0;i=i-1|0;if(i){continue}break}}m=d+544|0;va:{if(!a){break va}j=v[k+12>>2];if(!j){break va}n=a-1|0;s=a>>>1|0;i=a;e=v[h+20>>2];while(1){f=zb(w[g+3|0]);o=e;f=f|zb(w[g+2|0])<<8|zb(w[g+1|0])<<16|zb(w[g|0])<<24;l=f>>31;h=f;f=l<<31|f>>>1;h=s|h<<31;wa:{if((f|0)>0?1:(f|0)>=0){f=pqa(h,f,i,0);h=jb;break wa}l=n;h=pqa(l-h|0,0-((h>>>0>l>>>0)+f|0)|0,i,0);f=0-h|0;h=0-(jb+((h|0)!=0)|0)|0}E=o,F=ed(zc(f,h),16),u[E>>1]=F;g=g+4|0;e=e+2|0;j=j-1|0;if(j){continue}break}}if(m){v[m>>2]=a}gb=k+16|0;e=v[k+12>>2]<<2}if(!e){break x}a=v[d+544>>2];if((a|0)==-2147483648){break x}a=mqa(x[b+32>>1],0,a,0)+1073741824|0;f=jb;f=a>>>0<1073741824?f+1|0:f;E=b,F=Jd(Uc((f&2147483647)<<1|a>>>31,f>>>31|0),1,64),u[E+32>>1]=F;u[b+34>>1]=x[b+34>>1]|8192;break x}xa:{if(!(w[a|0]!=32|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=15)){v[d+544>>2]=1065353216;e=v[d+2708>>2];ya:{if(!w[a+2|0]){v[d+372>>2]=0;v[d+376>>2]=1065353216;a=v[d+380>>2];v[d+72>>2]=v[d+376>>2];v[d+76>>2]=a;v[22640]=0;a=v[d+372>>2];v[d+64>>2]=v[d+368>>2];v[d+68>>2]=a;e=ga(1247,b|0,g|0,e|0,d+544|0,d- -64|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break ya}break xa}v[d+356>>2]=0;v[d+360>>2]=1065353216;a=v[d+364>>2];v[d+88>>2]=v[d+360>>2];v[d+92>>2]=a;v[22640]=0;a=v[d+356>>2];v[d+80>>2]=v[d+352>>2];v[d+84>>2]=a;e=ga(1248,b|0,g|0,e|0,d+544|0,d+80|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break xa}}if(!e){break x}q=z[d+544>>2];if(q==C(1)){break x}a=b;h=a;q=re(Fo(C(q*C(x[a+32>>1])),C(1),C(64)));a=65535;za:{if(!(q<C(65535))){break za}a=0;if(!(q>C(0))){break za}a=~~q>>>0;if(q<C(4294967296)&q>=C(0)){break za}a=0}u[h+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break x}Aa:{if(!(w[a|0]!=64|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=15)){v[d+544>>2]=0;v[d+548>>2]=1072693248;e=v[d+2708>>2];Ba:{if(!w[a+2|0]){v[d+336>>2]=0;v[d+340>>2]=1072693248;v[d+328>>2]=0;v[d+332>>2]=0;v[d+104>>2]=0;v[d+108>>2]=0;v[d+112>>2]=0;v[d+116>>2]=1072693248;a=v[d+348>>2];v[d+120>>2]=v[d+344>>2];v[d+124>>2]=a;v[22640]=0;a=v[d+324>>2];v[d+96>>2]=v[d+320>>2];v[d+100>>2]=a;e=ga(1249,b|0,g|0,e|0,d+544|0,d+96|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break Ba}break Aa}v[d+304>>2]=0;v[d+308>>2]=1072693248;v[d+296>>2]=0;v[d+300>>2]=0;v[d+136>>2]=0;v[d+140>>2]=0;v[d+144>>2]=0;v[d+148>>2]=1072693248;a=v[d+316>>2];v[d+152>>2]=v[d+312>>2];v[d+156>>2]=a;v[22640]=0;a=v[d+292>>2];v[d+128>>2]=v[d+288>>2];v[d+132>>2]=a;e=ga(1250,b|0,g|0,e|0,d+544|0,d+128|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break Aa}}if(!e){break x}r=A[d+544>>3];if(r==1){break x}a=b;h=a;r=fe(qA(r*+x[a+32>>1],1,64));a=65535;Ca:{if(!(r<65535)){break Ca}a=0;if(!(r>0)){break Ca}a=~~r>>>0;if(r<4294967296&r>=0){break Ca}a=0}u[h+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break x}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=13)){e=v[d+2708>>2];if(!w[a+2|0]){v[d+280>>2]=939524096;v[22640]=0;a=v[d+284>>2];v[d+160>>2]=v[d+280>>2];v[d+164>>2]=a;e=ca(1251,b|0,g|0,e|0,d+160|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[d+272>>2]=939524096;v[22640]=0;a=v[d+276>>2];v[d+168>>2]=v[d+272>>2];v[d+172>>2]=a;e=ca(1252,b|0,g|0,e|0,d+168|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=13)){e=v[d+2708>>2];if(!w[a+2|0]){v[d+264>>2]=939524096;v[22640]=0;a=v[d+268>>2];v[d+176>>2]=v[d+264>>2];v[d+180>>2]=a;e=ca(1253,b|0,g|0,e|0,d+176|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[d+256>>2]=939524096;v[22640]=0;a=v[d+260>>2];v[d+184>>2]=v[d+256>>2];v[d+188>>2]=a;e=ca(1254,b|0,g|0,e|0,d+184|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=14)){e=v[d+2708>>2];if(!w[a+2|0]){v[d+248>>2]=872415232;v[22640]=0;a=v[d+252>>2];v[d+192>>2]=v[d+248>>2];v[d+196>>2]=a;e=ca(1251,b|0,g|0,e|0,d+192|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}v[d+240>>2]=872415232;v[22640]=0;a=v[d+244>>2];v[d+200>>2]=v[d+240>>2];v[d+204>>2]=a;e=ca(1252,b|0,g|0,e|0,d+200|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}e=0;if(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=14){break x}e=v[d+2708>>2];if(!w[a+2|0]){v[d+232>>2]=872415232;v[22640]=0;a=v[d+236>>2];v[d+208>>2]=v[d+232>>2];v[d+212>>2]=a;e=ca(1253,b|0,g|0,e|0,d+208|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break x}break b}v[d+224>>2]=872415232;v[22640]=0;a=v[d+228>>2];v[d+216>>2]=v[d+224>>2];v[d+220>>2]=a;e=ca(1254,b|0,g|0,e|0,d+216|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break x}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=V(27860)|0}if((O()|0)!=(ea(27860)|0)){break E}Z(a|0)|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)==1){break G}}e=i+4|0;yb(f);break x}a=P()|0;O()|0;break E}a=P()|0;O()|0}yb(f);break a}a=P()|0;O()|0;break a}e=v[d+520>>2]+16|0}v[22640]=0;Q(227,c|0,e+D|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}}xc(p)}gb=d+2736|0;return e|0}a=P()|0;O()|0}xc(p);S(a|0);L()}function mu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,T=0,V=0,X=0,Z=0,$=0,aa=0,ba=0,da=0,ea=0,fa=0,ia=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;l=gb-192|0;gb=l;$=ad(a);o=l+160|0;t[o+26|0]=0;u[o+24>>1]=0;v[o+16>>2]=0;v[o+20>>2]=-1;v[o+8>>2]=-1;v[o+12>>2]=-1;v[o>>2]=0;v[o+4>>2]=0;E=v[d+16>>2];Z=w[d+6|0];aa=b+484360|0;if(Z>>>0>=Oi(aa)>>>0){Z=w[aa+16|0]}s=Nj(aa,Z);v[22640]=0;r=Q(1255,l+120|0,b|0)|0;a=v[22640];v[22640]=0;a:{if((a|0)!=1){g=v[r+4>>2];v[22640]=0;F=W(1256,l+80|0,b|0,Z|0)|0;a=v[22640];v[22640]=0;b:{if((a|0)!=1){h=x[d+4>>1];c:{d:{if(h>>>0>=sc(s)>>>0){break d}while(1){v[22640]=0;a=Q(497,s|0,h&65535)|0;k=v[22640];v[22640]=0;if((k|0)==1){break c}if(a){break d}v[d>>2]=0;h=h+1|0;u[d+4>>1]=h;if(sc(s)>>>0>(h&65535)>>>0){continue}break}}a=v[d>>2];v[g+52>>2]=a;v[g+48>>2]=a;v[o+16>>2]=a;u[g+74>>1]=h;u[g+72>>1]=h;u[o+24>>1]=h;G=l+72|0;Sd(G);ia=wr(l- -64|0);ka=c&7;ma=(ka|0)!=7;e:{if(ma){break e}Il(G,1);Il(G,2);Il(G,3);Il(G,28);Il(G,38);Il(G,40);Il(G,39);Il(G,41);bQ(ia,12);bQ(ia,13);if((E|0)!=2){break e}a=x[d+12>>1];if(sc(s)>>>0<=a>>>0){break e}a=x[rc(s,a)>>1];v[22640]=0;k=b+484344|0;h=ke(k,a);e=v[22640];v[22640]=0;if((e|0)==1){break c}if(!h){break e}e=_b(k,a);h=v[d+8>>2];v[22640]=0;e=aQ(e,h);i=v[22640];v[22640]=0;if((i|0)==1){break c}if(!e){break e}a=_b(k,a);v[22640]=0;h=Tc(a,h,0);a=v[22640];v[22640]=0;if((a|0)==1){break c}if(!x[b+480188>>1]){break e}a=r+20|0;while(1){f:{g:{h:{switch(w[h|0]-253|0){case 0:if(x[b+480192>>1]){break g}break;case 1:case 2:break g;default:break h}}v[22640]=0;k=ce(h);e=v[22640];v[22640]=0;if((e|0)==1){break c}if(!k){break f}if(nu(h)){break f}}sa=ze(a,f),ta=-1,v[sa>>2]=ta}h=h+6|0;f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break}}X=g+74|0;I=g+48|0;K=g+80|0;pa=g+44|0;D=r+20|0;la=r+8|0;ba=c&1;da=g+20|0;z=b+1074312|0;na=g+616|0;H=b+484344|0;fa=32768;qa=(E|0)!=3;oa=(E|0)!=2;f=0;h=0;i:{j:{while(1){M=h;k:{l:{while(1){e=x[d+12>>1];ra=A[d+8>>3];while(1){v[22640]=0;Ez(l+32|0,b,g,f&1);a=v[22640];v[22640]=0;if((a|0)==1){break c}k=w[l+32|0];if(!(A[r+32>>3]<ra?1:qa)){break l}h=x[g+72>>1];a=g;m:{if(sc(s)>>>0>h>>>0){h=x[rc(s,x[g+72>>1])>>1];break m}h=65535}u[a+70>>1]=h;v[22640]=0;a=ke(H,h&65535);h=v[22640];v[22640]=0;if((h|0)==1){break i}if(!((e|0)==x[g+72>>1]?x[g+70>>1]==65535|oa|a:1)){break l}n:{if(x[g+70>>1]<Oe(H)>>>0){break n}while(1){a=g;n=a;o:{p:{if(x[a+70>>1]!=65535){h=x[g+72>>1];if(sc(s)>>>0>h>>>0){break p}}if(x[s+28>>1]==x[g+72>>1]){break n}h=x[s+28>>1];break o}h=x[g+72>>1]+1|0}u[n+72>>1]=h;a=g;q:{if(sc(s)>>>0>(h&65535)>>>0){h=x[rc(s,x[g+72>>1])>>1];break q}h=65535}u[a+70>>1]=h;u[g+74>>1]=x[g+72>>1];v[22640]=0;a=ke(H,h&65535);h=v[22640];v[22640]=0;if((h|0)==1){break i}r:{if(a){break r}a=x[g+72>>1];h=Nq(l+32|0,na);v[22640]=0;a=ga(1259,F|0,a|0,0,h|0,(k|0)!=0|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break c}if(!a){break r}if(E>>>0<2){a=x[g+72>>1];v[o+8>>2]=0;u[o+20>>1]=a;if(!E){break n}}v[22640]=0;a=ca(1260,F|0,X|0,I|0,1)|0;h=v[22640];v[22640]=0;if((h|0)==1){break i}if(!a){break n}A[o>>3]=A[r+32>>3];v[22640]=0;R(1261,$|0,o|0);a=v[22640];v[22640]=0;if((a|0)==1){break i}v[o+16>>2]=v[I>>2];u[o+24>>1]=x[X>>1];v[22640]=0;_(1262,r|0);a=v[22640];v[22640]=0;if((a|0)==1){break i}a=x[g+74>>1];u[g+72>>1]=a;sa=g,ta=x[rc(s,a)>>1],u[sa+70>>1]=ta;v[g+52>>2]=v[g+48>>2];break n}if(x[g+70>>1]>=Oe(H)>>>0){continue}break}}if(x[X>>1]==65535){break j}a=x[g+70>>1];v[22640]=0;a=ke(H,a);h=v[22640];v[22640]=0;if((h|0)==1){break i}if(!a){if(x[s+28>>1]==x[g+72>>1]){if(!E){break j}v[22640]=0;a=ca(1260,F|0,X|0,I|0,1)|0;k=v[22640];v[22640]=0;if((k|0)==1){break i}if(!a){break j}A[o>>3]=A[r+32>>3];v[22640]=0;R(1261,$|0,o|0);a=v[22640];v[22640]=0;if((a|0)==1){break i}v[o+16>>2]=v[I>>2];u[o+24>>1]=x[X>>1];v[22640]=0;_(1262,r|0);a=v[22640];v[22640]=0;if((a|0)==1){break i}v[g+52>>2]=v[g+48>>2];continue}u[g+74>>1]=x[g+72>>1]+1;continue}break}if(y[g+48>>2]>=y[_b(H,x[g+70>>1])+12>>2]){v[I>>2]=0}if(!(v[I>>2]==v[d+8>>2]?x[g+72>>1]!=x[d+12>>1]|oa:1)){break l}h=0;if(!((E|0)==3|y[F+28>>2]<fa>>>0)){v[r+32>>2]=0;v[r+36>>2]=2146435072;v[F+28>>2]=0;fa=fa>>>(fa>>>0>256)|0;h=1}a=v[g+48>>2];e=x[g+72>>1];i=Nq(l+32|0,na);v[22640]=0;a=ga(1259,F|0,e|0,a|0,i|0,(k|0)!=0|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break c}if((a|h)==1){if(E>>>0<2){u[o+20>>1]=x[g+72>>1];v[o+8>>2]=v[g+48>>2];if(!E){break j}}v[22640]=0;a=ca(1260,F|0,X|0,I|0,1)|0;k=v[22640];v[22640]=0;if((k|0)==1){break c}if(!a){break j}A[o>>3]=A[r+32>>3];v[22640]=0;R(1261,$|0,o|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}v[o+16>>2]=v[I>>2];u[o+24>>1]=x[X>>1];v[22640]=0;_(1262,r|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}v[g+52>>2]=v[g+48>>2];continue}u[o+22>>1]=x[g+72>>1];v[o+12>>2]=v[g+48>>2];v[22640]=0;Dz(b,g,0);a=v[22640];v[22640]=0;if((a|0)==1){break c}if(y[g+48>>2]>=y[_b(H,x[g+70>>1])+12>>2]){v[I>>2]=0}if(k){continue}break}a=_b(H,x[g+70>>1]);k=v[g+48>>2];v[22640]=0;h=Tc(a,k,0);a=v[22640];v[22640]=0;s:{if((a|0)!=1){Db(l+32|0,z,77);f=Cb(l+32|0);e=0;if(x[b+480188>>1]){break s}break k}break c}while(1){t:{if(sa=oA(h),ta=1,ua=!f|!(w[((e<<5)+b|0)+480281|0]&4),ua?sa:ta){Yo((B(e,872)+g|0)+1404|0);break t}v[22640]=0;a=xg(h);k=v[22640];v[22640]=0;if((k|0)==1){break c}if(a){u:{if(!ba){break u}a=w[h+1|0];if(a-251>>>0<5|!a){break u}v[22640]=0;a=Eo(h);k=v[22640];v[22640]=0;if((k|0)==1){break c}v[22640]=0;k=Mq(h);i=v[22640];v[22640]=0;if((i|0)==1){break c}u[l+8>>1]=k;t[l+32|0]=w[h+1|0];u[l+34>>1]=x[l+8>>1];v[22640]=0;k=Q(1267,la|0,l+32|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break c}u[k>>1]=a}Yo((B(e,872)+g|0)+1404|0);break t}a=B(e,872)+g|0;k=a+1408|0;i=w[h+4|0]|w[h+5|0]<<8;t[k|0]=i;t[k+1|0]=i>>>8;a=a+1404|0;k=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[a|0]=k;t[a+1|0]=k>>>8;t[a+2|0]=k>>>16;t[a+3|0]=k>>>24;v:{switch(w[h+3|0]-16|0){case 0:a=w[h+5|0];v[22640]=0;U(1268,b|0,g|0,a|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}break t;case 1:Db(l+32|0,z,5);if(!Cb(l+32|0)){break t}a=w[h+5|0];if(!a){break t}v[22640]=0;U(1268,b|0,g|0,a|0);a=v[22640];v[22640]=0;if((a|0)!=1){break t}break c;case 4:a=w[h+5|0];k=a&240;if((k|0)!=224){if((k|0)!=96){break t}v[g+24>>2]=v[g+24>>2]+(a&15);break t}if(v[da>>2]){break t}a=w[h+5|0]&15;if(a?0:v[b+480180>>2]&2){break t}v[da>>2]=a+1;break t;case 3:break v;default:break t}}a=w[h+5|0];if((a&240)!=224){break t}v[da>>2]=(a&15)+1}h=h+6|0;e=e+1|0;if(e>>>0<x[b+480188>>1]){continue}break}break k}t[o+26|0]=1;break j}k=sk(g);v[22640]=0;v[l+32>>2]=1;a=Jc(da,l+32|0);h=v[22640];v[22640]=0;w:{if((h|0)!=1){a=v[a>>2];u[g+68>>1]=65535;v[g+60>>2]=-1;v[g+64>>2]=-1;if(!x[b+480188>>1]){break w}N=k-1|0;h=k-a|0;J=B(h,1e4);e=0;while(1){x:{i=B(e,872)+g|0;a=i+1404|0;y:{if(oA(a)){break y}m=i+616|0;f=w[i+1409|0];T=i+1407|0;n=w[T|0];z:{A:{if(!ba){break A}j=w[a|0];p=i+1405|0;q=w[p|0];if(q){t[i+1415|0]=0;t[i+1419|0]=q;sa=ze(D,e),ta=255,t[sa+5|0]=ta}v[22640]=0;q=ce(a);ea=v[22640];v[22640]=0;if((ea|0)==1){break x}if(q){t[i+1415|0]=j}v[22640]=0;q=ce(a);ea=v[22640];v[22640]=0;if((ea|0)==1){break x}B:{if(!(w[p|0]?1:q)){break B}C:{p=i+1419|0;q=w[p|0];if(!q|q>>>0>x[b+480192>>1]){break C}q=v[((w[p|0]<<2)+b|0)+900380>>2];if(!q|!(t[q+15|0]&1)){break C}q=v[q+8>>2];v[22640]=0;Ro(m,q,b);q=v[22640];v[22640]=0;if((q|0)!=1){break C}break c}j=Qz(b,j,w[p|0]);if(!j){break B}j=B(j,104)+b|0;if(!(w[j+484414|0]&32)){break B}j=x[j+484408>>1];v[22640]=0;Ro(m,j,b);j=v[22640];v[22640]=0;if((j|0)!=1){break B}break c}D:{E:{F:{j=w[i+1406|0];switch(j-1|0){case 1:break A;case 2:case 3:break E;case 0:break F;default:break D}}sa=ze(D,e),ta=w[i+1408|0],t[sa+5|0]=ta;break A}a=w[i+1408|0];if(!a){break A}t[i+1450|0]=a;break A}if(!w[i+1408|0]|(j|0)!=11){break A}nA(l+32|0,b,a,0);a=Re(l+32|0);u[i+1384>>1]=x[l+32>>1];if(w[a|0]){break z}}G:{H:{switch(n-12|0){case 0:v[22640]=0;mA(b,g,e&65535);a=v[22640];v[22640]=0;if((a|0)!=1){break G}break x;case 2:v[22640]=0;a=kA(b,g,e&65535,f);j=v[22640];v[22640]=0;if((j|0)!=1){if((a|0)==-1){break G}v[g+60>>2]=a;break G}break c;case 5:Db(l+32|0,z,5);if(Cb(l+32|0)){break G}a=v[g+48>>2];j=x[g+70>>1];v[22640]=0;a=Om(b,j,a,e&65535,0);j=v[22640];v[22640]=0;I:{J:{if((j|0)!=1){a=B(a,1e4);if(!ba|!(v[b+480180>>2]&16777250)){break I}if(a>>>0<1e4){break J}t[i+1451|0]=(a>>>0)/1e4;break I}break c}a=B(w[i+1451|0],1e4)}j=(a>>>0)/1e4|0;K:{if(a>>>0>319999){break K}p=B(J,j&15);a=v[g+44>>2];if((j&240)==16){a=a+p|0;break K}j=a-p|0;a=a>>>0<j>>>0?0:j}v[g+44>>2]=a;a=v[v[b+8>>2]+20>>2];j=v[v[b+8>>2]+24>>2];Db(l+32|0,z,8);Gp(pa,B(a,1e4),Cb(l+32|0)?255e4:B(j,1e4));break G;case 8:L:{switch((f&240)-144>>>4|0){case 0:if(f>>>0>145){break G}v[i+704>>2]=v[i+704>>2]&-257|((f|0)==145)<<8;break G;case 1:t[i+1452|0]=f&15;break G;case 2:lu(b,g,m,f&15);break G;case 6:break L;default:break G}}t[i+1460|0]=f&15;break G;case 7:a=f&240;if((a|0)!=240){if((a|0)!=96){break G}lu(b,g,m,f&15);break G}t[i+1460|0]=f&15;break G;case 1:case 3:case 4:case 6:break G;default:break H}}if((n|0)!=28|(f&240)!=160){break G}Db(l+32|0,z,58);if(Cb(l+32|0)){break G}t[i+1452|0]=f&15}if(!ba){break y}M:{N:{O:{P:{Q:{R:{S:{switch(n-2|0){case 0:if(!f){break z}Db(l+32|0,z,90);if(!Cb(l+32|0)){t[i+1428|0]=f}t[i+1427|0]=f;break z;case 1:if(!f){break z}Db(l+32|0,z,90);if(!Cb(l+32|0)){t[i+1427|0]=f}t[i+1428|0]=f;break z;case 2:if(!f){break z}u[i+1384>>1]=f;break z;case 8:if(!f){break z}v[i+1280>>2]=f<<8;break z;case 4:case 9:if(!f){break z}t[i+1425|0]=f;break z;case 11:sa=ze(D,e),ta=f,t[sa+5|0]=ta;break z;case 21:a=f<<(!(v[b+480180>>2]&59593760)&f<<24>>24>-1)&255;if(a>>>0<=128){v[K>>2]=a<<1;break z}if(v[b+480180>>2]&16777250){break z}v[K>>2]=256;break z;case 22:Db(l+32|0,z,9);T:{if(Cb(l+32|0)){a=i+1433|0;if(f){t[a|0]=f;break T}f=w[a|0];break T}if(f){t[g+1433|0]=f;break T}f=w[g+1433|0]}a=K;n=f&240;j=f&15;U:{if(!(!n|(j|0)!=15)){V=v[K>>2]+(n>>>4<<!(v[b+480180>>2]&59593760)<<1)|0;break U}V=v[K>>2]-(j<<(v[b+480180>>2]&59593760?1:2))|0;if(!(!j|(n|0)!=240)){break U}V=v[K>>2]+B(h,(f>>>3&30)<<!(v[b+480180>>2]&59593760))|0;if(n){break U}V=v[K>>2]-B(h,j<<(v[b+480180>>2]&59593760?1:2))|0}v[a>>2]=V;Qd(K,0,256);break z;case 19:if(f>>>0>64){break z}v[i+1364>>2]=f;break z;case 20:a=i+1432|0;V:{if(f){t[a|0]=f;break V}f=w[a|0]}n=f&255;j=i+1364|0;a=v[j>>2];p=f&240;f=f&15;W:{if(!(!p|(f|0)!=15)){v[l+32>>2]=a+(n>>>4|0);break W}if(!(!f|(p|0)!=240)){v[l+32>>2]=a-f;break W}if(f){v[l+32>>2]=a-B(f,h);break W}v[l+32>>2]=a+B(h,n>>>4|0)}Qd(l+32|0,0,64);v[j>>2]=v[l+32>>2];break z;case 7:Nm(b,m,f,8);break z;case 25:break M;case 6:break N;case 24:break O;case 3:break P;case 5:break Q;case 18:break R;case 17:break S;default:break z}}if(!x[b+480188>>1]|f>>>0>15){break R}n=(f&1)<<14;a=0;while(1){j=B(a,872)+g|0;v[j+704>>2]=(n|v[j+704>>2]&-16385)^16384;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if((f&240)!=128){break z}Nm(b,m,f&15,4);break z}if(f){t[i+1425|0]=f}f=0}Hl(m,f);break z}_P(b,m,f);break z}ZP(m,f);break z}YP(m,f)}X:{Y:{switch(w[i+1406|0]-2|0){case 0:Nm(b,m,w[i+1408|0],6);break X;case 5:Db(l+32|0,z,53);f=Cb(l+32|0);a=w[i+1408|0];if(f){t[i+1439|0]=a&15;break X}Hl(m,a<<4);break X;case 6:break Y;default:break X}}Hl(m,w[i+1408|0])}Z:{_:{$:{aa:{a=w[T|0];switch(a-5|0){case 3:break _;case 0:case 2:break $;case 1:break y;default:break aa}}switch(a-26|0){case 1:break Z;case 0:break $;default:break y}}ba:{if(v[b+480180>>2]&16777248){a=k;if(!(w[b+480208|0]&4)){break ba}}a=h}f=w[i+1439|0];Db(l+32|0,z,21);m=Cb(l+32|0);i=i+1435|0;a=B(a,f);t[i|0]=w[i|0]+(m?a<<2:a);break y}ca:{if(v[b+480180>>2]&16777248){a=k;if(!(w[b+480208|0]&4)){break ca}}a=h}f=w[i+1442|0];Db(l+32|0,z,21);m=Cb(l+32|0);i=i+1436|0;a=B(a,f);t[i|0]=w[i|0]+(m?a<<2:a);break y}a=i+1437|0;t[a|0]=w[a|0]+B(N,w[i+1445|0]);v[22640]=0;Gz(b,m);a=v[22640];v[22640]=0;if((a|0)==1){break x}}e=e+1|0;if(e>>>0<x[b+480188>>1]){continue}break w}break}break c}break c}if(v[g+40>>2]==65535?v[b+480180>>2]==4:0){break j}v[g+32>>2]=v[b+480216>>2];if(XP(_b(H,x[g+70>>1]))){sa=g,ta=v[_b(H,x[g+70>>1])+16>>2],v[sa+32>>2]=ta}v[22640]=0;h=Q(1274,b|0,g|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){a=B(h,k);A[r+32>>3]=+(a>>>0)/+y[b+24620>>2]+A[r+32>>3];v[g>>2]=a+v[g>>2];if(!(!x[b+480188>>1]|ma)){a=0;ea=(M|0)!=0&(h|0)!=(M|0);while(1){da:{if(v[ze(D,a)>>2]==-1){break da}j=B(a,872)+g|0;T=j+1404|0;n=j+1316|0;if(!v[n>>2]){if(oA(T)){break da}}N=1;ea:{fa:{J=j+1407|0;switch(w[J|0]-4|0){case 0:case 2:break ea;default:break fa}}N=w[j+1406|0]==11}if(w[j+1405|0]){v[j+1276>>2]=0}q=j+1409|0;e=w[q|0];v[22640]=0;p=ce(T);f=v[22640];v[22640]=0;ga:{if((f|0)==1){break ga}i=j+616|0;m=e&15;f=0;ha:{if(!p){break ha}ia:{if(!N){break ia}if(!w[ze(D,a)+4|0]){break ia}f=v[n>>2];v[22640]=0;ha(1275,l+32|0,b|0,i|0,f|0,0);f=v[22640];v[22640]=0;if((f|0)==1){break c}f=v[l+36>>2];v[j+624>>2]=v[l+32>>2];v[j+628>>2]=f}t[j+1418|0]=w[j+1415|0];p=j+1308|0;V=v[p>>2];f=w[j+1419|0];if(f){v[22640]=0;Do(b,i,f,N,1,1);f=v[22640];v[22640]=0;if((f|0)==1){break i}}f=w[T|0];v[22640]=0;ja(1277,b|0,i|0,f|0,N|0,1,0,65535);f=v[22640];v[22640]=0;if((f|0)==1){break i}e=e>>>4|0;sa=ze(D,a),ta=1,t[sa+4|0]=ta;n=w[J|0];ja:{if(!((w[q|0]&240)!=208|(n-19&255)>>>0>1)){f=m;if(k>>>0>f>>>0){break ja}}f=(n|0)==33?e>>>0<k>>>0?e:0:0}f=!(v[b+480180>>2]&16777250)|(!f|y[da>>2]<2)?f:B(v[g+20>>2]-1|0,v[g+24>>2]+v[g+40>>2]|0)+f|0;if(!N){sa=ze(D,a),ta=0,v[sa>>2]=ta}n=w[J|0];ka:{la:{if((n|0)==9){break la}ma:{if((n|0)!=19){if((n|0)!=20|(e|0)!=8){break ma}break la}if((e|0)==8){break la}}if(w[j+1406|0]!=2){break ka}}v[p>>2]=V}na:{oa:{pa:{switch(n-42|0){default:if((n|0)!=10){break oa}v[22640]=0;Y(1278,b|0,i|0,a&65535,g|0);e=v[22640];v[22640]=0;if((e|0)==1){break i}break ha;case 2:break na;case 1:break oa;case 0:break pa}}if(!v[j+720>>2]){break oa}v[22640]=0;Y(1279,r|0,a&65535,M|0,-1);f=v[22640];v[22640]=0;if((f|0)==1){break i}f=w[q|0];v[22640]=0;jA(i,f);f=v[22640];v[22640]=0;if((f|0)==1){break i}f=v[g+40>>2]-1|0;break ha}if(w[j+1406|0]!=15){break ha}e=j+1408|0;if(w[e|0]>9){break ha}n=v[j+720>>2];if(!n){break ha}e=w[e|0];qa:{if(!e){p=v[j+1280>>2];break qa}p=v[(n+(e<<2)|0)- -64>>2];v[j+1280>>2]=p}v[22640]=0;Mm(b,i,p);e=v[22640];v[22640]=0;if((e|0)!=1){break ha}break c}n=mqa(w[q|0],0,v[j+692>>2],0);e=jb;p=e>>>8|0;e=Uc((e&255)<<24|n>>>8,p);v[22640]=0;Mm(b,i,e);e=v[22640];v[22640]=0;if((e|0)==1){break i}}ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{switch(w[T|0]-253|0){case 0:if(x[b+480192>>1]){break Aa}break;case 1:case 2:break Aa;default:break Ba}}e=w[J|0];if((e-19&255)>>>0<=1){p=0;if((w[q|0]&240)!=192){break ya}if(k>>>0>m>>>0){break Aa}break ya}p=0;n=e;if((e|0)==33&(m|0)!=0&f+m>>>0<k>>>0){break Aa}if((n|0)!=25){break za}}e=w[J|0];p=1}if((e|0)==13){break xa}}if(w[j+1406|0]==1){v[j+1304>>2]=w[j+1408|0]<<2}if(!v[j+720>>2]|p){break ua}p=0;if(e>>>0<=44){break wa}break va}v[j+1304>>2]=w[q|0]<<2;if(!v[j+720>>2]|p){break ua}e=13}Db(l+32|0,G,e);p=1;if(Cb(l+32|0)){break va}p=0;if(w[J|0]!=19){break va}e=w[q|0]&240;p=(e|0)==16|(e|0)==32}e=w[j+1406|0];if(e>>>0>15){break ta}nl(l+32|0,ia,e);if(Cb(l+32|0)|p){break ra}break sa}if(!p){break sa}break ra}if(p){break ra}}if(ea){v[22640]=0;Y(1279,r|0,a&65535,M|0,-1);e=v[22640];v[22640]=0;if((e|0)==1){break ga}}e=w[J|0];Ca:{if(e>>>0<=18){if(!k|(!(v[b+480180>>2]==1?w[q|0]:1)|((e|0)!=11?e-6>>>0>=2:0))){break Ca}m=j+1467|0;e=0;while(1){t[m|0]=!e|w[m|0]&254;Co(b,i,w[q|0]);e=e+1|0;if((k|0)!=(e|0)){continue}break}break Ca}Da:{switch(e-19|0){case 0:e=w[q|0];if(!(e&15)){if(!(v[b+480180>>2]&1048580)){break Ca}e=w[q|0]}m=j+1467|0;t[m|0]=w[m|0]|1;m=e&240;if((m|0)!=176){if((m|0)!=160){break Ca}Lq(b,i,e&15,0);break Ca}Kq(b,i,e&15,0);break Ca;case 1:Ea:{Fa:{Ga:{e=w[q|0];switch(e-158|0){case 1:break Fa;case 0:break Ga;default:break Ea}}v[22640]=0;Y(1279,r|0,a&65535,M|0,-1);e=v[22640];v[22640]=0;if((e|0)==1){break ga}v[j+704>>2]=v[j+704>>2]&-129;break Ca}v[22640]=0;Y(1279,r|0,a&65535,M|0,-1);e=v[22640];v[22640]=0;if((e|0)==1){break ga}v[j+704>>2]=v[j+704>>2]|128;if(!v[j+692>>2]|v[i+4>>2]){break Ca}v[22640]=0;e=ce(T);m=v[22640];v[22640]=0;if((m|0)==1){break ga}if(!(w[j+704|0]&2?e:1)){break Ca}m=v[j+692>>2]-1|0;e=i;v[e>>2]=-1;v[e+4>>2]=m;break Ca}if((e&240)!=112|e>>>0<115){break Ca}v[22640]=0;YA(i,e,b);e=v[22640];v[22640]=0;if((e|0)!=1){break Ca}break ga;default:break Da}}if(e-35>>>0>=2){break Ca}v[22640]=0;e=a&65535;Y(1279,r|0,e|0,M|0,-1);m=v[22640];v[22640]=0;if((m|0)==1){break ga}v[22640]=0;Y(1283,b|0,e|0,g|0,0);e=v[22640];v[22640]=0;if((e|0)==1){break ga}}m=j+1467|0;e=w[m|0]|1;t[m|0]=e;Ha:{Ia:{Ja:{Ka:{La:{n=j+1406|0;switch(w[n|0]-3|0){case 11:break Ia;case 0:case 1:break Ja;case 3:break Ka;case 2:break La;default:break Ha}}e=w[j+1408|0];Db(l+32|0,z,41);Lq(b,i,e,Cb(l+32|0));break Ha}e=w[j+1408|0];Db(l+32|0,z,41);Kq(b,i,e,Cb(l+32|0));break Ha}e=w[j+1408|0];Ma:{if(e){break Ma}Db(l+32|0,z,41);e=0;if(!Cb(l+32|0)){break Ma}e=w[j+1450|0];if(!e){break Ha}}if(!k){break Ha}n=w[n|0]==3?e<<4:e;e=0;while(1){t[m|0]=!e|w[m|0]&254;Co(b,i,n&255);e=e+1|0;if((k|0)!=(e|0)){continue}break}break Ha}i=w[j+1408|0];if(i>>>0>1){break Ha}t[m|0]=e&251|!i<<2}if(w[m|0]&4){break da}if(N){i=ze(D,a);e=v[i>>2];v[i>>2]=e+k;v[22640]=0;Y(1279,r|0,a&65535,h|0,(f+e|0)+1|0);f=v[22640];v[22640]=0;if((f|0)!=1){break da}break c}e=ze(D,a);v[e>>2]=v[e>>2]+(k-f|0);break da}v[22640]=0;_A(i);f=v[22640];v[22640]=0;if((f|0)==1){break ga}sa=ze(D,a),ta=0,v[sa>>2]=ta;break da}break c}a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}f=UP(b,g,0);continue}break}break c}if(!(!x[b+480188>>1]|(ka|0)!=7)){a=0;while(1){Na:{if(v[ze(D,a)>>2]==-1){break Na}v[22640]=0;Y(1279,r|0,a&65535,M|0,-1);d=v[22640];v[22640]=0;if((d|0)!=1){break Na}break c}a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if(w[o+26|0]){u[o+20>>1]=x[g+72>>1];v[o+8>>2]=v[g+48>>2]}A[o>>3]=A[r+32>>3];v[22640]=0;R(1261,$|0,o|0);a=v[22640];v[22640]=0;Oa:{if((a|0)==1){break Oa}Pa:{Qa:{if(!ba){break Qa}Ra:{Sa:{if(E?w[o+26|0]:1){h=b+1074376|0;f=hc(h,g,614);a=0;while(1){k=B(a,872);d=(k+g|0)+616|0;k=hc((f+k|0)+616|0,d,88);v[k+88>>2]=v[d+88>>2];hc(k+92|0,d+92|0,576);v[k+668>>2]=v[d+668>>2];hc(k+672|0,d+672|0,52);xo(k+724|0,d+724|0);xo(k+732|0,d+732|0);xo(k+740|0,d+740|0);hc(k+748|0,d+748|0,123);a=a+1|0;if((a|0)!=256){continue}break}iA(h);a=0;v[b+1074400>>2]=0;t[b+1074476|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];d=b+1298260|0;if(Bd(d)){g=v[d>>2];v[22640]=0;MA(g);g=v[22640];v[22640]=0;if((g|0)==1){break Oa}}if(x[b+480188>>1]){k=(ka|0)==7;while(1){g=B(a,872)+b|0;h=w[g+1075791|0];if(h){t[g+1075794|0]=h}h=ze(D,a);if(!(k|w[h+5|0]==255)){v[22640]=0;t[l+32|0]=64;h=ac(h+5|0,l+32|0);f=v[22640];v[22640]=0;if((f|0)==1){break c}v[g+1075680>>2]=w[h|0]<<2}Ta:{h=g+1075096|0;f=v[h>>2];if(!f|!(w[f+35|0]&2)){break Ta}if(!Bd(d)){break Ta}f=v[d>>2];h=v[h>>2];v[22640]=0;e=f;f=a&65535;wu(e,f,h+68|0);h=v[22640];v[22640]=0;if((h|0)!=1){h=v[d>>2];v[22640]=0;Mi(h,f,1);h=v[22640];v[22640]=0;if((h|0)!=1){break Ta}}break c}v[g+1075008>>2]=0;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}d=KB(l+32|0);sa=l,ta=or(la),v[sa+24>>2]=ta;sa=l,ta=zh(la),v[sa+16>>2]=ta;if(!kg(l+24|0,l+16|0)){break Sa}while(1){g=Vl(l+24|0);k=w[g|0]-1&255;a=v[(B(k,160)+b|0)+906300>>2];if(a){Db(l+8|0,d,k);if(!Cb(l+8|0)){v[22640]=0;R(1288,d|0,k|0);k=v[22640];v[22640]=0;if((k|0)==1){break Pa}k=v[v[a>>2]+172>>2];v[22640]=0;R(k|0,a|0,-1);k=v[22640];v[22640]=0;if((k|0)==1){break Pa}}k=x[g+2>>1];h=v[v[a>>2]+44>>2];g=x[g+4>>1];v[22640]=0;Aa(h|0,a|0,k|0,C(C(C(g>>>0)*C(.0010010009864345193))));a=v[22640];v[22640]=0;if((a|0)==1){break Pa}}Oj(l+24|0);if(kg(l+24|0,l+16|0)){continue}break}break Sa}if((c|0)==3){break Ra}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074456>>2]=v[b+480200>>2];break Ra}e=250;a=d;f=a;Ua:{Va:{while(1){if(v[f>>2]){break Va}f=f+4|0;e=e-32|0;if(e>>>0>31){continue}break}a=(v[a+28>>2]&67108863)!=0;break Ua}a=1}if(!a){break Ra}a=0;while(1){Db(l+8|0,d,a);Wa:{if(!Cb(l+8|0)){break Wa}g=v[(B(a,160)+b|0)+906300>>2];k=v[v[g>>2]+176>>2];v[22640]=0;_(k|0,g|0);g=v[22640];v[22640]=0;if((g|0)!=1){break Wa}break c}a=a+1|0;if((a|0)!=250){continue}break}}if(w[aa+16|0]==(Z|0)){break Qa}v[22640]=0;Pi(aa,Z);a=v[22640];v[22640]=0;if((a|0)==1){break Oa}}if(c&9){a=F;d=b+1298224|0;c=d;b=d;if(v[b>>2]){Cc(b);vR(b);sR(b);im(wb(b),v[b>>2],qg(b));sa=wb(b),ta=0,v[sa>>2]=ta;v[b>>2]=0;v[b+4>>2]=0}ip(c,a);v[c>>2]=v[a>>2];v[c+4>>2]=v[a+4>>2];b=wb(a);sa=wb(c),ta=v[b>>2],v[sa>>2]=ta;v[b>>2]=0;v[a>>2]=0;v[a+4>>2]=0;b=d+12|0;Qq(b,v[ec(b)>>2]);a=a+12|0;v[b>>2]=v[a>>2];v[b+4>>2]=v[a+4>>2];ec(a);ec(b);v[b+8>>2]=v[a+8>>2];d=v[wb(b)>>2];c=ec(b);Xa:{if(!d){v[b>>2]=c;break Xa}sa=v[ec(b)>>2],ta=c,v[sa+8>>2]=ta;sa=a,ta=ec(a),v[sa>>2]=ta;sa=ec(a),ta=0,v[sa>>2]=ta;sa=wb(a),ta=0,v[sa>>2]=ta}}Jq(F);TP(r);gb=l+192|0;return}}}}a=P()|0;O()|0;Jq(F);break b}a=P()|0;O()|0}TP(r);break a}a=P()|0;O()|0}en($);S(a|0);L()}function l6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=C(0),s=0,A=C(0),D=0,E=0,F=0,G=0,H=C(0),I=0,J=0,K=0,M=C(0),N=0,O=C(0),P=0,Q=0,R=C(0),S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=C(0),$=0,aa=0,ca=0,da=0,ea=C(0),fa=C(0),ga=C(0),ha=C(0),ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;aa=gb-16|0;gb=aa;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;e=b;f=0;b=0;d=a;b:{c:{d:{g=v[a+1420>>2];if((g|0)<1){break d}while(1){v[(d+B(f,20)|0)+1436>>2]=0;f=f+1|0;if((g|0)!=(f|0)){continue}break}if((g|0)<=3){break d}b=c;break c}if((c|0)<4){break b}a=c-3|0;e:{while(1){f:{l=b+e|0;if(w[l|0]!=79|(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24))!=(w[89848]|w[89849]<<8|(w[89850]<<16|w[89851]<<24))){break f}h=b+26|0;if((h|0)>=(a|0)){break e}i=b+27|0;o=e+h|0;c=w[o|0];if((a|0)<=(i+c|0)){break e}j=c+27|0;f=0;if(c){while(1){j=w[e+(f+i|0)|0]+j|0;f=f+1|0;if((c|0)!=(f|0)){continue}break}}f=0;c=0;while(1){f=cy(f,w[e+(b+c|0)|0]);c=c+1|0;if((c|0)!=22){continue}break}c=23;while(1){f=cy(f,0);if((c|0)!=26){c=c+1|0;continue}break}v[d+1420>>2]=g+1;c=d+B(g,20)|0;v[c+1432>>2]=f;v[c+1428>>2]=j-26;v[c+1424>>2]=w[l+22|0]|w[l+23|0]<<8|(w[l+24|0]<<16|w[l+25|0]<<24);f=w[e+(h+w[o|0]|0)|0]==255?-1:w[l+6|0]|w[l+7|0]<<8|(w[l+8|0]<<16|w[l+9|0]<<24);v[c+1436>>2]=h;v[c+1440>>2]=f;g=v[d+1420>>2];if((g|0)!=4){break f}b=a;g=4;break c}b=b+1|0;if((a|0)!=(b|0)){continue}break}b=a}if((g|0)<1){break b}}a=0;while(1){l=d+B(a,20)|0;o=l+1432|0;c=v[o>>2];f=0;i=v[l+1436>>2];h=b-i|0;k=l+1428|0;j=v[k>>2];h=(h|0)<(j|0)?h:j;if((h|0)>=1){while(1){c=cy(c,w[e+(f+i|0)|0]);n=f+1|0;f=n;if((h|0)!=(n|0)){continue}break}}f=j-h|0;v[k>>2]=f;v[o>>2]=c;g:{if(!f){f=c;c=l+1424|0;if((f|0)==v[c>>2]){v[d+1380>>2]=-1;v[d+992>>2]=0;v[d+1420>>2]=-1;a=v[(d+B(a,20)|0)+1440>>2];v[d+1060>>2]=a;v[d+1064>>2]=(a|0)!=-1;b=h+i|0;break b}f=g-1|0;v[d+1420>>2]=f;f=d+B(f,20)|0;v[c+16>>2]=v[f+1440>>2];g=f+1432|0;l=v[g+4>>2];v[c+8>>2]=v[g>>2];v[c+12>>2]=l;f=f+1424|0;g=v[f+4>>2];v[c>>2]=v[f>>2];v[c+4>>2]=g;g=v[d+1420>>2];break g}a=a+1|0}if((a|0)<(g|0)){continue}break}}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!kJ(a)){v[f>>2]=0;b=0;break a}ia=gb-16|0;gb=ia;h=aa+4|0;i=h;l=a;c=l;v[c+1504>>2]=0;v[c+1508>>2]=0;h:{if(v[c+96>>2]){break h}g=c;i:{j:{k:{if(v[c+1380>>2]!=-1){break k}o=Le(g);if(v[g+96>>2]){break i}if((o|0)!=79){break j}if((Le(g)|0)!=103){break j}if((Le(g)|0)!=103){break j}if((Le(g)|0)!=83){break j}if(!fJ(g)){break i}if(!(t[g+1375|0]&1)){break k}t[g+1376|0]=0;v[g+1384>>2]=0;dc(g,32);break i}k=$x(g);break i}dc(g,30)}if(!k){break h}if(oc(c,1)){dc(c,35);break h}o=ia;l:{m:{if(!(v[c+84>>2]!=v[c+92>>2]?v[c+80>>2]:0)){g=oc(c,Am(v[c+408>>2]-1|0));if((g|0)==-1|(g|0)>=v[c+408>>2]){break h}v[ia+12>>2]=g;k=c+B(g,6)|0;if(!w[k+412|0]){j=v[c+112>>2];g=j>>1;break m}j=v[c+116>>2];g=j>>1;n=oc(c,1);I=oc(c,1);if(n|!w[k+412|0]){break m}v[i>>2]=j-v[c+112>>2]>>2;i=v[c+112>>2]+j>>2;break l}ba(3388,10568,3137,8077);L()}v[i>>2]=0;i=g}v[o+8>>2]=i;n:{if(!(!w[k+412|0]|I)){g=B(j,3);v[aa+8>>2]=g-v[c+112>>2]>>2;j=g+v[c+112>>2]>>2;break n}v[aa+8>>2]=g}v[ia+4>>2]=j;j=1}if(j){o:{Z=v[h>>2];oa=v[aa+8>>2];na=v[ia+4>>2];qa=h;j=0;Q=gb-2368|0;gb=Q;q=v[l+404>>2];pa=l+B(v[ia+12>>2],6)|0;D=w[pa+413|0];W=q+B(D,40)|0;ca=W;X=v[(l+(w[pa+412|0]<<2)|0)+104>>2];p:{o=v[l+4>>2];q:{if((o|0)>0){while(1){c=w[(v[ca+4>>2]+B(j,3)|0)+2|0];S=(Q+1344|0)+(j<<2)|0;v[S>>2]=0;g=w[(c+W|0)+9|0];if(!x[(l+(g<<1)|0)+132>>1]){dc(l,21);c=0;break q}h=v[l+260>>2];r:{s:{if(oc(l,1)){c=2;k=v[(l+(j<<2)|0)+996>>2];o=h+B(g,1596)|0;F=v[(w[o+1588|0]<<2)+69484>>2];g=Am(F)-1|0;za=k,Aa=oc(l,g),u[za>>1]=Aa;za=k,Aa=oc(l,g),u[za+2>>1]=Aa;i=0;if(w[o|0]){while(1){T=w[(i+o|0)+1|0];h=T+o|0;n=w[h+33|0];g=0;s=w[h+49|0];t:{if(!s){break t}h=v[l+124>>2]+B(w[h+65|0],2096)|0;if(v[l+1396>>2]<=9){tl(l)}m=v[l+1392>>2];g=u[(h+((m&1023)<<1)|0)+36>>1];u:{if((g|0)>=0){E=m;m=w[g+v[h+8>>2]|0];v[l+1392>>2]=E>>>m;P=v[l+1396>>2]-m|0;m=(P|0)<0;v[l+1396>>2]=m?0:P;g=m?-1:g;break u}g=zm(l,h)}if(!w[h+23|0]){break t}g=v[v[h+2088>>2]+(g<<2)>>2]}if(n){K=-1<<s^-1;h=c+n|0;while(1){m=0;n=u[((o+(T<<4)|0)+((g&K)<<1)|0)+82>>1];v:{if((n|0)<0){break v}n=v[l+124>>2]+B(n&65535,2096)|0;if(v[l+1396>>2]<=9){tl(l)}P=v[l+1392>>2];m=u[(n+((P&1023)<<1)|0)+36>>1];w:{if((m|0)>=0){E=P;P=w[m+v[n+8>>2]|0];v[l+1392>>2]=E>>>P;I=v[l+1396>>2]-P|0;P=(I|0)<0;v[l+1396>>2]=P?0:I;m=P?-1:m;break w}m=zm(l,n)}if(!w[n+23|0]){break v}m=v[v[n+2088>>2]+(m<<2)>>2]}g=g>>s;u[k+(c<<1)>>1]=m;c=c+1|0;if((h|0)!=(c|0)){continue}break}c=h}i=i+1|0;if(i>>>0<w[o|0]){continue}break}}if(v[l+1396>>2]!=-1){break s}}v[S>>2]=1;break r}u[Q+320>>1]=257;i=o+1592|0;c=v[o+1592>>2];if((c|0)>=3){g=2;while(1){h=o+338|0;n=g<<1;s=n+o|0;S=w[s+1088|0];P=S<<1;m=x[h+P>>1];T=w[s+1089|0];K=T<<1;I=u[k+P>>1];s=u[K+k>>1]-I|0;P=s>>31;h=(B(x[h+n>>1]-m|0,P^s+P)|0)/(x[h+K>>1]-m|0)|0;m=I+((s|0)<0?0-h|0:h)|0;P=k+n|0;n=x[P>>1];x:{y:{if(n){t[T+(Q+320|0)|0]=1;t[S+(Q+320|0)|0]=1;t[(Q+320|0)+g|0]=1;h=n<<16>>16;s=F-m|0;if((h|0)>=((m|0)>(s|0)?s:m)<<1){if((m|0)<(s|0)){break x}m=F+(n^-1)|0;break y}if(h&1){m=m-(h+1>>>1|0)|0;break y}m=(h>>1)+m|0;break y}t[(Q+320|0)+g|0]=0}u[P>>1]=m;c=v[i>>2]}g=g+1|0;if((g|0)<(c|0)){continue}break}}m=0;if((c|0)<=0){break r}while(1){if(!w[(Q+320|0)+m|0]){u[k+(m<<1)>>1]=65535;c=v[i>>2]}m=m+1|0;if((m|0)<(c|0)){continue}break}}j=j+1|0;o=v[l+4>>2];if((j|0)<(o|0)){continue}break}}z:{A:{c=v[l+80>>2];if(!(v[l+84>>2]!=v[l+92>>2]?c:0)){hc(Q+320|0,Q+1344|0,o<<2);h=x[W>>1];if(h){i=v[ca+4>>2];m=0;while(1){j=i+B(m,3)|0;g=w[j+1|0];j=(Q+1344|0)+(w[j|0]<<2)|0;if(!(v[(Q+1344|0)+(g<<2)>>2]?v[j>>2]:0)){v[(Q+1344|0)+(g<<2)>>2]=0;v[j>>2]=0}m=m+1|0;if((h|0)!=(m|0)){continue}break}}P=X>>1;la=q+B(D,40)|0;if(w[la+8|0]){c=0;while(1){B:{if((o|0)<1){g=0;break B}j=v[ca+4>>2];m=0;g=0;while(1){if(w[(j+B(m,3)|0)+2|0]==(c|0)){k=g+Q|0;h=m<<2;C:{if(v[h+(Q+1344|0)>>2]){i=1;h=0;break C}i=0;h=v[(h+l|0)+800>>2]}t[k|0]=i;v[(Q+256|0)+(g<<2)>>2]=h;g=g+1|0}m=m+1|0;if((m|0)!=(o|0)){continue}break}}da=Q+256|0;D=Q;J=gb-16|0;gb=J;h=l;I=v[h+4>>2];m=v[h+396>>2];j=w[(c+la|0)+24|0];U=m+B(j,24)|0;k=v[U+4>>2];o=P;ma=x[(h+(j<<1)|0)+268>>1];i=o<<((ma|0)==2);n=i>>>0>k>>>0?k:i;k=v[U>>2];E=(n-(i>>>0>k>>>0?k:i)>>>0)/y[U+8>>2]|0;F=E<<2;i=B(I,F+4|0);V=v[v[h+124>>2]+B(w[U+13|0],2096)>>2];va=v[h+92>>2];D:{if(v[h+80>>2]){i=eo(h,i);I=v[h+4>>2];break D}i=Ad(i)}k=0;if((I|0)>=1){n=(I<<2)+i|0;while(1){v[(k<<2)+i>>2]=n;n=n+F|0;k=k+1|0;if((I|0)!=(k|0)){continue}break}}F=i;E:{F:{G:{H:{if((g|0)>=1){i=o<<2;k=0;while(1){if(!w[k+D|0]){Qb(v[da+(k<<2)>>2],0,i)}k=k+1|0;if((k|0)!=(g|0)){continue}break}if((g|0)==1|(ma|0)!=2){break F}k=0;break H}if((ma|0)!=2){break F}i=!g;break G}while(1){if(w[k+D|0]){k=k+1|0;if((k|0)!=(g|0)){continue}break E}break}i=(g|0)==(k|0)}if(i){break E}m=m+B(j,24)|0;s=m;S=(g|0)!=2;D=(E|0)<1;T=(g|0)<3;n=0;while(1){I:{if(!S){k=0;I=0;if(D){break I}while(1){i=v[U>>2]+B(v[U+8>>2],k)|0;v[J+12>>2]=i&1;v[J+8>>2]=i>>1;if(!n){j=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){tl(h)}q=v[h+1392>>2];i=u[(j+((q&1023)<<1)|0)+36>>1];J:{if((i|0)>=0){K=q;q=w[i+v[j+8>>2]|0];v[h+1392>>2]=K>>>q;K=v[h+1396>>2]-q|0;q=(K|0)<0;v[h+1396>>2]=q?0:K;i=q?-1:i;break J}i=zm(h,j)}i=w[j+23|0]?v[v[j+2088>>2]+(i<<2)>>2]:i;if((i|0)==-1){break E}v[v[F>>2]+(I<<2)>>2]=v[v[m+16>>2]+(i<<2)>>2]}K:{if((V|0)<1){break K}j=0;if((k|0)>=(E|0)){break K}while(1){i=v[U+8>>2];q=u[(v[s+20>>2]+(w[v[v[F>>2]+(I<<2)>>2]+j|0]<<4)|0)+(n<<1)>>1];L:{if((q|0)>=0){if(eJ(h,v[h+124>>2]+B(q&65535,2096)|0,da,2,J+12|0,J+8|0,o,i)){break L}break E}i=v[U>>2]+(i+B(i,k)|0)|0;v[J+8>>2]=i>>1;v[J+12>>2]=i&1}k=k+1|0;j=j+1|0;if((V|0)<=(j|0)){break K}if((k|0)<(E|0)){continue}break}}I=I+1|0;if((k|0)<(E|0)){continue}break}break I}if(T){break I}k=0;I=0;if(D){break I}while(1){j=v[U>>2]+B(v[U+8>>2],k)|0;i=(j|0)/(g|0)|0;v[J+12>>2]=j-B(g,i);v[J+8>>2]=i;if(!n){j=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){tl(h)}q=v[h+1392>>2];i=u[(j+((q&1023)<<1)|0)+36>>1];M:{if((i|0)>=0){K=q;q=w[i+v[j+8>>2]|0];v[h+1392>>2]=K>>>q;K=v[h+1396>>2]-q|0;q=(K|0)<0;v[h+1396>>2]=q?0:K;i=q?-1:i;break M}i=zm(h,j)}i=w[j+23|0]?v[v[j+2088>>2]+(i<<2)>>2]:i;if((i|0)==-1){break E}v[v[F>>2]+(I<<2)>>2]=v[v[m+16>>2]+(i<<2)>>2]}N:{if((V|0)<1){break N}j=0;if((k|0)>=(E|0)){break N}while(1){i=v[U+8>>2];q=u[(v[s+20>>2]+(w[v[v[F>>2]+(I<<2)>>2]+j|0]<<4)|0)+(n<<1)>>1];O:{if((q|0)>=0){if(eJ(h,v[h+124>>2]+B(q&65535,2096)|0,da,g,J+12|0,J+8|0,o,i)){break O}break E}i=v[U>>2]+(i+B(i,k)|0)|0;q=(i|0)/(g|0)|0;v[J+8>>2]=q;v[J+12>>2]=i-B(g,q)}k=k+1|0;j=j+1|0;if((V|0)<=(j|0)){break N}if((k|0)<(E|0)){continue}break}}I=I+1|0;if((k|0)<(E|0)){continue}break}}n=n+1|0;if((n|0)!=8){continue}break}break E}ra=m+B(j,24)|0;wa=ra;xa=(E|0)<1;I=0;while(1){if(!xa){i=0;sa=(g|0)<1;ya=sa|(I|0)!=0;o=0;while(1){k=0;if(!ya){while(1){if(!w[k+D|0]){j=v[h+124>>2]+B(w[U+13|0],2096)|0;if(v[h+1396>>2]<=9){tl(h)}m=v[h+1392>>2];n=u[(j+((m&1023)<<1)|0)+36>>1];P:{if((n|0)>=0){q=m;m=w[n+v[j+8>>2]|0];v[h+1392>>2]=q>>>m;s=v[h+1396>>2]-m|0;m=(s|0)<0;v[h+1396>>2]=m?0:s;n=m?-1:n;break P}n=zm(h,j)}n=w[j+23|0]?v[v[j+2088>>2]+(n<<2)>>2]:n;if((n|0)==-1){break E}v[v[F+(k<<2)>>2]+(i<<2)>>2]=v[v[ra+16>>2]+(n<<2)>>2]}k=k+1|0;if((k|0)!=(g|0)){continue}break}}Q:{if((V|0)<1){break Q}n=0;if((o|0)>=(E|0)){break Q}while(1){k=0;if(!sa){while(1){R:{if(w[k+D|0]){break R}m=k<<2;j=u[(v[wa+20>>2]+(w[v[v[m+F>>2]+(i<<2)>>2]+n|0]<<4)|0)+(I<<1)>>1];if((j|0)<0){break R}S=h;j=v[h+124>>2]+B(j&65535,2096)|0;$=v[m+da>>2];Y=v[U+8>>2];m=v[U>>2]+B(Y,o)|0;S:{T:{U:{if(ma){N=0;T=1;if((Y|0)<=0){break S}while(1){ja=$+(m<<2)|0;K=Y-N|0;s=0;p=C(0);G=cJ(S,j);V:{if((G|0)<0){break V}q=j;s=v[j>>2];K=(s|0)<(K|0)?s:K;ka=B(s,G);W:{X:{if(w[j+22|0]){G=0;if((K|0)>0){break X}break W}G=0;if((K|0)<=0){break W}while(1){s=ja+(G<<2)|0;z[s>>2]=z[s>>2]+z[v[q+28>>2]+(G+ka<<2)>>2];s=1;G=G+1|0;if((K|0)!=(G|0)){continue}break}break V}while(1){s=ja+(G<<2)|0;p=C(z[v[q+28>>2]+(G+ka<<2)>>2]+p);z[s>>2]=z[s>>2]+p;p=C(z[q+12>>2]+p);s=1;G=G+1|0;if((K|0)!=(G|0)){continue}break}break V}s=1}if(!s){break U}s=v[j>>2];m=s+m|0;N=s+N|0;if((Y|0)>(N|0)){continue}break}break S}N=0;q=(Y|0)/v[j>>2]|0;if((q|0)<=0){break T}ja=$+(m<<2)|0;while(1){ka=ja+(N<<2)|0;G=Y-(m+N|0)|0;K=q;s=0;p=C(0);ta=cJ(S,j);Y:{if((ta|0)<0){break Y}s=1;T=j;$=v[j>>2];ua=(G|0)>($|0)?$:G;if((ua|0)<1){break Y}$=B($,ta);G=0;while(1){s=ka+(B(G,K)<<2)|0;A=C(z[v[T+28>>2]+(G+$<<2)>>2]+p);z[s>>2]=z[s>>2]+A;p=w[T+22|0]?A:p;s=1;G=G+1|0;if((ua|0)!=(G|0)){continue}break}}if(!s){break U}N=N+1|0;if((q|0)!=(N|0)){continue}break}break T}T=0;break S}T=1}if(!T){break E}}k=k+1|0;if((k|0)!=(g|0)){continue}break}}o=o+1|0;n=n+1|0;if((V|0)<=(n|0)){break Q}if((o|0)<(E|0)){continue}break}}i=i+1|0;if((o|0)<(E|0)){continue}break}}I=I+1|0;if((I|0)!=8){continue}break}}if(!v[h+80>>2]){Zb(F)}v[h+92>>2]=va;gb=J+16|0;c=c+1|0;if(c>>>0<w[la+8|0]){o=v[l+4>>2];continue}break}c=v[l+80>>2]}if(!(v[l+84>>2]!=v[l+92>>2]?c:0)){j=x[W>>1];if(j){h=(P|0)>1?P:1;g=l+800|0;while(1){c=j;j=c-1|0;if((X|0)>=2){i=v[ca+4>>2]+B(j,3)|0;o=v[g+(w[i+1|0]<<2)>>2];i=v[g+(w[i|0]<<2)>>2];m=0;while(1){k=m<<2;n=k+o|0;r=z[n>>2];k=i+k|0;p=z[k>>2];Z:{if(!(p<=C(0))){if(!(r<=C(0))){A=C(p-r);break Z}A=p;p=C(r+p);break Z}if(!(r<=C(0))){A=C(r+p);break Z}A=p;p=C(p-r)}z[k>>2]=p;z[n>>2]=A;m=m+1|0;if((h|0)!=(m|0)){continue}break}}if((c|0)>1){continue}break}}m=0;if(v[l+4>>2]<=0){break z}U=P<<2;while(1){g=m<<2;h=g+l|0;c=h;_:{if(v[g+(Q+320|0)>>2]){Qb(v[c+800>>2],0,U);break _}g=X;i=v[c+800>>2];T=v[h+996>>2];k=1;c=l;h=w[(W+w[(v[W+4>>2]+B(m,3)|0)+2|0]|0)+9|0];$:{if(!x[(c+(h<<1)|0)+132>>1]){dc(c,21);break $}s=g>>1;F=v[c+260>>2]+B(h,1596)|0;g=B(w[F+1588|0],u[T>>1]);c=0;n=v[F+1592>>2];if((n|0)>=2){G=F+1592|0;J=F+1588|0;while(1){h=w[(k+F|0)+838|0]<<1;j=u[h+T>>1];if((j|0)>=0){j=B(w[J|0],j&65535);h=x[(h+F|0)+338>>1];if((h|0)!=(c|0)){o=i;n=c;D=j-g|0;q=h-c|0;S=(D|0)/(q|0)|0;aa:{K=(h|0)>(s|0)?s:h;if((K|0)<=(c|0)){break aa}c=o+(n<<2)|0;z[c>>2]=z[c>>2]*z[((g&255)<<2)+69504>>2];c=n+1|0;if((K|0)<=(c|0)){break aa}n=(D|0)>-1?1:-1;E=D;D=D>>31;E=E+D^D;D=S>>31;D=E-B(q,D+S^D)|0;I=D;while(1){E=o+(c<<2)|0;N=E;p=z[E>>2];E=(q|0)>(I|0);g=(g+S|0)+(E?0:n)|0;z[N>>2]=p*z[((g&255)<<2)+69504>>2];c=c+1|0;if((K|0)==(c|0)){break aa}I=D+(I-(E?0:q)|0)|0;continue}}n=v[G>>2];c=h}g=j}k=k+1|0;if((n|0)>(k|0)){continue}break}}if((c|0)<(s|0)){p=z[(g<<2)+69504>>2];while(1){g=i+(c<<2)|0;z[g>>2]=z[g>>2]*p;c=c+1|0;if((s|0)!=(c|0)){continue}break}}}}m=m+1|0;c=v[l+4>>2];if((m|0)<(c|0)){continue}break}break A}ba(3388,10568,3319,2726);L()}ba(3388,10568,3286,2726);L()}m=0;if((c|0)<=0){break z}while(1){ca=w[pa+412|0];F=X;V=F>>1;g=V<<2;s=l;ma=v[l+92>>2];o=v[(l+(m<<2)|0)+800>>2];c=V<<2;W=o+c|0;ba:{if(v[l+80>>2]){n=eo(s,g);break ba}n=Ad(g)}h=(n+c|0)-8|0;j=v[(s+(ca<<2)|0)+1068>>2];ca:{if(F>>>0<2){c=j;break ca}g=o;c=j;while(1){z[h+4>>2]=C(z[c>>2]*z[g>>2])-C(z[c+4>>2]*z[g+8>>2]);z[h>>2]=C(z[c>>2]*z[g+8>>2])+C(z[c+4>>2]*z[g>>2]);c=c+8|0;h=h-8|0;g=g+16|0;if((W|0)!=(g|0)){continue}break}}if(h>>>0>=n>>>0){g=((V<<2)+o|0)-12|0;while(1){z[h+4>>2]=C(z[c+4>>2]*z[g>>2])-C(z[c>>2]*z[g+8>>2]);z[h>>2]=C(z[c>>2]*C(-z[g>>2]))-C(z[c+4>>2]*z[g+8>>2]);g=g-16|0;c=c+8|0;h=h-8|0;if(n>>>0<=h>>>0){continue}break}}da=F>>2;if((F|0)>=16){c=da<<2;h=c+n|0;k=c+o|0;c=(j+(V<<2)|0)-32|0;i=o;g=n;while(1){p=z[g>>2];A=z[h>>2];r=z[g+4>>2];H=z[h+4>>2];z[k+4>>2]=r+H;z[k>>2]=z[g>>2]+z[h>>2];r=C(H-r);p=C(A-p);z[i+4>>2]=C(z[c+16>>2]*r)-C(z[c+20>>2]*p);z[i>>2]=C(z[c+20>>2]*r)+C(z[c+16>>2]*p);p=z[g+8>>2];A=z[h+8>>2];r=z[g+12>>2];H=z[h+12>>2];z[k+12>>2]=r+H;z[k+8>>2]=z[g+8>>2]+z[h+8>>2];r=C(H-r);p=C(A-p);z[i+12>>2]=C(z[c>>2]*r)-C(z[c+4>>2]*p);z[i+8>>2]=C(z[c+4>>2]*r)+C(z[c>>2]*p);g=g+16|0;h=h+16|0;i=i+16|0;k=k+16|0;c=c-32|0;if(j>>>0<=c>>>0){continue}break}}D=Am(F);g=F>>4;k=V-1|0;c=F>>3;h=0-c|0;dJ(g,o,k,h,j);dJ(g,o,k-da|0,h,j);Y=F>>5;g=0-g|0;dq(Y,o,k,g,j,16);dq(Y,o,k-c|0,g,j,16);dq(Y,o,k-(c<<1)|0,g,j,16);dq(Y,o,k+B(c,-3)|0,g,j,16);i=2;if((D|0)>=10){i=D-4>>>1|0;h=2;while(1){g=h;h=g+1|0;q=2<<g;if((q|0)>=1){S=8<<g;T=F>>g+4;c=0;g=F>>g+2;K=0-(g>>1)|0;while(1){dq(T,o,k-B(c,g)|0,K,j,S);c=c+1|0;if((q|0)!=(c|0)){continue}break}}if((h|0)!=(i|0)){continue}break}}la=D-7|0;if((la|0)>(i|0)){while(1){g=i;i=g+1|0;c=F>>g+6;if((c|0)>=1){T=2<<g;K=8<<g;$=K<<2;I=F>>g+2;U=0-(I>>1)|0;h=j;g=k;while(1){G=o;J=g;E=U;D=h;q=K;N=I;S=T;if((S|0)>=1){ja=D+B(q,12)|0;p=z[ja>>2];ka=q<<3;A=z[ka+D>>2];q=D+(q<<2)|0;r=z[q>>2];H=z[ja+4>>2];M=z[D+(ka|4)>>2];ea=z[q+4>>2];fa=z[D+4>>2];ga=z[D>>2];D=G+(J<<2)|0;G=D+(E<<2)|0;q=0-N<<2;while(1){J=G-4|0;R=z[J>>2];ha=z[G>>2];_=z[D>>2];z[D>>2]=ha+_;E=D-4|0;O=z[E>>2];z[E>>2]=z[J>>2]+O;O=C(O-R);R=C(_-ha);z[J>>2]=C(O*ga)+C(R*fa);z[G>>2]=C(R*ga)-C(O*fa);J=G-12|0;ha=z[J>>2];E=D-8|0;O=z[E>>2];N=E;E=G-8|0;_=z[E>>2];z[N>>2]=_+O;N=D-12|0;R=z[N>>2];z[N>>2]=z[J>>2]+R;R=C(R-ha);O=C(O-_);z[J>>2]=C(R*r)+C(O*ea);z[E>>2]=C(O*r)-C(R*ea);J=G-20|0;ha=z[J>>2];E=D-16|0;O=z[E>>2];N=E;E=G-16|0;_=z[E>>2];z[N>>2]=_+O;N=D-20|0;R=z[N>>2];z[N>>2]=z[J>>2]+R;R=C(R-ha);O=C(O-_);z[J>>2]=C(R*A)+C(O*M);z[E>>2]=C(O*A)-C(R*M);J=G-28|0;ha=z[J>>2];E=D-24|0;O=z[E>>2];N=E;E=G-24|0;_=z[E>>2];z[N>>2]=_+O;N=D-28|0;R=z[N>>2];z[N>>2]=z[J>>2]+R;R=C(R-ha);O=C(O-_);z[J>>2]=C(R*p)+C(O*H);z[E>>2]=C(O*p)-C(R*H);G=q+G|0;D=D+q|0;J=(S|0)>1;S=S-1|0;if(J){continue}break}}g=g-8|0;h=($<<2)+h|0;D=(c|0)>1;c=c-1|0;if(D){continue}break}}if((i|0)!=(la|0)){continue}break}}c=o;g=F;if((0-(Y<<4)|0)<=-1){c=c+(k<<2)|0;h=c-(Y<<6)|0;p=z[j+(g>>3<<2)>>2];while(1){g=c-32|0;r=z[g>>2];H=z[c>>2];z[c>>2]=r+H;i=c-4|0;A=z[i>>2];j=i;i=c-36|0;M=z[i>>2];z[j>>2]=M+A;z[g>>2]=H-r;z[i>>2]=A-M;i=c-8|0;A=z[i>>2];j=i;i=c-40|0;H=z[i>>2];z[j>>2]=H+A;j=c-12|0;r=z[j>>2];k=j;j=c-44|0;M=z[j>>2];z[k>>2]=M+r;r=C(r-M);A=C(A-H);z[i>>2]=C(r+A)*p;z[j>>2]=C(r-A)*p;i=c-20|0;A=z[i>>2];j=c-52|0;r=z[j>>2];k=c-16|0;H=z[k>>2];q=k;k=c-48|0;M=z[k>>2];z[q>>2]=H+M;z[i>>2]=r+A;z[k>>2]=A-r;z[j>>2]=M-H;i=c-60|0;A=z[i>>2];j=c-28|0;r=z[j>>2];k=c-24|0;H=z[k>>2];q=k;k=c-56|0;M=z[k>>2];z[q>>2]=H+M;z[j>>2]=A+r;A=C(r-A);r=C(M-H);z[k>>2]=C(A+r)*p;z[i>>2]=C(r-A)*p;bJ(c);bJ(g);c=c+-64|0;if(h>>>0<c>>>0){continue}break}}D=V-4|0;c=(n+(da<<2)|0)-16|0;if(n>>>0<=c>>>0){h=n+(D<<2)|0;g=v[(s+(ca<<2)|0)+1100>>2];while(1){i=(x[g>>1]<<2)+o|0;z[h+12>>2]=z[i>>2];z[h+8>>2]=z[i+4>>2];z[c+12>>2]=z[i+8>>2];z[c+8>>2]=z[i+12>>2];i=(x[g+2>>1]<<2)+o|0;z[h+4>>2]=z[i>>2];z[h>>2]=z[i+4>>2];z[c+4>>2]=z[i+8>>2];z[c>>2]=z[i+12>>2];g=g+4|0;h=h-16|0;c=c-16|0;if(n>>>0<=c>>>0){continue}break}}h=n+(V<<2)|0;j=h-16|0;if(n>>>0<j>>>0){g=v[(s+(ca<<2)|0)+1084>>2];k=h;c=n;while(1){p=z[g+4>>2];i=k-4|0;A=z[i>>2];r=z[c+4>>2];H=C(A+r);M=z[g>>2];ea=z[c>>2];q=k-8|0;fa=z[q>>2];ga=C(ea-fa);O=C(C(p*H)-C(M*ga));A=C(r-A);z[c+4>>2]=O+A;p=C(C(M*H)+C(p*ga));r=C(fa+ea);z[c>>2]=p+r;z[i>>2]=O-A;z[q>>2]=r-p;p=z[g+12>>2];i=k-12|0;A=z[i>>2];r=z[c+12>>2];H=C(A+r);M=z[g+8>>2];ea=z[c+8>>2];fa=z[j>>2];ga=C(ea-fa);O=C(C(p*H)-C(M*ga));A=C(r-A);z[c+12>>2]=O+A;p=C(C(M*H)+C(p*ga));r=C(fa+ea);z[c+8>>2]=p+r;z[j>>2]=r-p;z[i>>2]=O-A;g=g+16|0;c=c+16|0;k=j;j=j-16|0;if(c>>>0<j>>>0){continue}break}}j=h-32|0;if(n>>>0<=j>>>0){c=v[(s+(ca<<2)|0)+1076>>2]+(V<<2)|0;g=(D<<2)+o|0;k=((F<<2)+o|0)-16|0;while(1){p=z[c-4>>2];A=z[h-8>>2];r=z[c-8>>2];H=z[h-4>>2];M=C(C(p*A)-C(r*H));z[o>>2]=M;z[g+12>>2]=-M;p=C(C(r*C(-A))-C(H*p));z[W>>2]=p;z[k+12>>2]=p;p=z[c-12>>2];A=z[h-16>>2];r=z[c-16>>2];H=z[h-12>>2];M=C(C(p*A)-C(r*H));z[o+4>>2]=M;z[g+8>>2]=-M;p=C(C(r*C(-A))-C(H*p));z[W+4>>2]=p;z[k+8>>2]=p;p=z[c-20>>2];A=z[h-24>>2];r=z[c-24>>2];H=z[h-20>>2];M=C(C(p*A)-C(r*H));z[o+8>>2]=M;z[g+4>>2]=-M;p=C(C(r*C(-A))-C(H*p));z[W+8>>2]=p;z[k+4>>2]=p;p=z[c-28>>2];A=z[j>>2];c=c-32|0;r=z[c>>2];H=z[h-28>>2];M=C(C(p*A)-C(r*H));z[o+12>>2]=M;z[g>>2]=-M;p=C(C(r*C(-A))-C(H*p));z[W+12>>2]=p;z[k>>2]=p;k=k-16|0;g=g-16|0;W=W+16|0;o=o+16|0;h=j;j=h-32|0;if(n>>>0<=j>>>0){continue}break}}if(!v[s+80>>2]){Zb(n)}v[s+92>>2]=ma;m=m+1|0;if((m|0)<v[l+4>>2]){continue}break}}hJ(l);da:{if(w[l+1377|0]){v[l+1060>>2]=0-P;t[l+1377|0]=0;v[l+1064>>2]=1;v[l+1412>>2]=X-na;break da}c=v[l+1412>>2];if(!c){break da}g=oa-Z|0;if((g|0)<=(c|0)){v[l+1412>>2]=c-g;v[qa>>2]=oa;Z=oa;break da}Z=c+Z|0;v[qa>>2]=Z;v[l+1412>>2]=0}g=v[l+1064>>2];c=l;ea:{fa:{ga:{if(v[c+1388>>2]==v[c+1404>>2]){ha:{if(!g|!(w[l+1375|0]&4)){break ha}g=v[l+1408>>2];h=v[l+1060>>2];if(g>>>0>=h+(na-Z|0)>>>0){break ha}c=g-h|0;c=(c>>>0>g>>>0?0:c)+Z|0;c=(c|0)>(na|0)?na:c;v[aa+12>>2]=c;v[l+1060>>2]=c+v[l+1060>>2];break ea}v[l+1064>>2]=1;g=v[l+1408>>2]+(Z-P|0)|0;break ga}if(!g){break fa}g=v[l+1060>>2]}v[c+1060>>2]=(oa-Z|0)+g}if(v[l+84>>2]!=v[l+92>>2]?v[l+80>>2]:0){break p}v[aa+12>>2]=na}c=1}gb=Q+2368|0;break o}ba(3388,10568,3435,2726);L()}}else{c=0}gb=ia+16|0;if(!c){ia:{ja:{ka:{c=v[a+100>>2];switch(c-32|0){case 0:break ja;case 3:break ka;default:break ia}}v[a+100>>2]=0;while(1){if(za=0,Aa=(nh(a)|0)!=-1,Ba=v[a+96>>2],Ba?za:Aa){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break ia}v[a+100>>2]=0;while(1){if(za=0,Aa=(nh(a)|0)!=-1,Ba=v[a+96>>2],Ba?za:Aa){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;b=1;break a}i=aa;k=v[i+12>>2];F=v[i+4>>2];n=F;g=v[i+8>>2];j=0;la:{ma:{na:{oa:{c=a;o=v[c+992>>2];pa:{if(!o){h=v[c+4>>2];o=0;break pa}X=o<<1;qa:{if((X|0)==v[c+112>>2]){h=l+1092|0}else{h=0;if((X|0)!=v[l+116>>2]){break qa}h=l+1096|0}h=v[h>>2]}l=h;if(!l){break ma}h=v[c+4>>2];if((h|0)<=0){break oa}X=(o|0)<1;while(1){if(!X){m=c+(j<<2)|0;Q=m;h=0;while(1){Z=v[m+800>>2]+(h+n<<2)|0;s=h<<2;z[Z>>2]=C(z[l+(o+(h^-1)<<2)>>2]*z[s+v[Q+928>>2]>>2])+C(z[l+s>>2]*z[Z>>2]);h=h+1|0;if((o|0)!=(h|0)){continue}break}h=v[c+4>>2]}j=j+1|0;if((j|0)<(h|0)){continue}break}o=v[c+992>>2]}X=k-g|0;v[c+992>>2]=X;if((h|0)>=1){j=0;while(1){if((g|0)<(k|0)){m=c+(j<<2)|0;Q=m;h=0;l=g;while(1){z[v[Q+928>>2]+(h<<2)>>2]=z[v[m+800>>2]+(l<<2)>>2];h=h+1|0;l=g+h|0;if((h|0)!=(X|0)){continue}break}h=v[c+4>>2]}j=j+1|0;if((j|0)<(h|0)){continue}break}}if(!o){break ma}break na}v[c+992>>2]=k-g}h=c;j=v[c+1416>>2];c=((g|0)>(k|0)?k:g)-n|0;v[h+1416>>2]=j+c;break la}c=0}g=c;v[i+12>>2]=c;l=v[a+4>>2];if((l|0)>=1){c=0;while(1){h=(c<<2)+a|0;v[h+864>>2]=v[h+800>>2]+(F<<2);c=c+1|0;if((l|0)!=(c|0)){continue}break}}if(d){v[d>>2]=l}v[f>>2]=g;v[e>>2]=a+864;b=v[a+32>>2]-b|0}gb=aa+16|0;return b|0}function k6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=C(0),F=0,G=0,I=0,J=C(0),K=0,M=0,N=0,O=0,P=0,Q=0,R=C(0);s=gb-1520|0;gb=s;g=Qb(s+8|0,0,1512);if(e){h=v[e+4>>2];v[g+80>>2]=v[e>>2];v[g+84>>2]=h;e=h&-8;v[g+92>>2]=e;v[g+84>>2]=e}v[g+96>>2]=0;v[g+100>>2]=0;v[g+1420>>2]=-1;v[g+124>>2]=0;v[g+32>>2]=0;t[s+56|0]=1;v[s+48>>2]=a+b;v[s+40>>2]=a;b=0;o=gb-1024|0;gb=o;f=s+8|0;t[f+1377|0]=1;a:{if(!lt(f)){break a}e=w[f+1375|0];if(!(e&2)){dc(f,34);break a}if(e&4){dc(f,34);break a}if(e&1){dc(f,34);break a}if(v[f+1116>>2]!=1){dc(f,34);break a}e=w[f+1120|0];if((e|0)!=30){b:{if((e|0)!=64){break b}if(!by(f,o+1018|0,6)|w[o+1018|0]!=102|(w[o+1019|0]!=105|w[o+1020|0]!=115)){break b}if(w[o+1021|0]!=104|w[o+1022|0]!=101|w[o+1023|0]!=97){break b}if((Le(f)|0)!=100){break b}if(Le(f)){break b}dc(f,38);break a}dc(f,34);break a}if((Le(f)|0)!=1){dc(f,34);break a}if(!by(f,o+1018|0,6)){dc(f,10);break a}if(!ay(o+1018|0)){dc(f,34);break a}if(wj(f)){dc(f,34);break a}e=Le(f);v[f+4>>2]=e;if(!e){dc(f,34);break a}if(e>>>0>=17){dc(f,5);break a}e=wj(f);v[f>>2]=e;if(!e){dc(f,34);break a}wj(f);wj(f);wj(f);e=Le(f);h=e>>>4|0;v[f+116>>2]=1<<h;g=e&15;v[f+112>>2]=1<<g;if(g-6>>>0>=8){dc(f,20);break a}if((e<<24)-1610612736>>24<=-1){dc(f,20);break a}if(g>>>0>h>>>0){dc(f,20);break a}if(!(Le(f)&1)){dc(f,34);break a}if(!lt(f)){break a}if(!$x(f)){break a}if(!_x(f)){break a}c:{d:{if((nh(f)|0)==3){while(1){P=(o+1018|0)+b|0,Q=nh(f),t[P|0]=Q;b=b+1|0;if((b|0)!=6){continue}break}if(!ay(o+1018|0)){dc(f,20);break c}g=Zx(f);e=Zd(f,g+1|0);v[f+20>>2]=e;if(e){b=0;if((g|0)>0){while(1){e=nh(f);t[v[f+20>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[f+20>>2]}t[e+g|0]=0;b=Zx(f);v[f+24>>2]=b;b=Zd(f,b<<2);v[f+28>>2]=b;e=v[f+24>>2];if(!(b?0:(e|0)>=1)){e:{if((e|0)>0){while(1){g=Zx(f);b=Zd(f,g+1|0);h=i<<2;v[h+v[f+28>>2]>>2]=b;e=v[h+v[f+28>>2]>>2];if(!e){break e}b=0;if((g|0)>0){while(1){e=nh(f);t[v[h+v[f+28>>2]>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[h+v[f+28>>2]>>2]}t[e+g|0]=0;i=i+1|0;if((i|0)<v[f+24>>2]){continue}break}}if(!(nh(f)&1)){dc(f,20);break c}jJ(f,w[f+1376|0]);t[f+1376|0]=0;while(1){b=_x(f);jJ(f,b);t[f+1376|0]=0;if(b){continue}break}b=0;if(!$x(f)){break a}if(!kJ(f)){if(v[f+100>>2]!=21){break a}v[f+100>>2]=20;break a}e=0;while(1){g=e<<24;h=1;while(1){g=g>>31&79764919^g<<1;if((h|0)!=8){h=h+1|0;continue}break}v[(e<<2)+459440>>2]=g;e=e+1|0;if((e|0)!=256){continue}break}if((nh(f)|0)==5){while(1){P=(o+1018|0)+b|0,Q=nh(f),t[P|0]=Q;b=b+1|0;if((b|0)!=6){continue}break}if(!ay(o+1018|0)){dc(f,20);break c}b=oc(f,8)+1|0;v[f+120>>2]=b;b=Zd(f,B(b,2096));v[f+124>>2]=b;if(!b){dc(f,3);break c}Qb(b,0,B(v[f+120>>2],2096));f:{g:{h:{if(v[f+120>>2]>=1){while(1){b=v[f+124>>2];if((oc(f,8)&255)!=66){dc(f,20);break c}if((oc(f,8)&255)!=67){dc(f,20);break c}if((oc(f,8)&255)!=86){dc(f,20);break c}g=b+B(M,2096)|0;P=g,Q=oc(f,8)&255|oc(f,8)<<8,v[P>>2]=Q;P=g,Q=oc(f,8)&255|(oc(f,8)<<8&65280|oc(f,8)<<16),v[P+4>>2]=Q;p=g+4|0;b=g;j=oc(f,1);if(j){e=0}else{e=oc(f,1)}t[b+23|0]=e;b=v[p>>2];i:{if(v[g>>2]){h=b;break i}h=0;if(!b){break i}dc(f,20);break c}j:{if(e&255){h=eo(f,h);break j}h=Zd(f,h);v[g+8>>2]=h}if(!h){dc(f,3);break c}k:{if(!j){b=0;k=0;e=v[p>>2];if((e|0)<=0){break k}while(1){l:{m:{if(w[g+23|0]){if(!oc(f,1)){break m}}e=oc(f,5)+1|0;t[b+h|0]=e;if((e&255)!=32){k=k+1|0;break l}dc(f,20);break c}t[b+h|0]=255}b=b+1|0;e=v[p>>2];if((b|0)<(e|0)){continue}break}break k}i=oc(f,5);k=0;b=0;e=v[p>>2];if((e|0)<1){break k}while(1){j=oc(f,Am(e-b|0));i=i+1|0;if((i|0)>=32){dc(f,20);break c}e=b+j|0;if((e|0)>v[p>>2]){dc(f,20);break c}Qb(b+h|0,i,j);b=e;e=v[p>>2];if((b|0)<(e|0)){continue}break}}n:{o:{if(w[g+23|0]){if(e>>2>(k|0)){break o}b=g;j=f;if(v[f+16>>2]<(e|0)){v[f+16>>2]=e;e=v[p>>2]}k=b;b=Zd(j,e);v[k+8>>2]=b;if(!b){dc(f,3);break c}hc(b,h,v[p>>2]);vj(f,h,v[p>>2]);h=v[g+8>>2];t[g+23|0]=0;e=v[p>>2]}j=0;b=0;i=0;if((e|0)>=1){while(1){i=((w[b+h|0]-11&255)>>>0<244)+i|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}}v[g+2092>>2]=i;b=Zd(f,e<<2);v[g+32>>2]=b;if(b){l=g+2092|0;break n}dc(f,3);break c}v[g+2092>>2]=k;l=g+2092|0;p:{if(!k){j=0;b=0;break p}b=Zd(f,k);v[g+8>>2]=b;if(!b){dc(f,3);break c}b=eo(f,v[l>>2]<<2);v[g+32>>2]=b;if(!b){dc(f,3);break c}j=eo(f,v[l>>2]<<2);if(!j){break f}e=v[p>>2];b=v[l>>2]<<3}b=b+e|0;if(b>>>0<=y[f+16>>2]){break n}v[f+16>>2]=b}e=g;k=h;r=v[p>>2];q=j;i=0;b=gb-128|0;gb=b;A=Qb(b,0,128);q:{r:{s:{t:{if((r|0)<1){break t}while(1){if(w[i+k|0]!=255){break t}i=i+1|0;if((r|0)!=(i|0)){continue}break}break s}if((i|0)!=(r|0)){break r}}b=1;if(!v[e+2092>>2]){break q}ba(12870,10568,1088,4626);L()}b=i+k|0;aJ(e,0,i,0,w[b|0],q);n=w[b|0];if(n){b=1;while(1){v[A+(b<<2)>>2]=1<<32-b;m=(b|0)==(n|0);b=b+1|0;if(!m){continue}break}}I=1;m=i+1|0;if((r|0)<=(m|0)){b=1;break q}u:{v:{w:{while(1){x:{i=k+m|0;n=w[i|0];y:{if((n|0)==255){break y}b=n;if(!b){break u}while(1){K=A+(b<<2)|0;F=v[K>>2];if(!F){F=(b|0)>1;b=b-1|0;if(F){continue}break u}break}if(b>>>0>=32){break x}v[K>>2]=0;aJ(e,ym(F),m,I,n,q);I=I+1|0;i=w[i|0];if((i|0)==(b|0)){break y}if(i>>>0>31){break w}if((b|0)>=(i|0)){break y}while(1){n=A+(i<<2)|0;if(v[n>>2]){break v}v[n>>2]=F+(1<<32-i);i=i-1|0;if((i|0)>(b|0)){continue}break}}b=1;m=m+1|0;if((r|0)!=(m|0)){continue}break q}break}ba(12366,10568,1111,4626);L()}ba(12383,10568,1116,4626);L()}ba(12914,10568,1118,4626);L()}b=0}gb=A+128|0;if(!b){if(w[g+23|0]){vj(f,j,0)}dc(f,20);break c}b=v[l>>2];if(b){b=Zd(f,(b<<2)+4|0);v[g+2084>>2]=b;if(!b){dc(f,3);break c}b=Zd(f,(v[l>>2]<<2)+4|0);v[g+2088>>2]=b;if(!b){dc(f,3);break c}v[g+2088>>2]=b+4;v[b>>2]=-1;q=h;n=j;i=0;m=0;z:{b=g;if(w[b+23|0]){m=v[b+2092>>2];if((m|0)<=0){break z}while(1){e=i<<2;P=e+v[b+2084>>2]|0,Q=ym(v[e+v[b+32>>2]>>2]),v[P>>2]=Q;i=i+1|0;m=v[b+2092>>2];if((i|0)<(m|0)){continue}break}break z}if(v[b+4>>2]>=1){while(1){if($I(b,w[i+q|0])){P=v[b+2084>>2]+(m<<2)|0,Q=ym(v[v[b+32>>2]+(i<<2)>>2]),v[P>>2]=Q;m=m+1|0}i=i+1|0;if((i|0)<v[b+4>>2]){continue}break}}if(v[b+2092>>2]==(m|0)){break z}ba(4567,10568,1185,7308);L()}QI(v[b+2084>>2],m,2262);v[v[b+2084>>2]+(v[b+2092>>2]<<2)>>2]=-1;A:{m=w[b+23|0];F=v[b+(m?2092:4)>>2];if((F|0)<1){break A}e=0;while(1){B:{k=e;i=b;if(m&255){k=v[n+(e<<2)>>2]}K=w[k+q|0];C:{if(!$I(i,K)){break C}N=e<<2;k=ym(v[N+v[b+32>>2]>>2]);r=v[b+2084>>2];i=0;m=v[b+2092>>2];if((m|0)>=2){while(1){A=m>>>1|0;O=A+i|0;I=k>>>0<y[r+(O<<2)>>2];i=I?i:O;m=I?A:m-A|0;if((m|0)>1){continue}break}}m=i<<2;if((k|0)!=v[m+r>>2]){break B}if(w[b+23|0]){v[m+v[b+2088>>2]>>2]=v[n+N>>2];t[v[b+8>>2]+i|0]=K;break C}v[m+v[b+2088>>2]>>2]=e}e=e+1|0;if((F|0)==(e|0)){break A}m=w[b+23|0];continue}break}ba(9535,10568,1215,7308);L()}}if(w[g+23|0]){vj(f,j,v[l>>2]<<2);vj(f,v[g+32>>2],v[l>>2]<<2);vj(f,h,v[p>>2]);v[g+32>>2]=0}b=g;Qb(b+36|0,255,2048);e=v[b+(w[b+23|0]?2092:4)>>2];if((e|0)>=1){k=(e|0)<32767?e:32767;j=v[b+8>>2];e=0;while(1){D:{if(w[e+j|0]>10){break D}E:{if(w[b+23|0]){h=ym(v[v[b+2084>>2]+(e<<2)>>2]);break E}h=v[v[b+32>>2]+(e<<2)>>2]}if(h>>>0>1023){break D}while(1){u[(b+(h<<1)|0)+36>>1]=e;j=v[b+8>>2];h=(1<<w[j+e|0])+h|0;if(h>>>0<1024){continue}break}}e=e+1|0;if((k|0)!=(e|0)){continue}break}}b=oc(f,4);t[g+21|0]=b;b=b&255;if(b>>>0>=3){dc(f,20);break c}if(b){P=g,R=iJ(oc(f,32)),z[P+12>>2]=R;P=g,R=iJ(oc(f,32)),z[P+16>>2]=R;P=g,Q=oc(f,4)+1|0,t[P+20|0]=Q;P=g,Q=oc(f,1),t[P+22|0]=Q;h=v[g>>2];j=v[p>>2];F:{if(w[g+21|0]==1){G=H(Ow(+C(C(Up(+C(j|0)))/C(h|0))));G:{if(D(G)<2147483648){b=~~G;break G}b=-2147483648}e=b;G=H(gy(+C(C(b|0)+C(1)),h));H:{if(D(G)<2147483648){b=~~G;break H}b=-2147483648}b=e+((b|0)<=(j|0))|0;E=C(b|0);if(gy(+C(E+C(1)),h)<=+(j|0)){b=-1}else{G=H(gy(+E,h));I:{if(D(G)<2147483648){e=~~G;break I}e=-2147483648}b=(e|0)>(j|0)?-1:b}if((b|0)>-1){break F}dc(f,20);break c}b=B(h,j)}v[g+24>>2]=b;if(!b){dc(f,20);break c}e=eo(f,b<<1);if(!e){break g}b=0;i=v[g+24>>2];if((i|0)>0){while(1){h=oc(f,w[g+20|0]);if((h|0)==-1){vj(f,e,v[g+24>>2]<<1);dc(f,20);break c}u[e+(b<<1)>>1]=h;b=b+1|0;i=v[g+24>>2];if((b|0)<(i|0)){continue}break}}J:{if(w[g+21|0]==1){h=w[g+23|0];K:{if(h){b=v[l>>2];if(b){break K}break J}b=v[p>>2]}b=Zd(f,B(v[g>>2],b)<<2);v[g+28>>2]=b;if(!b){vj(f,e,v[g+24>>2]<<1);dc(f,3);break c}n=v[(h?l:p)>>2];if((n|0)>=1){p=g+2088|0;E=C(0);q=0;while(1){l=q;l=h?v[v[p>>2]+(l<<2)>>2]:l;L:{j=v[g>>2];if((j|0)<1){break L}k=v[g+24>>2];b=1;i=0;while(1){J=C(C(z[g+12>>2]+E)+C(z[g+16>>2]*C(x[e+(((l>>>0)/(b>>>0)>>>0)%(k>>>0)<<1)>>1])));z[v[g+28>>2]+(B(j,q)+i<<2)>>2]=J;E=w[g+22|0]?J:E;i=i+1|0;j=v[g>>2];if((i|0)>=(j|0)){break L}k=v[g+24>>2];mqa(k,0,b,0);if(!jb){b=B(b,k);continue}else{vj(f,e,k<<1);dc(f,20);break c}}}q=q+1|0;if((n|0)!=(q|0)){continue}break}}t[g+21|0]=2;i=v[g+24>>2];break J}b=Zd(f,i<<2);v[g+28>>2]=b;i=v[g+24>>2];if(!b){break h}if((i|0)<1){break J}E=C(z[g+12>>2]+C(z[g+16>>2]*C(x[e>>1])));z[b>>2]=E;b=1;i=v[g+24>>2];if((i|0)<=1){break J}J=C(0);while(1){J=w[g+22|0]?E:J;E=C(C(z[g+12>>2]+J)+C(z[g+16>>2]*C(x[e+(b<<1)>>1])));z[v[g+28>>2]+(b<<2)>>2]=E;b=b+1|0;i=v[g+24>>2];if((b|0)<(i|0)){continue}break}}vj(f,e,i<<1)}M=M+1|0;if((M|0)<v[f+120>>2]){continue}break}}M:{e=oc(f,6)+1&255;if(!e){break M}b=1;while(1){if(!oc(f,16)){if((b|0)==(e|0)){break M}b=b+1|0;continue}break}dc(f,20);break c}b=oc(f,6)+1|0;v[f+128>>2]=b;b=Zd(f,B(b,1596));v[f+260>>2]=b;if(b){q=0;if(v[f+128>>2]<=0){break d}k=0;N:while(1){b=oc(f,16);u[((q<<1)+f|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){dc(f,20);break c}if(!b){e=v[f+260>>2]+B(q,1596)|0;P=e,Q=oc(f,8),t[P|0]=Q;P=e,Q=oc(f,16),u[P+2>>1]=Q;P=e,Q=oc(f,16),u[P+4>>1]=Q;P=e,Q=oc(f,6),t[P+6|0]=Q;P=e,Q=oc(f,8),t[P+7|0]=Q;b=(oc(f,4)&255)+1|0;t[e+8|0]=b;if((b|0)==(b&255)){g=e+9|0;b=0;while(1){P=b+g|0,Q=oc(f,8),t[P|0]=Q;b=b+1|0;if(b>>>0<w[e+8|0]){continue}break}}dc(f,4);break c}l=v[f+260>>2]+B(q,1596)|0;g=oc(f,5);t[l|0]=g;b=-1;i=0;e=0;if(g&255){while(1){g=oc(f,4);t[(e+l|0)+1|0]=g;g=g&255;b=(b|0)<(g|0)?g:b;e=e+1|0;if(e>>>0<w[l|0]){continue}break}while(1){g=i+l|0;P=g,Q=oc(f,3)+1|0,t[P+33|0]=Q;e=oc(f,2);t[g+49|0]=e;O:{if(e&255){e=oc(f,8);t[g+65|0]=e;if(v[f+120>>2]<=(e&255)){dc(f,20);break c}if(w[g+49|0]==31){break O}}e=0;while(1){P:{h=oc(f,8)-1|0;u[((l+(i<<4)|0)+(e<<1)|0)+82>>1]=h;if(v[f+120>>2]<=h<<16>>16){break P}e=e+1|0;if((e|0)<1<<w[g+49|0]){continue}break O}break}dc(f,20);break c}e=(b|0)!=(i|0);i=i+1|0;if(e){continue}break}}h=2;P=l,Q=oc(f,2)+1|0,t[P+1588|0]=Q;b=oc(f,4);v[l+1592>>2]=2;j=0;u[l+338>>1]=0;t[l+1589|0]=b;u[l+340>>1]=1<<b;n=l+1592|0;e=w[l|0];Q:{if(e){b=l+1589|0;while(1){g=l+w[(j+l|0)+1|0]|0;if(w[g+33|0]){e=1;while(1){h=oc(f,w[b|0]);u[(l+(v[n>>2]<<1)|0)+338>>1]=h;h=v[n>>2]+1|0;v[n>>2]=h;if(w[g+33|0]>e>>>0){e=e+1|0;continue}break}e=w[l|0]}j=j+1|0;if(j>>>0<(e&255)>>>0){continue}break}if((h|0)<=0){break Q}}e=0;while(1){b=x[(l+(e<<1)|0)+338>>1];g=(o+16|0)+(e<<2)|0;u[g+2>>1]=e;u[g>>1]=b;e=e+1|0;h=v[n>>2];if((e|0)<(h|0)){continue}break}}j=l+338|0;QI(o+16|0,h,2261);e=0;h=v[n>>2];b=h-1|0;b=(b|0)>0?b:0;while(1){if((b|0)==(e|0)){e=0;R:{if((h|0)<=0){break R}while(1){t[(e+l|0)+838|0]=w[((o+16|0)+(e<<2)|0)+2|0];e=e+1|0;h=v[n>>2];if((e|0)<(h|0)){continue}break}e=2;if((h|0)<=2){break R}while(1){v[o+12>>2]=0;v[o+8>>2]=0;b=j;h=0;g=e;if((e|0)>=1){p=b+(g<<1)|0;r=-1;m=65536;while(1){A=b+(h<<1)|0;i=x[A>>1];if(!((r|0)>=(i|0)|x[p>>1]<=i>>>0)){v[o+12>>2]=h;i=x[A>>1];r=i}if(!((i|0)>=(m|0)|x[p>>1]>=i>>>0)){v[o+8>>2]=h;m=x[A>>1]}h=h+1|0;if((g|0)!=(h|0)){continue}break}}b=l+(e<<1)|0;t[b+1088|0]=v[o+12>>2];t[b+1089|0]=v[o+8>>2];e=e+1|0;h=v[n>>2];if((e|0)<(h|0)){continue}break}}k=(h|0)>(k|0)?h:k;q=q+1|0;if((q|0)<v[f+128>>2]){continue N}q=k<<1;break d}g=x[(o+16|0)+(e<<2)>>1];e=e+1|0;if((g|0)!=x[(o+16|0)+(e<<2)>>1]){continue}break}break}dc(f,20);break c}dc(f,3);break c}vj(f,e,i<<1);dc(f,3);break c}dc(f,3);break c}dc(f,3);break c}dc(f,20);break c}dc(f,3);break c}dc(f,3);break c}dc(f,3);break c}dc(f,20);break c}b=oc(f,6)+1|0;v[f+264>>2]=b;b=Zd(f,B(b,24));v[f+396>>2]=b;if(!b){dc(f,3);break c}l=0;Qb(b,0,B(v[f+264>>2],24));S:{if(v[f+264>>2]>=1){while(1){b=v[f+396>>2];e=oc(f,16);u[((l<<1)+f|0)+268>>1]=e;if((e&65535)>>>0>=3){dc(f,20);break c}h=b+B(l,24)|0;P=h,Q=oc(f,24),v[P>>2]=Q;b=oc(f,24);v[h+4>>2]=b;if(b>>>0<y[h>>2]){dc(f,20);break c}P=h,Q=oc(f,24)+1|0,v[P+8>>2]=Q;P=h,Q=oc(f,6)+1|0,t[P+12|0]=Q;b=oc(f,8);t[h+13|0]=b;T:{U:{if(v[f+120>>2]>(b&255)){b=0;if(w[h+12|0]){break U}e=0;break T}dc(f,20);break c}while(1){g=oc(f,3);j=(o+16|0)+b|0;if(oc(f,1)){e=oc(f,5)<<3}else{e=0}t[j|0]=e+g;b=b+1|0;e=w[h+12|0];if(b>>>0<e>>>0){continue}break}}b=Zd(f,e<<4);v[h+20>>2]=b;if(!b){break S}if(w[h+12|0]){j=0;while(1){e=w[(o+16|0)+j|0];b=0;while(1){V:{if(e>>>b&1){g=oc(f,8);n=b<<1;k=j<<4;u[n+(k+v[h+20>>2]|0)>>1]=g;if(v[f+120>>2]>u[n+(k+v[h+20>>2]|0)>>1]){break V}dc(f,20);break c}u[(v[h+20>>2]+(j<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;if((b|0)!=8){continue}break}j=j+1|0;if(j>>>0<w[h+12|0]){continue}break}}b=Zd(f,v[(v[f+124>>2]+B(w[h+13|0],2096)|0)+4>>2]<<2);v[h+16>>2]=b;if(!b){dc(f,3);break c}k=0;Qb(b,0,v[(v[f+124>>2]+B(w[h+13|0],2096)|0)+4>>2]<<2);b=v[f+124>>2];e=w[h+13|0];if(v[(b+B(e,2096)|0)+4>>2]>0){while(1){g=v[B(e,2096)+b>>2];b=Zd(f,g);j=k<<2;v[j+v[h+16>>2]>>2]=b;W:{e=v[j+v[h+16>>2]>>2];if(e){if((g|0)<1){break W}b=g-1|0;t[e+b|0]=(k>>>0)%w[h+12|0];e=k;if((g|0)==1){break W}while(1){g=b-1|0;n=w[h+12|0];e=(e|0)/(n|0)|0;t[g+v[j+v[h+16>>2]>>2]|0]=(e|0)%(n|0);n=(b|0)>1;b=g;if(n){continue}break}break W}dc(f,3);break c}k=k+1|0;b=v[f+124>>2];e=w[h+13|0];if((k|0)<v[(b+B(e,2096)|0)+4>>2]){continue}break}}l=l+1|0;if((l|0)<v[f+264>>2]){continue}break}}b=oc(f,6)+1|0;v[f+400>>2]=b;b=Zd(f,B(b,40));v[f+404>>2]=b;if(!b){dc(f,3);break c}j=0;Qb(b,0,B(v[f+400>>2],40));if(v[f+400>>2]>=1){while(1){b=v[f+404>>2];if(oc(f,16)){dc(f,20);break c}g=b+B(j,40)|0;b=Zd(f,B(v[f+4>>2],3));v[g+4>>2]=b;if(!b){dc(f,3);break c}b=g;if(oc(f,1)){e=oc(f,4)+1|0}else{e=1}t[b+8|0]=e;X:{if(oc(f,1)){b=oc(f,8)+1|0;u[g>>1]=b;Y:{e=v[f+4>>2];b=b&65535;if((e|0)>=(b|0)){k=0;if(b){break Y}break X}dc(f,20);break c}while(1){e=oc(f,Am(e-1|0));b=B(k,3);t[b+v[g+4>>2]|0]=e;e=oc(f,Am(v[f+4>>2]-1|0));t[(b+v[g+4>>2]|0)+1|0]=e;e=v[f+4>>2];b=b+v[g+4>>2]|0;h=w[b|0];if((e|0)<=(h|0)){dc(f,20);break c}b=w[b+1|0];if((b|0)>=(e|0)){dc(f,20);break c}if((b|0)!=(h|0)){k=k+1|0;if(k>>>0>=x[g>>1]){break X}continue}break}dc(f,20);break c}u[g>>1]=0}if(oc(f,2)){dc(f,20);break c}h=v[f+4>>2];Z:{_:{b=w[g+8|0];if(b>>>0<=1){e=0;if((h|0)>0){while(1){t[(v[g+4>>2]+B(e,3)|0)+2|0]=0;e=e+1|0;if((e|0)<v[f+4>>2]){continue}break}b=w[g+8|0]}if(!(b&255)){break Z}break _}e=0;if((h|0)<=0){break _}while(1){$:{b=oc(f,4);h=B(e,3);t[(h+v[g+4>>2]|0)+2|0]=b;if(w[(h+v[g+4>>2]|0)+2|0]>=w[g+8|0]){break $}e=e+1|0;if((e|0)<v[f+4>>2]){continue}break _}break}dc(f,20);break c}b=0;while(1){oc(f,8);h=b+g|0;e=h;P=e,Q=oc(f,8),t[P+9|0]=Q;h=oc(f,8);t[e+24|0]=h;if(v[f+128>>2]<=w[e+9|0]){dc(f,20);break c}if(v[f+264>>2]>(h&255)){b=b+1|0;if(b>>>0>=w[g+8|0]){break Z}continue}break}dc(f,20);break c}j=j+1|0;if((j|0)<v[f+400>>2]){continue}break}}b=oc(f,6)+1|0;v[f+408>>2]=b;e=0;aa:{if((b|0)<=0){break aa}while(1){b=B(e,6)+f|0;P=b,Q=oc(f,1),t[P+412|0]=Q;P=b,Q=oc(f,16),u[P+414>>1]=Q;P=b,Q=oc(f,16),u[P+416>>1]=Q;g=oc(f,8);t[b+413|0]=g;if(x[b+414>>1]){dc(f,20);break c}if(x[b+416>>1]){dc(f,20);break c}if(v[f+400>>2]>(g&255)){e=e+1|0;if((e|0)>=v[f+408>>2]){break aa}continue}break}dc(f,20);break c}hJ(f);b=0;v[f+992>>2]=0;if(v[f+4>>2]>=1){while(1){e=(b<<2)+f|0;P=e,Q=Zd(f,v[f+116>>2]<<2),v[P+800>>2]=Q;P=e,Q=Zd(f,v[f+116>>2]<<1&2147483646),v[P+928>>2]=Q;g=Zd(f,q);v[e+996>>2]=g;h=v[e+800>>2];if(g?!h|!v[e+928>>2]:1){dc(f,3);break c}Qb(h,0,v[f+116>>2]<<2);b=b+1|0;if((b|0)<v[f+4>>2]){continue}break}}b=0;if(!gJ(f,0,v[f+112>>2])){break a}if(!gJ(f,1,v[f+116>>2])){break a}v[f+104>>2]=v[f+112>>2];h=v[f+116>>2];v[f+108>>2]=h;g=(h|0)/2|0;q=f;l=h<<1&2147483646;r=l;n=v[f+264>>2];if((n|0)<1){e=4}else{i=v[f+396>>2];h=0;k=0;while(1){j=i+B(k,24)|0;p=v[j+4>>2];e=g>>>0>p>>>0?p:g;p=v[j>>2];j=(e-(g>>>0>p>>>0?p:g)>>>0)/y[j+8>>2]|0;h=(h|0)<(j|0)?j:h;k=k+1|0;if((n|0)!=(k|0)){continue}break}e=(h<<2)+4|0}e=B(e,v[f+4>>2]);e=e>>>0<l>>>0?r:e;v[q+12>>2]=e;ba:{ca:{if(!v[f+80>>2]){break ca}g=v[f+92>>2];if((g|0)!=v[f+84>>2]){break ba}if(g>>>0>=(e+v[f+88>>2]|0)+1512>>>0){break ca}dc(f,3);break a}if(v[f+1380>>2]==-1){v[f+52>>2]=w[f+48|0]?0:v[f+32>>2]-v[f+36>>2]|0;b=1;break a}v[f+52>>2]=0;b=1;break a}ba(4394,10568,4182,6040);L()}dc(f,3)}b=0}gb=o+1024|0;da:{ea:{if(!b){v[d>>2]=v[s+104>>2]?1:v[s+108>>2];break ea}b=Zd(s+8|0,1512);if(b){P=c,Q=v[hc(b,s+8|0,1512)+32>>2]-a|0,v[P>>2]=Q;v[d>>2]=0;break da}lJ(s+8|0)}b=0}gb=s+1520|0;return b|0}function hqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=gb-384|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{if(!Hh(b,d+376|0)){break O}if(!TY(d+376|0)){break O}if(!c){p=1;break O}q=Xi(d+352|0,b);v[22640]=0;R(432,d+336|0,q|0);b=v[22640];v[22640]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{if((b|0)!=1){v[22640]=0;U(433,d+192|0,d+336|0,1229866575);b=v[22640];v[22640]=0;if((b|0)==1){break aa}v[22640]=0;p=Q(434,d+192|0,d+320|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break ca}yb(d+192|0);if(!p){break P}v[22640]=0;R(407,a|0,524288);b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;wg(a);b=v[22640];v[22640]=0;if((b|0)!=1){break ba}break c}b=P()|0;O()|0;break a}b=P()|0;O()|0;yb(d+192|0);break b}v[a+480208>>2]=12;G=a,H=Jd(Ib(w[d+328|0]|w[d+329|0]<<8),1,127),u[G+480188>>1]=H;G=d,H=Ib(w[d+320|0]|w[d+321|0]<<8),u[G+192>>1]=H;v[22640]=0;u[d+296>>1]=255;b=Oc(d+192|0,d+296|0);e=v[22640];v[22640]=0;if((e|0)==1){break d}u[a+480192>>1]=x[b>>1];b=d+320|2;G=d,H=Ib(w[b|0]|w[b+1|0]<<8),u[G+192>>1]=H;v[22640]=0;u[d+296>>1]=3999;b=Oc(d+192|0,d+296|0);e=v[22640];v[22640]=0;if((e|0)==1){break e}u[a+480190>>1]=x[b>>1];v[22640]=0;b=a+1074312|0;W(437,b|0,6,1)|0;e=v[22640];v[22640]=0;if((e|0)==1){break c}v[22640]=0;Q(438,b|0,21)|0;e=v[22640];v[22640]=0;if((e|0)==1){break c}v[22640]=0;Q(438,b|0,13)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;b=Q(2,d+192|0,6457)|0;e=v[22640];v[22640]=0;if((e|0)==1){break f}Eb(a+1298304|0,b);vb(b);v[22640]=0;b=Q(2,d+192|0,7643)|0;e=v[22640];v[22640]=0;if((e|0)==1){break g}Eb(a+1298316|0,b);vb(b);v[22640]=0;R(439,d+296|0,1445);b=v[22640];v[22640]=0;if((b|0)==1){break h}v[22640]=0;R(440,d+272|0,d+376|4);b=v[22640];v[22640]=0;if((b|0)==1){break j}v[22640]=0;R(440,d+248|0,d+376|5);b=v[22640];v[22640]=0;if((b|0)==1){break l}v[22640]=0;Y(173,d+192|0,d+296|0,d+272|0,d+248|0);b=v[22640];v[22640]=0;if((b|0)==1){break m}Eb(a+1298328|0,d+192|0);vb(d+192|0);vb(d+248|0);vb(d+272|0);Hb(d+296|0);v[a+1298364>>2]=2;v[22640]=0;U(433,d+296|0,d+336|0,1312902469);b=v[22640];v[22640]=0;if((b|0)==1){break n}v[22640]=0;b=T(232,d+296|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break p}v[22640]=0;f=a+1298268|0;W(441,d+296|0,f|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break p}b=0;v[22640]=0;U(433,d+272|0,d+336|0,1397706311);e=v[22640];v[22640]=0;if((e|0)==1){break q}e=a+484360|0;sn(Rb(e));da:{h=d+320|4;h=Ib(w[h|0]|w[h+1|0]<<8);ea:{if(!h){break ea}while(1){v[22640]=0;g=Q(228,d+272|0,46)|0;j=v[22640];v[22640]=0;fa:{if((j|0)!=1){if(!g){break ea}v[22640]=0;R(442,d+272|0,d+192|0);g=v[22640];v[22640]=0;if((g|0)!=1){if(!dd(f)){break fa}v[22640]=0;Q(443,f|0,d+192|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){break fa}}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}v[22640]=0;g=T(444,d+272|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break da}if(!$c(Rb(e))){v[22640]=0;j=T(445,e|0)|0;l=v[22640];v[22640]=0;if((l|0)==1){break da}if((j|0)==255){break ea}}j=Rb(e);v[22640]=0;U(6,d+248|0,2,d+192|0);l=v[22640];v[22640]=0;if((l|0)==1){break s}v[22640]=0;R(446,j|0,d+248|0);j=v[22640];v[22640]=0;if((j|0)==1){break t}vb(d+248|0);j=Rb(e);v[22640]=0;U(447,j|0,d+272|0,g|0);g=v[22640];v[22640]=0;if((g|0)==1){break da}b=b+1|0;if(h>>>0>(b&65535)>>>0){continue}break}}v[22640]=0;Pi(e,0);b=v[22640];v[22640]=0;if((b|0)==1){break u}v[22640]=0;U(433,d+248|0,d+336|0,1229869908);b=v[22640];v[22640]=0;if((b|0)==1){break v}v[22640]=0;b=T(449,d+248|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break C}ga:{if(!b){break ga}if(x[a+480192>>1]){b=1;while(1){v[22640]=0;R(450,d+248|0,d+192|0);e=v[22640];v[22640]=0;ha:{ia:{ja:{if((e|0)!=1){e=Ib(w[d+222|0]|w[d+223|0]<<8);v[22640]=0;e=W(415,a|0,b&65535,e|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ja}if(!e){break ha}if(Ib(w[d+222|0]|w[d+223|0]<<8)>>>0>3999){break ha}v[22640]=0;Kv(d+56|0,2,d+192|0);f=v[22640];v[22640]=0;if((f|0)!=1){v[22640]=0;R(377,d+104|0,d+56|0);f=v[22640];v[22640]=0;if((f|0)!=1){break ia}}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}v[22640]=0;Q(333,e+492|0,d+104|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break x}vb(d+104|0);v[22640]=0;Kv(d+56|0,2,d+192|0);f=v[22640];v[22640]=0;if((f|0)==1){break y}v[22640]=0;R(377,d+104|0,d+56|0);f=v[22640];v[22640]=0;if((f|0)==1){break y}f=Ib(w[d+222|0]|w[d+223|0]<<8);v[22640]=0;Q(333,((f<<5)+a|0)+946304|0,d+104|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break z}vb(d+104|0);v[e>>2]=0;G=e,H=Ib(w[d+238|0]|w[d+239|0]<<8)+128&65535,v[G+8>>2]=H;tc(e+8|0,256);t[e+15|0]=w[e+15|0]|1;e=Ib(w[d+222|0]|w[d+223|0]<<8);v[22640]=0;e=B(e,104)+a|0;R(352,e+484380|0,0);f=v[22640];v[22640]=0;if((f|0)==1){break A}G=d,H=Ib(w[d+224|0]|w[d+225|0]<<8),u[G+104>>1]=H;v[22640]=0;u[d+56>>1]=64;f=Oc(d+104|0,d+56|0);h=v[22640];v[22640]=0;if((h|0)==1){break B}u[e+484410>>1]=x[f>>1]<<2;G=e+484404|0,H=Xb(w[d+226|0]|w[d+227|0]<<8|(w[d+228|0]<<16|w[d+229|0]<<24)),v[G>>2]=H;if(!Xb(w[d+234|0]|w[d+235|0]<<8|(w[d+236|0]<<16|w[d+237|0]<<24))){break ha}if(!(Ib(w[d+240|0]|w[d+241|0]<<8)&3)){break ha}f=Xb(w[d+230|0]|w[d+231|0]<<8|(w[d+232|0]<<16|w[d+233|0]<<24));v[e+484384>>2]=f;G=e+484388|0,H=Xb(w[d+234|0]|w[d+235|0]<<8|(w[d+236|0]<<16|w[d+237|0]<<24))+f|0,v[G>>2]=H;e=e+484414|0;u[e>>1]=x[e>>1]|2;if(!(Ib(w[d+240|0]|w[d+241|0]<<8)&2)){break ha}u[e>>1]=x[e>>1]|4}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}v[22640]=0;U(433,d+168|0,d+336|0,1447382614);b=v[22640];v[22640]=0;if((b|0)==1){break C}b=v[d+180>>2];v[d+32>>2]=v[d+176>>2];v[d+36>>2]=b;v[d+40>>2]=v[d+184>>2];v[22640]=0;b=v[d+172>>2];v[d+24>>2]=v[d+168>>2];v[d+28>>2]=b;Y(452,d+24|0,0,a|0,0);b=v[22640];v[22640]=0;if((b|0)==1){break C}v[22640]=0;U(433,d+144|0,d+336|0,1346719318);b=v[22640];v[22640]=0;if((b|0)==1){break C}b=v[d+156>>2];v[d+8>>2]=v[d+152>>2];v[d+12>>2]=b;v[d+16>>2]=v[d+160>>2];v[22640]=0;b=v[d+148>>2];v[d>>2]=v[d+144>>2];v[d+4>>2]=b;Y(452,d|0,1,a|0,w[d+380|0]>2|0);b=v[22640];v[22640]=0;if((b|0)==1){break C}if(!x[a+480192>>1]){break ga}b=1;while(1){e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!e|t[e+60|0]&1)){v[e>>2]=32767}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}yb(d+248|0);v[22640]=0;U(433,d+192|0,d+336|0,1346458708);b=v[22640];v[22640]=0;if((b|0)==1){break D}v[22640]=0;b=T(307,d+192|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break F}if(!b|!(c&1)){break $}v[22640]=0;U(433,d+248|0,d+336|0,1347305805);b=v[22640];v[22640]=0;if((b|0)==1){break G}v[22640]=0;Q(350,d+248|0,1)|0;b=v[22640];v[22640]=0;if((b|0)==1){break I}e=0;j=d+320|6;b=Ib(w[j|0]|w[j+1|0]<<8);v[22640]=0;l=a+484344|0;R(364,l|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break I}f=ad(d+128|0);if(!Ib(w[j|0]|w[j+1|0]<<8)){break _}z=d+56|5;A=d+56|3;C=d+56|4;D=d+56|2;E=d+56|1;b=0;while(1){v[22640]=0;y=T(444,d+192|0)|0;h=v[22640];v[22640]=0;ka:{la:{ma:{na:{oa:{if((h|0)!=1){v[22640]=0;h=T(453,d+192|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break oa}v[22640]=0;U(320,d+104|0,d+192|0,h|0);h=v[22640];v[22640]=0;if((h|0)==1){break na}v[22640]=0;h=W(365,l|0,e&65535,y|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break ma}if(!h){break ka}o=Kb(d+88|0);v[22640]=0;U(454,d+248|0,o|0,-1);h=v[22640];v[22640]=0;if((h|0)!=1){h=_b(l,e);v[22640]=0;Q(455,h|0,o|0)|0;h=v[22640];v[22640]=0;if((h|0)!=1){break la}}break L}b=P()|0;O()|0;break J}b=P()|0;O()|0;break J}b=P()|0;O()|0;break J}b=P()|0;O()|0;break K}h=_b(l,e);v[22640]=0;h=Pf(h,0);g=v[22640];v[22640]=0;if((g|0)==1){break L}Nd(f);n=0;pa:{while(1){v[22640]=0;g=Q(228,d+104|0,1)|0;k=v[22640];v[22640]=0;qa:{ra:{sa:{if((k|0)!=1){if(!g){break pa}v[22640]=0;k=T(353,d+104|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break L}if(k){break ra}G=d,H=Sb(f),v[G+80>>2]=H;G=d,H=Wb(f),v[G+72>>2]=H;if(Gb(d+80|0,d+72|0)){break sa}break qa}break L}while(1){ta:{h=v[d+80>>2];g=_b(l,e);k=w[h+1|0];h=w[h|0];v[22640]=0;h=Be(d+56|0,h,k);k=v[22640];v[22640]=0;if((k|0)==1){break ta}h=Qe(h,n);v[22640]=0;Q(458,g|0,h|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break ta}nD(d+80|0);if(Gb(d+80|0,d+72|0)){continue}break qa}break}break L}gi(d+56|0);r=x[a+480188>>1];v[22640]=0;g=T(353,d+104|0)|0;i=v[22640];v[22640]=0;ua:{va:{if((i|0)!=1){s=k-1|0;wa:{if(!(g&1)){break wa}v[22640]=0;i=T(353,d+104|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break L}if(!i){break wa}m=k>>>0>r>>>0?d+56|0:B(s,6)+h|0;if((i|0)!=31){if(i>>>0>253){break wa}i=(B(i>>>4|0,12)+(i&15)|0)+13|0}else{i=255}t[m|0]=i}if(!(g&2)){break ua}v[22640]=0;i=T(353,d+104|0)|0;m=v[22640];v[22640]=0;if((m|0)!=1){break va}}break L}t[(k>>>0>r>>>0?E:(B(s,6)+h|0)+1|0)|0]=i}if(!(g&60)){continue}t[d+55|0]=0;t[d+54|0]=0;t[d+53|0]=0;t[d+52|0]=0;if(g&4){v[22640]=0;i=T(353,d+104|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break L}t[d+54|0]=i}if(g&8){v[22640]=0;i=T(353,d+104|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break L}t[d+52|0]=i}if(g&16){v[22640]=0;i=T(353,d+104|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break L}t[d+55|0]=i}if(g&32){v[22640]=0;g=T(353,d+104|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break L}t[d+53|0]=g}RY(d+55|0,d+53|0);RY(d+54|0,d+52|0);g=w[d+54|0];if(!(w[d+55|0]==13|g?(g|0)!=13:0)){Dh(d+55|0,d+54|0);Dh(d+53|0,d+52|0)}v[22640]=0;so(d+72|0,d+55|0,d+53|0,d+54|0,d+52|0);g=v[22640];v[22640]=0;xa:{if((g|0)==1){break xa}v[22640]=0;g=fz(w[d+72|0],w[d+73|0]);i=v[22640];v[22640]=0;if((i|0)==1){break xa}ya:{if(!g){break ya}G=d,H=Sb(f),v[G+80>>2]=H;Fd(d+48|0,d+80|0);v[22640]=0;U(461,f|0,v[d+48>>2],d+72|0);g=v[22640];v[22640]=0;if((g|0)!=1){break ya}break L}g=B(s,6)+h|0;k=k>>>0>r>>>0;t[(k?D:g+2|0)|0]=w[d+55|0];t[(k?C:g+4|0)|0]=w[d+53|0];i=w[d+54|0];t[(k?A:g+3|0)|0]=i;t[(k?z:g+5|0)|0]=w[d+52|0];if((i|0)==43){F=1;continue}if((i|0)!=31){continue}b=1;continue}break L}Nd(f);n=n+1|0;if(y>>>0<=n>>>0){break pa}h=_b(l,e);v[22640]=0;h=Pf(h,n);g=v[22640];v[22640]=0;if((g|0)!=1){continue}break}break L}vb(o)}yb(d+104|0);e=e+1|0;if(Ib(w[j|0]|w[j+1|0]<<8)>>>0>e>>>0){continue}break}break Z}b=P()|0;O()|0;break r}b=P()|0;O()|0;break b}h=0;f=0;if(c&4){break Y}break Q}b=0}Fv(f);yb(d+248|0);if(!(c&4)){break X}f=0;h=(b|0)!=0;if(!F){break Y}e=x[a+480188>>1];if(!e){f=1;break Y}b=0;while(1){f=1;g=(b<<5)+a|0;t[g+480288|0]=1;g=g+480280|0;v[g>>2]=v[g>>2]|67108864;b=b+1|0;if((e|0)!=(b|0)){continue}break}}v[d+104>>2]=-1778364416;v[d+108>>2]=-16756736;v[22640]=0;U(433,d+248|0,d+336|0,1146310725);b=v[22640];v[22640]=0;za:{Aa:{Ba:{if((b|0)!=1){v[22640]=0;b=T(449,d+248|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break za}if(!b){break Aa}v[22640]=0;g=T(444,d+248|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break V}if(g){break Ba}e=f;break W}b=P()|0;O()|0;break E}b=0;e=f;while(1){v[22640]=0;j=T(353,d+248|0)|0;l=v[22640];v[22640]=0;Ca:{Da:{if((l|0)!=1){if(x[a+480188>>1]<=b>>>0){break Ca}if(!f){break Da}l=((b<<5)+a|0)+480280|0;v[l>>2]=v[l>>2]&-67108865|((j|0)!=0)<<26;break Ca}break V}if(j){break Ca}e=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((g|0)!=(b|0)){continue}break}break W}yb(d+248|0);if(!f){break S}break T}break V}if(!b){break Q}break R}v[22640]=0;Q(462,d+248|0,d+104|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break U}}b=P()|0;O()|0;yb(d+248|0);break E}yb(d+248|0);if(!(e&1)){break S}}v[22640]=0;_(463,a+906300|0);b=v[22640];v[22640]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{if((b|0)==1){break Ja}b=a+906316|0;v[b>>2]=810369604;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[22640]=0;v[d+248>>2]=0;b=a+906332|0;mD(b,b+16|0,d+248|0);b=v[22640];v[22640]=0;if((b|0)==1){break Ia}v[22640]=0;e=Q(112,d+248|0,6731)|0;b=v[22640];v[22640]=0;if((b|0)==1){break Ha}v[22640]=0;Hv(a+906348|0,e);b=v[22640];v[22640]=0;if((b|0)==1){break Ga}vb(e);v[22640]=0;e=Q(112,d+248|0,6695)|0;b=v[22640];v[22640]=0;if((b|0)==1){break Fa}v[22640]=0;Gv(a+906380|0,e);b=v[22640];v[22640]=0;if((b|0)==1){break Ea}vb(e);v[22640]=0;b=a+906304|0;R(467,b|0,8);e=v[22640];v[22640]=0;if((e|0)==1){break Ja}PY(d+248|0,w[d+105|0],w[d+107|0],w[d+109|0],w[d+111|0]);e=v[d+252>>2];b=v[b>>2];f=v[d+248>>2];t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;t[b+4|0]=e;t[b+5|0]=e>>>8;t[b+6|0]=e>>>16;t[b+7|0]=e>>>24;break S}b=P()|0;O()|0;break E}b=P()|0;O()|0;break E}b=P()|0;O()|0;break E}b=P()|0;O()|0;vb(e);break E}b=P()|0;O()|0;break E}b=P()|0;O()|0;vb(e);break E}if(!h){break Q}}b=0;Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{while(1){fb:{v[d+88>>2]=B(b,127)>>>5;v[22640]=0;R(468,d+104|0,1202);e=v[22640];v[22640]=0;if((e|0)==1){break fb}v[22640]=0;R(469,d+56|0,d+88|0);e=v[22640];v[22640]=0;if((e|0)==1){break eb}v[22640]=0;U(470,d+248|0,d+104|0,d+56|0);e=v[22640];v[22640]=0;if((e|0)==1){break db}v[22640]=0;e=(b<<5)+a|0;R(471,d+128|0,e+902204|0);f=v[22640];v[22640]=0;if((f|0)==1){break cb}v[22640]=0;Q(429,d+128|0,d+248|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break cb}vb(d+248|0);vb(d+56|0);Hb(d+104|0);v[22640]=0;R(468,d+104|0,1184);f=v[22640];v[22640]=0;if((f|0)==1){break $a}v[22640]=0;R(469,d+56|0,d+88|0);f=v[22640];v[22640]=0;if((f|0)==1){break _a}v[22640]=0;U(470,d+248|0,d+104|0,d+56|0);f=v[22640];v[22640]=0;if((f|0)==1){break Za}v[22640]=0;R(471,d+128|0,e+903228|0);f=v[22640];v[22640]=0;if((f|0)==1){break Ya}v[22640]=0;Q(429,d+128|0,d+248|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break Ya}vb(d+248|0);vb(d+56|0);Hb(d+104|0);v[22640]=0;R(468,d+104|0,1175);f=v[22640];v[22640]=0;if((f|0)==1){break Va}v[22640]=0;R(469,d+56|0,d+88|0);f=v[22640];v[22640]=0;if((f|0)==1){break Ua}v[22640]=0;U(470,d+248|0,d+104|0,d+56|0);f=v[22640];v[22640]=0;if((f|0)==1){break Ta}v[22640]=0;R(471,d+128|0,e+904252|0);f=v[22640];v[22640]=0;if((f|0)==1){break Sa}v[22640]=0;Q(429,d+128|0,d+248|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break Sa}vb(d+248|0);vb(d+56|0);Hb(d+104|0);v[22640]=0;R(468,d+104|0,1148);f=v[22640];v[22640]=0;if((f|0)==1){break Pa}v[22640]=0;R(469,d+56|0,d+88|0);f=v[22640];v[22640]=0;if((f|0)==1){break Oa}v[22640]=0;U(470,d+248|0,d+104|0,d+56|0);f=v[22640];v[22640]=0;if((f|0)==1){break Na}v[22640]=0;R(471,d+128|0,e+905276|0);e=v[22640];v[22640]=0;if((e|0)==1){break Ma}v[22640]=0;Q(429,d+128|0,d+248|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break Ma}vb(d+248|0);vb(d+56|0);Hb(d+104|0);b=b+1|0;if((b|0)!=32){continue}break Q}break}b=P()|0;O()|0;break E}b=P()|0;O()|0;break ab}b=P()|0;O()|0;break bb}b=P()|0;O()|0;vb(d+248|0)}vb(d+56|0)}Hb(d+104|0);break E}b=P()|0;O()|0;break E}b=P()|0;O()|0;break Wa}b=P()|0;O()|0;break Xa}b=P()|0;O()|0;vb(d+248|0)}vb(d+56|0)}Hb(d+104|0);break E}b=P()|0;O()|0;break E}b=P()|0;O()|0;break Qa}b=P()|0;O()|0;break Ra}b=P()|0;O()|0;vb(d+248|0)}vb(d+56|0)}Hb(d+104|0);break E}b=P()|0;O()|0;break E}b=P()|0;O()|0;break Ka}b=P()|0;O()|0;break La}b=P()|0;O()|0;vb(d+248|0)}vb(d+56|0)}Hb(d+104|0);break E}v[22640]=0;U(433,d+248|0,d+336|0,1397575756);b=v[22640];v[22640]=0;if((b|0)==1){break M}v[22640]=0;b=T(307,d+248|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break N}if(!(!x[a+480190>>1]|(!b|!(c&2)))){f=1;b=1;while(1){v[22640]=0;c=T(453,d+248|0)|0;e=v[22640];v[22640]=0;gb:{if((e|0)!=1){v[22640]=0;e=T(453,d+248|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break N}if(!(c&7)){break gb}f=(B(f,104)+a|0)+484380|0;v[f>>2]=e;c=Pc(d+104|0,c&4?32:c&2?16:8,1,1,0);v[22640]=0;W(363,c|0,f|0,d+248|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break gb}break N}break N}b=b+1|0;f=b&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}yb(d+248|0);yb(d+192|0);yb(d+272|0);yb(d+296|0)}Cd(d+336|0);yb(q)}gb=d+384|0;return p|0}b=P()|0;O()|0;yb(d+248|0);break E}b=P()|0;O()|0;break E}b=P()|0;O()|0;vb(o)}yb(d+104|0)}Fv(f);break H}b=P()|0;O()|0}yb(d+248|0);break E}b=P()|0;O()|0;break E}b=P()|0;O()|0}yb(d+192|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;vb(d+104|0);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;vb(d+104|0)}yb(d+248|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;vb(d+248|0);break r}b=P()|0;O()|0}yb(d+272|0);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0}yb(d+296|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(d+248|0);break k}b=P()|0;O()|0}vb(d+272|0);break i}b=P()|0;O()|0}Hb(d+296|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}Cd(d+336|0)}yb(q);S(b|0);L()}function vla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;d=gb-352|0;gb=d;vc(b);a:{if(!Ar(b,d+336|0)){break a}if(!MU(d+336|0)){break a}q=Xi(d+312|0,b);o=eh(d+296|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if(!c){v[22640]=0;R(863,d|0,q|0);b=v[22640];v[22640]=0;if((b|0)==1){break r}break t}v[22640]=0;R(864,d|0,q|0);b=v[22640];v[22640]=0;if((b|0)==1){break s}}LU(o,d);Cd(d);v[22640]=0;U(865,d|0,o|0,1413891155);b=v[22640];v[22640]=0;u:{v:{if((b|0)!=1){v[22640]=0;e=Q(866,d|0,11454)|0;b=v[22640];v[22640]=0;if((b|0)==1){break v}yb(d);if(!e){break b}if(c){break u}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;yb(d);break c}v[22640]=0;R(407,a|0,4194304);b=v[22640];v[22640]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[22640]=0;U(865,d+272|0,o|0,1280592212);b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;b=T(232,d+272|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break g}v[22640]=0;W(636,d+272|0,a+1298268|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}l=a+484360|0;sn(Rb(l));k=ad(d+256|0);t[d+255|0]=0;v[22640]=0;U(867,d+240|0,o|0,1196314451);b=v[22640];v[22640]=0;if((b|0)==1){break i}s=d,y=Sb(d+240|0),v[s+232>>2]=y;s=d,y=Wb(d+240|0),v[s+224>>2]=y;w:{x:{y:{z:{A:{B:{if(!Gb(d+232|0,d+224|0)){break B}n=d+12|0;j=d+24|0;m=d+44|0;while(1){f=Xi(d+200|0,v[d+232>>2]);v[22640]=0;e=Q(868,d+200|0,d+184|0)|0;b=v[22640];v[22640]=0;C:{D:{E:{F:{G:{H:{if((b|0)!=1){b=1;if(!(e&w[d+193|0]==1)){break C}s=a,y=Jd(w[d+194|0],x[a+480188>>1],127),u[s+480188>>1]=y;v[22640]=0;i=T(869,d|0)|0;b=v[22640];v[22640]=0;I:{J:{K:{L:{if((b|0)!=1){nf(d+168|0,d+184|0,9,1);v[22640]=0;R(377,d+120|0,d+168|0);b=v[22640];v[22640]=0;if((b|0)==1){break L}v[22640]=0;R(870,d+160|0,m|0);b=v[22640];v[22640]=0;if((b|0)==1){break K}v[22640]=0;Q(429,d+160|0,d+120|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break K}vb(d+120|0);if($c(Rb(l))){break I}v[22640]=0;b=T(445,l|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break J}if((b|0)!=255){break I}b=2;break D}e=P()|0;O()|0;break k}e=P()|0;O()|0;break l}e=P()|0;O()|0;vb(d+120|0);break l}e=P()|0;O()|0;break l}b=Rb(l);v[22640]=0;U(6,d+120|0,5,m|0);e=v[22640];v[22640]=0;M:{N:{O:{if((e|0)!=1){v[22640]=0;R(446,b|0,d+120|0);b=v[22640];v[22640]=0;if((b|0)==1){break O}vb(d+120|0);v[22640]=0;R(864,d+168|0,f|0);b=v[22640];v[22640]=0;if((b|0)==1){break N}s=d,y=Sb(d+168|0),v[s+152>>2]=y;s=d,y=Wb(d+168|0),v[s+144>>2]=y;if(Gb(d+152|0,d+144|0)){break M}break G}e=P()|0;O()|0;break l}e=P()|0;O()|0;vb(d+120|0);break l}e=P()|0;O()|0;break l}P:{Q:{while(1){R:{b=v[d+152>>2];h=Je(d+120|0,wb(b));f=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+160>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+164>>2]=f;b=1;S:{f=w[d+160|0]|w[d+161|0]<<8|(w[d+162|0]<<16|w[d+163|0]<<24);if((f|0)!=1212960847){if((f|0)!=1312903248){break S}e=0;if(!x[a+480188>>1]){break S}T:{while(1){v[22640]=0;f=Q(228,h|0,2)|0;g=v[22640];v[22640]=0;if((g|0)==1){break T}if(!f){break S}v[22640]=0;R(431,d+96|0,h|0);f=v[22640];v[22640]=0;U:{V:{W:{X:{if((f|0)!=1){f=md(d+96|0);switch(w[d+96|0]){case 4:break V;case 2:break W;case 0:break X;default:break U}}break H}f=w[f|0];s=kc(d,e),y=f^128,t[s|0]=y;oe(d+104|0,j,e);Af(d+104|0,0);break U}s=kc(d,e),y=128,t[s|0]=y;oe(d+104|0,j,e);Af(d+104|0,1);break U}s=kc(d,e),y=128,t[s|0]=y;oe(d+104|0,j,e);Af(d+104|0,0)}e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break S}break H}if(dn(d+160|0)>>>0<9){break S}e=0;v[22640]=0;Q(350,h|0,2)|0;b=v[22640];v[22640]=0;g=65535;if((b|0)==1){break R}while(1){v[22640]=0;b=Q(228,h|0,1)|0;f=v[22640];v[22640]=0;Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{if((f|0)!=1){f=1;if(!b){break $}v[22640]=0;p=T(353,h|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break H}b=0;switch(p|0){case 14:break Z;case 13:break _;case 0:break $;case 12:break aa;case 8:break ba;case 7:break ca;case 4:break da;case 1:break ea;default:break S}}break H}if(x[d+36>>1]==65535){s=d,y=Yl(Rb(l)),u[s+36>>1]=y}b=Yl(Rb(l));v[22640]=0;u[d+38>>1]=b;b=Q(871,h|0,d+255|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break H}fa:{ga:{switch(b-254|0){case 1:v[22640]=0;b=65535;f=v[22640];v[22640]=0;if((f|0)!=1){break fa}break H;case 0:break ga;default:break fa}}v[22640]=0;b=65534;f=v[22640];v[22640]=0;if((f|0)==1){break H}}f=Rb(l);v[22640]=0;R(729,f|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break H}g=(g&65535)==65535?e:g;break Y}v[22640]=0;b=T(319,h|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break H}if(b>>>0>=(g&65535)>>>0){u[d+40>>1]=b-g}af(Rb(l),x[d+40>>1]);break Y}v[22640]=0;b=T(353,h|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break H}t[d+43|0]=b;break Y}v[22640]=0;b=T(353,h|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break H}t[d+42|0]=b;break Y}v[22640]=0;b=Q(829,h|0,d+104|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break H}f=0;if(!(b&!w[d+104|0])|w[d+105|0]!=255|(w[d+106|0]|w[d+107|0])){break $}if(w[d+108|0]!=1){break $}if(!w[d+109|0]){break Y}}b=f;break S}v[22640]=0;R(740,d+112|0,h|0);b=v[22640];v[22640]=0;ha:{ia:{ja:{ka:{if((b|0)!=1){f=md(d+112|0);p=Re(d+112|0);b=d+112|0;if(w[b|0]>=pc(d)>>>0){break Y}switch(w[p|0]){case 4:break ia;case 2:break ja;case 0:break ka;default:break ha}}break H}f=w[f|0];s=kc(d,w[b|0]),y=f^128,t[s|0]=y;oe(d+104|0,j,w[b|0]);Af(d+104|0,0);break ha}s=kc(d,w[b|0]),y=128,t[s|0]=y;oe(d+104|0,j,w[b|0]);Af(d+104|0,1);break ha}s=kc(d,w[b|0]),y=128,t[s|0]=y;oe(d+104|0,j,w[b|0]);Af(d+104|0,0)}la:{if(r){break la}r=0;if(!dr(k)){break Y}if(w[kc(KU(k),w[b|0])|0]!=w[kc(d,w[b|0])|0]){break la}oe(d+104|0,KU(k)+24|0,w[b|0]);f=Cb(d+104|0);oe(d+96|0,j,w[b|0]);if((Cb(d+96|0)|0)==(f|0)){break Y}}r=1;break Y}v[22640]=0;R(431,d+104|0,h|0);b=v[22640];v[22640]=0;if((b|0)==1){break P}b=md(d+104|0);f=d+104|0;p=w[f|0];if(pc(n)>>>0<=p>>>0){break Y}b=w[b|0];s=kc(n,w[f|0]),y=(b>>>2|0)+1|0,t[s|0]=y}e=e+1|0;continue}}yb(h);if(!b){break Q}pp(d+152|0);if(Gb(d+152|0,d+144|0)){continue}break G}break}break H}b=1;break E}break H}e=P()|0;O()|0;break k}e=P()|0;O()|0;yb(h);break F}b=0;if(x[d+36>>1]==65535|x[d+38>>1]==65535){break E}b=Rb(l);v[22640]=0;_(874,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){b=0;v[22640]=0;R(875,k|0,i|0);f=v[22640];v[22640]=0;if((f|0)!=1){break E}}e=P()|0;O()|0}Cd(d+168|0);break l}Cd(d+168|0)}Su(i)}yb(d+200|0);if(!b){Ah(d+232|0);if(Gb(d+232|0,d+224|0)){continue}break B}break}e=0;if((b|0)!=2){break A}}e=0;v[22640]=0;Pi(l,0);b=v[22640];v[22640]=0;if((b|0)==1){break q}if($c(k)){break A}if(c&2){v[22640]=0;U(867,d+200|0,o|0,1347244868);b=v[22640];v[22640]=0;if((b|0)==1){break w}s=d,y=Sb(d+200|0),v[s+184>>2]=y;s=d,y=Wb(d+200|0),v[s+160>>2]=y;e=w[d+255|0];if(Gb(d+184|0,d+160|0)){f=a+480190|0;h=d+13|0;j=d+17|0;while(1){b=v[d+184>>2];ma:{na:{oa:{pa:{qa:{if(!e){v[22640]=0;g=Q(876,b|0,d|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break qa}if(!g){break ma}g=w[d+52|0]|w[d+53|0]<<8;u[d+104>>1]=g+1;if(g>>>0>3998){break oa}v[22640]=0;g=Ie(f,d+104|0);i=v[22640];v[22640]=0;if((i|0)==1){break qa}u[a+480190>>1]=x[g>>1];v[22640]=0;R(877,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);g=v[22640];v[22640]=0;if((g|0)==1){break qa}JU(d+168|0,h);v[22640]=0;R(377,d+120|0,d+168|0);g=v[22640];v[22640]=0;ra:{if((g|0)!=1){v[22640]=0;Q(333,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break ra}vb(d+120|0);break oa}e=P()|0;O()|0;break na}e=P()|0;O()|0;vb(d+120|0);break na}v[22640]=0;g=Q(878,b|0,d|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break pa}if(!g){break ma}g=w[d+56|0]|w[d+57|0]<<8;u[d+104>>1]=g+1;if(g>>>0>3998){break oa}v[22640]=0;g=Ie(f,d+104|0);i=v[22640];v[22640]=0;if((i|0)==1){break pa}u[a+480190>>1]=x[g>>1];v[22640]=0;R(879,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);g=v[22640];v[22640]=0;if((g|0)==1){break pa}JU(d+168|0,j);v[22640]=0;R(377,d+120|0,d+168|0);g=v[22640];v[22640]=0;sa:{if((g|0)!=1){v[22640]=0;Q(333,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break sa}vb(d+120|0);break oa}e=P()|0;O()|0;break na}e=P()|0;O()|0;vb(d+120|0);break na}e=P()|0;O()|0;break na}e=P()|0;O()|0;break na}if((x[d+104>>1]-1&65535)>>>0>3998){break ma}g=Pc(d,8,1,0,2);v[22640]=0;W(363,g|0,(B(x[d+104>>1],104)+a|0)+484380|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break ma}e=P()|0;O()|0}fd(d+200|0);break j}Ah(d+184|0);if(Gb(d+184|0,d+160|0)){continue}break}}fd(d+200|0)}b=0;s=a,y=w[cn(k,0)+43|0],v[s+480196>>2]=y;s=a,y=B(w[cn(k,0)+42|0],1e4),v[s+480204>>2]=y;af(Rb(l),x[cn(k,0)+40>>1]);if(x[a+480188>>1]){while(1){v[22640]=0;f=(b<<5)+a|0;e=f+480280|0;Se(e);h=v[22640];v[22640]=0;if((h|0)==1){break x}s=f+480286|0,y=w[kc(cn(k,0)+12|0,b)|0],u[s>>1]=y;s=f+480284|0,y=w[kc(cn(k,0),b)|0],u[s>>1]=y;oe(d,cn(k,0)+24|0,b);f=Cb(d);v[e>>2]=v[e>>2]&-257|(f?256:0);b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}ta:{if(w[d+255|0]){v[22640]=0;Q(2,d|0,14223)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break ta}break m}v[22640]=0;Q(2,d|0,14096)|0;b=v[22640];v[22640]=0;if((b|0)==1){break m}}Eb(a+1298304|0,d);vb(d);v[22640]=0;b=Q(2,d|0,7463)|0;f=v[22640];v[22640]=0;e=1;if((f|0)==1){break y}Eb(a+1298316|0,b);vb(b);v[a+1298364>>2]=5;if(!(c&1)|!x[a+480188>>1]){break A}v[22640]=0;U(867,d+200|0,o|0,1146045008);b=v[22640];v[22640]=0;if((b|0)==1){break n}b=Ze(d+200|0);v[22640]=0;j=a+484344|0;R(364,j|0,b&65535);b=v[22640];v[22640]=0;if((b|0)==1){break p}s=d,y=Sb(d+200|0),v[s+120>>2]=y;s=d,y=Wb(d+200|0),v[s+168>>2]=y;if(Gb(d+120|0,d+168|0)){while(1){h=v[d+120>>2];v[22640]=0;b=T(232,h|0)|0;c=v[22640];v[22640]=0;ua:{va:{wa:{if((c|0)==1){break wa}v[22640]=0;c=T(229,h|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break wa}if((b|0)!=(c|0)){break ua}v[22640]=0;b=Q(880,h|0,8)|0;c=v[22640];v[22640]=0;if((c|0)==1){break wa}if(b){break va}break ua}e=P()|0;O()|0;break o}v[22640]=0;n=Q(871,h|0,d+255|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){v[22640]=0;g=T(319,h|0)|0;b=v[22640];v[22640]=0;xa:{if((b|0)==1){break xa}v[22640]=0;b=W(365,j|0,n|0,g|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break xa}i=0;if(!(b&(g|0)!=0)){break ua}while(1){ya:{b=_b(j,n);v[22640]=0;c=Pf(b,i);b=v[22640];v[22640]=0;za:{Aa:{Ba:{if((b|0)!=1){v[22640]=0;b=T(319,h|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break Ba}if(b>>>0<3){break za}v[22640]=0;U(320,d|0,h|0,b-2|0);b=v[22640];v[22640]=0;if((b|0)!=1){break Aa}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}while(1){v[22640]=0;b=Q(228,d|0,3)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ya}if(b){v[22640]=0;R(431,d+184|0,d|0);b=v[22640];v[22640]=0;Ca:{Da:{Ea:{Fa:{if((b|0)!=1){e=d+184|0;b=md(d+184|0);u[d+160>>1]=x[a+480188>>1]-1;b=w[b|0];v[22640]=0;u[d+104>>1]=b;b=Oc(d+160|0,d+104|0);f=v[22640];v[22640]=0;if((f|0)==1){break ya}f=x[b>>1];b=t[e|0];if((b|0)>-1){break Ca}v[22640]=0;b=T(353,d|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break ya}if(w[d+255|0]){break Ea}if((b|0)!=255){break Fa}b=254;break Da}break ya}if(b>>>0>128){break Da}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break Da}b=b>>>0<85?b+36|0:b}t[c+B(f,6)|0]=b;b=w[e|0]}if(b&64){v[22640]=0;b=T(353,d|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break ya}t[(c+B(f,6)|0)+1|0]=b+1;b=w[e|0]}if(b&32){v[22640]=0;b=T(353,d|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break ya}t[d+160|0]=b;b=c+B(f,6)|0;t[b+2|0]=1;v[22640]=0;t[d+104|0]=127;m=ac(d+160|0,d+104|0);p=v[22640];v[22640]=0;if((p|0)==1){break ya}t[b+4|0]=w[m|0]+1>>>1;b=w[e|0]}if(!(b&16)){continue}v[22640]=0;R(431,d+160|0,d|0);b=v[22640];v[22640]=0;if((b|0)==1){break ya}b=c+B(f,6)|0;e=w[md(d+160|0)|0];t[b+5|0]=e;Ga:{switch(w[d+160|0]-1|0){case 0:t[(c+B(f,6)|0)+3|0]=11;if(!w[d+255|0]){t[b+5|0]=e<<3|15;continue}t[b+5|0]=e<<4|15;continue;case 1:t[(c+B(f,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=e<<4;continue}t[b+5|0]=e<<3&240;continue;case 2:t[(c+B(f,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=e|240;continue}t[b+5|0]=e>>>1|240;continue;case 3:t[(c+B(f,6)|0)+3|0]=11;if(w[d+255|0]){t[b+5|0]=e&15;continue}if(e>>>0<=1){t[b+5|0]=e|240;continue}t[b+5|0]=e>>>1&15;continue;case 10:t[(c+B(f,6)|0)+3|0]=2;s=b,y=Ru(e,w[d+255|0])|240,t[s+5|0]=y;continue;case 11:t[(c+B(f,6)|0)+3|0]=2;s=b,y=Ru(e,w[d+255|0]),t[s+5|0]=y;continue;case 12:t[(c+B(f,6)|0)+3|0]=3;s=b,y=Ru(e,w[d+255|0])|240,t[s+5|0]=y;continue;case 13:t[(c+B(f,6)|0)+3|0]=3;s=b,y=Ru(e,w[d+255|0]),t[s+5|0]=y;continue;case 14:t[(c+B(f,6)|0)+3|0]=4;if(w[d+255|0]){continue}t[b+5|0]=(e&252)>>>2;continue;case 16:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&1|16;continue;case 15:t[(c+B(f,6)|0)+3|0]=6;t[b+5|0]=e&240;continue;case 17:t[(c+B(f,6)|0)+3|0]=6;t[b+5|0]=(e&240)>>>4;continue;case 18:t[(c+B(f,6)|0)+3|0]=20;continue;case 20:t[(c+B(f,6)|0)+3|0]=5;continue;case 21:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|48;continue;case 22:t[(c+B(f,6)|0)+3|0]=7;t[b+5|0]=e|240;continue;case 23:t[(c+B(f,6)|0)+3|0]=7;continue;case 30:t[(c+B(f,6)|0)+3|0]=8;continue;case 31:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|64;continue;case 40:t[(c+B(f,6)|0)+3|0]=10;v[22640]=0;f=T(353,d|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break ya}t[b+5|0]=f;v[22640]=0;Q(350,d|0,1)|0;b=v[22640];v[22640]=0;if((b|0)!=1){continue}break ya;case 41:t[(c+B(f,6)|0)+3|0]=15;continue;case 42:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|192;continue;case 43:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|208;continue;case 50:t[(c+B(f,6)|0)+3|0]=12;t[b+5|0]=(e&254)>>>1;v[22640]=0;Q(350,d|0,1)|0;b=v[22640];v[22640]=0;if((b|0)!=1){continue}break ya;case 51:t[(c+B(f,6)|0)+3|0]=14;t[b+5|0]=0;continue;case 52:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|176;continue;case 53:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|224;continue;case 60:t[(c+B(f,6)|0)+3|0]=16;continue;case 61:t[(c+B(f,6)|0)+3|0]=17;continue;case 70:t[(c+B(f,6)|0)+3|0]=1;continue;case 71:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|32;continue;case 72:t[(c+B(f,6)|0)+3|0]=20;t[b+5|0]=e&15|128;continue;default:break Ga}}t[(c+B(f,6)|0)+3|0]=0;continue}break}yb(d)}i=i+1|0;if((g|0)!=(i|0)){continue}break ua}break}e=P()|0;O()|0;yb(d);break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}Ah(d+120|0);if(Gb(d+120|0,d+168|0)){continue}break}}if(dr(k)>>>0>=2){f=0;while(1){b=Nj(l,f&255);c=cn(k,f);e=x[rc(b,x[c+36>>1])>>1];v[22640]=0;e=ke(j,e);h=v[22640];v[22640]=0;Ha:{Ia:{if((h|0)!=1){if(!e){break Ha}e=x[c+36>>1];v[22640]=0;e=Q(565,b|0,e|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break Ia}}e=P()|0;O()|0;break o}if(!(!r|!x[a+480188>>1])){g=c+24|0;b=0;while(1){oe(d,g,b);i=Cb(d);h=_b(j,e);Ja:{if(i){v[22640]=0;i=Be(d,20,145);n=v[22640];v[22640]=0;if((n|0)!=1){i=Eh(np(Qe(i,0),b&65535));v[22640]=0;Q(458,h|0,i|0)|0;h=v[22640];v[22640]=0;if((h|0)!=1){break Ja}}e=P()|0;O()|0;break o}i=w[kc(c,b)|0];v[22640]=0;i=Be(d,9,i);n=v[22640];v[22640]=0;if((n|0)!=1){i=Eh(np(Qe(i,0),b&65535));v[22640]=0;Q(458,h|0,i|0)|0;h=v[22640];v[22640]=0;if((h|0)!=1){break Ja}}e=P()|0;O()|0;break o}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}b=_b(j,e);h=w[c+43|0];v[22640]=0;h=Be(d,16,h);g=v[22640];v[22640]=0;if((g|0)==1){break z}h=Eh(Qe(h,0));v[22640]=0;Q(458,b|0,h|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break z}b=_b(j,e);c=w[c+42|0];v[22640]=0;c=Be(d,17,c);e=v[22640];v[22640]=0;if((e|0)!=1){c=Eh(Qe(c,0));v[22640]=0;Q(458,b|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break Ha}}e=P()|0;O()|0;break o}f=f+1|0;if(dr(k)>>>0>f>>>0){continue}break}}fd(d+200|0);e=1}fd(d+240|0);FU(k);yb(d+272|0);break b}e=P()|0;O()|0;break o}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break j}e=P()|0;O()|0}fd(d+200|0);break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}Su(i)}yb(d+200|0)}fd(d+240|0);break h}e=P()|0;O()|0}FU(k);break f}e=P()|0;O()|0}yb(d+272|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0}Cd(o);yb(q);S(e|0);L()}Cd(o);yb(q)}gb=d+352|0;return e|0}function hpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;d=gb-272|0;gb=d;vc(b);f=gb-32|0;gb=f;l=d+248|0;uv(f+24|0,l);h=xb(f+24|0);e=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=e;v[f>>2]=i;v[f+4>>2]=e;e=b;fc(f+16|0,b,f);i=xb(f+16|0);if((i|0)==(h|0)){Yb(e,xb(f+24|0))}gb=f+32|0;e=(h|0)==(i|0);if(!e){NX(l)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!e){break u}if(!PX(d+248|0)){break u}if(!c){g=1;break u}Gd(a,1024);wg(a);v[a+480208>>2]=v[a+480208>>2]|12;Yf(a+1074312|0,21);if(Ib(w[d+264|0]|w[d+265|0]<<8)){E=a,F=B(Ib(w[d+264|0]|w[d+265|0]<<8),1e4),v[E+480204>>2]=F}if(Ib(w[d+262|0]|w[d+263|0]<<8)){E=a,F=Ib(w[d+262|0]|w[d+263|0]<<8),v[E+480196>>2]=F}if(!w[d+258|0]){rh(a,1)}e=d+248|4;pD(b,a+1298268|0,Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))-14|0);b=Xi(d+144|0,b);v[22640]=0;R(538,d+232|0,b|0);e=v[22640];v[22640]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((e|0)!=1){yb(b);v[22640]=0;U(539,d+144|0,d+232|0,1395544366);b=v[22640];v[22640]=0;if((b|0)==1){break E}v[22640]=0;b=T(449,d+144|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break L}if(!b){break F}v[22640]=0;b=T(444,d+144|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break L}v[22640]=0;e=T(444,d+144|0)|0;f=v[22640];v[22640]=0;N:{if((f|0)==1){break N}v[22640]=0;Q(350,d+144|0,4)|0;f=v[22640];v[22640]=0;if((f|0)==1){break N}f=a+484360|0;h=Rb(f);v[22640]=0;ga(540,h|0,d+144|0,b|0,65535,65535)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break M}}break L}a=P()|0;O()|0;yb(b);break a}af(Rb(f),e);yb(d+144|0);v[22640]=0;U(539,d+144|0,d+232|0,1346458708);b=v[22640];v[22640]=0;if((b|0)==1){break K}v[22640]=0;b=T(449,d+144|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break J}if(!b){break H}v[22640]=0;b=T(444,d+144|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break J}u[a+480188>>1]=b;if((b-1&65535)>>>0>31){break H}v[22640]=0;b=T(444,d+144|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break J}v[22640]=0;p=a+484344|0;R(364,p|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break J}v[22640]=0;l=T(453,d+144|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break J}switch(l-841887796|0){case 0:case 2:break G;case 1:break H;default:break I}}a=P()|0;O()|0;yb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+144|0);break b}if(!l){break G}}yb(d+144|0);break A}yb(d+144|0);v[22640]=0;U(539,d+208|0,d+232|0,1398157625);b=v[22640];v[22640]=0;if((b|0)==1){break D}v[22640]=0;b=T(449,d+208|0)|0;e=v[22640];v[22640]=0;O:{if((e|0)==1){break O}if(!b){break B}v[22640]=0;Q(350,d+208|0,2)|0;b=v[22640];v[22640]=0;if((b|0)==1){break O}v[22640]=0;e=T(453,d+208|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}b=a;f=b;q=(+(e>>>0)*2.3283064365386963e-10+ +(y[b+480204>>2]/1e4>>>0))*1e4;P:{if(q<4294967296&q>=0){b=~~q>>>0;break P}b=0}v[f+480204>>2]=b;v[22640]=0;Q(541,d+208|0,d+144|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break C}e=(d+144|0)+(b<<1)|0;E=d,F=Ib(w[e|0]|w[e+1|0]<<8),v[E+80>>2]=F;v[22640]=0;v[d+64>>2]=180;e=ld(d+80|0,d- -64|0);f=v[22640];v[22640]=0;if((f|0)!=1){e=v[e>>2]-90|0;f=e>>31;E=((b<<5)+a|0)+480284|0,F=zc(nqa(e<<7|45,f<<7|e>>>25,90,0),jb)+128|0,u[E>>1]=F;b=b+1|0;if((b|0)!=32){continue}break C}break}break c}break c}yb(d+144|0);break A}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}v[22640]=0;Q(350,d+208|0,16)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;b=Q(228,d+208|0,2)|0;e=v[22640];v[22640]=0;if((e|0)==1){break c}if(b){v[22640]=0;b=T(444,d+208|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break c}u[d+80>>1]=b;v[22640]=0;u[d+64>>1]=256;b=Oc(d+80|0,d- -64|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}v[a+480200>>2]=x[b>>1]}v[22640]=0;Q(350,d+208|0,128)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;b=Q(541,d+208|0,d+80|0)|0;e=v[22640];v[22640]=0;Q:{if((e|0)!=1){if(!b){break B}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break Q}e=(d+80|0)+(b<<1)|0;E=d,F=Ib(w[e|0]|w[e+1|0]<<8),v[E+64>>2]=F;v[22640]=0;v[d+40>>2]=128;e=ld(d- -64|0,d+40|0);f=v[22640];v[22640]=0;if((f|0)!=1){u[((b<<5)+a|0)+480286>>1]=v[e>>2]/2&255;b=b+1|0;if((b|0)!=32){continue}break Q}break}break c}break c}v[a+480228>>2]=v[a+480228>>2]<<1}yb(d+208|0);v[22640]=0;U(539,d+144|0,d+232|0,1413830740);b=v[22640];v[22640]=0;R:{S:{if((b|0)!=1){v[22640]=0;b=T(449,d+144|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break d}if(!b){break R}v[22640]=0;R(542,d+144|0,d+80|0);b=v[22640];v[22640]=0;if((b|0)==1){break d}if((Ib(w[d+90|0]|w[d+91|0]<<8)|0)!=65535){break S}v[22640]=0;Q(350,d+144|0,1)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break S}break d}a=P()|0;O()|0;break b}v[22640]=0;b=T(492,d+144|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;ca(532,a+1298292|0,d+144|0,b|0,2)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}}yb(d+144|0);v[22640]=0;U(539,d+80|0,d+232|0,1229869908);b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;b=T(449,d+80|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){if(b){v[22640]=0;b=T(444,d+80|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break g}T:{e=b<<16>>16;h=e&32767;if(h>>>0>3999){break T}v[22640]=0;b=Q(228,d+80|0,B(h,(e>>>14&2)+50|0)|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break y}if(!b){break T}u[a+480190>>1]=h;g=a+480190|0;if(!h){break z}i=d+162|0;b=1;j=(e|0)>-1;U:{V:{while(1){W:{e=b;f=d;X:{Y:{Z:{if(!j){v[22640]=0;e=T(444,d+80|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break Z}e=e+1|0}u[f+40>>1]=e;v[22640]=0;R(543,d+80|0,d+144|0);e=v[22640];v[22640]=0;if((e|0)!=1){if((x[d+40>>1]-1&65535)>>>0>3998){break X}v[22640]=0;e=Ie(g,d+40|0);f=v[22640];v[22640]=0;if((f|0)!=1){break Y}}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}u[a+480190>>1]=x[e>>1];e=x[d+40>>1];f=Xb(w[d+266|0]|w[d+267|0]<<8|(w[d+268|0]<<16|w[d+269|0]<<24));v[22640]=0;Y(544,d+144|0,(B(e,104)+a|0)+484380|0,f|0,l|0);e=v[22640];v[22640]=0;if((e|0)==1){break W}v[22640]=0;Mk(d- -64|0,2,i);e=v[22640];v[22640]=0;if((e|0)==1){break V}v[22640]=0;R(377,d+208|0,d- -64|0);e=v[22640];v[22640]=0;if((e|0)==1){break V}v[22640]=0;Q(333,((x[d+40>>1]<<5)+a|0)+946304|0,d+208|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break U}vb(d+208|0)}e=b&65535;b=b+1|0;if(e>>>0<h>>>0){continue}break z}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+208|0);break f}yb(d+80|0);break A}break w}a=P()|0;O()|0;break f}break v}v[22640]=0;b=T(444,d+80|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){break x}}a=P()|0;O()|0;break f}if((b|0)==4){u[d+144>>1]=x[g>>1];v[22640]=0;u[d+208>>1]=255;b=Oc(d+144|0,d+208|0);e=v[22640];v[22640]=0;if((e|0)==1){break h}u[a+480192>>1]=x[b>>1];v[22640]=0;U(539,d+208|0,d+232|0,1229278806);b=v[22640];v[22640]=0;if((b|0)==1){break i}h=d- -64|4;g=d- -64|3;i=d- -64|5;j=d- -64|7;while(1){v[22640]=0;b=Q(228,d+80|0,15)|0;e=v[22640];v[22640]=0;_:{if((e|0)!=1){$:{if(b){v[22640]=0;R(546,d+80|0,d- -64|0);b=v[22640];v[22640]=0;aa:{if((b|0)!=1){b=d- -64|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>=x[a+480192>>1]){continue}b=d- -64|0;b=B(Ib(w[b|0]|w[b+1|0]<<8),104)+a|0;t[b+484524|0]=w[d+72|0];e=w[j|0];t[b+484523|0]=255;t[b+484525|0]=e;b=d- -64|0;b=Ib(w[b|0]|w[b+1|0]<<8);e=d- -64|0;e=Ib(w[e|0]|w[e+1|0]<<8);v[22640]=0;e=W(415,a|0,b+1&65535,e+1&65535)|0;b=v[22640];v[22640]=0;if((b|0)==1){break $}if(!e){continue}E=d,F=Ib(w[i|0]|w[i+1|0]<<8),u[E+144>>1]=F;v[22640]=0;u[d+40>>1]=4095;b=Oc(d+144|0,d+40|0);f=v[22640];v[22640]=0;if((f|0)==1){break $}v[e>>2]=x[b>>1];if(w[g|0]==255){continue}b=w[g|0];v[22640]=0;b=Q(227,d+208|0,B(b,34)+2|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break $}if(!b){continue}v[22640]=0;R(547,d+208|0,d+144|0);b=v[22640];v[22640]=0;if((b|0)==1){break $}t[e+60|0]=w[e+60|0]|1;b=Ib(w[d+144|0]|w[d+145|0]<<8);v[d+60>>2]=3;v[d+44>>2]=16;v[d+48>>2]=240;v[d+40>>2]=b;v[d+56>>2]=d+40;b=v[d+60>>2];v[d+8>>2]=v[d+56>>2];v[d+12>>2]=b;b=OX(d+8|0);v[22640]=0;f=e+48|0;R(475,f|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break $}b=0;if(Nb(f)){break aa}break _}break $}while(1){ba:{t[d+40|0]=64;m=(d+144|0)+(b<<1)|0;o=w[m+2|0];v[22640]=0;t[d+32|0]=o;o=ac(d+40|0,d+32|0);n=v[22640];v[22640]=0;if((n|0)==1){break ba}o=w[o|0];E=Mb(f,b),F=o,t[E+2|0]=F;m=w[m+3|0];E=Mb(f,b),F=m,u[E>>1]=F;b=b+1|0;if(Nb(f)>>>0>b>>>0){continue}break _}break}break $}yb(d+208|0);break w}}a=P()|0;O()|0;yb(d+208|0);break f}if(w[h|0]!=255){t[e+60|0]=w[e+60|0]|4;b=w[h|0];t[e+63|0]=b;t[e- -64|0]=b}if($c(f)){continue}t[e+60|0]=w[e+60|0]|2;b=Nb(f)-1|0;t[e+61|0]=b;t[e+62|0]=b;continue}}}yb(d+80|0);v[22640]=0;U(548,d+80|0,d+232|0,1145131092);b=v[22640];v[22640]=0;if((b|0)==1){break j}E=d,F=Sb(d+80|0),v[E+32>>2]=F;E=d,F=Wb(d+80|0),v[E+24>>2]=F;if(Gb(d+32|0,d+24|0)){z=c&1;m=d+208|4;o=(l|0)!=841887798;A=(l|0)!=841887796;while(1){h=v[d+32>>2];v[22640]=0;Q(350,h|0,4)|0;b=v[22640];v[22640]=0;ca:{da:{ea:{if((b|0)!=1){v[22640]=0;e=T(444,h|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break l}v[22640]=0;i=T(444,h|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break m}i=o?i:(i>>>0)/y[a+480196>>2]|0;if(!z|e>>>0>255){break ca}v[22640]=0;b=W(365,p|0,e|0,i|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break m}if(!b){break ca}if(o){break da}v[22640]=0;Q(350,h|0,4)|0;b=v[22640];v[22640]=0;if((b|0)==1){break m}j=0;if(!x[a+480188>>1]){break ca}while(1){v[22640]=0;b=T(444,h|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ea}v[22640]=0;U(320,d+144|0,h|0,b+(b&1)&65535);b=v[22640];v[22640]=0;if((b|0)==1){break n}v[d+208>>2]=0;v[d+212>>2]=0;f=0;fa:{while(1){v[22640]=0;b=Q(228,d+144|0,6)|0;g=v[22640];v[22640]=0;if((g|0)==1){break o}if(!(b&y[d+208>>2]<i>>>0)){break fa}b=_b(p,e);v[22640]=0;b=Tc(b,v[d+208>>2],j&65535);g=v[22640];v[22640]=0;ga:{ha:{if((g|0)!=1){v[22640]=0;R(549,d+40|0,d+144|0);g=v[22640];v[22640]=0;if((g|0)==1){break o}g=md(d+40|0);r=Re(d+40|0);C=aj(d+40|0);n=ec(d+40|0);D=d+45|0;k=t[d+40|0];if((k-1&255)>>>0>95){break ha}t[b|0]=k+13;if(!v[d+212>>2]){break ga}t[b+3|0]=19;v[22640]=0;v[d+64>>2]=15;k=ld(m,d- -64|0);s=v[22640];v[22640]=0;if((s|0)==1){break o}t[b+5|0]=w[k|0]|208;break ga}break o}if((k|0)>-1){break ga}if(v[d+212>>2]){t[b+3|0]=19;v[22640]=0;v[d+64>>2]=15;k=ld(m,d- -64|0);s=v[22640];v[22640]=0;if((s|0)!=1){t[b+5|0]=w[k|0]|192;break ga}break o}t[b|0]=254}if(w[g|0]){t[b+2|0]=1;v[22640]=0;t[d+64|0]=64;g=ac(g,d- -64|0);k=v[22640];v[22640]=0;if((k|0)==1){break o}t[b+4|0]=w[g|0]}g=w[r|0];if(g){t[b+1|0]=g}g=w[C|0];if(g|w[n|0]){t[b+3|0]=g;t[b+5|0]=w[n|0];v[22640]=0;Mf(b);b=v[22640];v[22640]=0;if((b|0)==1){break o}}b=w[D|0];if(b&128){v[22640]=0;g=T(353,d+144|0)|0;n=v[22640];v[22640]=0;if((n|0)==1){break o}b=g|b<<8&32512}g=v[a+480196>>2];v[22640]=0;f=b+f|0;gt(d- -64|0,f,g);b=v[22640];v[22640]=0;if((b|0)!=1){b=v[d+68>>2];v[d+208>>2]=v[d+64>>2];v[d+212>>2]=b;continue}break}break o}yb(d+144|0);j=j+1|0;if(x[a+480188>>1]>(j&65535)>>>0){continue}break}break ca}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}b=_b(p,e);v[22640]=0;b=Tc(b,0,0);e=v[22640];v[22640]=0;if((e|0)==1){break s}j=0;if(!i){break ca}while(1){g=0;ia:{if(!x[a+480188>>1]){break ia}while(1){ja:{v[22640]=0;R(550,d+144|0,h|0);e=v[22640];v[22640]=0;if((e|0)==1){break ja}ka:{if(!A){v[d+208>>2]=v[d+144>>2];n=md(d+208|0);k=Re(d+208|0);r=aj(d+208|0);e=t[d+208|0];if((e|0)>=1){t[b|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+12}f=b;e=w[n|0];if(e>>>0>=4){t[b+2|0]=1;t[b+4|0]=(e>>>2|0)-1;e=w[n|0]}t[f+1|0]=e<<4&48|w[k|0]>>>4;t[b+3|0]=w[k|0]&15;t[b+5|0]=w[r|0];break ka}e=v[d+144>>2];v[d+20>>2]=e;v[22640]=0;v[d+16>>2]=e;gr(d+16|0,b);e=v[22640];v[22640]=0;if((e|0)==1){break ja}e=lc(d+144|0,0);t[b+1|0]=w[b+1|0]|w[e|0]&48}v[22640]=0;Mf(b);e=v[22640];v[22640]=0;if((e|0)==1){break ja}e=w[b+3|0];la:{if(e>>>0>11){break la}e=1<<e;ma:{if(!(e&2240)){if(!(e&12)){break la}if(!w[b+5|0]){break ma}break la}e=w[b+5|0];f=e&240;if(f){t[b+5|0]=f;break la}if(e){break la}}t[b+3|0]=0}b=b+6|0;g=g+1|0;if(x[a+480188>>1]>(g&65535)>>>0){continue}break ia}break}a=P()|0;O()|0;break k}j=j+1|0;if((j|0)!=(i|0)){continue}break}}Ah(d+32|0);if(Gb(d+32|0,d+24|0)){continue}break}}fd(d+80|0);v[22640]=0;U(539,d+144|0,d+232|0,1346458702);b=v[22640];v[22640]=0;if((b|0)==1){a=P()|0;O()|0;break b}v[22640]=0;b=T(449,d+144|0)|0;e=v[22640];v[22640]=0;na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{if((e|0)!=1){if(b){e=Kb(d+80|0);b=0;Ba:{while(1){Ca:{v[22640]=0;f=Q(228,d+144|0,1)|0;h=v[22640];v[22640]=0;if((h|0)==1){break Ca}if(!f){break Ba}if(Oe(p)>>>0<=b>>>0){break Ba}v[22640]=0;W(552,d+144|0,e|0,32)|0;f=v[22640];v[22640]=0;if((f|0)==1){break Ca}f=_b(p,b);v[22640]=0;Q(455,f|0,e|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break Ca}b=b+1|0;continue}break}a=P()|0;O()|0;vb(e);break Aa}vb(e)}yb(d+144|0);v[22640]=0;U(539,d+144|0,d+232|0,1414679374);b=v[22640];v[22640]=0;if((b|0)==1){break za}v[22640]=0;b=T(449,d+144|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break va}if(!b){break wa}e=Kb(d+80|0);b=0;while(1){v[22640]=0;f=Q(228,d+144|0,1)|0;h=v[22640];v[22640]=0;if((h|0)==1){break ya}if(!f|x[a+480188>>1]<=b>>>0){break xa}v[22640]=0;W(552,d+144|0,e|0,32)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ya}v[22640]=0;Q(427,((b<<5)+a|0)+480289|0,e|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ya}b=b+1|0;continue}}a=P()|0;O()|0}yb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(e);break ua}vb(e)}yb(d+144|0);v[22640]=0;U(548,d+144|0,d+232|0,1145129300);b=v[22640];v[22640]=0;if((b|0)==1){break ta}E=d,F=Sb(d+144|0),v[E+80>>2]=F;E=d,F=Wb(d+144|0),v[E+208>>2]=F;if(Gb(d+80|0,d+208|0)){e=c&2;while(1){b=v[d+80>>2];v[22640]=0;c=T(444,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break p}if(!(!e|c>>>0>=x[a+480190>>1])){c=B(c,104)+a|0;f=x[c+484518>>1];f=Pc(d- -64|0,f&1?16:8,f&64?2:1,1,0);v[22640]=0;W(363,f|0,c+484484|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break p}}Ah(d+80|0);if(Gb(d+80|0,d+208|0)){continue}break}}fd(d+144|0);b=Kb(d+80|0);if((l|0)!=841887798){break ra}v[22640]=0;c=Q(2,d+144|0,6665)|0;e=v[22640];v[22640]=0;if((e|0)==1){break sa}Eb(b,c);vb(c);break qa}a=P()|0;O()|0}yb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break q}v[22640]=0;U(539,d+144|0,d+232|0,1447383635);c=v[22640];v[22640]=0;Da:{Ea:{Fa:{Ga:{Ha:{if((c|0)!=1){v[22640]=0;c=T(449,d+144|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break pa}if(!c){break Ea}v[22640]=0;c=T(453,d+144|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break Ha}v[22640]=0;R(439,d- -64|0,1401);e=v[22640];v[22640]=0;if((e|0)==1){break Ga}v[d+40>>2]=c>>>4;v[22640]=0;v[d+32>>2]=c&15;Y(553,d+208|0,d- -64|0,d+40|0,d+32|0);c=v[22640];v[22640]=0;if((c|0)==1){break Fa}Eb(b,d+208|0);vb(d+208|0);Hb(d- -64|0);break Da}a=P()|0;O()|0;break q}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;Hb(d- -64|0);break r}v[22640]=0;c=Q(2,d+208|0,5736)|0;e=v[22640];v[22640]=0;if((e|0)==1){break t}Eb(b,c);vb(c)}yb(d+144|0)}v[22640]=0;c=Q(2,d+144|0,5736)|0;e=v[22640];v[22640]=0;if((e|0)==1){break oa}Eb(a+1298304|0,c);vb(c);v[22640]=0;c=Q(2,d+144|0,7459)|0;e=v[22640];v[22640]=0;if((e|0)==1){break na}Eb(a+1298316|0,c);vb(c);Eb(a+1298328|0,b);v[a+1298364>>2]=2;vb(b);g=1;break v}a=P()|0;O()|0;break r}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}Cd(d+232|0)}gb=d+272|0;return g|0}a=P()|0;O()|0;break r}a=P()|0;O()|0;break k}yb(d+144|0)}vb(b);break b}a=P()|0;O()|0;fd(d+144|0);break b}a=P()|0;O()|0;yb(d+144|0);break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0}fd(d+80|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0}yb(d+80|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+144|0);break b}a=P()|0;O()|0;yb(d+208|0)}Cd(d+232|0)}S(a|0);L()}function CI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;u=gb-48|0;gb=u;a:{if(c>>>0<=2){c=c<<2;H=v[c+74556>>2];I=v[c+74544>>2];while(1){c=v[b+4>>2];b:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=jd(b)}if(xm(c)){continue}break}n=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}n=(c|0)==45?-1:1;c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=jd(b)}e:{f:{while(1){if(t[f+2048|0]==(c|32)){g:{if(f>>>0>6){break g}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=jd(b)}f=f+1|0;if((f|0)!=8){continue}break f}break}if((f|0)!=3){if((f|0)==8){break f}if(!d|f>>>0<4){break e}if((f|0)==8){break f}}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(!d|f>>>0<4){break f}while(1){if(c){v[b+4>>2]=v[b+4>>2]-1}f=f-1|0;if(f>>>0>3){continue}break}}b=u;k=gb-16|0;gb=k;h=(p(C(C(n|0)*C(N))),j(2));c=h&2147483647;h:{if(c-8388608>>>0<=2130706431){d=c;c=c>>>7|0;f=d<<25;d=c+1065353216|0;break h}f=h;d=f>>>7|0;f=f<<25;d=d|2147418112;if(c>>>0>=2139095040){break h}f=0;d=0;if(!c){break h}d=c;c=E(c);If(k,d,0,0,0,c+81|0);i=v[k>>2];g=v[k+4>>2];f=v[k+8>>2];d=v[k+12>>2]^65536|16265-c<<16}v[b>>2]=i;v[b+4>>2]=g;v[b+8>>2]=f;v[b+12>>2]=h&-2147483648|d;gb=k+16|0;i=v[u+8>>2];g=v[u+12>>2];l=v[u>>2];h=v[u+4>>2];break a}i:{j:{k:{if(f){break k}f=0;while(1){if(t[f+7304|0]!=(c|32)){break k}l:{if(f>>>0>1){break l}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=jd(b)}f=f+1|0;if((f|0)!=3){continue}break}break j}m:{switch(f|0){case 0:n:{if((c|0)!=48){break n}f=v[b+4>>2];o:{if(f>>>0<y[b+104>>2]){v[b+4>>2]=f+1;f=w[f|0];break o}f=jd(b)}if((f&-33)==88){f=gb-432|0;gb=f;h=v[b+104>>2];c=b;b=v[c+4>>2];p:{if(h>>>0>b>>>0){v[c+4>>2]=b+1;b=w[b|0];break p}b=jd(c)}q:{r:{while(1){if((b|0)!=48){s:{if((b|0)!=46){break q}b=v[c+4>>2];if(b>>>0>=y[c+104>>2]){break s}v[c+4>>2]=b+1;b=w[b|0];break r}}else{b=v[c+4>>2];if(b>>>0<y[c+104>>2]){k=1;v[c+4>>2]=b+1;b=w[b|0]}else{k=1;b=jd(c)}continue}break}b=jd(c)}e=1;if((b|0)!=48){break q}while(1){b=m;m=b-1|0;x=x-(b>>>0<1)|0;b=v[c+4>>2];t:{if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0];break t}b=jd(c)}if((b|0)==48){continue}break}k=1}h=1073676288;u:{while(1){v:{z=b|32;w:{x:{J=b-48|0;if(J>>>0<10){break x}if((b|0)!=46?z-97>>>0>=6:0){break u}if((b|0)!=46){break x}if(e){break v}e=1;m=i;x=g;break w}b=(b|0)>57?z-87|0:J;y:{if((g|0)<0?1:(g|0)<=0?i>>>0<=7:0){s=b+(s<<4)|0;break y}if((g|0)<0?1:(g|0)<=0?i>>>0<=28:0){Sg(f+48|0,b);Dd(f+32|0,F,G,l,h,0,0,0,1073414144);F=v[f+32>>2];G=v[f+36>>2];l=v[f+40>>2];h=v[f+44>>2];Dd(f+16|0,F,G,l,h,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2]);tg(f,q,r,A,D,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2]);A=v[f+8>>2];D=v[f+12>>2];q=v[f>>2];r=v[f+4>>2];break y}if(!b|o){break y}Dd(f+80|0,F,G,l,h,0,0,0,1073610752);tg(f- -64|0,q,r,A,D,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2]);A=v[f+72>>2];D=v[f+76>>2];o=1;q=v[f+64>>2];r=v[f+68>>2]}b=i+1|0;k=b>>>0<1?g+1|0:g;i=b;g=k;k=1}b=v[c+4>>2];if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0]}else{b=jd(c)}continue}break}b=46}z:{A:{B:{if(!k){if(!v[c+104>>2]){if(d){break A}break B}b=v[c+4>>2];v[c+4>>2]=b-1;if(!d){break B}v[c+4>>2]=b-2;if(!e){break A}v[c+4>>2]=b-3;break A}if((g|0)<0?1:(g|0)<=0?i>>>0<=7:0){l=i;h=g;while(1){s=s<<4;k=l+1|0;h=k>>>0<1?h+1|0:h;l=k;if((k|0)!=8|h){continue}break}}C:{D:{E:{if((b&-33)==80){l=BI(c,d);b=jb;h=b;if(l|(b|0)!=-2147483648){break C}if(d){if(v[c+104>>2]){break E}break D}q=0;r=0;xi(c,0,0);c=0;b=0;break z}if(!v[c+104>>2]){break D}}v[c+4>>2]=v[c+4>>2]-1}l=0;h=0}if(!s){sj(f+112|0,+(n|0)*0);q=v[f+112>>2];r=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break z}b=e?m:i;c=(e?x:g)<<2|b>>>30;b=l+(b<<2)|0;c=c+h|0;c=b>>>0<l>>>0?c+1|0:c;i=b-32|0;g=c-(b>>>0<32)|0;b=g;if((b|0)>0?1:(b|0)>=0?i>>>0>0-H>>>0:0){v[115121]=68;Sg(f+160|0,n);Dd(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);Dd(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);q=v[f+128>>2];r=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break z}b=H-226|0;c=i>>>0>=b>>>0;b=b>>31;if((b|0)<(g|0)?1:(g|0)>=(b|0)?c:0){if((s|0)>-1){while(1){tg(f+416|0,q,r,A,D,0,0,0,-1073807360);c=bB(q,r,A,D,1073610752);b=(c|0)<0;tg(f+400|0,q,r,A,D,b?q:v[f+416>>2],b?r:v[f+420>>2],b?A:v[f+424>>2],b?D:v[f+428>>2]);b=i;i=b-1|0;g=g-(b>>>0<1)|0;A=v[f+408>>2];D=v[f+412>>2];q=v[f+400>>2];r=v[f+404>>2];s=s<<1|(c|0)>-1;if((s|0)>-1){continue}break}}b=i;c=H;d=(b-c|0)+32|0;c=g-((c>>31)+(b>>>0<c>>>0)|0)|0;c=d>>>0<32?c+1|0:c;b=d;c=((c|0)<0?1:(c|0)<=0?b>>>0<I>>>0:0)?(b|0)>0?b:0:I;F:{if((c|0)>=113){Sg(f+384|0,n);m=v[f+392>>2];x=v[f+396>>2];F=v[f+384>>2];G=v[f+388>>2];g=0;b=0;break F}sj(f+352|0,$i(1,144-c|0));Sg(f+336|0,n);F=v[f+336>>2];G=v[f+340>>2];m=v[f+344>>2];x=v[f+348>>2];EI(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],F,G,m,x);K=v[f+376>>2];L=v[f+380>>2];g=v[f+372>>2];b=v[f+368>>2]}c=!(s&1)&((tn(q,r,A,D,0,0,0,0)|0)!=0&(c|0)<32);$n(f+320|0,c+s|0);Dd(f+304|0,F,G,m,x,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);tg(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,g,K,L);Dd(f+288|0,c?0:q,c?0:r,c?0:A,c?0:D,F,G,m,x);tg(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);Lx(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],b,g,K,L);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];g=v[f+252>>2];if(!tn(b,c,d,g,0,0,0,0)){v[115121]=68}DI(f+224|0,b,c,d,g,i);q=v[f+224>>2];r=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break z}v[115121]=68;Sg(f+208|0,n);Dd(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);Dd(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);q=v[f+176>>2];r=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2];break z}xi(c,0,0)}sj(f+96|0,+(n|0)*0);q=v[f+96>>2];r=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2]}v[u+16>>2]=q;v[u+20>>2]=r;v[u+24>>2]=b;v[u+28>>2]=c;gb=f+432|0;i=v[u+24>>2];g=v[u+28>>2];l=v[u+16>>2];h=v[u+20>>2];break a}if(!v[b+104>>2]){break n}v[b+4>>2]=v[b+4>>2]-1}m=b;f=c;s=n;b=0;n=0;e=gb-8976|0;gb=e;K=H+I|0;L=0-K|0;G:{H:{while(1){if((f|0)!=48){I:{if((f|0)!=46){break G}c=v[m+4>>2];if(c>>>0>=y[m+104>>2]){break I}v[m+4>>2]=c+1;f=w[c|0];break H}}else{c=v[m+4>>2];if(c>>>0<y[m+104>>2]){v[m+4>>2]=c+1;f=w[c|0]}else{f=jd(m)}n=1;continue}break}f=jd(m)}o=1;if((f|0)!=48){break G}i=-1;g=-1;while(1){c=v[m+4>>2];J:{if(c>>>0<y[m+104>>2]){v[m+4>>2]=c+1;f=w[c|0];break J}f=jd(m)}if((f|0)==48){c=i;i=c-1|0;g=g-(c>>>0<1)|0;continue}break}n=1}v[e+784>>2]=0;K:{L:{k=(f|0)==46;c=f-48|0;M:{N:{O:{P:{if(c>>>0>9?k:1){while(1){Q:{if(k&1){if(!o){i=l;g=h;o=1;break Q}k=!n;break P}k=h;h=l+1|0;k=h>>>0<1?k+1|0:k;l=h;h=k;if((b|0)<=2044){J=(f|0)==48?J:l;k=(e+784|0)+(b<<2)|0;n=k;if(z){c=(B(v[k>>2],10)+f|0)-48|0}v[n>>2]=c;n=1;f=z+1|0;c=(f|0)==9;z=c?0:f;b=b+c|0;break Q}if((f|0)==48){break Q}v[e+8960>>2]=v[e+8960>>2]|1;J=18396}c=v[m+4>>2];R:{if(c>>>0<y[m+104>>2]){v[m+4>>2]=c+1;f=w[c|0];break R}f=jd(m)}k=(f|0)==46;c=f-48|0;if(k|c>>>0<10){continue}break}}i=o?i:l;g=o?g:h;if(!(!n|(f&-33)!=69)){c=BI(m,d);f=jb;k=f;S:{if(c|(f|0)!=-2147483648){d=g+k|0;i=c+i|0;d=i>>>0<c>>>0?d+1|0:d;g=d;break S}if(!d){break M}if(!v[m+104>>2]){break S}v[m+4>>2]=v[m+4>>2]-1}if(!n){break N}break L}k=!n;if((f|0)<0){break O}}if(!v[m+104>>2]){break O}v[m+4>>2]=v[m+4>>2]-1}if(!k){break L}}v[115121]=28}l=0;h=0;xi(m,0,0);c=0;b=0;break K}c=v[e+784>>2];if(!c){sj(e,+(s|0)*0);l=v[e>>2];h=v[e+4>>2];c=v[e+12>>2];b=v[e+8>>2];break K}if(!((i|0)!=(l|0)|(g|0)!=(h|0)|((h|0)>0?1:(h|0)>=0?l>>>0>9:0)|(c>>>I|0?(I|0)<=30:0))){Sg(e+48|0,s);$n(e+32|0,c);Dd(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);l=v[e+16>>2];h=v[e+20>>2];c=v[e+28>>2];b=v[e+24>>2];break K}if((g|0)>0?1:(g|0)>=0?i>>>0>(H|0)/-2>>>0:0){v[115121]=68;Sg(e+96|0,s);Dd(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);Dd(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);l=v[e+64>>2];h=v[e+68>>2];c=v[e+76>>2];b=v[e+72>>2];break K}c=H-226|0;d=i>>>0<c>>>0;c=c>>31;if((c|0)>(g|0)?1:(g|0)<=(c|0)?d:0){v[115121]=68;Sg(e+144|0,s);Dd(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);Dd(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);l=v[e+112>>2];h=v[e+116>>2];c=v[e+124>>2];b=v[e+120>>2];break K}if(z){if((z|0)<=8){d=(e+784|0)+(b<<2)|0;c=v[d>>2];while(1){c=B(c,10);z=z+1|0;if((z|0)!=9){continue}break}v[d>>2]=c}b=b+1|0}T:{o=i;if((J|0)>(i|0)|(J|0)>=9|(i|0)>17){break T}if((o|0)==9){Sg(e+192|0,s);$n(e+176|0,v[e+784>>2]);Dd(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);l=v[e+160>>2];h=v[e+164>>2];c=v[e+172>>2];b=v[e+168>>2];break K}if((o|0)<=8){Sg(e+272|0,s);$n(e+256|0,v[e+784>>2]);Dd(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);Sg(e+224|0,v[(0-o<<2)+74544>>2]);$E(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);l=v[e+208>>2];h=v[e+212>>2];c=v[e+220>>2];b=v[e+216>>2];break K}c=(B(o,-3)+I|0)+27|0;d=v[e+784>>2];if(d>>>c|0?(c|0)<=30:0){break T}Sg(e+352|0,s);$n(e+336|0,d);Dd(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);Sg(e+304|0,v[(o<<2)+74472>>2]);Dd(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);l=v[e+288>>2];h=v[e+292>>2];c=v[e+300>>2];b=v[e+296>>2];break K}while(1){c=b;b=c-1|0;if(!v[(e+784|0)+(b<<2)>>2]){continue}break}z=0;b=(o|0)%9|0;U:{if(!b){b=0;break U}d=(o|0)>-1?b:b+9|0;V:{if(!c){b=0;c=0;break V}i=v[(0-d<<2)+74544>>2];h=1e9/(i|0)|0;k=0;f=0;b=0;while(1){g=k;k=(e+784|0)+(f<<2)|0;l=v[k>>2];n=(l>>>0)/(i>>>0)|0;g=g+n|0;v[k>>2]=g;g=!g&(b|0)==(f|0);b=g?b+1&2047:b;o=g?o-9|0:o;k=B(h,l-B(i,n)|0);f=f+1|0;if((f|0)!=(c|0)){continue}break}if(!k){break V}v[(e+784|0)+(c<<2)>>2]=k;c=c+1|0}o=(o-d|0)+9|0}while(1){l=(e+784|0)+(b<<2)|0;W:{while(1){if((o|0)!=36|y[l>>2]>10384592?(o|0)>=36:0){break W}f=c+2047|0;i=0;while(1){k=0;f=f&2047;n=(e+784|0)+(f<<2)|0;g=v[n>>2];d=g>>>3|0;g=i+(g<<29)|0;h=d;h=g>>>0<i>>>0?h+1|0:h;i=g;g=h;if(!g&i>>>0>=1000000001|g){k=pqa(i,g,1e9,0);i=i-mqa(k,jb,1e9,0)|0}v[n>>2]=i;d=(b|0)==(f|0);c=(f|0)!=(c-1&2047)?c:d?c:i?c:f;if(!d){f=f-1|0;i=k;continue}break}z=z-29|0;if(!k){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=(e+784|0)+((c+2046&2047)<<2)|0;c=c-1&2047;v[d>>2]=v[d>>2]|v[(e+784|0)+(c<<2)>>2]}o=o+9|0;v[(e+784|0)+(b<<2)>>2]=k;continue}break}X:{Y:while(1){d=c+1&2047;g=(e+784|0)+((c-1&2047)<<2)|0;while(1){i=(o|0)>45?9:1;Z:{while(1){n=b;f=0;_:{while(1){$:{b=f+n&2047;if((b|0)==(c|0)){break $}b=v[(e+784|0)+(b<<2)>>2];h=v[(f<<2)+74496>>2];if(b>>>0<h>>>0){break $}if(b>>>0>h>>>0){break _}f=f+1|0;if((f|0)!=4){continue}}break}if((o|0)!=36){break _}i=0;g=0;f=0;l=0;h=0;while(1){b=f+n&2047;if((b|0)==(c|0)){c=c+1&2047;v[(e+(c<<2)|0)+780>>2]=0}Dd(e+768|0,i,g,l,h,0,0,1342177280,1075633366);$n(e+752|0,v[(e+784|0)+(b<<2)>>2]);tg(e+736|0,v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2],v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2]);l=v[e+744>>2];h=v[e+748>>2];i=v[e+736>>2];g=v[e+740>>2];f=f+1|0;if((f|0)!=4){continue}break}Sg(e+720|0,s);Dd(e+704|0,i,g,l,h,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);l=v[e+712>>2];h=v[e+716>>2];i=0;g=0;q=v[e+704>>2];r=v[e+708>>2];o=z+113|0;d=o-H|0;f=(d|0)<(I|0);b=f?(d|0)>0?d:0:I;if((b|0)<=112){break Z}m=0;break X}z=i+z|0;b=c;if((n|0)==(c|0)){continue}break}k=1e9>>>i|0;l=-1<<i^-1;f=0;b=n;while(1){h=f;f=(e+784|0)+(n<<2)|0;m=v[f>>2];h=h+(m>>>i|0)|0;v[f>>2]=h;h=!h&(b|0)==(n|0);b=h?b+1&2047:b;o=h?o-9|0:o;f=B(k,l&m);n=n+1&2047;if((n|0)!=(c|0)){continue}break}if(!f){continue}if((b|0)!=(d|0)){v[(e+784|0)+(c<<2)>>2]=f;c=d;continue Y}v[g>>2]=v[g>>2]|1;b=d;continue}break}break}sj(e+656|0,$i(1,225-b|0));EI(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],q,r,l,h);F=v[e+696>>2];G=v[e+700>>2];A=v[e+688>>2];D=v[e+692>>2];sj(e+640|0,$i(1,113-b|0));GE(e+672|0,q,r,l,h,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);i=v[e+672>>2];g=v[e+676>>2];m=v[e+680>>2];x=v[e+684>>2];Lx(e+624|0,q,r,l,h,i,g,m,x);tg(e+608|0,A,D,F,G,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);l=v[e+616>>2];h=v[e+620>>2];q=v[e+608>>2];r=v[e+612>>2]}k=n+4&2047;aa:{if((k|0)==(c|0)){break aa}k=v[(e+784|0)+(k<<2)>>2];ba:{if(k>>>0<=499999999){if(!((n+5&2047)==(c|0)?k:1)){break ba}sj(e+496|0,+(s|0)*.25);tg(e+480|0,i,g,m,x,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);m=v[e+488>>2];x=v[e+492>>2];i=v[e+480>>2];g=v[e+484>>2];break ba}if((k|0)!=5e8){sj(e+592|0,+(s|0)*.75);tg(e+576|0,i,g,m,x,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);m=v[e+584>>2];x=v[e+588>>2];i=v[e+576>>2];g=v[e+580>>2];break ba}M=+(s|0);if((n+5&2047)==(c|0)){sj(e+528|0,M*.5);tg(e+512|0,i,g,m,x,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);m=v[e+520>>2];x=v[e+524>>2];i=v[e+512>>2];g=v[e+516>>2];break ba}sj(e+560|0,M*.75);tg(e+544|0,i,g,m,x,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);m=v[e+552>>2];x=v[e+556>>2];i=v[e+544>>2];g=v[e+548>>2]}if((b|0)>111){break aa}GE(e+464|0,i,g,m,x,0,0,0,1073676288);if(tn(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break aa}tg(e+448|0,i,g,m,x,0,0,0,1073676288);m=v[e+456>>2];x=v[e+460>>2];i=v[e+448>>2];g=v[e+452>>2]}tg(e+432|0,q,r,l,h,i,g,m,x);Lx(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],A,D,F,G);l=v[e+424>>2];h=v[e+428>>2];q=v[e+416>>2];r=v[e+420>>2];ca:{if((-2-K|0)>=(o&2147483647)){break ca}v[e+408>>2]=l;v[e+412>>2]=h&2147483647;v[e+400>>2]=q;v[e+404>>2]=r;Dd(e+384|0,q,r,l,h,0,0,0,1073610752);n=v[e+400>>2];o=v[e+404>>2];s=v[e+408>>2];H=v[e+412>>2];c=bB(n,o,s,H,1081081856);k=(c|0)<0;l=k?l:v[e+392>>2];h=k?h:v[e+396>>2];q=k?q:v[e+384>>2];r=k?r:v[e+388>>2];z=((c|0)>-1)+z|0;if((z+110|0)<=(L|0)){if((((bB(n,o,s,H,1081081856)|0)<0?f:f&(b|0)!=(d|0))|0)!=1){break ca}if(!tn(i,g,m,x,0,0,0,0)){break ca}}v[115121]=68}DI(e+368|0,q,r,l,h,z);l=v[e+368>>2];h=v[e+372>>2];c=v[e+380>>2];b=v[e+376>>2]}v[u+32>>2]=l;v[u+36>>2]=h;v[u+40>>2]=b;v[u+44>>2]=c;gb=e+8976|0;i=v[u+40>>2];g=v[u+44>>2];l=v[u+32>>2];h=v[u+36>>2];break a;case 3:break j;default:break m}}if(v[b+104>>2]){v[b+4>>2]=v[b+4>>2]-1}break i}da:{c=v[b+4>>2];ea:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ea}c=jd(b)}if((c|0)==40){f=1;break da}g=2147450880;if(!v[b+104>>2]){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];fa:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break fa}c=jd(b)}if(c-97>>>0>=26?c-48>>>0<10|c-65>>>0<26|(c|0)==95:1){f=f+1|0;continue}break}g=2147450880;if((c|0)==41){break a}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(d){if(!f){break a}while(1){f=f-1|0;if(c){v[b+4>>2]=v[b+4>>2]-1}if(f){continue}break}break a}}v[115121]=28;xi(b,0,0)}g=0}v[a>>2]=l;v[a+4>>2]=h;v[a+8>>2]=i;v[a+12>>2]=g;gb=u+48|0}function Hna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=gb-400|0;gb=d;vc(b);e=d+392|0;g=Rv(b,e);if(!g){rW(e)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if(!g){break q}if(!BW(d+392|0)){break q}if(!c){p=1;break q}A=Xi(d+368|0,b);v[22640]=0;R(686,d+352|0,A|0);b=v[22640];v[22640]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((b|0)!=1){v[22640]=0;U(687,d+328|0,d+352|0,20041);b=v[22640];v[22640]=0;if((b|0)==1){break F}v[22640]=0;b=T(307,d+328|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break w}if(!b){break r}v[22640]=0;b=Q(688,d+328|0,d+232|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break w}if(!b){break r}v[22640]=0;R(407,a|0,16384);b=v[22640];v[22640]=0;if((b|0)==1){break w}v[a+480208>>2]=8;v[22640]=0;b=a+1074312|0;W(437,b|0,9,1)|0;e=v[22640];v[22640]=0;if((e|0)==1){break w}v[22640]=0;Q(438,b|0,21)|0;e=v[22640];v[22640]=0;if((e|0)==1){break w}v[22640]=0;Q(438,b|0,30)|0;b=v[22640];v[22640]=0;if((b|0)==1){break w}v[22640]=0;b=Q(2,d+176|0,5493)|0;e=v[22640];v[22640]=0;if((e|0)==1){break C}Eb(a+1298304|0,b);vb(b);v[22640]=0;b=Q(2,d+176|0,8065)|0;e=v[22640];v[22640]=0;if((e|0)==1){break B}Eb(a+1298316|0,b);vb(b);v[22640]=0;b=Q(2,d+216|0,14573)|0;e=v[22640];v[22640]=0;if((e|0)==1){break A}e=w[d+396|0];switch(e-16|0){case 1:break z;case 0:break E;default:break D}}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}v[22640]=0;Q(2,d+200|0,12242)|0;e=v[22640];v[22640]=0;if((e|0)!=1){break x}break e}if(!e){break y}v[22640]=0;Q(2,d+200|0,18693)|0;e=v[22640];v[22640]=0;if((e|0)==1){break e}break x}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}v[22640]=0;Q(2,d+200|0,12260)|0;e=v[22640];v[22640]=0;if((e|0)!=1){break x}break e}v[22640]=0;Q(2,d+200|0,10641)|0;e=v[22640];v[22640]=0;if((e|0)==1){break e}}v[22640]=0;U(3,d+176|0,b|0,d+200|0);e=v[22640];v[22640]=0;if((e|0)==1){break f}Eb(a+1298328|0,d+176|0);vb(d+176|0);vb(d+200|0);vb(b);v[a+1298364>>2]=5;v[22640]=0;_e(d+216|0,3,d+232|0);b=v[22640];v[22640]=0;if((b|0)==1){break g}v[22640]=0;R(377,d+176|0,d+216|0);b=v[22640];v[22640]=0;if((b|0)==1){break g}Eb(a+1298268|0,d+176|0);vb(d+176|0);v[22640]=0;Vj(d+200|0,3,d+264|0);b=v[22640];v[22640]=0;if((b|0)==1){break h}v[22640]=0;R(377,d+216|0,d+200|0);b=v[22640];v[22640]=0;if((b|0)==1){break h}v[22640]=0;U(13,d+176|0,5,d+216|0);b=v[22640];v[22640]=0;if((b|0)==1){break i}Eb(a+1298280|0,d+176|0);vb(d+176|0);vb(d+216|0);v[a+480200>>2]=w[d+288|0]+1;H=a,I=Jd(w[d+289|0],1,255),v[H+480196>>2]=I;H=a,I=B(Jd(w[d+290|0],4,255),1e4),v[H+480204>>2]=I;b=a+484360|0;e=Rb(b);g=w[d+284|0]|w[d+285|0]<<8;v[22640]=0;ga(540,e|0,d+328|0,g|0,65535,65535)|0;e=v[22640];v[22640]=0;if((e|0)==1){break w}af(Rb(b),w[d+286|0]|w[d+287|0]<<8);u[a+480188>>1]=0;b=0;while(1){v[22640]=0;e=(b<<5)+a|0;g=e+480280|0;Se(g);f=v[22640];v[22640]=0;if((f|0)==1){break j}f=b+d|0;h=w[f+291|0]<<1&254;u[e+480284>>1]=(h|0)==254?256:h;G:{if(t[f+291|0]<=-1){v[g>>2]=v[g>>2]|1024;break G}u[a+480188>>1]=b+1}v[22640]=0;R(690,d+328|0,e+480289|0);e=v[22640];v[22640]=0;if((e|0)==1){break j}b=b+1|0;if((b|0)!=32){continue}break}v[22640]=0;U(687,d+176|0,d+352|0,17741);b=v[22640];v[22640]=0;if((b|0)==1){break k}od(d+328|0,d+176|0);yb(d+176|0);v[22640]=0;b=T(232,d+328|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break w}v[22640]=0;ca(532,a+1298292|0,d+328|0,b|0,0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break w}v[22640]=0;U(687,d+176|0,d+352|0,21321);b=v[22640];v[22640]=0;if((b|0)==1){break l}od(d+328|0,d+176|0);yb(d+176|0);v[22640]=0;b=T(307,d+328|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break w}H:{if(b){v[22640]=0;U(687,d+176|0,d+352|0,16723);b=v[22640];v[22640]=0;if((b|0)==1){break m}v[22640]=0;l=T(353,d+328|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break n}I:{if(!l){break I}j=c&2;g=0;while(1){v[22640]=0;e=T(353,d+328|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break n}if(!e){break I}v[22640]=0;b=Q(228,d+328|0,56)|0;f=v[22640];v[22640]=0;if((f|0)==1){break n}if(!b){break I}if(e>>>0>x[a+480190>>1]){u[a+480190>>1]=e}v[22640]=0;b=B(e,104)+a|0;f=b+484380|0;R(352,f|0,0);h=v[22640];v[22640]=0;if((h|0)==1){break n}v[22640]=0;W(499,d+328|0,((e<<5)+a|0)+946304|0,32)|0;e=v[22640];v[22640]=0;if((e|0)==1){break n}v[22640]=0;W(502,d+328|0,b+484423|0,8)|0;e=v[22640];v[22640]=0;if((e|0)==1){break n}J:{if(w[d+396|0]<=15){v[22640]=0;e=T(319,d+328|0)|0;h=v[22640];v[22640]=0;if((h|0)!=1){break J}break n}v[22640]=0;e=T(229,d+328|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break n}}v[b+484404>>2]=e<<1;v[22640]=0;e=T(229,d+328|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break n}v[f>>2]=e;v[22640]=0;h=T(229,d+328|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break n}e=b+484384|0;v[e>>2]=h;v[22640]=0;h=T(229,d+328|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break n}k=b+484388|0;v[k>>2]=h;if(h){i=b+484414|0;u[i>>1]=x[i>>1]|2;v[k>>2]=h+v[e>>2]}v[22640]=0;h=T(353,d+328|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break H}if(w[d+396|0]<=15){u[b+484410>>1]=h}v[22640]=0;h=T(353,d+328|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break n}m=b+484414|0;b=x[m>>1];i=8;if(h&1){b=b|1;u[m>>1]=b;v[f>>2]=v[f>>2]>>>1;v[e>>2]=v[e>>2]>>>1;v[k>>2]=v[k>>2]>>>1;i=16}u[m>>1]=b&65531|h<<1&4;b=Pc(d+216|0,i,1,0,((h&12)!=0)<<3);K:{if(!j){break K}v[22640]=0;W(363,b|0,f|0,d+176|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break K}break n}g=g+1|0;if(l>>>0>(g&255)>>>0){continue}break}}yb(d+176|0)}v[22640]=0;U(687,d+176|0,d+352|0,18761);b=v[22640];v[22640]=0;if((b|0)==1){break p}od(d+328|0,d+176|0);yb(d+176|0);v[22640]=0;b=T(307,d+328|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break w}if(b){l=ad(d+216|0);i=ad(d+200|0);m=ad(d+160|0);v[22640]=0;U(687,d+136|0,d+352|0,17750);b=v[22640];v[22640]=0;if((b|0)==1){break o}b=v[d+148>>2];v[d+56>>2]=v[d+144>>2];v[d+60>>2]=b;v[d- -64>>2]=v[d+152>>2];v[22640]=0;b=v[d+140>>2];v[d+48>>2]=v[d+136>>2];v[d+52>>2]=b;R(691,d+48|0,l|0);b=v[22640];v[22640]=0;if((b|0)==1){break o}v[22640]=0;U(687,d+112|0,d+352|0,17744);b=v[22640];v[22640]=0;if((b|0)==1){break o}b=v[d+124>>2];v[d+32>>2]=v[d+120>>2];v[d+36>>2]=b;v[d+40>>2]=v[d+128>>2];v[22640]=0;b=v[d+116>>2];v[d+24>>2]=v[d+112>>2];v[d+28>>2]=b;R(691,d+24|0,i|0);b=v[22640];v[22640]=0;if((b|0)==1){break o}v[22640]=0;U(687,d+88|0,d+352|0,17734);b=v[22640];v[22640]=0;if((b|0)==1){break o}b=v[d+100>>2];v[d+8>>2]=v[d+96>>2];v[d+12>>2]=b;v[d+16>>2]=v[d+104>>2];v[22640]=0;b=v[d+92>>2];v[d>>2]=v[d+88>>2];v[d+4>>2]=b;R(691,d|0,m|0);b=v[22640];v[22640]=0;if((b|0)==1){break o}k=0;v[22640]=0;o=T(353,d+328|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break o}if(o){y=d+176|4;z=d+176|2;q=d+176|6;r=d+176|5;s=d+176|3;e=d+176|1;while(1){v[22640]=0;R(431,d+72|0,d+328|0);b=v[22640];v[22640]=0;if((b|0)==1){break o}j=md(d+72|0);L:{M:{b=d+72|0;N:{if(!w[b|0]){break N}g=w[j|0];v[22640]=0;g=Q(228,d+328|0,B(g,14)+32|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break o}if(!g){break N}b=w[b|0];v[22640]=0;h=W(415,a|0,b|0,0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break o}if(h){break M}}b=w[j|0];v[22640]=0;Q(350,d+328|0,B(b,14)+32|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break L}break o}v[22640]=0;W(499,d+328|0,h+492|0,32)|0;b=v[22640];v[22640]=0;if((b|0)==1){break o}if(!w[j|0]){break L}C=h+88|0;D=h+68|0;E=h+48|0;F=h+236|0;f=0;b=0;while(1){v[22640]=0;R(692,d+328|0,d+176|0);g=v[22640];v[22640]=0;if((g|0)==1){break o}O:{if(!w[d+176|0]|x[a+480190>>1]<w[d+176|0]){break O}g=e;if(w[e|0]>128){t[g|0]=128}if(w[e|0]>=(b&255)>>>0){while(1){g=w[d+176|0];H=sd(F,b&255),I=g,u[H>>1]=I;b=b+1|0;if(w[e|0]>=(b&255)>>>0){continue}break}}G=w[e|0];b=w[s|0];v[22640]=0;U(693,E|0,b|0,l|0);b=v[22640];v[22640]=0;if((b|0)==1){break o}b=w[r|0];v[22640]=0;U(693,D|0,b|0,i|0);b=v[22640];v[22640]=0;if((b|0)==1){break o}b=w[d+189|0];v[22640]=0;U(693,C|0,b|0,m|0);b=v[22640];v[22640]=0;if((b|0)==1){break o}v[h>>2]=(w[q|0]|w[q+1|0]<<8)+1>>>1;b=w[d+176|0];P:{if(w[s|0]&64){u[(B(b,104)+a|0)+484410>>1]=w[z|0];break P}g=(B(b,104)+a|0)+484414|0;u[g>>1]=x[g>>1]|32768}u[d+86>>1]=w[y|0]<<1;v[22640]=0;u[d+84>>1]=254;n=Oc(d+86|0,d+84|0);g=v[22640];v[22640]=0;Q:{R:{if((g|0)!=1){g=B(b,104)+a|0;u[g+484408>>1]=x[n>>1];t[g+484418|0]=w[(w[d+187|0]&3)+29253|0];n=g+484419|0;t[n|0]=w[d+186|0];p=g+484420|0;t[p|0]=w[d+185|0]+3>>>2;t[g+484421|0]=w[d+184|0];b=w[n|0];if(b){break R}p=255;break Q}break o}p=dm(Uc((((w[p|0]<<8|b>>>1)&65407)>>>0)/(b>>>0)|0,0))}b=G+1|0;t[n|0]=p;if(!(w[r|0]&64)){break O}g=g+484414|0;u[g>>1]=x[g>>1]|32}f=f+1|0;if(w[j|0]>(f&255)>>>0){continue}break}}k=k+1|0;if(o>>>0>(k&255)>>>0){continue}break}}bp(m);bp(i);bp(l)}p=1;l=nc(d+216|0);if(!(c&1)){break s}v[22640]=0;U(687,d+176|0,d+352|0,21076);b=v[22640];v[22640]=0;S:{T:{U:{if((b|0)!=1){b=od(d+328|0,d+176|0);v[22640]=0;b=T(307,b|0)|0;c=v[22640];v[22640]=0;V:{W:{X:{Y:{Z:{_:{if((c|0)!=1){yb(d+176|0);$:{if(!b){break $}v[22640]=0;c=T(319,d+328|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break _}v[22640]=0;R(694,l|0,c+1|0);b=v[22640];v[22640]=0;if((b|0)==1){break _}if(!c){break $}b=1;while(1){v[22640]=0;e=T(319,d+328|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break Z}v[22640]=0;U(320,d+176|0,d+328|0,e|0);e=v[22640];v[22640]=0;if((e|0)==1){break Z}od(Hg(l,b),d+176|0);e=(b|0)==(c|0);yb(d+176|0);b=b+1|0;if(!e){continue}break}}v[22640]=0;U(687,d+176|0,d+352|0,16720);b=v[22640];v[22640]=0;if((b|0)==1){break Y}b=od(d+328|0,d+176|0);v[22640]=0;b=T(307,b|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break X}yb(d+176|0);if(!b){break V}f=0;v[22640]=0;m=T(353,d+328|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break u}if(m){while(1){j=32;aa:{if(w[d+396|0]>=16){v[22640]=0;R(695,d+328|0,d+176|0);b=v[22640];v[22640]=0;if((b|0)==1){break U}if(!(w[d+176|0]>32|x[a+480188>>1]>=w[d+176|0])){u[a+480188>>1]=w[d+176|0]}j=w[d+176|0];if(!j){break aa}}b=0;while(1){v[22640]=0;e=T(319,d+328|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break T}c=b;b=b+1|0;if(!(!e|x[a+480188>>1]>(c&65535)>>>0)){u[a+480188>>1]=b}if((b&65535)>>>0<j>>>0){continue}break}}f=f+1|0;if(m>>>0>(f&65535)>>>0){continue}break}}v[22640]=0;Q(227,d+328|0,1)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break W}break u}e=P()|0;O()|0;yb(d+176|0);break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;yb(d+176|0);break t}v[22640]=0;o=a+484344|0;R(364,o|0,m|0);b=v[22640];v[22640]=0;if((b|0)==1){break u}if(!m){break V}C=d+176|2;D=d+176|1;g=0;while(1){q=Kb(d+200|0);r=64;s=32;if(w[d+396|0]>=16){v[22640]=0;R(695,d+328|0,d+176|0);b=v[22640];v[22640]=0;if((b|0)==1){break v}s=w[d+176|0];b=w[D|0];v[22640]=0;AW(d+72|0,3,C);c=v[22640];v[22640]=0;if((c|0)==1){break v}v[22640]=0;R(377,d+160|0,d+72|0);c=v[22640];v[22640]=0;if((c|0)==1){break v}Eb(q,d+160|0);vb(d+160|0);r=b+1|0}v[22640]=0;b=W(365,o|0,g&65535,r|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break v}ba:{if(!b){v[22640]=0;Q(350,d+328|0,s<<1)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break ba}break v}b=_b(o,g);v[22640]=0;Q(455,b|0,q|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break v}k=0;if(!s){break ba}while(1){v[22640]=0;b=T(319,d+328|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break v}ca:{if(!b){break ca}if(Ze(l)>>>0<=b>>>0){break ca}n=k&65535;if(n>>>0>=x[a+480188>>1]){break ca}h=Hg(l,b);vc(h);c=0;while(1){v[22640]=0;b=Q(228,h|0,1)|0;e=v[22640];v[22640]=0;da:{ea:{fa:{ga:{ha:{ia:{if((e|0)!=1){if(!b){break ca}b=_b(o,g);v[22640]=0;b=Tc(b,c,n);e=v[22640];v[22640]=0;if((e|0)==1){break v}v[22640]=0;f=T(353,h|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break v}e=f>>>2|0;switch((f&3)-1|0){case 2:break fa;case 1:break ga;case 0:break ha;default:break ia}}break v}c=(c+e|0)+1|0;break da}if(!c){c=0;break da}f=_b(o,g);v[22640]=0;f=Tc(f,c-1|0,n);i=v[22640];v[22640]=0;if((i|0)!=1){while(1){i=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[b|0]=i;t[b+1|0]=i>>>8;t[b+2|0]=i>>>16;t[b+3|0]=i>>>24;i=w[f+4|0]|w[f+5|0]<<8;t[b+4|0]=i;t[b+5|0]=i>>>8;c=c+1|0;if(r>>>0<=c>>>0){break da}b=B(x[a+480188>>1],6)+b|0;i=e&255;e=e-1|0;if(i){continue}break da}}break v}if(c>>>0<=e>>>0){break ea}f=_b(o,g);v[22640]=0;e=Tc(f,e,n);f=v[22640];v[22640]=0;if((f|0)==1){break S}f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;e=w[e+4|0]|w[e+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;break ea}if(e&1){v[22640]=0;f=T(353,h|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break S}t[b|0]=f>>>0>120?-1:f}if(e&2){v[22640]=0;f=T(353,h|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break S}t[b+1|0]=f}j=0;f=0;if(e&4){v[22640]=0;f=T(353,h|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break v}}y=0;if(e&8){v[22640]=0;i=T(353,h|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break v}y=i>>>4|0;j=i&15}z=0;i=0;if(e&16){v[22640]=0;i=T(353,h|0)|0;E=v[22640];v[22640]=0;if((E|0)==1){break v}}if(e&32){v[22640]=0;z=T(353,h|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break v}}v[22640]=0;zW(b,f,j,y,i,z);b=v[22640];v[22640]=0;if((b|0)==1){break v}}c=c+1|0}if(c>>>0<r>>>0){continue}break}}k=k+1|0;if((k&65535)>>>0<s>>>0){continue}break}}vb(q);g=g+1|0;if((m|0)!=(g|0)){continue}break}}v[22640]=0;U(687,d+176|0,d+352|0,20048);b=v[22640];v[22640]=0;ja:{ka:{la:{if((b|0)!=1){b=od(d+328|0,d+176|0);v[22640]=0;b=T(307,b|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break la}yb(d+176|0);if(!b){break s}a=a+484344|0;if(!Oe(a)){break s}while(1){v[22640]=0;b=Q(228,d+328|0,16)|0;c=v[22640];v[22640]=0;if((c|0)==1){break ka}if(!b){break s}v[22640]=0;R(698,d+328|0,d+176|0);b=v[22640];v[22640]=0;if((b|0)==1){break ja}b=_b(a,0);v[22640]=0;R(699,b|0,d+176|0);b=v[22640];v[22640]=0;if((b|0)==1){break ja}if(Oe(a)){continue}break}break s}e=P()|0;O()|0;break t}e=P()|0;O()|0;yb(d+176|0);break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}e=P()|0;O()|0;break t}break v}break n}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(q);break t}e=P()|0;O()|0}fd(l);break c}fd(l)}yb(d+328|0);Cd(d+352|0);yb(A)}gb=d+400|0;return p|0}e=P()|0;O()|0;break c}e=P()|0;O()|0;bp(m);bp(i);bp(l);break c}e=P()|0;O()|0;yb(d+176|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+216|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+200|0);break d}e=P()|0;O()|0}vb(b)}yb(d+328|0)}Cd(d+352|0)}yb(A);S(e|0);L()}function Rja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;d=gb-496|0;gb=d;vc(b);g=d+416|0;f=dW(b,g);if(!f){bW(g)}a:{if(!f){break a}if(!iT(d+416|0)){break a}if(!Pb(b,Uc(hT(d+416|0),jb))){break a}b:{if(!c){break b}Gd(a,4);wg(a);t[a+1074368|0]=4;l=Kb(d+400|0);c:{d:{j=d+454|0;e:{if(!(yd(j,14859,20)|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24))!=276)){e=48;if((w[d+474|0]|w[d+475|0]<<8)>>>0<260){break e}v[22640]=0;g=qv(d+433|0,0,20);e=v[22640];v[22640]=0;if((e|0)==1){break d}e=g?1154:34;break e}if(!yd(j,14838,20)){e=1;break e}v[22640]=0;Vj(d+384|0,3,j);g=v[22640];v[22640]=0;f:{g:{h:{if((g|0)==1){break h}v[22640]=0;R(377,d+40|0,d+384|0);g=v[22640];v[22640]=0;if((g|0)==1){break h}v[22640]=0;U(13,d+112|0,5,d+40|0);g=v[22640];v[22640]=0;if((g|0)==1){break g}Eb(l,d+112|0);vb(d+112|0);vb(d+40|0);if((w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24))!=1852141647|(w[j+4|0]|w[j+5|0]<<8|(w[j+6|0]<<16|w[j+7|0]<<24))!=542396493){break f}e=1048;break e}c=P()|0;O()|0;break c}c=P()|0;O()|0;vb(d+40|0);break c}if(!yd(j,14586,12)){e=16;if((x[d+466>>1]|x[d+468>>1]<<16)==538976288&(x[d+470>>1]|x[d+472>>1]<<16)==538976288){break e}t[a+1074368|0]=5;break e}if(!yd(j,8961,20)){e=48;break e}if(!yd(j,33776,15)){v[22640]=0;g=a+1074312|0;Q(438,g|0,54)|0;e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;Q(438,g|0,51)|0;g=v[22640];v[22640]=0;e=16;if((g|0)==1){break d}break e}if(!yd(j,33792,14)){v[22640]=0;Q(438,a+1074312|0,57)|0;g=v[22640];v[22640]=0;e=16;if((g|0)!=1){break e}break d}e=yd(j,14674,11)?16:256}v[22640]=0;s=d+433|0;Vj(d+40|0,3,s);g=v[22640];v[22640]=0;i:{if((g|0)==1){break i}v[22640]=0;R(377,d+112|0,d+40|0);g=v[22640];v[22640]=0;if((g|0)==1){break i}Eb(a+1298268|0,d+112|0);vb(d+112|0);v[a+480260>>2]=1;v[a+480264>>2]=31999;q=a+484360|0;af(Rb(q),w[d+482|0]|w[d+483|0]<<8);u[a+480188>>1]=w[d+484|0]|w[d+485|0]<<8;u[d+112>>1]=w[d+488|0]|w[d+489|0]<<8;v[22640]=0;u[d+40>>1]=255;g=Oc(d+112|0,d+40|0);f=v[22640];v[22640]=0;if((f|0)!=1){u[a+480192>>1]=x[g>>1];if(w[d+492|0]|w[d+493|0]<<8){v[a+480196>>2]=w[d+492|0]|w[d+493|0]<<8}if(w[d+494|0]|w[d+495|0]<<8){g=B(w[d+494|0]|w[d+495|0]<<8,1e4);v[a+480204>>2]=g>>>0>=32e4?g>>>0>1e7?1e7:g:32e4}v[a+480208>>2]=0;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+490|0]|w[d+491|0]<<8)<<4&16;g=(w[d+490|0]|w[d+491|0]<<8)<<3&32768;v[a+480208>>2]=g|v[a+480208>>2]&-32769;f=Rb(q);m=w[d+480|0]|w[d+481|0]<<8;v[22640]=0;ga(540,f|0,b|0,m|0,65535,65535)|0;f=v[22640];v[22640]=0;if((f|0)==1){break d}f=g>>>15|0?(e|0)==34?146:e:e;if(!(f&1024|(w[d+480|0]|w[d+481|0]<<8))){g=Rb(q);v[22640]=0;U(967,g|0,1,0);g=v[22640];v[22640]=0;if((g|0)==1){break d}}g=w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24);v[22640]=0;Q(227,b|0,g+60|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break d}if((w[d+474|0]|w[d+475|0]<<8)>>>0>=260){v[22640]=0;U(968,b|0,d+416|0,a|0);g=v[22640];v[22640]=0;if((g|0)==1){break d}}t[d+383|0]=0;p=c&2;m=nc(d+384|0);j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if(x[a+480192>>1]){C=d+58|0;D=d+145|0;e=1;g=-1;i=1;D:{while(1){v[22640]=0;k=T(229,b|0)|0;h=v[22640];v[22640]=0;E:{F:{G:{H:{I:{J:{if((h|0)!=1){lg(b,4);v[22640]=0;U(969,b|0,d+112|0,(k?k:263)|0);k=v[22640];v[22640]=0;if((k|0)==1){break D}K:{if((f|0)==1){if((w[d+112|0]|w[d+113|0]<<8|(w[d+114|0]<<16|w[d+115|0]<<24))==245){v[a+1074308>>2]=16777381;v[22640]=0;f=Q(2,d+40|0,10728)|0;k=v[22640];v[22640]=0;if((k|0)!=1){Eb(l,f);vb(f);f=17;break K}c=P()|0;O()|0;break j}f=16;if((w[d+112|0]|w[d+113|0]<<8|(w[d+114|0]<<16|w[d+115|0]<<24))!=263){break K}v[a+1074308>>2]=16777395;v[22640]=0;f=Q(2,d+40|0,10652)|0;k=v[22640];v[22640]=0;if((k|0)!=1){Eb(l,f);vb(f);f=17;break K}c=P()|0;O()|0;break j}if(w[d+139|0]|w[d+140|0]<<8){break K}if(!(!(f&2)|(w[d+141|0]|w[d+142|0]<<8|(w[d+143|0]<<16|w[d+144|0]<<24))|(w[d+112|0]|w[d+113|0]<<8|(w[d+114|0]<<16|w[d+115|0]<<24))!=263)){f=f|16;break K}if(!(!(f&256)|(w[d+112|0]|w[d+113|0]<<8|(w[d+114|0]<<16|w[d+115|0]<<24))==29)){f=f&-257;break K}if(!(f&160)){break K}f=(w[d+112|0]|w[d+113|0]<<8|(w[d+114|0]<<16|w[d+115|0]<<24))==33?f:0}v[22640]=0;k=W(415,a|0,i&65535,0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break D}if(!k){break E}k=((e<<2)+a|0)+900380|0;e=v[k>>2];v[22640]=0;R(970,d+112|0,e|0);e=v[22640];v[22640]=0;if((e|0)==1){break D}e=w[d+138|0];L:{if((g|0)==-1){g=e;break L}if(!(f&32)|(e|0)==(g|0)){break L}f=f&-161|128}if(!(w[d+139|0]|w[d+140|0]<<8)){break E}e=w[d+353|0];h=w[d+354|0];o=w[d+355|0]|w[d+356|0]<<8;n=w[d+359|0];r=w[d+139|0]|w[d+140|0]<<8;v[22640]=0;U(971,d+96|0,a|0,r|0);r=v[22640];v[22640]=0;if((r|0)==1){break J}f=n|(o|(e|h))?f&-4:f;e=12;while(1){h=x[sd(v[k>>2]+236|0,e)>>1];if(sc(d+96|0)>>>0>h>>>0){h=x[rc(d+96|0,x[sd(v[k>>2]+236|0,e)>>1])>>1];E=sd(v[k>>2]+236|0,e),F=h,u[E>>1]=F}e=e+1|0;if((e|0)!=108){continue}break}if((w[d+474|0]|w[d+475|0]<<8)>>>0>259){Nb(m);Dq(m);gw(m)}e=w[d+139|0]|w[d+140|0]<<8;v[22640]=0;k=Q(972,d+80|0,e|0)|0;e=v[22640];v[22640]=0;M:{if((e|0)!=1){e=0;if(w[d+139|0]|w[d+140|0]<<8){break M}break I}c=P()|0;O()|0;break G}N:{O:{P:{Q:{while(1){v[22640]=0;Q(973,b|0,d+40|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break N}v[22640]=0;XN(d+24|0,d+40|0);h=v[22640];v[22640]=0;R:{if((h|0)==1){break R}v[22640]=0;R(975,m|0,d+24|0);h=v[22640];v[22640]=0;if((h|0)==1){break R}h=w[d+40|0]|w[d+41|0]<<8|(w[d+42|0]<<16|w[d+43|0]<<24);E=Mb(k,e),F=h,v[E>>2]=F;o=w[d+57|0];if(sc(d+96|0)>>>0>e>>>0){h=x[rc(d+96|0,e)>>1];v[22640]=0;n=(B(h,104)+a|0)+484380|0;R(976,d+40|0,n|0);r=v[22640];v[22640]=0;if((r|0)==1){break Q}v[22640]=0;ZN(D,n);n=v[22640];v[22640]=0;if((n|0)==1){break Q}v[22640]=0;Mk(d+8|0,3,C);n=v[22640];v[22640]=0;if((n|0)==1){break P}v[22640]=0;R(377,d+24|0,d+8|0);n=v[22640];v[22640]=0;if((n|0)==1){break P}v[22640]=0;Q(333,((h<<5)+a|0)+946304|0,d+24|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break O}vb(d+24|0);f=(w[d+54|0]&3)==3?(f&2)>>>1|0?f|4:f:f}z=o|z;e=e+1|0;if(e>>>0>=(w[d+139|0]|w[d+140|0]<<8)>>>0){break I}continue}break}c=P()|0;O()|0;break H}c=P()|0;O()|0;break H}c=P()|0;O()|0;break H}c=P()|0;O()|0;vb(d+24|0);break H}c=P()|0;O()|0;break H}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}if((w[d+474|0]|w[d+475|0]<<8)>>>0<260){break F}e=0;if(!(w[d+139|0]|w[d+140|0]<<8)){break F}S:{while(1){T:{o=w[Mb(m,e)+3|0];h=v[Mb(k,e)>>2];v[22640]=0;U(320,d+40|0,b|0,((o|0)==11?(h+1>>>1|0)+16|0:h)|0);h=v[22640];v[22640]=0;if((h|0)==1){break T}if(!(!p|sc(d+96|0)>>>0<=e>>>0)){o=x[rc(d+96|0,e)>>1];h=Mb(m,e);h=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);v[22640]=0;v[d+4>>2]=h;v[d>>2]=h;h=ca(978,(B(o,104)+a|0)+484380|0,d|0,d+40|0,d+383|0)|0;o=v[22640];v[22640]=0;if((o|0)==1){break S}A=h^1|A}yb(d+40|0);e=e+1|0;if(e>>>0<(w[d+139|0]|w[d+140|0]<<8)>>>0){continue}break F}break}c=P()|0;O()|0;break H}c=P()|0;O()|0;yb(d+40|0)}Lc(k)}Ue(d+96|0);break j}Lc(k);Ue(d+96|0)}i=i+1|0;e=i&65535;if(e>>>0<=x[a+480192>>1]){continue}break}k=!(z&255);break C}c=P()|0;O()|0;break j}g=-1;k=1}if(!(!k|!(f&2))){v[22640]=0;e=qv(s,0,20);i=v[22640];v[22640]=0;if((i|0)==1){break B}f=e?f|16:f}U:{if((w[d+474|0]|w[d+475|0]<<8)>>>0>259){break U}if(c&3){v[22640]=0;U(968,b|0,d+416|0,a|0);c=v[22640];v[22640]=0;if((c|0)==1){break B}}if(!p|!x[a+480190>>1]){break U}e=1;c=1;while(1){i=Mb(m,e-1|0);v[22640]=0;W(363,i|0,(B(e,104)+a|0)+484380|0,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break q}c=c+1|0;e=c&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}if(A&1){v[22640]=0;e=Q(2,d+112|0,13761)|0;c=v[22640];v[22640]=0;if((c|0)==1){break A}v[22640]=0;U(580,a|0,2,e|0);c=v[22640];v[22640]=0;if((c|0)==1){break z}vb(e)}v[22640]=0;c=Q(575,b|0,2650)|0;e=v[22640];v[22640]=0;if((e|0)==1){break B}if(c){v[22640]=0;c=T(229,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break B}v[22640]=0;ca(532,a+1298292|0,b|0,c|0,0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break B}f=f|16}v[22640]=0;c=Q(575,b|0,11434)|0;e=v[22640];v[22640]=0;if((e|0)==1){break k}if(c){v[22640]=0;e=T(229,b|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break k}v[22640]=0;i=a+901404|0;U(979,b|0,i|0,e|0);e=v[22640];v[22640]=0;if((e|0)==1){break k}v[22640]=0;Bu(i);e=v[22640];v[22640]=0;if((e|0)==1){break k}f=f|16}v[22640]=0;e=Q(575,b|0,11215)|0;i=v[22640];v[22640]=0;if((i|0)==1){break k}if(e){v[22640]=0;e=T(229,b|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break y}u[d+112>>1]=e>>>5;i=a+484344|0;e=Oe(i);v[22640]=0;u[d+40>>1]=e;e=Oc(d+112|0,d+40|0);h=v[22640];v[22640]=0;if((h|0)==1){break x}h=x[e>>1];if(h){e=0;while(1){v[22640]=0;W(783,b|0,d+112|0,32)|0;p=v[22640];v[22640]=0;if((p|0)==1){break w}p=_b(i,e);v[22640]=0;Q(784,p|0,d+112|0)|0;p=v[22640];v[22640]=0;if((p|0)==1){break w}e=e+1|0;if((h|0)!=(e|0)){continue}break}}f=f|16}v[22640]=0;e=Q(575,b|0,11220)|0;i=v[22640];v[22640]=0;if((i|0)==1){break k}if(e){v[22640]=0;e=T(229,b|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break v}u[d+112>>1]=(e>>>0)/20;e=x[a+480188>>1];v[22640]=0;u[d+40>>1]=e;e=Oc(d+112|0,d+40|0);i=v[22640];v[22640]=0;if((i|0)==1){break u}i=x[e>>1];if(i){e=0;while(1){v[22640]=0;W(591,b|0,((e<<5)+a|0)+480289|0,20)|0;h=v[22640];v[22640]=0;if((h|0)==1){break p}e=e+1|0;if((i|0)!=(e|0)){continue}break}}f=f|16}v[22640]=0;e=Q(228,b|0,8)|0;i=v[22640];v[22640]=0;if((i|0)==1){break k}if(e){e=v[b+8>>2];v[22640]=0;Q(592,a|0,b|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break o}f=(e|0)==v[b+8>>2]?f:f|16}if(!(f&16)){break r}if(!(f&4)){break s}v[a+1074308>>2]=17367040;v[22640]=0;e=Q(2,d+112|0,11937)|0;i=v[22640];v[22640]=0;if((i|0)==1){break t}Eb(l,e);vb(e);break r}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;vb(e);break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}if(!(f&2)){break r}v[a+1074308>>2]=18219008;v[22640]=0;e=Q(2,d+112|0,12063)|0;i=v[22640];v[22640]=0;if((i|0)==1){break n}Eb(l,e);vb(e)}V:{W:{X:{Y:{Z:{_:{$:{if((w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24))==1852141647&(w[j+4|0]|w[j+5|0]<<8|(w[j+6|0]<<16|w[j+7|0]<<24))==542396493){v[22640]=0;e=Q(980,d+112|0,d+462|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break $}v[22640]=0;U(13,d+40|0,1,e|0);f=v[22640];v[22640]=0;if((f|0)==1){break _}v[22640]=0;f=T(981,d+40|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break Z}v[a+1074308>>2]=f;vb(d+40|0);t[a+1074368|0]=y[a+1074308>>2]<19007257?4:5;vb(e);f=24}if(!(!v[a+1074308>>2]|f&8)){t[a+1074368|0]=0;ov(a+1074312|0)}e=f&32;aa:{if(!e){break aa}t[a+1074368|0]=5;if(!c){v[22640]=0;To(a+901404|0);c=v[22640];v[22640]=0;if((c|0)==1){break k}}if((w[d+474|0]|w[d+475|0]<<8)>>>0<260){break aa}v[22640]=0;W(437,a+1074312|0,4,1)|0;c=v[22640];v[22640]=0;if((c|0)==1){break k}}if(!dd(l)){break V}if(!(k&f>>>8)|g+1>>>0>1){break W}v[22640]=0;c=Q(2,d+112|0,5505)|0;g=v[22640];v[22640]=0;if((g|0)==1){break X}Eb(l,c);vb(c);break V}c=P()|0;O()|0;break j}c=P()|0;O()|0;break Y}c=P()|0;O()|0;vb(d+40|0)}vb(e);break j}c=P()|0;O()|0;break j}if(e){v[22640]=0;c=Q(2,d+112|0,9373)|0;g=v[22640];v[22640]=0;if((g|0)!=1){Eb(l,c);vb(c);break V}c=P()|0;O()|0;break j}v[22640]=0;c=Q(2,d+112|0,6910)|0;g=v[22640];v[22640]=0;if((g|0)==1){break m}Eb(l,c);vb(c)}t[d+8|0]=0;ba:{if(x[a+480192>>1]){v[22640]=0;c=Q(608,a|0,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break ba}t[d+8|0]=c}v[22640]=0;Y(609,a|0,b|0,1,d+8|0);b=v[22640];v[22640]=0;if((b|0)==1){break ba}c=a+1074308|0;e=v[c>>2];ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{if(w[d+8|0]){if(e>>>0>18284543){break pa}v[a+1074308>>2]=18284544;break pa}if(e>>>0<18284544){break oa}}v[22640]=0;b=Q(2,d+40|0,14686)|0;g=v[22640];v[22640]=0;if((g|0)==1){break na}v[22640]=0;R(982,d+96|0,c|0);g=v[22640];v[22640]=0;if((g|0)==1){break ma}v[22640]=0;U(3,d+112|0,b|0,d+96|0);g=v[22640];v[22640]=0;if((g|0)==1){break la}Eb(l,d+112|0);vb(d+112|0);vb(d+96|0);vb(b);e=v[c>>2]}qa:{if(e-1>>>0>19005952){break qa}v[22640]=0;b=a+484344|0;c=ke(b,254);g=v[22640];v[22640]=0;if((g|0)==1){break ba}if(!c){c=Rb(q);v[22640]=0;R(983,c|0,254);c=v[22640];v[22640]=0;if((c|0)==1){break ba}}v[22640]=0;b=ke(b,255);c=v[22640];v[22640]=0;if((c|0)==1){break ba}if(b){break qa}b=Rb(q);v[22640]=0;c=v[22640];v[22640]=0;if((c|0)==1){break ba}v[22640]=0;Zu(b,255,65535);b=v[22640];v[22640]=0;if((b|0)==1){break ba}}if(!w[d+383|0]){break ca}v[22640]=0;b=Q(2,d+112|0,12439)|0;c=v[22640];v[22640]=0;if((c|0)==1){break ja}Eb(a+1298304|0,b);vb(b);v[22640]=0;b=Q(2,d+112|0,7427)|0;c=v[22640];v[22640]=0;if((c|0)==1){break ia}Eb(a+1298316|0,b);vb(b);v[22640]=0;R(985,d+40|0,1211);b=v[22640];v[22640]=0;if((b|0)==1){break ha}v[d+80>>2]=w[d+475|0];b=w[d+474|0];v[22640]=0;v[d+24>>2]=b;R(619,d+96|0,d+24|0);b=v[22640];v[22640]=0;if((b|0)==1){break ga}v[22640]=0;Y(602,d+112|0,d+40|0,d+80|0,d+96|0);b=v[22640];v[22640]=0;if((b|0)==1){break fa}Eb(a+1298340|0,d+112|0);vb(d+112|0);vb(d+96|0);Hb(d+40|0);v[22640]=0;b=Q(2,d+112|0,7428)|0;c=v[22640];v[22640]=0;if((c|0)==1){break da}Eb(a+1298352|0,b);break l}c=P()|0;O()|0;break j}c=P()|0;O()|0;break ka}c=P()|0;O()|0;vb(d+96|0)}vb(b);break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break ea}c=P()|0;O()|0;vb(d+96|0)}Hb(d+40|0);break j}c=P()|0;O()|0;break j}v[22640]=0;R(985,d+40|0,1211);b=v[22640];v[22640]=0;ra:{sa:{ta:{ua:{if((b|0)!=1){v[d+80>>2]=w[d+475|0];b=w[d+474|0];v[22640]=0;v[d+24>>2]=b;R(619,d+96|0,d+24|0);b=v[22640];v[22640]=0;if((b|0)==1){break ua}v[22640]=0;Y(602,d+112|0,d+40|0,d+80|0,d+96|0);b=v[22640];v[22640]=0;if((b|0)==1){break ta}Eb(a+1298304|0,d+112|0);vb(d+112|0);vb(d+96|0);Hb(d+40|0);v[22640]=0;b=Q(2,d+112|0,7428)|0;c=v[22640];v[22640]=0;if((c|0)==1){break ra}Eb(a+1298316|0,b);break l}c=P()|0;O()|0;break j}c=P()|0;O()|0;break sa}c=P()|0;O()|0;vb(d+96|0)}Hb(d+40|0);break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}vb(b);Eb(a+1298328|0,l);v[a+1298364>>2]=v[a+1074308>>2]?8:5;bi(m);vb(l);break b}c=P()|0;O()|0}bi(m);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0}vb(l);S(c|0);L()}e=1}gb=d+496|0;return e|0}function wJ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,O=0,P=0;K=gb-144|0;gb=K;k=v[f>>2];N=g&4;M=N?-1:k+((d^-1)+e|0)|0;C=M+1|0;a:{b:{if(d>>>0<=e>>>0?C&M:1){v[f>>2]=0;v[c>>2]=0;l=-3;break b}D=e+k|0;r=v[c>>2];s=r+b|0;E=v[a+60>>2];q=v[a+40>>2];k=v[a+36>>2];A=v[a+32>>2];m=v[a+56>>2];i=v[a+4>>2];j=b;p=e;l=-1;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{switch(v[a>>2]){case 37:v[a>>2]=37;break c;case 21:v[a>>2]=21;break c;case 17:v[a>>2]=17;break c;case 35:v[a>>2]=35;break c;case 10:v[a>>2]=10;break c;case 39:v[a>>2]=39;break c;case 36:v[a>>2]=36;break c;case 34:break h;case 42:break k;case 41:break l;case 53:break m;case 52:break n;case 51:break o;case 38:break p;case 27:break q;case 26:break r;case 25:break s;case 24:break t;case 23:break u;case 18:break v;case 16:break w;case 14:break x;case 11:break y;case 9:break z;case 7:break A;case 6:break B;case 3:break C;case 32:break D;case 5:break E;case 2:break G;case 1:break H;case 0:break I;default:break c}}v[a+28>>2]=1;m=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=1;q=0;k=0;A=0;i=0;if(g&1){break H}break F}l=1;if((r|0)<1){break d}v[a+8>>2]=w[b|0];j=b+1|0}l=2;if(j>>>0>=s>>>0){break d}n=w[j|0];v[a+12>>2]=n;h=1;j=j+1|0;l=-1;z=36;k=v[a+8>>2];if(((n|k<<8)>>>0)%31|n&32){break e}n=k&15;if(!N){if((n|0)!=8){break e}n=256<<(k>>>4);if(n>>>0>32768){break e}k=0;if(n>>>0<=C>>>0){break F}break e}k=0;if((n|0)!=8){break e}}h=0;break j}if((r|0)<1){l=5;break d}O=i+8|0;j=b+1|0;m=w[b|0]<<i|m;h=2;break j}if((r|0)<1){l=32;break d}j=b+1|0;m=w[b|0]<<i|m;i=i+8|0;break i}h=1;break j}h=4;break j}h=3;break j}h=7;break j}h=9;break j}h=10;break j}h=11;break j}h=12;break j}h=13;break j}h=14;break j}h=15;break j}h=16;break j}h=17;break j}h=8;break j}h=5;break j}h=6;break j}h=18;break j}o=2;break f}o=1;break f}J:while(1){K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{switch(h|0){case 0:if(i>>>0>2){break xa}h=1;continue;case 17:break fa;case 16:break ga;case 15:break ha;case 14:break ia;case 13:break ja;case 12:break ka;case 11:break la;case 10:break ma;case 9:break na;case 8:break pa;case 7:break qa;case 6:break ra;case 5:break sa;case 4:break ua;case 3:break va;case 2:break wa;case 1:break ya;default:break ea}}l=3;while(1){if(j>>>0>=s>>>0){break d}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(i>>>0<3){continue}break}j=h}h=m&7;v[a+20>>2]=h;C=h>>>1|0;v[a+24>>2]=C;i=i-3|0;m=m>>>3|0;if(h>>>0>=2){break oa}O=i;break da}i=O&-8;m=m>>>(O&7)|0;k=0;h=0;break ba}if(j>>>0<s>>>0){break ta}l=7;break d}while(1){if(j>>>0>=s>>>0){l=6;break d}m=w[j|0]<<i|m;l=i>>>0>4294967287;n=j+1|0;j=n;h=i+8|0;i=h;if(l){continue}break}j=n;i=h;h=1;break ba}t[(a+k|0)+10528|0]=w[j|0];j=j+1|0;h=2;break ba}while(1){if(j>>>0>=s>>>0){l=51;break d}m=w[j|0]<<i|m;l=i>>>0>4294967287;n=j+1|0;j=n;h=i+8|0;i=h;if(l){continue}break}j=n;i=h;break N}if(p>>>0>=D>>>0){l=2;z=52;h=k;break e}t[p|0]=A;k=k-1|0;p=p+1|0;break O}if(p>>>0<D>>>0){break ca}l=2;z=9;h=k;break e}if(j>>>0<s>>>0){n=D-p|0;h=s-j|0;h=h>>>0>n>>>0?n:h;h=h>>>0<k>>>0?h:k;k=k-h|0;p=hc(p,j,h)+h|0;j=h+j|0;break M}l=38;break d}l=-1;z=10;n=0;h=k;za:{switch(C-1|0){case 0:break za;case 2:break e;default:break aa}}v[a+44>>2]=288;v[a+48>>2]=32;h=a+3552|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3560|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3568|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3576|0;v[h>>2]=84215045;v[h+4>>2]=84215045;Qb(a- -64|0,8,144);Qb(a+208|0,9,112);t[a+336|0]=7;t[a+337|0]=7;t[a+338|0]=7;t[a+339|0]=7;t[a+340|0]=7;t[a+341|0]=7;t[a+342|0]=7;t[a+343|0]=7;t[a+328|0]=7;t[a+329|0]=7;t[a+330|0]=7;t[a+331|0]=7;t[a+332|0]=7;t[a+333|0]=7;t[a+334|0]=7;t[a+335|0]=7;t[a+320|0]=7;t[a+321|0]=7;t[a+322|0]=7;t[a+323|0]=7;t[a+324|0]=7;t[a+325|0]=7;t[a+326|0]=7;t[a+327|0]=7;t[a+344|0]=8;t[a+345|0]=8;t[a+346|0]=8;t[a+347|0]=8;t[a+348|0]=8;t[a+349|0]=8;t[a+350|0]=8;t[a+351|0]=8;F=1;break S}l=k+18674|0;while(1){if(j>>>0>=s>>>0){l=11;break d}m=w[j|0]<<i|m;n=j+1|0;j=n;h=i+8|0;i=h;G=t[l|0];if(h>>>0<G>>>0){continue}break}j=n;n=k;i=h;k=1;break U}while(1){if(j>>>0>=s>>>0){l=14;break d}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(i>>>0<3){continue}break}j=h;h=1;break T}if(j>>>0>=s>>>0){l=16;break d}m=w[j|0]<<i|m;j=j+1|0;i=i+8|0;if(i>>>0<15){break $}break _}while(1){if(j>>>0>=s>>>0){l=18;break d}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(q>>>0>i>>>0){continue}break}P=A-16|0;j=h;h=3;break R}if(j>>>0>=s>>>0){l=23;break d}m=w[j|0]<<i|m;j=j+1|0;i=i+8|0;if(i>>>0<15){break Z}break Y}if(p>>>0>=D>>>0){l=2;z=24;h=k;break e}t[p|0]=k;p=p+1|0;break Q}while(1){if(j>>>0>=s>>>0){l=25;break d}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(q>>>0>i>>>0){continue}break}j=h;h=3;break P}if(j>>>0>=s>>>0){l=26;break d}m=w[j|0]<<i|m;j=j+1|0;i=i+8|0;if(i>>>0<15){break X}break W}while(1){if(j>>>0>=s>>>0){l=27;break d}m=w[j|0]<<i|m;h=j+1|0;j=h;i=i+8|0;if(q>>>0>i>>>0){continue}break}j=h;h=6;break P}if(p>>>0>=D>>>0){l=2;z=53;h=k;break e}t[p|0]=w[(E-A&M)+d|0];p=p+1|0;E=E+1|0;break V}h=2;continue}h=8;continue}while(1){Aa:{Ba:{Ca:{Da:{Ea:{switch(h|0){case 0:if(k>>>0>3){break Da}if(!i){i=0;h=3;continue J}if(i>>>0>7){break Ba}h=4;continue J;case 1:t[(a+k|0)+10528|0]=m;i=i-8|0;m=m>>>8|0;break Aa;default:break Ea}}k=k+1|0;break Ca}h=x[a+10528>>1];if((h|0)==(x[a+10530>>1]^65535)){k=h;break O}l=-1;z=39;break e}h=0;continue}h=1;continue}h=2;continue}}k=0;break U}h=1;break R}h=2;break R}h=0;break P}h=1;break P}h=4;break P}h=5;break P}h=7;break P}while(1){Fa:{Ga:{Ha:{if(!k){if(n>>>0>2){break Ha}k=n;G=t[k+18674|0];if(G>>>0<=i>>>0){break Fa}h=9;continue J}k=n<<2;v[(k+a|0)+44>>2]=v[k+61476>>2]+((-1<<G^-1)&m);n=n+1|0;i=i-G|0;m=m>>>G|0;break Ga}k=0;Qb(a+7040|0,0,288);h=0;break T}k=0;continue}k=1;continue}}while(1){Ia:{Ja:{Ka:{if(!h){if(y[a+52>>2]<=k>>>0){break Ka}if(i>>>0>2){break Ia}h=10;continue J}t[(w[k+61456|0]+a|0)+7040|0]=m&7;k=k+1|0;i=i-3|0;m=m>>>3|0;break Ja}v[a+52>>2]=19;F=v[a+24>>2];break S}h=0;continue}h=1;continue}}h=0}while(1){La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{switch(h|0){case 0:h=0;if((F|0)<0){break Q}H=Qb(K,0,64);l=B(F,3488)+a|0;Qb(l+352|0,0,3200);r=v[a+24>>2];C=v[((r<<2)+a|0)+44>>2];if(C){while(1){n=(w[(h+l|0)- -64|0]<<2)+H|0;v[n>>2]=v[n>>2]+1;h=h+1|0;if((C|0)!=(h|0)){continue}break}}v[H+64>>2]=0;v[H+68>>2]=0;n=0;z=0;h=1;while(1){l=h<<2;h=h+1|0;l=v[l+H>>2];n=l+n<<1;v[(H- -64|0)+(h<<2)>>2]=n;z=l+z|0;if((h|0)!=16){continue}break};if(!((n|0)==65536|z>>>0<=1)){l=-1;z=35;h=k;break e}if(C){l=-1;I=0;J=B(F,3488)+a|0;while(1){r=w[(I+J|0)- -64|0];Wa:{if(!r){break Wa}n=(H- -64|0)+(r<<2)|0;h=v[n>>2];v[n>>2]=h+1;n=0;z=r;while(1){C=n;n=h&1|n<<1;h=h>>>1|0;z=z-1|0;if(z){continue}break}if(r>>>0<=10){if(n>>>0>1023){break Wa}C=1<<r;h=r<<9|I;while(1){u[((n<<1)+J|0)+352>>1]=h;n=n+C|0;if(n>>>0<1024){continue}break}break Wa}n=((n&1023)<<1)+J|0;h=u[n+352>>1];Xa:{if(h){n=l;l=h;break Xa}u[n+352>>1]=l;n=l-2|0}h=C>>>8&8388607;if(r>>>0>=12){while(1){h=h>>>1|0;C=(((h&1)+(l^-1)<<1)+J|0)+2400|0;l=u[C>>1];if(!l){u[C>>1]=n;l=n;n=n-2|0}r=r-1|0;if(r>>>0>11){continue}break}}u[(((h>>>1&1)+(l^-1)<<1)+J|0)+2400>>1]=I;l=n}I=I+1|0;r=v[a+24>>2];if(I>>>0<y[((r<<2)+a|0)+44>>2]){continue}break}}h=0;if((r|0)!=2){break Oa}break Sa;case 1:h=u[(((m&1023)<<1)+a|0)+7328>>1];Ya:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>i>>>0){break Ya}break Ra}if(i>>>0<11){break Ya}l=10;while(1){h=u[(((m>>>l&1)+(h^-1)<<1)+a|0)+9376>>1];if((h|0)<=-1){n=l+2|0;l=l+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>-1){break Ra}}h=11;continue J;case 2:l=u[(((m&1023)<<1)+a|0)+7328>>1];if((l|0)>=0){break Ua}h=10;while(1){n=m>>>h|0;h=h+1|0;l=u[(((n&1)+(l^-1)<<1)+a|0)+9376>>1];if((l|0)<0){continue}break};break Ta;default:break Va}}l=t[P+14892|0]+((-1<<q^-1)&m)|0;i=i-q|0;m=m>>>q|0;n=a+k|0;Qb(n+10532|0,(A|0)==16?w[n+10531|0]:0,l);h=l+k|0;break Sa}h=l>>9;l=l&511}i=i-h|0;m=m>>>h|0;A=l;if(l>>>0>15){break Qa}t[(a+k|0)+10532|0]=A;h=k+1|0}n=v[a+48>>2];l=v[a+44>>2];k=n+l|0;if(k>>>0<=h>>>0){break Pa}if(i>>>0<=14){if((s-j|0)<=1){k=h;h=1;continue}m=w[j|0]<<i|m|w[j+1|0]<<i+8;i=i+16|0;j=j+2|0}k=h}h=2;continue}if(!((A|0)!=16|k)){l=-1;h=0;z=17;A=16;break e}q=t[A+18649|0];if(q>>>0>i>>>0){break Na}P=A-16|0;break La}if((h|0)!=(k|0)){l=-1;z=21;break e}k=a+10532|0;hc(a- -64|0,k,l);hc(a+3552|0,l+k|0,n);r=v[a+24>>2];k=h}F=r-1|0;v[a+24>>2]=F;break Ma}h=12;continue J}h=0;continue}h=3;continue}}o=m;h=2}Za:while(1){_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{switch(h|0){case 0:h=u[(((m&1023)<<1)+a|0)+352>>1];nb:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>i>>>0){break nb}break _a}if(i>>>0<11){break nb}l=10;while(1){h=u[(((m>>>l&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<=-1){n=l+2|0;l=l+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>-1){break _a}}h=13;continue J;case 1:l=u[(((m&1023)<<1)+a|0)+352>>1];if((l|0)>=0){break lb}h=10;while(1){k=m>>>h|0;h=h+1|0;l=u[(((k&1)+(l^-1)<<1)+a|0)+2400>>1];if((l|0)<0){continue}break};k=l;break kb;case 3:break bb;case 4:break cb;case 5:break gb;case 6:break hb;case 2:break mb;default:break ib}}while(1){h=s-j|0;if(!((D-p|0)>1?(h|0)>=4:0)){if(i>>>0>14){m=o;break _a}if((h|0)<=1){m=o;h=0;continue Za}m=w[j|0]<<i|o|w[j+1|0]<<i+8;i=i+16|0;j=j+2|0;break _a}ob:{if(i>>>0>14){m=i;h=j;break ob}m=i+16|0;o=(w[j|0]|w[j+1|0]<<8)<<i|o;h=j+2|0}k=u[(((o&1023)<<1)+a|0)+352>>1];pb:{if((k|0)<0){j=10;while(1){i=o>>>j|0;j=j+1|0;k=u[(((i&1)+(k^-1)<<1)+a|0)+2400>>1];if((k|0)<0){continue}break}break pb}j=k>>9}i=m-j|0;m=o>>>j|0;if(k&256){j=h;break jb}if(!(i>>>0>14)){m=(w[h|0]|w[h+1|0]<<8)<<i|m;h=h+2|0;i=i+16|0}l=i;j=h;h=u[(((m&1023)<<1)+a|0)+352>>1];qb:{if((h|0)<0){o=10;while(1){i=m>>>o|0;o=o+1|0;h=u[(((i&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){continue}break}break qb}o=h>>9}t[p|0]=k;i=l-o|0;o=m>>>o|0;if(!(h&256)){t[p+1|0]=h;p=p+2|0;continue}break}p=p+1|0;m=o;k=h;break jb}h=l>>9;k=l&511}i=i-h|0;m=m>>>h|0;if(k>>>0>255){break jb}h=14;continue J}l=k&511;k=256;if((l|0)==256){break L}q=0;h=m;n=l<<2;k=v[n+59916>>2];r=k;if(l-265>>>0>19){break ab}q=v[n+60044>>2];if(q>>>0>i>>>0){h=15;continue J}h=3;continue}if(!k){o=m;k=-1;break eb}k=k-1|0;h=18;continue J}i=i-q|0;o=m>>>q|0;A=((-1<<q^-1)&m)+A|0;break fb}q=u[(((m&1023)<<1)+a|0)+3840>>1];rb:{if((q|0)<0){h=10;while(1){n=m>>>h|0;h=h+1|0;q=u[(((n&1)+(q^-1)<<1)+a|0)+5888>>1];if((q|0)<0){continue}break}n=q;break rb}h=q>>9;n=q&511}i=i-h|0;m=m>>>h|0;h=n<<2;A=v[h+61200>>2];q=0;if(n-4>>>0>25){o=m;break fb}q=v[h+61328>>2];if(q>>>0<=i>>>0){break db}h=17;continue J}E=p-d|0;if(!(!N|E>>>0>=A>>>0)){l=-1;z=37;m=o;h=k;break e}h=(E-A&M)+d|0;if((h>>>0<p>>>0?p:h)+k>>>0>D>>>0){m=o;h=7;continue}if(k>>>0>2){while(1){t[p|0]=w[h|0];t[p+1|0]=w[h+1|0];t[p+2|0]=w[h+2|0];h=h+3|0;p=p+3|0;k=k-3|0;if(k>>>0>2){continue}break}}if(!k){break eb}t[p|0]=w[h|0];if((k|0)!=1){t[p+1|0]=w[h+1|0]}p=k+p|0}h=2;continue}h=6;continue}h=u[(((m&1023)<<1)+a|0)+3840>>1];sb:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>i>>>0){break sb}break $a}if(i>>>0<11){break sb}l=10;while(1){h=u[(((m>>>l&1)+(h^-1)<<1)+a|0)+5888>>1];if((h|0)<=-1){n=l+2|0;l=l+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>-1){break $a}}h=16;continue J}i=i-q|0;h=m>>>q|0;r=((-1<<q^-1)&m)+k|0}k=r;m=h;if(i>>>0>14){break $a}if((s-j|0)<=1){h=4;continue}m=m|w[j|0]<<i|w[j+1|0]<<i+8;i=i+16|0;j=j+2|0}h=5;continue}h=1;continue}}if(!k|!i){break M}if(i>>>0>7){break N}h=5;continue}i=i-8|0;A=m&255;m=m>>>8|0;h=6;continue}if(k){break K}k=0}if(t[a+20|0]&1){break i}h=0;continue}h=7;continue}}o=i&-8;tb:{if(!o|b>>>0>=j>>>0){break tb}while(1){o=o-8|0;j=j-1|0;if(j>>>0<=b>>>0){break tb}if(o){continue}break}}if(o){break g}m=(((o&63)>>>0>=32?0:-1<<o)^-1)&m>>>(i&7);h=0;n=0;i=0;if(!(g&1)){break h}o=0;break f}v[a>>2]=34;l=0;break c}ba(3902,10546,2787,3912);L()}while(1){ub:{vb:{wb:{xb:{yb:{zb:{switch(o|0){case 0:if(h>>>0>3){l=0;z=34;i=n;break e}if(n){break yb}i=0;k=h;o=1;continue;case 1:break zb;default:break xb}}if(j>>>0<s>>>0){break vb}l=42;break d}k=h;i=n;if(i>>>0>7){break wb}o=2;continue}while(1){if(j>>>0>=s>>>0){l=41;break d}m=w[j|0]<<i|m;h=i>>>0>4294967287;d=j+1|0;j=d;n=i+8|0;i=n;if(h){continue}break}j=d;h=k}o=m&255;m=m>>>8|0;n=n-8|0;break ub}o=w[j|0];j=j+1|0;h=k;n=i}v[a+16>>2]=v[a+16>>2]<<8|o;h=h+1|0;o=0;continue}}v[a>>2]=z;Ab:{if(i>>>0<8|b>>>0>=j>>>0){break Ab}while(1){i=i-8|0;j=j-1|0;if(j>>>0<=b>>>0){break Ab}if(i>>>0>7){continue}break}}k=h;break c}v[a>>2]=l;l=g&2?1:-4}v[a+4>>2]=i;v[a+60>>2]=E;v[a+40>>2]=q;v[a+36>>2]=k;v[a+32>>2]=A;v[a+56>>2]=(((i&63)>>>0>=32?0:-1<<i)^-1)&m;v[c>>2]=j-b;c=p-e|0;v[f>>2]=c;if(!(g&9)|(l|0)<0){break b}b=v[a+28>>2];j=b>>>16|0;i=b&65535;if(c){o=(c>>>0)%5552|0;while(1){h=0;if(o>>>0>=8){m=8;while(1){p=w[e|0]+i|0;n=p+w[e+1|0]|0;h=n+w[e+2|0]|0;k=h+w[e+3|0]|0;f=k+w[e+4|0]|0;d=f+w[e+5|0]|0;b=d+w[e+6|0]|0;i=b+w[e+7|0]|0;j=i+(b+(d+(f+(k+(h+(n+(j+p|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;if(o>>>0>(m|7)>>>0){m=m+8|0;continue}break}h=o&8184}k=h;m=e;if(h>>>0<o>>>0){while(1){i=w[m|0]+i|0;j=j+i|0;m=m+1|0;k=k+1|0;if((o|0)!=(k|0)){continue}break}e=(o-h|0)+e|0}c=c-o|0;j=(j>>>0)%65521|0;i=(i>>>0)%65521|0;o=5552;if(c){continue}break}}b=j<<16|i;v[a+28>>2]=b;if(l){break b}l=0;if(g&1){break a}}gb=K+144|0;return l}gb=K+144|0;return v[a+16>>2]==(b|0)?0:-2}function m6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,A=0,D=0,E=0,F=0,G=C(0),H=0,I=0,J=C(0),K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=C(0),V=0,W=C(0),X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=C(0);A=gb-17168|0;gb=A;v[A+17164>>2]=0;a:{b:{c:{if(w[a+6152|0]!=255|(c|0)<5){break c}if(!fq(a+6152|0,b)){break c}h=ly(b,v[a+6148>>2])+eq(b)|0;v[A+17164>>2]=h;if((c|0)==(h|0)){h=c;break b}d:{if((h+4|0)<=(c|0)){if(fq(b,b+h|0)){break d}}v[A+17164>>2]=0;break c}if(h){break b}}k=b;o=Qb(a,0,6668)+6148|0;H=A+17164|0;f=c;e:{if((f|0)>=5){r=f-4|0;while(1){if(rJ(k)){s=ly(k,v[o>>2]);h=s+eq(k)|0;j=0;f:{g:{if(s){break g}i=4;y=l+4|0;while(1){if((r|0)<=((i<<1)+l|0)){break f}s=0;M=i+k|0;h:{if(!fq(k,M)){break h}D=i-eq(k)|0;m=eq(M)+D|0;if((f|0)<(m+(i+y|0)|0)){break h}if(!fq(k,m+M|0)){break h}v[o>>2]=D;s=D;h=i}j=!s;if(s){break g}D=i>>>0<2303;i=i+1|0;if(D){continue}break}}if((f|0)<(h+l|0)|j){break f}D=k;m=f-l|0;j=0;p=0;i:{while(1){i=j+D|0;j=(ly(i,s)+j|0)+eq(i)|0;i=(p|0)!=0;if((m|0)<(j+4|0)){break i}i=0;if(!fq(D,j+D|0)){break i}p=p+1|0;if((p|0)!=10){continue}break}i=1}if(i){break e}}if(!((f|0)!=(h|0)|l)){l=0;h=f;break e}v[o>>2]=0}k=k+1|0;l=l+1|0;if((r|0)!=(l|0)){continue}break}}h=0;l=f}v[H>>2]=h;h=v[A+17164>>2];p=l;if((l+h|0)<=(c|0)?h:0){break b}v[e>>2]=p;p=0;break a}D=b+p|0;v[a+6152>>2]=w[D|0]|w[D+1|0]<<8|(w[D+2|0]<<16|w[D+3|0]<<24);v[e+4>>2]=p;v[e>>2]=h+p;v[e+8>>2]=w[D+3|0]>191?1:2;aa=e,ba=vJ(D),v[aa+12>>2]=ba;v[e+16>>2]=4-(w[D+1|0]>>>1&3);aa=e,ba=ky(D),v[aa+20>>2]=ba;if(!d){p=jy(D);break a}tJ(A+17152|0,D+4|0,h-4|0);if(!(t[D+1|0]&1)){_d(A+17152|0,16)}j:{if(v[e+16>>2]==3){p=0;r=A+17152|0;h=A+3740|0;l=0;c=D;k=w[c+1|0];b=B((k>>>3&1)+(k>>>4&1)|0,3)+(w[c+2|0]>>>2&3)|0;f=b-((b|0)!=0)|0;i=w[c+3|0]>191?1:2;k:{if(k&8){j=_d(r,9);i=i<<1;l=_d(r,i+7|0);break k}j=_d(r,i|8)>>>i|0}b=B(f,40);H=b+61792|0;y=b+62112|0;m=B(f,23)+61600|0;f=-1;l:{while(1){s=w[c+3|0];k=_d(r,12);u[h+4>>1]=k;b=_d(r,9);u[h+6>>1]=b;if((b&65535)>>>0>288){break l}s=s>>>0>191?l<<4:l;aa=h,ba=_d(r,8),t[aa+10|0]=ba;b=_d(r,w[c+1|0]&8?4:9);t[h+13|0]=22;t[h+14|0]=0;v[h>>2]=m;u[h+8>>1]=b;m:{if(_d(r,1)){b=_d(r,2);t[h+11|0]=b;if(!(b&255)){break l}l=_d(r,1);u[h+18>>1]=65287;t[h+12|0]=l;if(w[h+11|0]==2){b=h;n:{if(!(l&255)){v[h>>2]=H;t[h+18|0]=8;M=39;l=0;break n}v[h>>2]=y;M=30;l=w[c+1|0]&8?8:6}t[b+14|0]=M;t[h+13|0]=l;s=s&3855}b=_d(r,10);aa=h,ba=_d(r,3),t[aa+21|0]=ba;aa=h,ba=_d(r,3),t[aa+22|0]=ba;aa=h,ba=_d(r,3),t[aa+23|0]=ba;l=b<<5;break m}t[h+11|0]=0;t[h+12|0]=0;l=_d(r,15);aa=h,ba=_d(r,4),t[aa+18|0]=ba;b=_d(r,3);t[h+20|0]=255;t[h+19|0]=b}t[h+17|0]=l&31;t[h+15|0]=l>>>10;t[h+16|0]=l>>>5&31;g=(k&65535)+g|0;b=h;o:{if(w[c+1|0]&8){k=_d(r,1);break o}k=x[h+8>>1]>499}t[b+24|0]=k;aa=h,ba=_d(r,1),t[aa+25|0]=ba;b=_d(r,1);t[h+27|0]=s>>>12&15;t[h+26|0]=b;h=h+28|0;l=s<<4;i=i-1|0;if(i){continue}break}f=(v[r+4>>2]+g|0)>(v[r+8>>2]+(j<<3)|0)?-1:j}if(!((f|0)<0|v[A+17156>>2]>v[A+17160>>2])){i=A+17152|0;k=v[i+4>>2];h=v[i+8>>2];c=A+912|0;l=v[a+6144>>2];b=l-f|0;s=(f|0)<(l|0)?f:l;l=hc(c+12|0,(((b|0)>0?b:0)+a|0)+6156|0,s);b=(h-k|0)/8|0;hc(l+s|0,v[i>>2]+(v[i+4>>2]/8|0)|0,b);tJ(c,l,b+s|0);h=v[a+6144>>2]>=(f|0);if(h){Y=a+2304|0;p=v[e+8>>2];Z=A+8620|0;_=A+3852|0;b=0;while(1){$=Qb(_,0,4608);l=A+912|0;s=(B(B(b,p),28)+A|0)+3740|0;i=0;M=a;r=a+6152|0;if((p|0)>=1){k=l+7548|0;while(1){f=B(i,28)+s|0;L=x[f+4>>1];N=v[l+4>>2];O=(l+B(i,39)|0)+16156|0;y=l;m=k;g=i;o=gb-48|0;gb=o;j=f;R=!w[f+13|0]+(w[f+14|0]!=0)|0;S=w[f+25|0];c=o;I=c+44|0;H=r;p:{if(w[r+1|0]&8){q=w[j+27|0];n=w[x[j+8>>1]+62528|0];g=n&3;t[o+47|0]=g;t[o+46|0]=g;g=n>>>2|0;t[o+45|0]=g;t[o+44|0]=g;g=B(R,28)+62432|0;break p}g=w[H+3|0]>>>4&(g|0)!=0;F=g?12:0;Q=x[j+8>>1]>>>g|0;while(1){E=1;n=3;while(1){g=n;q=w[(g+F|0)+62544|0];t[g+(o+44|0)|0]=((Q|0)/(E|0)|0)%(q|0);n=g-1|0;E=B(q,E);if(g){continue}break}F=F+4|0;Q=Q-E|0;if((Q|0)>-1){continue}break}q=-16;g=(B(R,28)+F|0)+62432|0}E=0;while(1){P=w[g+E|0];if(P){q:{if(q&8){hc(c,O,P);break q}T=w[E+I|0];if(!T){Qb(c,0,P);Qb(O,0,P);break q}n=(q|0)>-1?-1:-1<<T^-1;F=0;while(1){R=_d(y,T);t[F+O|0]=(n|0)==(R|0)?-1:R;t[c+F|0]=R;F=F+1|0;if((P|0)!=(F|0)){continue}break}}q=q<<1;c=c+P|0;O=O+P|0;E=E+1|0;if((E|0)!=4){continue}}break}t[c+2|0]=0;t[c|0]=0;t[c+1|0]=0;n=w[j+14|0];r:{if(n){c=2-S|0;q=w[j+23|0]<<c;y=w[j+22|0]<<c;g=w[j+21|0]<<c;c=w[j+13|0];E=0;while(1){I=o+(c+E|0)|0;t[I|0]=g+w[I|0];t[I+1|0]=y+w[I+1|0];t[I+2|0]=q+w[I+2|0];E=E+3|0;if(n>>>0>E>>>0){continue}break}break r}if(!w[j+24|0]){break r}q=0;while(1){c=o+q|0;t[c+11|0]=w[c+11|0]+w[q+62568|0];q=q+1|0;if((q|0)!=10){continue}break}}J=iy(C(2048),((((w[H+3|0]&224)==96)<<1)-w[j+10|0]|0)+258|0);q=0;if((n|0)!=(0-w[j+13|0]|0)){c=S+1|0;while(1){aa=m+(q<<2)|0,ca=iy(J,w[o+q|0]<<c),z[aa>>2]=ca;q=q+1|0;if(q>>>0<w[j+14|0]+w[j+13|0]>>>0){continue}break}}gb=o+48|0;o=(l+B(i,2304)|0)+2940|0;c=k;R=L+N|0;G=C(0);X=0;H=l;m=v[l+4>>2];y=v[l>>2]+((m|0)/8|0)|0;g=w[y|0]|w[y+1|0]<<8|(w[y+2|0]<<16|w[y+3|0]<<24);g=(g<<24|g<<8&16711680|(g>>>8&65280|g>>>24))<<(m&7);n=m|-8;K=y+4|0;y=f;E=v[f>>2];F=x[f+6>>1];if(F){while(1){f=y+X|0;m=w[f+15|0];V=(u[(m<<1)+66992>>1]<<1)+62608|0;O=w[f+18|0];s:{if(m>>>0>=16){L=w[m+67056|0];I=32-L|0;while(1){N=w[E|0]>>>1|0;q=(F|0)>(N|0)?N:F;G=z[c>>2];while(1){j=u[V+(g>>>26&62)>>1];if((j|0)<=-1){f=5;while(1){g=g<<f;n=f+n|0;m=j&7;f=m;j=u[V+((g>>>32-f|0)-(j<<16>>19)<<1)>>1];if((j|0)<0){continue}break}}P=j&65535;f=P>>>8|0;n=f+n|0;g=g<<f;Q=1;while(1){m=o;f=P&15;t:{if((f|0)==15){j=g<<L;f=(g>>>I|0)+15|0;n=n+L|0;if((n|0)>=0){while(1){j=w[K|0]<<n|j;g=(n|0)>7;n=n-8|0;K=K+1|0;if(g){continue}break}}g=f;u:{if((f|0)<=128){J=z[(g<<2)+67152>>2];break u}T=g<<3;S=g;g=(g|0)<1024;S=g?T:S;T=S<<1&64;J=C(C((S&63)-T|0)/C(T+(S&-64)|0));J=C(C(C(C(C(C(J*C(.2222222238779068))+C(1.3333333730697632))*J)+C(1))*(g?C(16):C(256)))*z[(S+T>>6<<2)+67152>>2])}J=C(C(J*G)*C(((j|0)>-1?1:-1)|0));break t}j=g;J=C(z[(((g>>>27&16|f)^16)<<2)+67088>>2]*G)}z[m>>2]=J;P=P>>>4|0;o=o+4|0;f=(f|0)!=0;n=f+n|0;g=j<<f;f=Q&1;Q=0;if(f){continue}break}if((n|0)>-1){while(1){g=w[K|0]<<n|g;f=(n|0)>7;n=n-8|0;K=K+1|0;if(f){continue}break}}q=q-1|0;if(q){continue}break}c=c+4|0;E=E+1|0;F=F-N|0;if((F|0)<1){break s}f=(O|0)>0;O=O-1|0;if(f){continue}break}break s}while(1){q=w[E|0]>>>1|0;Q=(q|0)<(F|0)?q:F;G=z[c>>2];while(1){j=u[V+(g>>>26&62)>>1];if((j|0)<=-1){f=5;while(1){g=g<<f;n=f+n|0;m=j&7;f=m;j=u[V+((g>>>32-f|0)-(j<<16>>19)<<1)>>1];if((j|0)<0){continue}break}}j=j&65535;f=j>>>8|0;n=f+n|0;g=g<<f;f=1;while(1){m=j&15;z[o>>2]=z[(((m|g>>>27&16)^16)<<2)+67088>>2]*G;j=j>>>4|0;o=o+4|0;m=(m|0)!=0;n=m+n|0;g=g<<m;m=f&1;f=0;if(m){continue}break}if((n|0)>-1){while(1){g=w[K|0]<<n|g;f=(n|0)>7;n=n-8|0;K=K+1|0;if(f){continue}break}}Q=Q-1|0;if(Q){continue}break}c=c+4|0;E=E+1|0;F=F-q|0;if((F|0)<1){break s}f=(O|0)>0;O=O-1|0;if(f){continue}break}}X=X+1|0;if((F|0)>0){continue}break}f=1-F|0}else{f=1}while(1){v:{m=w[y+26|0]?66976:66944;j=w[m+(g>>>28|0)|0];if(!(j&8)){j=w[m+((g<<4>>>32-(j&3))+(j>>>3)|0)|0]}m=j&7;n=m+n|0;if((R|0)<((n+(K-v[H>>2]<<3)|0)-24|0)){break v}f=f-1|0;if(!f){f=w[E|0];if(f>>>0<2){break v}E=E+1|0;G=z[c>>2];f=f>>>1|0;c=c+4|0}g=g<<m;if(j&128){z[o>>2]=(g|0)<0?C(-G):G;n=n+1|0;g=g<<1}if(j&64){z[o+4>>2]=(g|0)<0?C(-G):G;n=n+1|0;g=g<<1}f=f-1|0;if(!f){f=w[E|0];if(f>>>0<2){break v}E=E+1|0;G=z[c>>2];f=f>>>1|0;c=c+4|0}if(j&32){z[o+8>>2]=(g|0)<0?C(-G):G;n=n+1|0;g=g<<1}if(j&16){z[o+12>>2]=(g|0)<0?C(-G):G;n=n+1|0;g=g<<1}if((n|0)>=0){while(1){g=w[K|0]<<n|g;m=(n|0)>7;n=n-8|0;K=K+1|0;if(m){continue}break}}o=o+16|0;continue}break}v[H+4>>2]=R;i=i+1|0;if((p|0)!=(i|0)){continue}break}}c=w[M+6155|0];w:{if(c&16){j=0;L=gb-16|0;gb=L;q=l+2940|0;f=q+2304|0;m=s;n=v[m>>2];o=w[m+14|0];I=o+w[m+13|0]|0;H=I;N=L+4|0;v[N+8>>2]=-1;v[N>>2]=-1;v[N+4>>2]=-1;if(I>>>0>=1){while(1){c=0;y=j+n|0;i=w[y|0];g=0;x:{if(!i){break x}y:{while(1){g=c<<2;if(z[g+f>>2]!=C(0)|z[(g|4)+f>>2]!=C(0)){break y}c=c+2|0;if(i>>>0>c>>>0){continue}break}g=i;break x}v[N+((j>>>0)%3<<2)>>2]=j;g=w[y|0]}f=((g&255)<<2)+f|0;j=j+1|0;if((H|0)!=(j|0)){continue}break}}if(w[m+13|0]){k=v[L+12>>2];f=v[L+8>>2];c=v[L+4>>2];c=(c|0)<(f|0)?f:c;c=(c|0)<(k|0)?k:c;v[L+12>>2]=c;v[L+8>>2]=c;v[L+4>>2]=c}N=l+16195|0;i=o?3:1;k=I-i|0;j=0;while(1){f=j+k|0;c=f-i|0;if((c|0)<=v[(L+4|0)+(j<<2)>>2]){c=w[r+1|0]<<28>>31&3}else{c=w[c+N|0]}t[f+N|0]=c;j=j+1|0;if((i|0)!=(j|0)){continue}break}H=L+4|0;y=u[m+36>>1]&1;f=0;g=v[m>>2];c=w[g|0];if(c){m=w[r+1|0]&8?7:64;k=g;while(1){i=w[r+3|0]&32;z:{A:{if(v[H+((f>>>0)%3<<2)>>2]>=(f|0)){break A}o=w[f+N|0];if(o>>>0>=m>>>0){break A}U=i?C(1.4142135381698608):C(1);B:{if(w[r+1|0]&8){i=o<<3;J=z[i+67680>>2];G=z[(i|4)+67680>>2];break B}J=iy(C(1),o+1>>>1<<y);i=o&1;G=i?C(1):J;J=i?J:C(1)}i=q;W=C(J*U);J=C(G*U);n=0;while(1){o=i+(n<<2)|0;U=z[o>>2];z[o+2304>>2]=U*J;z[o>>2]=U*W;n=n+1|0;if((n|0)!=(c|0)){continue}break}break z}if(!i){break z}qJ(q,c)}q=(w[k|0]<<2)+q|0;f=f+1|0;k=g+f|0;c=w[k|0];if(c){continue}break}}gb=L+16|0;break w}if((c&224)!=96){break w}qJ(l+2940|0,576)}if((p|0)>=1){c=l+7708|0;i=0;while(1){f=w[M+6153|0];I=(w[s+12|0]!=0)<<1<<((B((f>>>3&1)+(f>>>4&1)|0,3)+(w[M+6154|0]>>>2&3)|0)==2);y=(l+B(i,2304)|0)+2940|0;n=y;if(w[s+14|0]){m=((l+B(i,2304)|0)+B(I,72)|0)+2940|0;k=c;g=c;K=v[s>>2]+w[s+13|0]|0;q=w[K|0];if(q){f=m;while(1){o=q&255;r=o<<1;q=1;while(1){z[g>>2]=z[f>>2];z[g+4>>2]=z[(o<<2)+f>>2];H=r<<2;z[g+8>>2]=z[H+f>>2];f=f+4|0;g=g+12|0;if((o|0)!=(q|0)){q=q+1|0;continue}break}f=f+H|0;q=w[K+3|0];K=K+3|0;if(q){continue}break}}hc(m,k,g-k|0);g=I-1|0}else{g=31}if((g|0)>=1){while(1){f=0;while(1){m=f<<2;k=m+n|0;H=k;G=z[m+67744>>2];U=z[k+72>>2];W=z[m+67776>>2];k=(17-f<<2)+n|0;J=z[k>>2];z[H+72>>2]=C(G*U)-C(W*J);z[k>>2]=C(W*U)+C(G*J);f=f+1|0;if((f|0)!=8){continue}break}n=n+72|0;f=(g|0)>1;g=g-1|0;if(f){continue}break}}f=y;g=M+B(i,1152)|0;k=w[s+11|0];if(I){pJ(f,g,67808,I);g=B(I,36)+g|0;f=B(I,72)+f|0}C:{if((k|0)==2){j=gb-80|0;gb=j;k=32-I|0;if((k|0)>=1){o=j|8;r=j|4;while(1){H=hc(j,f,72);m=v[g+20>>2];v[f+16>>2]=v[g+16>>2];v[f+20>>2]=m;m=v[g+12>>2];v[f+8>>2]=v[g+8>>2];v[f+12>>2]=m;m=v[g+4>>2];v[f>>2]=v[g>>2];v[f+4>>2]=m;m=g+24|0;hy(H,f+24|0,m);hy(r,f+48|0,m);hy(o,g,m);f=f+72|0;g=g+36|0;m=(k|0)>1;k=k-1|0;if(m){continue}break}}gb=j+80|0;break C}pJ(f,g,B((k|0)==3,72)+67808|0,32-I|0)}k=0;j=y+72|0;while(1){f=1;while(1){g=(f<<2)+j|0;z[g>>2]=-z[g>>2];g=f>>>0<16;f=f+2|0;if(g){continue}break}j=j+144|0;f=k>>>0<30;k=k+2|0;if(f){continue}break}s=s+28|0;i=i+1|0;if((p|0)!=(i|0)){continue}break}}sJ(Y,$,18,v[e+8>>2],d,Z);p=v[e+8>>2];d=B(p,1152)+d|0;b=b+1|0;if(b>>>0<(w[D+1|0]&8?2:1)>>>0){continue}break}}b=a;l=A+912|0;d=v[l+8>>2]>>>3|0;c=v[l+4>>2]+7>>>3|0;k=d-c|0;f=(k|0)>511;e=f?511:k;if((k|0)>=1){sh(b+6156|0,(l+(f?d-511|0:c)|0)+12|0,e)}v[b+6144>>2]=e;break j}ot(a);break a}y=A+17152|0;p=0;l=0;s=0;b=A;k=b;i=0;D:{E:{F:{c=D;h=w[c+3|0];f=h>>>6|0;switch(f-1|0){case 2:break D;case 0:break F;default:break E}}i=(h>>>2&12)+4|0;break D}i=32}h=w[c+1|0];G:{if((h&6)==6){h=32;c=69212;break G}if(!(h&8)){h=30;c=69215;break G}h=w[c+2|0]>>>2&3;c=ky(c)>>>((f|0)!=3)|0;c=c?c:192;if(c>>>0<=55){h=(h|0)==2?12:8;c=69236;break G}h=c>>>0>95?(h|0)!=1?30:27:27;c=69224}t[k+768|0]=h;t[k+769|0]=(h|0)<(i|0)?h:i;h=c;H:{if(!w[b+768|0]){break H}j=69120;while(1){if((p|0)==(s|0)){j=w[h|0]+69120|0;s=w[h+2|0]+s|0;l=w[h+1|0];h=h+3|0}c=p<<1;k=w[_d(y,l)+j|0];t[(c+b|0)+770|0]=k;g=w[b+769|0];if(p>>>0<g>>>0){k=w[_d(y,l)+j|0];g=w[b+769|0]}t[(b+(c|1)|0)+770|0]=g?k:0;k=w[b+768|0];p=p+1|0;if(k>>>0>p>>>0){continue}break}if(!k){l=k<<1;break H}p=0;while(1){c=b+p|0;I:{if(!w[c+770|0]){h=6;break I}if((w[D+1|0]&6)==6){h=2;break I}h=_d(y,2);k=w[b+768|0]}t[c+834|0]=h;l=k<<1&510;p=p+1|0;if(l>>>0>p>>>0){continue}break}}s=b+770|0;g=b+834|0;c=b;i=0;if((l|0)>=1){while(1){h=w[s|0];f=h?19>>>w[g+i|0]&3|4:0;s=s+1|0;D=B(h,3)-6|0;h=4;G=C(0);while(1){if(f&h){k=_d(y,6);m=(k|0)/3|0;G=C(z[(D+(k-B(m,3)|0)<<2)+69248>>2]*C(2097152>>>m|0))}z[c>>2]=G;c=c+4|0;k=h>>>0>1;h=h>>>1|0;if(k){continue}break}i=i+1|0;if((l|0)!=(i|0)){continue}break}}p=w[b+769|0];c=w[b+768|0];if(p>>>0<c>>>0){while(1){t[(b+(p<<1|1)|0)+770|0]=0;p=p+1|0;if((c|0)!=(p|0)){continue}break}}p=0;D=Qb(A+3852|0,0,4608);y=a+2304|0;m=A+8620|0;c=0;J:{while(1){s=((c<<2)+A|0)+3852|0;M=A+17152|0;r=v[e+16>>2]|1;g=0;k=A;i=w[k+768|0];b=576;while(1){K:{if(!(i&255)){i=0;break K}j=s+(B(g,r)<<2)|0;f=0;while(1){h=b;i=w[(f+k|0)+770|0];L:{if(!i){break L}if(i>>>0<=16){if((r|0)<1){break L}l=(-1<<i-1)+1|0;b=0;while(1){aa=(b<<2)+j|0,ca=C(_d(M,i)+l|0),z[aa>>2]=ca;b=b+1|0;if((r|0)!=(b|0)){continue}break}break L}i=2<<i-17;b=_d(M,(i-(i>>>3|0)|0)+3|0);if((r|0)<1){break L}l=i>>>1|0;H=i|1;i=0;while(1){n=b;b=(b>>>0)/(H>>>0)|0;z[(i<<2)+j>>2]=(n-B(H,b)|0)-l|0;i=i+1|0;if((r|0)!=(i|0)){continue}break}}b=18-h|0;j=(h<<2)+j|0;f=f+1|0;i=w[k+768|0];if(f>>>0<i<<1>>>0){continue}break}}g=g+1|0;if((g|0)!=4){continue}break}c=(r<<2)+c|0;if((c|0)==12){k=(p<<2)+A|0;b=D;c=A;f=w[c+769|0];h=b+B(f,72)|0;hc(h+2304|0,h,B(w[c+768|0]-f|0,72));if(w[c+768|0]){i=0;while(1){l=0;while(1){h=(l<<2)+b|0;z[h>>2]=z[h>>2]*z[k>>2];h=h+2304|0;z[h>>2]=z[h>>2]*z[k+12>>2];l=l+1|0;if((l|0)!=12){continue}break}k=k+24|0;b=b+72|0;i=i+1|0;if(i>>>0<w[c+768|0]){continue}break}}sJ(y,D,12,v[e+8>>2],d,m);Qb(D,0,4608);d=B(v[e+8>>2],768)+d|0;c=0}if(v[A+17156>>2]<=v[A+17160>>2]){p=p+1|0;if((p|0)==3){break J}continue}break}ot(a);p=0;break a}h=1}p=B(jy(a+6152|0),h)}gb=A+17168|0;return p|0}function Nka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0,Y=0;f=gb-400|0;gb=f;vc(b);e=gb-32|0;gb=e;j=f+192|0;aU(e+24|0,j);h=xb(e+24|0);i=v[e+28>>2];g=v[e+24>>2];v[e+8>>2]=g;v[e+12>>2]=i;v[e>>2]=g;v[e+4>>2]=i;i=b;fc(e+16|0,i,e);g=xb(e+16|0);if((g|0)==(h|0)){Yb(i,xb(e+24|0))}gb=e+32|0;i=(h|0)==(g|0);if(!i){$T(j)}a:{if(!i){break a}if(!iU(f+192|0)){break a}if(!c){d=1;break a}Gd(a,134217728);Df(f+136|0,1084);v[22640]=0;o=f+192|4;U(903,f+8|0,f+136|0,o|0);d=v[22640];v[22640]=0;b:{c:{d:{e:{f:{g:{h:{if((d|0)!=1){Eb(a+1298304|0,f+8|0);vb(f+8|0);Hb(f+136|0);d=Tb(f+8|0,6185);Eb(a+1298316|0,d);vb(d);v[a+480188>>2]=4;v[a+1298364>>2]=2;X=a,Y=Ib(w[f+328|0]|w[f+329|0]<<8),v[X+480196>>2]=Y;d=Ib(w[f+332|0]|w[f+333|0]<<8);v[a+480260>>2]=56;v[a+480264>>2]=13696;X=a,Y=hU(d),v[X+480204>>2]=Y;Fr(Rb(a+484360|0),f+200|0,w[f+192|6]);r=a+480190|0;p=ad(f+176|0);q=nc(f+160|0);i:{j:{k:{l:{m:{n:{if(Ib(w[f+392|0]|w[f+393|0]<<8)){while(1){v[22640]=0;d=T(444,b|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break h}u[f+112>>1]=d;if((d-1&65535)>>>0>=3999){break c}d=Ib(w[f+394|0]|w[f+395|0]<<8);if((Ib(w[o|0]|w[o+1|0]<<8)|0)==2){v[22640]=0;d=T(453,b|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break i}d=d-2|0}v[22640]=0;U(320,f+8|0,b|0,d|0);d=v[22640];v[22640]=0;o:{p:{q:{if((d|0)!=1){v[22640]=0;d=Ie(r,f+112|0);i=v[22640];v[22640]=0;if((i|0)==1){break q}C=x[d>>1];u[a+480190>>1]=C;v[22640]=0;i=B(x[f+112>>1],104)+a|0;e=i+484380|0;R(352,e|0,1);d=v[22640];v[22640]=0;r:{if((d|0)==1){break r}if(Ib(w[o|0]|w[o+1|0]<<8)>>>0>1){break p}v[22640]=0;R(904,f+8|0,i+484423|0);d=v[22640];v[22640]=0;if((d|0)==1){break r}v[22640]=0;Q(350,f+8|0,1)|0;d=v[22640];v[22640]=0;if((d|0)==1){break r}v[22640]=0;W(354,f+8|0,((x[f+112>>1]<<5)+a|0)+946304|0,30)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break o}}e=P()|0;O()|0;break f}e=P()|0;O()|0;break e}e=P()|0;O()|0;break f}d=Kb(f+136|0);v[22640]=0;W(552,f+8|0,d|0,257)|0;h=v[22640];v[22640]=0;s:{t:{if((h|0)==1){break t}v[22640]=0;Q(335,i+484423|0,d|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break t}v[22640]=0;Q(350,f+8|0,1)|0;h=v[22640];v[22640]=0;if((h|0)==1){break t}v[22640]=0;W(552,f+8|0,d|0,31)|0;h=v[22640];v[22640]=0;if((h|0)==1){break t}v[22640]=0;Q(333,((x[f+112>>1]<<5)+a|0)+946304|0,d|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break t}if(!(v[f+16>>2]&1)){break s}v[22640]=0;Q(350,f+8|0,1)|0;h=v[22640];v[22640]=0;if((h|0)!=1){break s}}e=P()|0;O()|0;vb(d);break f}vb(d)}v[22640]=0;R(905,f+8|0,f+136|0);d=v[22640];v[22640]=0;if((d|0)==1){break n}v[22640]=0;gU(f+136|0,e);d=v[22640];v[22640]=0;if((d|0)==1){break n}if((Ib(w[o|0]|w[o+1|0]<<8)|0)==2){t[i+484417|0]=w[f+154|0]<<3}u:{if(!Ib(w[o|0]|w[o+1|0]<<8)){break u}v[22640]=0;R(349,q|0,C|0);d=v[22640];v[22640]=0;if((d|0)==1){break n}v[22640]=0;R(907,p|0,C|0);d=v[22640];v[22640]=0;if((d|0)==1){break n}h=xd(p,x[f+112>>1]-1|0);Nd(h);v[22640]=0;e=T(444,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break j}v[22640]=0;d=Q(228,b|0,e<<3)|0;j=v[22640];v[22640]=0;if((j|0)==1){break j}if(!d){break l}v[22640]=0;R(908,h|0,e|0);d=v[22640];v[22640]=0;if((d|0)==1){break j}d=0;v[f+128>>2]=0;if(!e){if(!(w[i+484414|0]&2)){break u}d=v[i+484384>>2];v[f+120>>2]=d;i=v[i+484388>>2];v[22640]=0;v[f+124>>2]=i-d;R(909,h|0,f+120|0);d=v[22640];v[22640]=0;if((d|0)!=1){break u}e=P()|0;O()|0;break f}while(1){v[22640]=0;i=T(453,b|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break k}v[22640]=0;v[f+120>>2]=i;i=T(453,b|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break k}v[22640]=0;v[f+124>>2]=i;R(909,h|0,f+120|0);i=v[22640];v[22640]=0;if((i|0)==1){break k}d=d+1|0;if(e>>>0>(d&65535)>>>0){continue}break}}yb(f+8|0);n=n+1|0;if(Ib(w[f+392|0]|w[f+393|0]<<8)>>>0>(n&65535)>>>0){continue}break}}D=128;if(Ib(w[o|0]|w[o+1|0]<<8)){break m}v[22640]=0;D=T(444,b|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break m}e=P()|0;O()|0;break e}e=P()|0;O()|0;break f}n=a+480188|0;E=w[f+192|7];u[f+118>>1]=4;v:{w:{x:{if(!Ib(w[o|0]|w[o+1|0]<<8)){e=x[n>>1];break x}i=v[b+8>>2];y:{if(!D){break y}g=0;while(1){v[22640]=0;d=T(444,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break w}if((d|0)==65535){break y}v[22640]=0;E=T(444,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break w}v[22640]=0;d=T(444,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break w}v[22640]=0;u[f+118>>1]=d;d=Ie(n,f+118|0);e=v[22640];v[22640]=0;if((e|0)==1){break w}u[n>>1]=x[d>>1];v[22640]=0;Q(350,b|0,B(x[f+118>>1],E)<<2)|0;d=v[22640];v[22640]=0;if((d|0)==1){break w}g=g+1|0;if((g&65535)>>>0<D>>>0){continue}break}}d=0;v[22640]=0;Q(227,b|0,i|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break v}e=x[n>>1];if(e>>>0>127){break b}}v[22640]=0;G=Q(910,f+136|0,e&65535)|0;d=v[22640];v[22640]=0;if((d|0)!=1){H=Ib(w[f+330|0]|w[f+331|0]<<8);z:{if(!D){break z}K=a+484344|0;V=c&1;i=0;n=0;while(1){d=n;if(Ib(w[o|0]|w[o+1|0]<<8)){v[22640]=0;d=T(444,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break g}if((d|0)==65535){break z}v[22640]=0;E=T(444,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break g}v[22640]=0;e=T(444,b|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break g}u[f+118>>1]=e}F=E&65535;A:{B:{C:{if(!V){break C}v[22640]=0;M=d&65535;d=W(365,K|0,M|0,F|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break g}if(!d){break C}s=0;if(F){break B}break A}v[22640]=0;Q(350,b|0,B(x[f+118>>1],F)<<2)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break A}break g}while(1){d=_b(K,M);v[22640]=0;j=Pf(d,s);d=v[22640];v[22640]=0;D:{if((d|0)!=1){e=0;A=0;E:{F:{switch((H&3)-1|0){case 0:A=!(s&3);break E;case 1:A=!(s&1);break E;case 2:break F;default:break E}}A=(s&3)!=3}I=0;if(!x[f+118>>1]){break D}while(1){d=v[G>>2];v[22640]=0;R(550,f+120|0,b|0);h=v[22640];v[22640]=0;if((h|0)==1){break g}h=B(e,9)+d|0;d=md(f+120|0);z=Re(f+120|0);g=aj(f+120|0);k=j+B(e,6)|0;t[k+1|0]=w[f+120|0];d=w[d|0];t[k|0]=d;g=w[g|0];t[k+5|0]=g;l=k+5|0;if(d){t[k|0]=d+25;t[h+8|0]=0;t[h|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[h+3|0]=0;t[h+4|0]=0;t[h+5|0]=0;t[h+6|0]=0;t[h+7|0]=0;g=w[l|0]}m=g&255;z=w[z|0];G:{if(z>>>0>=240){d=m|(z&15)<<8;if(d){v[22640]=0;d=fn(+(hU(d)>>>0)*1e-4);g=v[22640];v[22640]=0;if((g|0)!=1){t[l|0]=d;t[k+3|0]=17;break G}break g}t[k+3|0]=0;break G}J=m>>>4|0;N=m<<4;d=J|N;H:{switch(z|0){case 0:d=j+B(e,6)|0;if(g&255){t[d+3|0]=1;break G}t[d+3|0]=0;break G;case 1:t[(j+B(e,6)|0)+3|0]=2;break G;case 2:t[(j+B(e,6)|0)+3|0]=3;break G;case 3:v[22640]=0;t[f+8|0]=15;d=ac(l,f+8|0);g=v[22640];v[22640]=0;if((g|0)!=1){t[h|0]=w[d|0]|16;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(j+B(e,6)|0)+3|0]=0;break G}break g;case 4:v[22640]=0;t[f+8|0]=15;d=ac(l,f+8|0);g=v[22640];v[22640]=0;if((g|0)!=1){t[h|0]=w[d|0]|32;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(j+B(e,6)|0)+3|0]=0;break G}break g;case 5:t[h+7|0]=0;t[h+2|0]=0;t[h+1|0]=g;t[h|0]=0;t[(j+B(e,6)|0)+3|0]=0;break G;case 6:t[h+7|0]=0;t[h+2|0]=g;t[h|0]=0;t[h+1|0]=0;t[(j+B(e,6)|0)+3|0]=0;break G;case 7:t[(j+B(e,6)|0)+3|0]=23;i=0;break G;case 8:t[(j+B(e,6)|0)+3|0]=0;i=d;break G;case 9:t[(j+B(e,6)|0)+3|0]=19;v[22640]=0;t[f+8|0]=15;d=ac(l,f+8|0);g=v[22640];v[22640]=0;if((g|0)!=1){t[l|0]=w[d|0]|16;break G}break g;case 10:t[(j+B(e,6)|0)+3|0]=19;v[22640]=0;t[f+8|0]=15;d=ac(l,f+8|0);g=v[22640];v[22640]=0;if((g|0)!=1){t[l|0]=w[d|0]|32;break G}break g;case 11:t[h+3|0]=d;t[(j+B(e,6)|0)+3|0]=0;break G;case 12:d=j+B(e,6)|0;t[d+4|0]=g;t[d+2|0]=1;t[h+3|0]=0;t[d+3|0]=0;break G;case 13:z=j+B(e,6)|0;I:{J:{if(m&240){t[(j+B(e,6)|0)+2|0]=4;d=(g&240)>>>4|0;break J}if(!(m&15)){break I}t[(j+B(e,6)|0)+2|0]=3;d=g&15}t[z+4|0]=d}t[h+3|0]=0;t[(j+B(e,6)|0)+3|0]=0;break G;case 14:t[(j+B(e,6)|0)+3|0]=19;t[l|0]=!(g&255);break G;case 15:t[(j+B(e,6)|0)+3|0]=16;t[l|0]=(g&240)>>>4;H=g&15;break G;case 16:t[h+5|0]=0;t[h+4|0]=g;t[(j+B(e,6)|0)+3|0]=0;break G;case 17:t[h+6|0]=m&15?g:0;t[(j+B(e,6)|0)+3|0]=0;break G;case 18:t[(j+B(e,6)|0)+3|0]=14;break G;case 19:t[h+8|0]=0;t[h+7|0]=g;t[h+2|0]=0;t[h|0]=0;t[h+1|0]=0;t[(j+B(e,6)|0)+3|0]=0;break G;case 20:t[(j+B(e,6)|0)+3|0]=12;break G;case 22:K:{d=w[k+1|0];L:{if(!d){break L}if(Cc(p)>>>0<d>>>0){break L}d=xd(p,d-1|0);g=g-1|0;t[l|0]=g;v[22640]=0;Q(912,f+8|0,0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break g}v[f+112>>2]=9;d=Cc(d);v[22640]=0;v[f+4>>2]=d;d=Fb(f+112|0,f+4|0);m=v[22640];v[22640]=0;if((m|0)==1){break K}if(y[d>>2]<=(g&255)>>>0){break L}d=j+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[l|0]}t[(j+B(e,6)|0)+3|0]=0;break G}break g;case 23:d=w[k+1|0];M:{if(!d){break M}if(Cc(p)>>>0<d>>>0){break M}d=xd(p,d-1|0);g=g-1|0;t[l|0]=g;g=g&255;if(Cc(d)>>>0<=g>>>0){break M}N:{if(x[xd(d,g)+8>>1]){break N}if(!ei(a)){g=w[l|0];break N}m=x[r>>1]+1|0;u[r>>1]=m;g=w[l|0];X=xd(d,g),Y=m,u[X+8>>1]=Y}X=k,Y=w[xd(d,g)+8|0],t[X+1|0]=Y}t[(j+B(e,6)|0)+3|0]=0;break G;case 24:O:{d=w[k+1|0];P:{if(!d){break P}if(Cc(p)>>>0<d>>>0){break P}d=xd(p,d-1|0);g=g-1|0;t[l|0]=g;v[22640]=0;Q(912,f+8|0,0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break g}v[f+112>>2]=9;d=Cc(d);v[22640]=0;v[f+4>>2]=d;d=Fb(f+112|0,f+4|0);m=v[22640];v[22640]=0;if((m|0)==1){break O}if(y[d>>2]>(g&255)>>>0){d=j+B(e,6)|0;t[d+2|0]=15;t[d+4|0]=w[l|0]}Q:{if(x[rc(q,w[k+1|0]-1|0)>>1]){break Q}if(!ei(a)){break Q}d=x[r>>1]+1|0;u[r>>1]=d;X=rc(q,w[k+1|0]-1|0),Y=d,u[X>>1]=Y}X=k,Y=w[rc(q,w[k+1|0]-1|0)|0],t[X+1|0]=Y}t[(j+B(e,6)|0)+3|0]=0;break G}break g;case 25:d=w[k+1|0];R:{if(!d){break R}if(Cc(p)>>>0<d>>>0){break R}d=xd(p,d-1|0);g=g-1|0;t[l|0]=g;g=g&255;if(Cc(d)>>>0<=g>>>0){break R}S:{if(x[xd(d,g)+10>>1]){break S}if(!ei(a)){g=w[l|0];break S}m=x[r>>1]+1|0;u[r>>1]=m;g=w[l|0];X=xd(d,g),Y=m,u[X+10>>1]=Y}X=k,Y=w[xd(d,g)+10|0],t[X+1|0]=Y}t[(j+B(e,6)|0)+3|0]=0;break G;case 29:t[(j+B(e,6)|0)+3|0]=11;t[l|0]=d;if(m&15){t[l|0]=N|15;break G}if((g&255)>>>0<16){break G}t[l|0]=J|240;break G;case 32:if(m&240){t[h+3|0]=J;t[(j+B(e,6)|0)+3|0]=0;break G}t[(j+B(e,6)|0)+3|0]=19;t[l|0]=g&15|192;break G;case 33:t[(j+B(e,6)|0)+3|0]=19;v[22640]=0;t[f+8|0]=15;d=ac(l,f+8|0);g=v[22640];v[22640]=0;if((g|0)!=1){t[l|0]=w[d|0]|208;break G}break g;case 34:t[(j+B(e,6)|0)+3|0]=19;v[22640]=0;t[f+8|0]=15;d=ac(l,f+8|0);g=v[22640];v[22640]=0;if((g|0)!=1){t[l|0]=w[d|0]|144;break G}break g;case 73:t[(j+B(e,6)|0)+3|0]=10;break G;case 78:if((g&112|128)==224){t[(j+B(e,6)|0)+3|0]=19;break G}t[(j+B(e,6)|0)+3|0]=0;break G;case 79:d=j+B(e,6)|0;if((g&255)>>>0<=31){t[d+3|0]=16;H=0;break G}t[d+3|0]=17;break G;default:break H}}t[(j+B(e,6)|0)+3|0]=0}m=0;g=w[h+3|0];if(!(w[k+2|0]|!g)){T:{if(g>>>0>=16){t[k+2|0]=5;g=g>>>4|0;break T}t[k+2|0]=6}t[k+4|0]=g;m=1}U:{if(w[k+3|0]){break U}d=w[h+1|0];V:{if(d){t[k+3|0]=2;break V}d=w[h+2|0];if(d){t[k+3|0]=3;break V}d=w[h|0];if(d){t[k+3|0]=19;break V}d=w[h+7|0];if(d){t[k+3|0]=4;t[h+8|0]=d;break V}d=w[h+4|0];if(d){t[k+3|0]=5;t[h+5|0]=d;break V}d=w[h+3|0];if(!(!d|m)){t[k+3|0]=11;t[l|0]=d;if(d&15){d=d|-16;break V}if(!(d&240)){break U}d=d|15;break V}d=w[h+6|0];if(d){t[k+3|0]=8;break V}if(A){t[k+3|0]=20;A=0;d=97;break V}A=0;if(I){break U}d=i&255;if(!d){break U}t[k+3|0]=24;t[l|0]=i;if(i&15){d=i|-16}else{if(!(d&240)){I=1;break U}d=i|15}I=1}t[l|0]=d}e=e+1|0;if(e>>>0<x[f+118>>1]){continue}break}break D}break g}s=s+1|0;if((F|0)!=(s|0)){continue}break}}n=n+1|0;if((n&65535)>>>0<D>>>0){continue}break}}v[a+480228>>2]=256/x[a+480188>>1];v[22640]=0;rh(a,1);d=v[22640];v[22640]=0;if((d|0)==1){break g}if(Ib(w[o|0]|w[o+1|0]<<8)){W:{while(1){v[22640]=0;d=Q(228,b|0,2)|0;n=v[22640];v[22640]=0;if((n|0)==1){break g}if(!d){break W}v[22640]=0;d=T(444,b|0)|0;n=v[22640];v[22640]=0;if((n|0)==1){break g}if((d|0)==65535){break W}v[22640]=0;Q(350,b|0,2)|0;d=v[22640];v[22640]=0;if((d|0)==1){break g}v[22640]=0;d=T(453,b|0)|0;n=v[22640];v[22640]=0;if((n|0)!=1){v[22640]=0;Q(350,b|0,d|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}}break}break g}v[22640]=0;Q(350,b|0,34)|0;d=v[22640];v[22640]=0;if((d|0)==1){break g}}X:{if(!(!(c&2)|!C)){d=1;n=1;while(1){c=(B(d,104)+a|0)+484380|0;Y:{if(!v[c>>2]){break Y}i=Pc(f+8|0,8,1,0,0);v[22640]=0;W(363,i|0,c|0,b|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break X}if(Cc(p)>>>0<d>>>0){break Y}d=d-1|0;i=xd(p,d);v[22640]=0;R(913,c|0,i|0);i=v[22640];v[22640]=0;Z:{if((i|0)!=1){if(!x[rc(q,d)>>1]){break Z}i=x[rc(q,d)>>1];e=v[c>>2];v[22640]=0;ha(914,c|0,(B(i,104)+a|0)+484380|0,0,e|0,0);i=v[22640];v[22640]=0;if((i|0)!=1){break Z}}break g}d=xd(p,d);X=f,Y=Sb(d),v[X+8>>2]=Y;X=f,Y=Wb(d),v[X+120>>2]=Y;if(!Gb(f+8|0,f+120|0)){break Y}while(1){d=v[f+8>>2];i=x[d+8>>1];if(i){e=v[d+4>>2];h=v[d>>2];v[22640]=0;ha(914,c|0,(B(i,104)+a|0)+484380|0,h|0,e|0,1);i=v[22640];v[22640]=0;if((i|0)==1){break g}}i=x[d+10>>1];if(i){e=v[d+4>>2];d=v[d>>2];v[22640]=0;ha(914,c|0,(B(i,104)+a|0)+484380|0,d|0,e|0,0);d=v[22640];v[22640]=0;if((d|0)==1){break g}}sr(f+8|0);if(Gb(f+8|0,f+120|0)){continue}break}}n=n+1|0;d=n&65535;if(C>>>0>=d>>>0){continue}break}}CB(G);d=1;break b}break g}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}yb(f+8|0);break c}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break e}e=P()|0;O()|0;Hb(f+136|0);break d}e=P()|0;O()|0;break e}e=P()|0;O()|0;CB(G);break e}yb(f+8|0)}Ue(q);bU(p)}S(e|0);L()}d=0}Ue(q);bU(p)}gb=f+400|0;return d|0}function Xka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;d=gb-272|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!Tu(b,d+176|0)){break h}if(!rU(d+176|0)){break h}if(!Pb(b,Uc(qU(d+176|0),jb))){break h}if(!c){s=1;break h}Gd(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;l=Kb(d+160|0);if((w[d+216|0]|w[d+217|0]<<8)==20479){g=w[d+230|0]|w[d+231|0]<<8}else{g=(w[d+216|0]|w[d+217|0]<<8)-16464|0}i:{j:{k:{l:{m:{n:{o:{p:{switch(((w[d+216|0]|w[d+217|0]<<8)&61440)-4096>>>12|0){case 0:q:{if(w[d+238|0]|w[d+239|0]<<8|(w[d+216|0]|w[d+217|0]<<8)!=4896|(w[d+228|0]|w[d+208|0]&15)){break q}if((w[d+214|0]|w[d+215|0]<<8)&65455){break q}v[a+1074308>>2]=18219008;v[22640]=0;e=Q(2,d+32|0,10993)|0;h=v[22640];v[22640]=0;f=1;if((h|0)==1){break o}Eb(l,e);vb(e);v[22640]=0;W(437,a+1074312|0,81,1)|0;i=v[22640];v[22640]=0;e=1;h=0;if((i|0)!=1){break i}break b}r:{if(w[d+238|0]|w[d+239|0]<<8|(w[d+216|0]|w[d+217|0]<<8)!=4896|(w[d+228|0]|(w[d+214|0]|w[d+215|0]<<8))){break r}if(w[d+229|0]){break r}v[22640]=0;e=Q(2,d+32|0,6651)|0;j=v[22640];v[22640]=0;if((j|0)!=1){Eb(l,e);break j}b=P()|0;O()|0;break a}v[22640]=0;h=Q(2,d+32|0,5721)|0;f=v[22640];v[22640]=0;j=1;if((f|0)!=1){Eb(l,h);vb(h);break k}b=P()|0;O()|0;break a;case 1:v[22640]=0;h=Q(2,d+32|0,3836)|0;f=v[22640];v[22640]=0;e=1;if((f|0)!=1){Eb(l,h);vb(h);break k}b=P()|0;O()|0;break a;case 2:s:{t:{u:{i=w[d+216|0]|w[d+217|0]<<8;v:{if(i>>>0<=12820){v[22640]=0;e=Q(2,d+32|0,5768)|0;f=v[22640];v[22640]=0;if((f|0)!=1){Eb(l,e);vb(e);break v}b=P()|0;O()|0;break a}v[22640]=0;R(617,d+144|0,1124);e=v[22640];v[22640]=0;if((e|0)==1){break u}e=w[d+216|0]|w[d+217|0]<<8;v[22640]=0;v[d+128>>2]=e-12820;U(618,d+32|0,d+144|0,d+128|0);e=v[22640];v[22640]=0;if((e|0)==1){break t}Eb(l,d+32|0);vb(d+32|0);Hb(d+144|0)}if((w[d+216|0]|w[d+217|0]<<8)>>>0<12807){break l}if(w[d+232|0]|w[d+233|0]<<8|(w[d+234|0]<<16|w[d+235|0]<<24)){break s}break l}b=P()|0;O()|0;break a}b=P()|0;O()|0;Hb(d+144|0);break a}e=w[d+216|0]|w[d+217|0]<<8;f=w[d+232|0]|w[d+233|0]<<8|(w[d+234|0]<<16|w[d+235|0]<<24);v[22640]=0;e=kw(e,f);f=v[22640];v[22640]=0;if((f|0)==1){break n}f=Er(d+32|0);v[f+44>>2]=e;v[22640]=0;R(621,a+1298368|0,f|0);e=v[22640];v[22640]=0;if((e|0)!=1){break l}b=P()|0;O()|0;break a;case 3:if((w[d+216|0]|w[d+217|0]<<8)==16640){v[22640]=0;j=Q(2,d+32|0,5553)|0;h=v[22640];v[22640]=0;e=1;if((h|0)!=1){Eb(l,j);vb(j);v[22640]=0;W(437,a+1074312|0,81,1)|0;i=v[22640];v[22640]=0;j=0;h=0;if((i|0)==1){break b}break i}b=P()|0;O()|0;break a}e=w[d+216|0]|w[d+217|0]<<8;h=w[d+230|0]|w[d+231|0]<<8;v[22640]=0;U(622,d+32|0,e|0,h|0);e=v[22640];v[22640]=0;w:{if((e|0)!=1){Eb(l,d+32|0);vb(d+32|0);v[a+480260>>2]=1;if((g|0)<4201){break w}v[22640]=0;W(437,a+1074312|0,7,1)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}break m}b=P()|0;O()|0;break a}if((g|0)>=2386){break m}e=1;h=1;break i;case 4:f=(w[d+216|0]|w[d+217|0]<<8)&4095;e=f<<16;j=a;if(f>>>0>=297){e=e|(w[d+230|0]|w[d+231|0]<<8)}v[j+1074308>>2]=e;v[22640]=0;e=Q(2,d+144|0,14686)|0;j=v[22640];v[22640]=0;x:{y:{z:{if((j|0)!=1){v[22640]=0;R(199,d+128|0,a+1074308|0);j=v[22640];v[22640]=0;if((j|0)==1){break z}f=0;v[22640]=0;U(3,d+32|0,e|0,d+128|0);j=v[22640];v[22640]=0;if((j|0)==1){break y}Eb(l,d+32|0);vb(d+32|0);vb(d+128|0);break j}b=P()|0;O()|0;break a}b=P()|0;O()|0;break x}b=P()|0;O()|0;vb(d+128|0)}vb(e);break a;case 5:v[22640]=0;e=Q(2,d+32|0,5553)|0;j=v[22640];v[22640]=0;if((j|0)!=1){Eb(l,e);vb(e);v[22640]=0;W(437,a+1074312|0,81,1)|0;i=v[22640];v[22640]=0;e=0;j=0;if((i|0)==1){break b}break i}b=P()|0;O()|0;break a;case 6:v[22640]=0;e=Q(2,d+32|0,5579)|0;j=v[22640];v[22640]=0;if((j|0)!=1){Eb(l,e);break j}b=P()|0;O()|0;break a;default:break p}}if((w[d+216|0]|w[d+217|0]<<8)!=51712){break i}v[22640]=0;e=Q(2,d+32|0,6450)|0;j=v[22640];v[22640]=0;if((j|0)!=1){Eb(l,e);break j}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}v[22640]=0;e=1;W(437,a+1074312|0,38,1)|0;i=v[22640];v[22640]=0;h=1;if((i|0)==1){break b}break i}v[22640]=0;e=a+1074312|0;W(437,e|0,7,1)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}v[22640]=0;W(437,e|0,23,1)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}v[22640]=0;W(437,e|0,38,1)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}v[22640]=0;W(437,e|0,107,1)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}e=1;v[a+480260>>2]=1;f=0;if(i>>>0>12820){break i}}v[22640]=0;_(894,d+144|0);h=v[22640];v[22640]=0;A:{B:{C:{if((h|0)!=1){v[d+16>>2]=w[d+217|0]&15;h=w[d+216|0];v[22640]=0;v[d>>2]=h;R(619,d+128|0,d|0);h=v[22640];v[22640]=0;if((h|0)==1){break C}f=0;v[22640]=0;ha(895,d+32|0,d+144|0,l|0,d+16|0,d+128|0);h=v[22640];v[22640]=0;if((h|0)==1){break B}Eb(l,d+32|0);vb(d+32|0);vb(d+128|0);Hb(d+144|0);h=0;break i}b=P()|0;O()|0;break a}b=P()|0;O()|0;break A}b=P()|0;O()|0;vb(d+128|0)}Hb(d+144|0);break a}vb(e);e=0;j=0}v[22640]=0;i=Q(2,d+32|0,12246)|0;k=v[22640];v[22640]=0;D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{if((k|0)!=1){Eb(a+1298304|0,i);vb(i);v[22640]=0;i=Q(2,d+32|0,7800)|0;k=v[22640];v[22640]=0;if((k|0)==1){break R}Eb(a+1298316|0,i);vb(i);Eb(a+1298328|0,l);v[a+1298364>>2]=v[a+1074308>>2]?8:5;if(e){v[22640]=0;e=a+1074312|0;Q(438,e|0,77)|0;i=v[22640];v[22640]=0;if((i|0)==1){break b}v[22640]=0;Q(438,e|0,78)|0;i=v[22640];v[22640]=0;if((i|0)==1){break b}v[22640]=0;Q(438,e|0,79)|0;i=v[22640];v[22640]=0;if((i|0)==1){break b}v[22640]=0;Q(438,e|0,80)|0;i=v[22640];v[22640]=0;if((i|0)==1){break b}v[22640]=0;Q(438,e|0,82)|0;i=v[22640];v[22640]=0;if((i|0)==1){break b}v[22640]=0;Q(438,e|0,96)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}}f=((w[d+216|0]|w[d+217|0]<<8)&61440)>>>0<4097|((w[d+216|0]|w[d+217|0]<<8)>>>0<12820?((w[d+216|0]|w[d+217|0]<<8)&61440)==12288:0)?f:1;v[22640]=0;e=a+901404|0;_(896,e|0);i=v[22640];v[22640]=0;if((i|0)==1){break b}if(!f){v[22640]=0;To(e);e=v[22640];v[22640]=0;if((e|0)==1){break b}}v[22640]=0;Hk(d+144|0,1,d+176|0);e=v[22640];v[22640]=0;if((e|0)==1){break Q}v[22640]=0;R(377,d+32|0,d+144|0);e=v[22640];v[22640]=0;if((e|0)==1){break Q}Eb(a+1298268|0,d+32|0);vb(d+32|0);if(w[d+214|0]&16){v[a+480208>>2]=v[a+480208>>2]|65536}if(t[d+214|0]&1){v[a+480208>>2]=v[a+480208>>2]|131072}if(!(w[d+214|0]&64?0:(w[d+216|0]|w[d+217|0]<<8)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}e=w[d+225|0];v[a+480196>>2]=e;if(!(!j|(e|0)!=255?e:0)){v[a+480196>>2]=6}v[a+480204>>2]=B(w[d+226|0],1e4);if(w[d+226|0]<=32){v[a+480204>>2]=j?125e4:32e4}t[d+32|0]=w[d+224|0];v[22640]=0;t[d+144|0]=64;e=ac(d+32|0,d+144|0);f=v[22640];v[22640]=0;if((f|0)==1){break M}e=w[e|0];v[a+480200>>2]=e<<2;if(!((w[d+216|0]|w[d+217|0]<<8)>>>0>4895|e)){v[a+480200>>2]=256}if((w[d+218|0]|w[d+219|0]<<8)!=1|w[d+227|0]>7){break O}v[d+32>>2]=(w[d+227|0]<<4)+16;v[22640]=0;v[d+144>>2]=127;e=ld(d+32|0,d+144|0);f=v[22640];v[22640]=0;if((f|0)==1){break P}v[a+480228>>2]=v[e>>2];break N}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}if(!(w[d+227|0]!=18?w[d+227|0]!=2:0)){v[a+480228>>2]=32;break N}v[d+32>>2]=w[d+227|0]&127;v[22640]=0;v[d+144>>2]=16;e=Nf(d+32|0,d+144|0);f=v[22640];v[22640]=0;if((f|0)==1){break L}v[a+480228>>2]=v[e>>2]}u[a+480188>>1]=4;v[a+480232>>2]=h?(g|0)<3299?64:36:36;h=wr(d+120|0);e=0;while(1){v[22640]=0;g=(e<<5)+a|0;k=g+480280|0;Se(k);f=v[22640];v[22640]=0;if((f|0)==1){break K}f=d+e|0;i=w[f+240|0];if(w[f+240|0]!=255){u[a+480188>>1]=e+1;u[g+480284>>1]=i&8?204:51}if(t[f+240|0]<=-1){v[k>>2]=1024}if(((i&127)-16&255)>>>0<=13){u[g+480284>>1]=128;nl(d+32|0,h,e);Af(d+32|0,1)}e=e+1|0;if((e|0)!=32){continue}break}if(!x[a+480188>>1]){u[a+480188>>1]=1}g=Rb(a+484360|0);e=w[d+208|0]|w[d+209|0]<<8;v[22640]=0;ga(540,g|0,b|0,e|0,255,254)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}q=nc(d+144|0);g=w[d+210|0]|w[d+211|0]<<8;v[22640]=0;W(358,b|0,q|0,g|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break e}i=nc(d+128|0);g=w[d+212|0]|w[d+213|0]<<8;v[22640]=0;W(358,b|0,i|0,g|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){if(w[d+229|0]==252){e=0;v[22640]=0;R(897,b|0,d+32|0);g=v[22640];v[22640]=0;if((g|0)==1){break g}while(1){f=(d+32|0)+e|0;g=w[f|0];S:{if(!(g&32)){break S}k=((e<<5)+a|0)+480284|0;if(j){nl(d+16|0,h,e);if(Cb(d+16|0)){break S}g=w[f|0]}u[k>>1]=(((g&15)<<8|8)>>>0)/15}e=e+1|0;if((e|0)!=32){continue}break}}u[d+32>>1]=w[d+210|0]|w[d+211|0]<<8;e=0;v[22640]=0;u[d+16>>1]=3999;g=Oc(d+32|0,d+16|0);h=v[22640];v[22640]=0;if((h|0)==1){break J}g=x[g>>1];u[a+480190>>1]=g;if(g){g=c&2;h=d+80|0;while(1){f=rc(q,e);f=w[f|0]|w[f+1|0]<<8;v[22640]=0;f=Q(227,b|0,f<<4)|0;k=v[22640];v[22640]=0;if((k|0)==1){break I}T:{if(!f){break T}v[22640]=0;f=Q(898,b|0,d+32|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break I}if(!f){break T}v[22640]=0;f=e+1|0;k=(B(f,104)+a|0)+484380|0;U(899,d+32|0,k|0,j|0);m=v[22640];v[22640]=0;if((m|0)==1){break I}v[22640]=0;Hk(d,1,h);m=v[22640];v[22640]=0;U:{V:{W:{if((m|0)==1){break W}v[22640]=0;R(377,d+16|0,d|0);m=v[22640];v[22640]=0;if((m|0)==1){break W}v[22640]=0;Q(333,((f<<5)+a|0)+946304|0,d+16|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break V}vb(d+16|0);if(!(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))|(!g|w[d+32|0]>1)){break T}f=w[d+46|0];m=w[d+47|0];n=w[d+45|0];v[22640]=0;f=Q(227,b|0,m<<12|f<<4|n<<20)|0;m=v[22640];v[22640]=0;if((m|0)==1){break U}if(!f){break T}f=w[d+218|0]|w[d+219|0]<<8;v[22640]=0;hR(d+16|0,d+32|0,(f|0)==1);f=v[22640];v[22640]=0;if((f|0)!=1){v[22640]=0;W(363,d+16|0,k|0,b|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){break T}}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(d+16|0);break f}b=P()|0;O()|0;break f}e=e+1|0;if(e>>>0<x[a+480190>>1]){continue}break}}s=1;if(!(c&1)){break D}c=w[d+216|0]|w[d+217|0]<<8;u[d+32>>1]=w[d+212|0]|w[d+213|0]<<8;v[22640]=0;u[d+16>>1]=255;g=Oc(d+32|0,d+16|0);e=v[22640];v[22640]=0;X:{Y:{if((e|0)!=1){r=x[g>>1];v[22640]=0;j=a+484344|0;R(364,j|0,r|0);g=v[22640];v[22640]=0;if((g|0)==1){break Y}y=c>>>0<4896;if(r){break X}k=0;m=0;break E}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}A=d+32|5;C=d+32|3;z=d+32|4;D=d+32|2;E=d+32|1;e=0;m=0;k=0;while(1){v[22640]=0;c=W(365,j|0,e&65535,64)|0;g=v[22640];v[22640]=0;if((g|0)==1){break H}Z:{if(!c){break Z}c=rc(i,e);if(!(w[c|0]|w[c+1|0]<<8)){break Z}c=rc(i,e);c=w[c|0]|w[c+1|0]<<8;v[22640]=0;c=Q(227,b|0,c<<4)|0;g=v[22640];v[22640]=0;if((g|0)==1){break H}if(!c){break Z}v[22640]=0;Q(350,b|0,2)|0;c=v[22640];v[22640]=0;if((c|0)==1){break H}p=0;c=_b(j,e);v[22640]=0;c=Pf(c,0);g=v[22640];v[22640]=0;if((g|0)==1){break G}while(1){v[22640]=0;n=T(353,b|0)|0;g=v[22640];v[22640]=0;_:{$:{if((g|0)!=1){if(n){break $}if(p>>>0>62){break Z}c=_b(j,e);v[22640]=0;p=p+1|0;c=Pf(c,p);g=v[22640];v[22640]=0;if((g|0)!=1){break _}}b=P()|0;O()|0;break f}F=Zi(d+32|0);h=n&31;g=h>>>0<x[a+480188>>1];f=B(h,6)+c|0;if(n&32){v[22640]=0;R(431,d+16|0,b|0);h=v[22640];v[22640]=0;aa:{ba:{ca:{if((h|0)!=1){o=md(d+16|0);h=w[d+16|0];if(h>>>0>239){break ca}h=(B(h>>>4|0,12)+(h&15)|0)+13|0;break ba}b=P()|0;O()|0;break f}da:{switch(h-254|0){case 0:break ba;case 1:break da;default:break aa}}h=0}t[(g?f:d+32|0)|0]=h}t[(g?f+1|0:E)|0]=w[o|0]}ea:{if(!(n&64)){break ea}v[22640]=0;h=T(353,b|0)|0;o=v[22640];v[22640]=0;fa:{if((o|0)!=1){o=g?f+2|0:D;t[d+16|0]=h;if(h<<24>>24>-1|h>>>0>192){break fa}t[o|0]=2;t[(g?f+4|0:z)|0]=w[d+16|0]^128;break ea}b=P()|0;O()|0;break f}t[o|0]=1;v[22640]=0;t[d|0]=64;h=ac(d+16|0,d);o=v[22640];v[22640]=0;if((o|0)==1){break F}t[(g?f+4|0:z)|0]=w[h|0]}if(!(n&128)){break _}v[22640]=0;R(431,d+16|0,b|0);h=v[22640];v[22640]=0;ga:{if((h|0)!=1){o=md(d+16|0);n=g?f+3|0:C;t[n|0]=w[d+16|0];h=g?f+5|0:A;t[h|0]=w[o|0];Pu(g?f:F,0);ha:{g=w[n|0];if((g|0)==20){if((w[h|0]&240)!=160){break _}if((w[d+216|0]|w[d+217|0]<<8)>>>0<4896){break ha}g=w[n|0]}if((g|0)!=31){break _}g=w[h|0];if(g>>>0<=15){break ga}y=0;break _}t[h|0]=w[h|0]&15^136;break _}b=P()|0;O()|0;break f}if(g>>>0<=7){m=m+1|0;break _}k=((g|0)!=8)+k|0}if(p>>>0<64){continue}break}}e=e+1|0;if((r|0)!=(e|0)){continue}break}break E}b=P()|0;O()|0;break f}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}if(!y){break D}a=x[a+480188>>1];if((a|0)>(k+m|0)|(a|0)<=(k-m|0)){break D}g=Oe(j)-1&65535;a=0;c=0;if(Oe(j)>>>0>g>>>0){while(1){if(hi($e(j,a))){b=Sb($e(j,a));e=Wb($e(j,a));a=gb-16|0;gb=a;v[a>>2]=e;v[a+8>>2]=b;if(Gb(a+8|0,a)){while(1){b=v[a+8>>2];if(w[b+3|0]==31){t[b+3|0]=20;t[b+5|0]=w[b+5|0]|128}Wj(a+8|0);if(Gb(a+8|0,a)){continue}break}}gb=a+16|0}c=c+1|0;a=c&65535;if(g>>>0>=a>>>0){continue}break}}}Lk(i);Lk(q);vb(l)}gb=d+272|0;return s|0}b=P()|0;O()|0}Lk(i);break d}b=P()|0;O()|0}Lk(q);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}vb(l);S(b|0);L()}function Ad(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;m=gb-16|0;gb=m;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(a>>>0<=244){f=v[116449];i=a>>>0<11?16:a+11&-8;c=i>>>3|0;b=f>>>c|0;if(b&3){d=c+((b^-1)&1)|0;b=d<<3;e=v[b+465844>>2];a=e+8|0;c=v[e+8>>2];b=b+465836|0;m:{if((c|0)==(b|0)){n=465796,o=qqa(-2,d)&f,v[n>>2]=o;break m}v[c+12>>2]=b;v[b+8>>2]=c}b=d<<3;v[e+4>>2]=b|3;b=b+e|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[116451];if(k>>>0>=i>>>0){break l}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;c=(c|a)+(b>>>a|0)|0;a=c<<3;g=v[a+465844>>2];b=v[g+8>>2];a=a+465836|0;n:{if((b|0)==(a|0)){f=qqa(-2,c)&f;v[116449]=f;break n}v[b+12>>2]=a;v[a+8>>2]=b}a=g+8|0;v[g+4>>2]=i|3;d=g+i|0;b=c<<3;e=b-i|0;v[d+4>>2]=e|1;v[b+g>>2]=e;if(k){b=k>>>3|0;c=(b<<3)+465836|0;g=v[116454];b=1<<b;o:{if(!(b&f)){v[116449]=b|f;b=c;break o}b=v[c+8>>2]}v[c+8>>2]=g;v[b+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=b}v[116454]=d;v[116451]=e;break a}h=v[116450];if(!h){break l}b=(h&0-h)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+466100>>2];d=(v[b+4>>2]&-8)-i|0;c=b;while(1){p:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break p}}c=(v[a+4>>2]&-8)-i|0;e=c>>>0<d>>>0;d=e?c:d;b=e?a:b;c=a;continue}break}j=b+i|0;if(j>>>0<=b>>>0){break k}l=v[b+24>>2];e=v[b+12>>2];if((e|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=e;v[e+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;e=a;c=a+20|0;a=v[c>>2];if(a){continue}c=e+16|0;a=v[e+16>>2];if(a){continue}break}v[g>>2]=0;break b}i=-1;if(a>>>0>4294967231){break l}a=a+11|0;i=a&-8;j=v[116450];if(!j){break l}d=0-i|0;f=0;q:{if(i>>>0<256){break q}f=31;if(i>>>0>16777215){break q}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;f=(a<<1|i>>>a+21&1)+28|0}c=v[(f<<2)+466100>>2];r:{s:{t:{if(!c){a=0;break t}a=0;b=i<<((f|0)==31?0:25-(f>>>1|0)|0);while(1){u:{g=(v[c+4>>2]&-8)-i|0;if(g>>>0>=d>>>0){break u}e=c;d=g;if(d){break u}d=0;a=c;break s}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|e)){e=0;a=2<<f;a=(0-a|a)&j;if(!a){break l}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+466100>>2]}if(!a){break r}}while(1){b=(v[a+4>>2]&-8)-i|0;c=b>>>0<d>>>0;d=c?b:d;e=c?a:e;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!e|v[116451]-i>>>0<=d>>>0){break l}h=e+i|0;if(h>>>0<=e>>>0){break k}f=v[e+24>>2];b=v[e+12>>2];if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=e+20|0;a=v[c>>2];if(!a){a=v[e+16>>2];if(!a){break i}c=e+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[116451];if(c>>>0>=i>>>0){d=v[116454];b=c-i|0;v:{if(b>>>0>=16){v[116451]=b;a=d+i|0;v[116454]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=i|3;break v}v[116454]=0;v[116451]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}h=v[116452];if(h>>>0>i>>>0){b=h-i|0;v[116452]=b;c=v[116455];a=c+i|0;v[116455]=a;v[a+4>>2]=b|1;v[c+4>>2]=i|3;a=c+8|0;break a}a=0;j=i+47|0;b=j;if(v[116567]){c=v[116569]}else{v[116570]=-1;v[116571]=-1;v[116568]=4096;v[116569]=4096;v[116567]=m+12&-16^1431655768;v[116572]=0;v[116560]=0;c=4096}g=b+c|0;e=0-c|0;c=g&e;if(c>>>0<=i>>>0){break a}d=v[116559];if(d){b=v[116557];f=b+c|0;if(d>>>0<f>>>0|b>>>0>=f>>>0){break a}}if(w[466240]&4){break f}w:{x:{d=v[116455];if(d){a=466244;while(1){b=v[a>>2];if(d>>>0<b+v[a+4>>2]>>>0?b>>>0<=d>>>0:0){break x}a=v[a+8>>2];if(a){continue}break}}b=Vp(0);if((b|0)==-1){break g}f=c;d=v[116568];a=d-1|0;if(a&b){f=(c-b|0)+(a+b&0-d)|0}if(f>>>0<=i>>>0|f>>>0>2147483646){break g}d=v[116559];if(d){a=v[116557];e=a+f|0;if(d>>>0<e>>>0|a>>>0>=e>>>0){break g}}a=Vp(f);if((b|0)!=(a|0)){break w}break e}f=e&g-h;if(f>>>0>2147483646){break g}b=Vp(f);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|i+48>>>0<=f>>>0)){b=v[116569];b=b+(j-f|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((Vp(b)|0)!=-1){f=b+f|0;b=a;break e}Vp(0-f|0);break g}b=a;if((a|0)!=-1){break e}break g}L()}e=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[116560]=v[116560]|4}if(c>>>0>2147483646){break d}b=v[22636];c=c+3&-4;a=b+c|0;y:{z:{if(a>>>0<=b>>>0?c:0){break z}if(Pw()>>>0<a>>>0){if(!(va(a|0)|0)){break z}}v[22636]=a;break y}v[115121]=48;a=v[22636];b=-1}A:{if(Pw()>>>0>=a>>>0){break A}if(va(a|0)|0){break A}v[115121]=48;break d}v[22636]=a;if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}f=a-b|0;if(f>>>0<=i+40>>>0){break d}}a=v[116557]+f|0;v[116557]=a;if(a>>>0>y[116558]){v[116558]=a}B:{C:{D:{g=v[116455];if(g){a=466244;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break D}a=v[a+8>>2];if(a){continue}break}break C}a=v[116453];if(!(a>>>0<=b>>>0?a:0)){v[116453]=b}a=0;v[116562]=f;v[116561]=b;v[116457]=-1;v[116458]=v[116567];v[116564]=0;while(1){d=a<<3;c=d+465836|0;v[d+465844>>2]=c;v[d+465848>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116452]=c;a=a+b|0;v[116455]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116456]=v[116571];break B}if(w[a+12|0]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break C}v[a+4>>2]=c+f;a=g+8&7?-8-g&7:0;c=a+g|0;v[116455]=c;b=v[116452]+f|0;a=b-a|0;v[116452]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[116456]=v[116571];break B}if(y[116453]>b>>>0){v[116453]=b}c=b+f|0;a=466244;E:{F:{G:{H:{I:{J:{while(1){if((c|0)!=v[a>>2]){a=v[a+8>>2];if(a){continue}break J}break}if(!(w[a+12|0]&8)){break I}}a=466244;while(1){c=v[a>>2];if(c>>>0<=g>>>0){e=c+v[a+4>>2]|0;if(e>>>0>g>>>0){break H}}a=v[a+8>>2];continue}}v[a>>2]=b;v[a+4>>2]=v[a+4>>2]+f;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=i|3;f=c+(c+8&7?-8-c&7:0)|0;h=i+j|0;c=f-h|0;if((g|0)==(f|0)){v[116455]=h;a=v[116452]+c|0;v[116452]=a;v[h+4>>2]=a|1;break F}if(v[116454]==(f|0)){v[116454]=h;a=v[116451]+c|0;v[116451]=a;v[h+4>>2]=a|1;v[a+h>>2]=a;break F}a=v[f+4>>2];if((a&3)==1){g=a&-8;K:{if(a>>>0<=255){d=v[f+8>>2];a=a>>>3|0;b=v[f+12>>2];if((b|0)==(d|0)){n=465796,o=v[116449]&qqa(-2,a),v[n>>2]=o;break K}v[d+12>>2]=b;v[b+8>>2]=d;break K}i=v[f+24>>2];b=v[f+12>>2];L:{if((f|0)!=(b|0)){a=v[f+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break L}M:{a=f+20|0;d=v[a>>2];if(d){break M}a=f+16|0;d=v[a>>2];if(d){break M}b=0;break L}while(1){e=a;b=d;a=b+20|0;d=v[a>>2];if(d){continue}a=b+16|0;d=v[b+16>>2];if(d){continue}break}v[e>>2]=0}if(!i){break K}d=v[f+28>>2];a=(d<<2)+466100|0;N:{if(v[a>>2]==(f|0)){v[a>>2]=b;if(b){break N}n=465800,o=v[116450]&qqa(-2,d),v[n>>2]=o;break K}v[i+(v[i+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break K}}v[b+24>>2]=i;a=v[f+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[f+20>>2];if(!a){break K}v[b+20>>2]=a;v[a+24>>2]=b}f=g+f|0;c=c+g|0}v[f+4>>2]=v[f+4>>2]&-2;v[h+4>>2]=c|1;v[c+h>>2]=c;if(c>>>0<=255){a=c>>>3|0;b=(a<<3)+465836|0;c=v[116449];a=1<<a;O:{if(!(c&a)){v[116449]=a|c;a=b;break O}a=v[b+8>>2]}v[b+8>>2]=h;v[a+12>>2]=h;v[h+12>>2]=b;v[h+8>>2]=a;break F}a=31;if(c>>>0<=16777215){a=c>>>8|0;e=a+1048320>>>16&8;a=a<<e;d=a+520192>>>16&4;a=a<<d;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(d|e))|0;a=(a<<1|c>>>a+21&1)+28|0}v[h+28>>2]=a;v[h+16>>2]=0;v[h+20>>2]=0;e=(a<<2)+466100|0;d=v[116450];b=1<<a;P:{if(!(d&b)){v[116450]=b|d;v[e>>2]=h;v[h+24>>2]=e;break P}a=c<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[e>>2];while(1){d=b;if((v[b+4>>2]&-8)==(c|0)){break G}b=a>>>29|0;a=a<<1;e=d+(b&4)|0;b=v[e+16>>2];if(b){continue}break}v[e+16>>2]=h;v[h+24>>2]=d}v[h+12>>2]=h;v[h+8>>2]=h;break F}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[116452]=c;a=a+b|0;v[116455]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[116456]=v[116571];a=(e+(e-39&7?39-e&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[116564];v[c+16>>2]=v[116563];v[c+20>>2]=a;a=v[116562];v[c+8>>2]=v[116561];v[c+12>>2]=a;v[116563]=c+8;v[116562]=f;v[116561]=b;v[116564]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<e>>>0){continue}break}if((c|0)==(g|0)){break B}v[c+4>>2]=v[c+4>>2]&-2;e=c-g|0;v[g+4>>2]=e|1;v[c>>2]=e;if(e>>>0<=255){a=e>>>3|0;b=(a<<3)+465836|0;c=v[116449];a=1<<a;Q:{if(!(c&a)){v[116449]=a|c;a=b;break Q}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break B}a=31;v[g+16>>2]=0;v[g+20>>2]=0;if(e>>>0<=16777215){a=e>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|e>>>a+21&1)+28|0}v[g+28>>2]=a;d=(a<<2)+466100|0;c=v[116450];b=1<<a;R:{if(!(c&b)){v[116450]=b|c;v[d>>2]=g;v[g+24>>2]=d;break R}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[d>>2];while(1){c=b;if((e|0)==(v[b+4>>2]&-8)){break E}b=a>>>29|0;a=a<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=g;v[g+24>>2]=c}v[g+12>>2]=g;v[g+8>>2]=g;break B}a=v[d+8>>2];v[a+12>>2]=h;v[d+8>>2]=h;v[h+24>>2]=0;v[h+12>>2]=d;v[h+8>>2]=a}a=j+8|0;break a}a=v[c+8>>2];v[a+12>>2]=g;v[c+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=c;v[g+8>>2]=a}a=v[116452];if(a>>>0<=i>>>0){break d}b=a-i|0;v[116452]=b;c=v[116455];a=c+i|0;v[116455]=a;v[a+4>>2]=b|1;v[c+4>>2]=i|3;a=c+8|0;break a}v[115121]=48;a=0;break a}S:{if(!f){break S}c=v[e+28>>2];a=(c<<2)+466100|0;T:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break T}j=qqa(-2,c)&j;v[116450]=j;break S}v[f+(v[f+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break S}}v[b+24>>2]=f;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break S}v[b+20>>2]=a;v[a+24>>2]=b}U:{if(d>>>0<=15){a=d+i|0;v[e+4>>2]=a|3;a=a+e|0;v[a+4>>2]=v[a+4>>2]|1;break U}v[e+4>>2]=i|3;v[h+4>>2]=d|1;v[d+h>>2]=d;if(d>>>0<=255){a=d>>>3|0;b=(a<<3)+465836|0;c=v[116449];a=1<<a;V:{if(!(c&a)){v[116449]=a|c;a=b;break V}a=v[b+8>>2]}v[b+8>>2]=h;v[a+12>>2]=h;v[h+12>>2]=b;v[h+8>>2]=a;break U}a=31;if(d>>>0<=16777215){a=d>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|d>>>a+21&1)+28|0}v[h+28>>2]=a;v[h+16>>2]=0;v[h+20>>2]=0;c=(a<<2)+466100|0;W:{b=1<<a;X:{if(!(b&j)){v[116450]=b|j;v[c>>2]=h;v[h+24>>2]=c;break X}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);i=v[c>>2];while(1){b=i;if((v[b+4>>2]&-8)==(d|0)){break W}c=a>>>29|0;a=a<<1;c=b+(c&4)|0;i=v[c+16>>2];if(i){continue}break}v[c+16>>2]=h;v[h+24>>2]=b}v[h+12>>2]=h;v[h+8>>2]=h;break U}a=v[b+8>>2];v[a+12>>2]=h;v[b+8>>2]=h;v[h+24>>2]=0;v[h+12>>2]=b;v[h+8>>2]=a}a=e+8|0;break a}Y:{if(!l){break Y}c=v[b+28>>2];a=(c<<2)+466100|0;Z:{if(v[a>>2]==(b|0)){v[a>>2]=e;if(e){break Z}n=465800,o=qqa(-2,c)&h,v[n>>2]=o;break Y}v[(v[l+16>>2]==(b|0)?16:20)+l>>2]=e;if(!e){break Y}}v[e+24>>2]=l;a=v[b+16>>2];if(a){v[e+16>>2]=a;v[a+24>>2]=e}a=v[b+20>>2];if(!a){break Y}v[e+20>>2]=a;v[a+24>>2]=e}_:{if(d>>>0<=15){a=d+i|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break _}v[b+4>>2]=i|3;v[j+4>>2]=d|1;v[d+j>>2]=d;if(k){a=k>>>3|0;c=(a<<3)+465836|0;e=v[116454];a=1<<a;$:{if(!(a&f)){v[116449]=a|f;a=c;break $}a=v[c+8>>2]}v[c+8>>2]=e;v[a+12>>2]=e;v[e+12>>2]=c;v[e+8>>2]=a}v[116454]=j;v[116451]=d}a=b+8|0}gb=m+16|0;return a|0}function _8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;a:{b:{c:{d:{e:{f:{if(ne(b,18693)){Kb(a);break f}if(ne(b,7207)){b=gb-96|0;gb=b;c=Kb(a);v[22640]=0;_(192,b- -64|0);a=v[22640];v[22640]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[22640]=0;v[b+32>>2]=0;R(2036,b+48|0,b+32|0);a=v[22640];v[22640]=0;if((a|0)==1){break p}v[22640]=0;Q(1183,c|0,b+48|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break o}vb(b+48|0);v[22640]=0;Q(1917,c|0,13880)|0;a=v[22640];v[22640]=0;q:{if((a|0)==1){break q}v[22640]=0;v[b+32>>2]=6;R(2036,b+48|0,b+32|0);a=v[22640];v[22640]=0;if((a|0)==1){break n}v[22640]=0;Q(1183,c|0,b+48|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break m}vb(b+48|0);v[22640]=0;Q(1917,c|0,13880)|0;a=v[22640];v[22640]=0;if((a|0)==1){break q}v[22640]=0;v[b+32>>2]=0;R(2036,b+48|0,b+32|0);a=v[22640];v[22640]=0;if((a|0)==1){break l}v[22640]=0;Q(1183,c|0,b+48|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break k}vb(b+48|0);v[22640]=0;a=Q(112,b+48|0,12234)|0;e=v[22640];v[22640]=0;if((e|0)==1){break j}e=Ab(a);vb(a);if(!e){break i}v[22640]=0;Q(1917,c|0,12234)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break c}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;vb(b+48|0);break h}a=P()|0;O()|0;break h}e=nc(b+48|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(v[(b- -64|0)+12>>2]){a=v[(b- -64|0)+12>>2];v[22640]=0;v[b+12>>2]=a;R(2036,b+16|0,b+12|0);a=v[22640];v[22640]=0;if((a|0)==1){break D}v[22640]=0;U(2037,b+32|0,6175,b+16|0);a=v[22640];v[22640]=0;if((a|0)==1){break C}v[22640]=0;R(1429,e|0,b+32|0);a=v[22640];v[22640]=0;if((a|0)==1){break B}vb(b+32|0);vb(b+16|0)}if(!w[(b- -64|0)+16|0]){break x}v[22640]=0;d=Q(112,b+32|0,10129)|0;a=v[22640];v[22640]=0;if((a|0)==1){break z}v[22640]=0;R(1429,e|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break y}vb(d);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d);break r}if(!w[(b- -64|0)+17|0]){break w}v[22640]=0;d=Q(112,b+32|0,9829)|0;a=v[22640];v[22640]=0;if((a|0)==1){break v}v[22640]=0;R(1429,e|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break u}vb(d)}if(w[(b- -64|0)+18|0]){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d);break r}v[22640]=0;d=Q(112,b+32|0,8389)|0;a=v[22640];v[22640]=0;E:{if((a|0)!=1){v[22640]=0;R(1429,e|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break E}vb(d);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;vb(d);break r}if($c(e)){break g}v[22640]=0;Q(1917,c|0,13910)|0;a=v[22640];v[22640]=0;if((a|0)!=1){v[22640]=0;d=Q(112,b+16|0,13880)|0;a=v[22640];v[22640]=0;F:{G:{H:{if((a|0)!=1){v[22640]=0;U(2038,b+32|0,e|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break H}v[22640]=0;Q(1183,c|0,b+32|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break G}vb(b+32|0);vb(d);break g}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;vb(b+32|0)}vb(d);break r}a=P()|0;O()|0}vd(e)}Ef(b- -64|0);break c}vd(e);Ef(b- -64|0);gb=b+96|0;break f}if(ne(b,5345)){v[f>>2]=0;lq(a,f);break f}if(ne(b,5323)){v[f>>2]=6;lq(a,f);break f}if(ne(b,8142)){v[f>>2]=0;lq(a,f);break f}if(ne(b,7939)){Tb(a,12234);break f}if(ne(b,8743)){b=Tb(f,12234);e=Ab(b);v[22640]=0;Q(112,a|0,(e?12943:12624)|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break e}vb(b);break f}if(ne(b,4450)){b=gb-48|0;gb=b;jG(b+16|0);v[22640]=0;_(210,b|0);e=v[22640];v[22640]=0;I:{J:{K:{L:{if((e|0)!=1){v[22640]=0;U(211,b+32|0,b+16|0,b|0);e=v[22640];v[22640]=0;if((e|0)==1){break L}v[22640]=0;R(2039,a|0,b+32|0);a=v[22640];v[22640]=0;if((a|0)==1){break K}vb(b+32|0);vb(b);vb(b+16|0);gb=b+48|0;break f}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(b+32|0)}vb(b)}vb(b+16|0);break a}if(ne(b,7235)){b=gb-16|0;gb=b;h=gb-16|0;gb=h;v[h+8>>2]=101;e=b;d=gb-112|0;gb=d;g=nc(d+96|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{c=v[h+8>>2];if(c&1){v[22640]=0;v[d+48>>2]=19923012;R(199,d- -64|0,d+48|0);c=v[22640];v[22640]=0;if((c|0)==1){break $}v[22640]=0;R(179,g|0,d- -64|0);c=v[22640];v[22640]=0;if((c|0)==1){break _}vb(d- -64|0);c=v[h+8>>2]}if(!(c&4)){break Y}v[22640]=0;c=fa(200)|0;i=v[22640];v[22640]=0;if((i|0)==1){break X}if(!c){break Z}break Y}c=P()|0;O()|0;break N}c=P()|0;O()|0;vb(d- -64|0);break N}v[22640]=0;_(201,d- -64|0);c=v[22640];v[22640]=0;aa:{if((c|0)!=1){v[22640]=0;R(179,g|0,d- -64|0);c=v[22640];v[22640]=0;if((c|0)==1){break aa}vb(d- -64|0);break Y}c=P()|0;O()|0;break N}c=P()|0;O()|0;vb(d- -64|0);break N}ba:{c=v[h+8>>2];if(!(c&32)){break ba}v[22640]=0;_(192,d- -64|0);c=v[22640];v[22640]=0;ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((c|0)!=1){v[22640]=0;R(202,d+48|0,d- -64|0);c=v[22640];v[22640]=0;if((c|0)==1){break da}c=dd(d+48|0);vb(d+48|0);if(!c){v[22640]=0;_(203,d+32|0);c=v[22640];v[22640]=0;if((c|0)==1){break ua}v[22640]=0;R(202,d+16|0,d- -64|0);c=v[22640];v[22640]=0;if((c|0)==1){break ta}v[22640]=0;U(204,d+48|0,d+32|0,d+16|0);c=v[22640];v[22640]=0;if((c|0)==1){break sa}v[22640]=0;R(179,g|0,d+48|0);c=v[22640];v[22640]=0;if((c|0)==1){break ra}vb(d+48|0);vb(d+16|0);Hb(d+32|0)}if(!dd(Pp(d- -64|0))){v[22640]=0;_(205,d+32|0);c=v[22640];v[22640]=0;if((c|0)==1){break oa}c=Pp(d- -64|0);v[22640]=0;U(206,d+48|0,d+32|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break na}v[22640]=0;R(179,g|0,d+48|0);c=v[22640];v[22640]=0;if((c|0)==1){break ma}vb(d+48|0);Hb(d+32|0)}v[22640]=0;R(207,d+48|0,d- -64|0);c=v[22640];v[22640]=0;if((c|0)==1){break ka}c=dd(d+48|0);vb(d+48|0);if(!c){v[22640]=0;_(203,d+32|0);c=v[22640];v[22640]=0;if((c|0)==1){break ja}v[22640]=0;R(207,d+16|0,d- -64|0);c=v[22640];v[22640]=0;if((c|0)==1){break ia}v[22640]=0;U(204,d+48|0,d+32|0,d+16|0);c=v[22640];v[22640]=0;if((c|0)==1){break ha}v[22640]=0;R(179,g|0,d+48|0);c=v[22640];v[22640]=0;if((c|0)==1){break ga}vb(d+48|0);vb(d+16|0);Hb(d+32|0)}Ef(d- -64|0);c=v[h+8>>2];break ba}c=P()|0;O()|0;break N}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break pa}c=P()|0;O()|0;break qa}c=P()|0;O()|0;vb(d+48|0)}vb(d+16|0)}Hb(d+32|0);break ca}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break la}c=P()|0;O()|0;vb(d+48|0)}Hb(d+32|0);break ca}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break ca}c=P()|0;O()|0;break ea}c=P()|0;O()|0;break fa}c=P()|0;O()|0;vb(d+48|0)}vb(d+16|0)}Hb(d+32|0);break ca}c=P()|0;O()|0}Ef(d- -64|0);break N}va:{if(!(c&64)){break va}v[22640]=0;c=fa(200)|0;i=v[22640];v[22640]=0;if((i|0)==1){break X}if(c){break va}Kb(d- -64|0);v[22640]=0;R(179,g|0,d- -64|0);c=v[22640];v[22640]=0;if((c|0)==1){break O}vb(d- -64|0)}if(w[h+8|0]&128){v[22640]=0;_(208,d- -64|0);c=v[22640];v[22640]=0;if((c|0)==1){break W}v[22640]=0;R(179,g|0,d- -64|0);c=v[22640];v[22640]=0;if((c|0)==1){break V}vb(d- -64|0)}v[22640]=0;i=Q(2,d- -64|0,18693)|0;c=v[22640];v[22640]=0;if((c|0)==1){break U}v[22640]=0;U(209,d|0,g|0,i|0);c=v[22640];v[22640]=0;if((c|0)==1){break T}v[22640]=0;_(210,d+48|0);c=v[22640];v[22640]=0;if((c|0)==1){break S}v[22640]=0;U(211,e|0,d|0,d+48|0);e=v[22640];v[22640]=0;if((e|0)==1){break R}vb(d+48|0);vb(d);vb(i);jm(g);gb=d+112|0;break M}c=P()|0;O()|0;break N}c=P()|0;O()|0;break N}c=P()|0;O()|0;vb(d- -64|0);break N}c=P()|0;O()|0;break N}c=P()|0;O()|0;break P}c=P()|0;O()|0;break Q}c=P()|0;O()|0;vb(d+48|0)}vb(d)}vb(i);break N}c=P()|0;O()|0;vb(d- -64|0)}jm(g);S(c|0);L()}gb=h+16|0;v[22640]=0;R(2039,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(ne(b,7851)){b=gb-48|0;gb=b;us(b);v[22640]=0;R(202,b+32|0,b|0);e=v[22640];v[22640]=0;wa:{xa:{if((e|0)!=1){v[22640]=0;R(2039,a|0,b+32|0);a=v[22640];v[22640]=0;if((a|0)==1){break xa}vb(b+32|0);Ef(b);gb=b+48|0;break f}a=P()|0;O()|0;break wa}a=P()|0;O()|0;vb(b+32|0)}Ef(b);break a}if(ne(b,8706)){b=gb-32|0;gb=b;us(b);e=Pp(b);v[22640]=0;R(2039,a|0,e|0);a=v[22640];v[22640]=0;if((a|0)!=1){Ef(b);gb=b+32|0;break f}a=P()|0;O()|0;Ef(b);break a}if(ne(b,7248)){b=gb-48|0;gb=b;us(b+16|0);ya:{if(v[b+28>>2]){e=v[b+28>>2];v[22640]=0;v[b+12>>2]=e;R(2036,a|0,b+12|0);a=v[22640];v[22640]=0;if((a|0)!=1){break ya}a=P()|0;O()|0;Ef(b+16|0);break a}Kb(a)}Ef(b+16|0);gb=b+48|0;break f}if(ne(b,10119)){us(f);b=w[f+16|0];v[22640]=0;Q(112,a|0,(b?12624:12943)|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){Ef(f);break f}a=P()|0;O()|0;Ef(f);break a}if(ne(b,7264)){us(f);b=w[f+17|0];v[22640]=0;Q(112,a|0,(b?12624:12943)|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){Ef(f);break f}a=P()|0;O()|0;Ef(f);break a}if(ne(b,9517)){us(f);b=w[f+18|0];v[22640]=0;Q(112,a|0,(b?12624:12943)|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){Ef(f);break f}a=P()|0;O()|0;Ef(f);break a}if(ne(b,9803)){b=gb-16|0;gb=b;e=gb-32|0;gb=e;d=Kb(b);v[22640]=0;_(192,e|0);c=v[22640];v[22640]=0;za:{Aa:{Ba:{if((c|0)!=1){c=Pp(e);v[22640]=0;Q(193,d|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break Ba}Ef(e);gb=e+32|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;Ef(e)}vb(d);break a}v[22640]=0;R(2039,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(ne(b,5466)){b=gb-16|0;gb=b;e=gb-48|0;gb=e;d=Kb(b);v[22640]=0;R(195,e+16|0,1244);c=v[22640];v[22640]=0;Ca:{Da:{Ea:{Fa:{Ga:{if((c|0)!=1){v[e+12>>2]=13;v[e+8>>2]=0;v[22640]=0;v[e+4>>2]=0;ha(196,e+32|0,e+16|0,e+12|0,e+8|0,e+4|0);c=v[22640];v[22640]=0;if((c|0)==1){break Ga}v[22640]=0;Q(155,d|0,e+32|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break Fa}vb(e+32|0);Hb(e+16|0);gb=e+48|0;break Ca}a=P()|0;O()|0;break Da}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;vb(e+32|0)}Hb(e+16|0)}vb(d);S(a|0);L()}v[22640]=0;R(2039,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(ne(b,3885)){b=gb-16|0;gb=b;ko(b,0,16639);v[22640]=0;R(2039,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(ne(b,3518)){b=gb-48|0;gb=b;c=Tb(b+16|0,14723);v[22640]=0;R(2040,b|0,2);e=v[22640];v[22640]=0;Ha:{Ia:{Ja:{Ka:{if((e|0)!=1){v[22640]=0;U(3,b+32|0,c|0,b|0);e=v[22640];v[22640]=0;if((e|0)==1){break Ka}v[22640]=0;R(2039,a|0,b+32|0);a=v[22640];v[22640]=0;if((a|0)==1){break Ja}vb(b+32|0);vb(b);vb(c);gb=b+48|0;break f}a=P()|0;O()|0;break Ha}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;vb(b+32|0)}vb(b)}break c}if(ne(b,8729)){b=gb-16|0;gb=b;ko(b,0,15039);v[22640]=0;R(2039,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(ne(b,7858)){b=gb-16|0;gb=b;rs(b,0);v[22640]=0;R(2039,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(ne(b,7833)){b=gb-16|0;gb=b;rs(b,2);v[22640]=0;R(2039,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}if(ne(b,7818)){b=gb-16|0;gb=b;rs(b,3);v[22640]=0;R(2039,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(b);gb=b+16|0;break f}break b}Kb(a)}gb=f+32|0;break d}a=P()|0;O()|0;vb(b);break a}return}vb(c);break a}a=P()|0;O()|0;vb(b)}S(a|0);L()}function W7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=gb-48|0;gb=e;d=Tb(e+32|0,8940);f=Wg(c,d);vb(d);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(f){zl(a,v[b+24>>2]+1298316|0);break k}d=Tb(e+32|0,8294);f=Wg(c,d);vb(d);if(f){zl(a,v[b+24>>2]+1298304|0);break k}d=Tb(e+32|0,8770);f=Wg(c,d);vb(d);if(f){zl(a,v[b+24>>2]+1298352|0);break k}d=Tb(e+32|0,8286);f=Wg(c,d);vb(d);if(f){zl(a,v[b+24>>2]+1298340|0);break k}d=Tb(e+32|0,5456);f=Wg(c,d);vb(d);if(f){c=e+32|0;d=v[v[b+24>>2]+480184>>2];b=39424;l:{while(1){if((d|0)==v[b>>2]){ko(c,0,v[b+8>>2]);break l}b=b+12|0;if((b|0)!=39472){continue}break}Kb(c)}v[22640]=0;R(2039,a|0,e+32|0);a=v[22640];v[22640]=0;if((a|0)==1){break j}vb(e+32|0);break k}d=Tb(e+32|0,8271);f=Wg(c,d);vb(d);if(f){m=v[v[b+24>>2]+480184>>2];c=gb-48|0;gb=c;b=39424;h=Ck(c+32|0);d=Kb(e+32|0);while(1){if((m|0)==v[b>>2]){f=v[b+4>>2];v[22640]=0;f=Q(2,c+16|0,f|0)|0;i=v[22640];v[22640]=0;m:{n:{o:{p:{q:{r:{if((i|0)!=1){v[22640]=0;U(1420,c|0,h|0,f|0);i=v[22640];v[22640]=0;if((i|0)==1){break p}if(!w[c+4|0]){break m}if(!dd(d)){v[22640]=0;i=Q(2,c|0,14834)|0;g=v[22640];v[22640]=0;if((g|0)==1){break r}v[22640]=0;Q(155,d|0,i|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break q}vb(i)}v[22640]=0;Q(155,d|0,f|0)|0;i=v[22640];v[22640]=0;if((i|0)!=1){break m}b=P()|0;O()|0;break o}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;vb(i);break o}b=P()|0;O()|0}vb(f)}vb(d);lO(h);S(b|0);L()}vb(f)}b=b+12|0;if((b|0)!=39472){continue}break}lO(h);gb=c+48|0;v[22640]=0;R(2039,a|0,e+32|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,5522);f=Wg(c,d);vb(d);if(f){zl(a,v[b+24>>2]+1298328|0);break k}d=Tb(e+32|0,2712);f=Wg(c,d);vb(d);if(f){zl(a,v[b+24>>2]+1298280|0);break k}d=Tb(e+32|0,9308);f=Wg(c,d);vb(d);if(f){cg(e+32|0,v[b+24>>2]+1298268|0);v[22640]=0;U(2092,a|0,b|0,e+32|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,8713);f=Wg(c,d);vb(d);if(f){s:{if(!$c(zy(v[b+24>>2]))){if(v[YK(zy(v[b+24>>2]))+12>>2]){break s}}Kb(a);break k}b=YK(zy(v[b+24>>2]));g=gb-192|0;gb=g;hc(g+144|0,b,44);h=v[b+44>>2];if(h){hc(g+44|0,b,44);c=gb-16|0;gb=c;b=dy(v[g+64>>2]+1900|0,v[g+60>>2]+1|0,v[g+56>>2])-dy(1970,1,1)|0;b=mqa(b,b>>31,86400,0);d=B(v[g+52>>2],3600);f=d;b=b+d|0;d=jb+(d>>31)|0;d=b>>>0<f>>>0?d+1|0:d;f=b;b=B(v[g+48>>2],60);i=b;f=f+b|0;b=(b>>31)+d|0;b=f>>>0<i>>>0?b+1|0:b;d=v[g+44>>2];i=d;f=d+f|0;d=(d>>31)+b|0;b=nJ(c+8|0,f,f>>>0<i>>>0?d+1|0:d);d=v[b+4>>2];b=v[b>>2];gb=c+16|0;v[g+96>>2]=b;v[g+100>>2]=d;d=g+88|0;f=v[g+96>>2];i=v[g+100>>2];c=2147483647;l=fe(+(h>>>0)*.054945054945054944);b=-1;t:{if(!(l<0x8000000000000000)){break t}c=-2147483648;b=0;if(!(l>-0x8000000000000000)){break t}if(D(l)<0x8000000000000000){c=D(l)>=1?~~(l>0?F(H(l*2.3283064365386963e-10),4294967295):I((l-+(~~l>>>0>>>0))*2.3283064365386963e-10))>>>0:0;b=~~l>>>0;break t}b=0}j=d;d=c+i|0;f=b+f|0;d=f>>>0<b>>>0?d+1|0:d;b=nJ(j,f,d);k=gb-16|0;gb=k;h=v[b>>2];n=v[b+4>>2];v[k+12>>2]=0;v[k+8>>2]=0;v[k+4>>2]=0;b=dy(1970,1,1)+nqa(h,n,86400,0)|0;m=b>>31;c=b;d=mqa(b,m,1e4,0)+14780|0;b=jb;i=d;b=d>>>0<14780?b+1|0:b;f=b;d=nqa(d,b,-14609700,-1);b=c;j=d+b|0;d=m+jb|0;d=b>>>0>j>>>0?d+1|0:d;b=j;j=nqa(i,f,365242500,0);b=b+j|0;d=jb+d|0;d=b>>>0<j>>>0?d+1|0:d;j=nqa(i,f,-146097e4,-1);b=j+b|0;d=jb+d|0;d=b>>>0<j>>>0?d+1|0:d;j=b;b=nqa(i,f,3652425,0);f=jb;o=f;i=j;j=mqa(b,f,-365,-1);i=i+j|0;f=jb+d|0;f=i>>>0<j>>>0?f+1|0:f;d=f;if(!((d|0)>0?1:(d|0)>=0)){d=o-(b>>>0<1)|0;b=b-1|0;f=mqa(b,d,-365,-1)+c|0;d=m+jb|0;d=c>>>0>f>>>0?d+1|0:d;c=f;f=(b|0)/-4|0;i=f;c=c+f|0;f=(f>>31)+d|0;f=c>>>0<i>>>0?f+1|0:f;d=c;c=(b|0)/100|0;i=c;d=d+c|0;c=(c>>31)+f|0;c=d>>>0<i>>>0?c+1|0:c;f=d;d=(b|0)/-400|0;i=d;f=f+d|0;d=(d>>31)+c|0;d=f>>>0<i>>>0?d+1|0:d;i=f}f=b;c=mqa(i,d,100,0)+52|0;b=jb;b=nqa(c,c>>>0<52?b+1|0:b,3060,0);c=b+2|0;d=(c|0)/12|0;v[k+12>>2]=f+d;v[k+8>>2]=(c-B(d,12)|0)+1;b=mqa(b,jb,306,0)+5|0;d=jb;b=nqa(b,b>>>0<5?d+1|0:d,-10,-1)+i|0;v[k+4>>2]=b+1;v[g+136>>2]=0;v[g+128>>2]=0;v[g+132>>2]=0;v[g+120>>2]=0;v[g+124>>2]=0;v[g+116>>2]=v[k+12>>2]-1900;v[g+112>>2]=v[k+8>>2]-1;b=v[k+4>>2];p=g,q=oqa(nqa(h,n,3600,0),jb,24),v[p+104>>2]=q;v[g+108>>2]=b;b=nqa(h,n,60,0);c=jb;p=g,q=oqa(b,c,60),v[p+100>>2]=q;p=g,q=h-mqa(b,c,60,0)|0,v[p+96>>2]=q;gb=k+16|0;hc(g+144|0,g+96|0,44)}i=e+32|0;m=hc(g,g+144|0,44);c=m;b=gb-112|0;gb=b;d=Kb(b+96|0);v[22640]=0;f=Q(2,b+80|0,10844)|0;h=v[22640];v[22640]=0;u:{v:{w:{x:{y:{if((h|0)!=1){h=v[c+20>>2];if(!h){break v}v[22640]=0;v[b+48>>2]=h+1900;R(154,b- -64|0,b+48|0);h=v[22640];v[22640]=0;if((h|0)!=1){v[22640]=0;Q(155,d|0,b- -64|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break y}vb(b- -64|0);if(y[c+16>>2]>11){break v}v[22640]=0;h=Q(2,b+48|0,13908)|0;g=v[22640];v[22640]=0;z:{A:{B:{C:{D:{E:{if((g|0)!=1){g=v[c+16>>2];v[22640]=0;v[b+16>>2]=g+1;R(156,b+32|0,b+16|0);g=v[22640];v[22640]=0;if((g|0)==1){break E}v[22640]=0;U(3,b- -64|0,h|0,b+32|0);g=v[22640];v[22640]=0;if((g|0)==1){break D}v[22640]=0;Q(155,d|0,b- -64|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break C}vb(b- -64|0);vb(b+32|0);vb(h);if(v[c+12>>2]-1>>>0<=30){break z}break v}a=P()|0;O()|0;break x}a=P()|0;O()|0;break A}a=P()|0;O()|0;break B}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(h);break x}v[22640]=0;h=Q(2,b+48|0,13908)|0;g=v[22640];v[22640]=0;F:{G:{H:{I:{J:{K:{L:{M:{if((g|0)!=1){v[22640]=0;R(156,b+32|0,c+12|0);g=v[22640];v[22640]=0;if((g|0)==1){break M}v[22640]=0;U(3,b- -64|0,h|0,b+32|0);g=v[22640];v[22640]=0;if((g|0)==1){break L}v[22640]=0;Q(155,d|0,b- -64|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break K}vb(b- -64|0);vb(b+32|0);vb(h);h=v[c+8>>2];if(h){break H}h=v[c+4>>2];if(h){break G}if(!v[c>>2]){break v}break F}a=P()|0;O()|0;break x}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(h);break x}if(h>>>0>23){break v}h=v[c+4>>2]}if(h>>>0>59){break v}}v[22640]=0;h=Q(2,b- -64|0,11037)|0;g=v[22640];v[22640]=0;N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{if((g|0)!=1){v[22640]=0;Q(155,d|0,h|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break ea}vb(h);if(v[c+32>>2]>=1){v[22640]=0;h=Q(2,b- -64|0,12717)|0;g=v[22640];v[22640]=0;if((g|0)==1){break da}Eb(f,h);vb(h)}v[22640]=0;R(156,b+32|0,c+8|0);h=v[22640];v[22640]=0;if((h|0)==1){break ca}v[22640]=0;h=Q(2,b+16|0,11887)|0;g=v[22640];v[22640]=0;if((g|0)==1){break ba}v[22640]=0;U(3,b+48|0,b+32|0,h|0);g=v[22640];v[22640]=0;if((g|0)==1){break aa}v[22640]=0;R(156,b|0,c+4|0);g=v[22640];v[22640]=0;if((g|0)==1){break $}v[22640]=0;U(3,b- -64|0,b+48|0,b|0);g=v[22640];v[22640]=0;if((g|0)==1){break _}v[22640]=0;Q(155,d|0,b- -64|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break Z}vb(b- -64|0);vb(b);vb(b+48|0);vb(h);vb(b+32|0);if(y[c>>2]<62){break U}v[22640]=0;U(157,i|0,d|0,f|0);c=v[22640];v[22640]=0;if((c|0)==1){break T}break u}a=P()|0;O()|0;break x}a=P()|0;O()|0;vb(h);break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break V}a=P()|0;O()|0;break W}a=P()|0;O()|0;break X}a=P()|0;O()|0;break Y}a=P()|0;O()|0;vb(b- -64|0)}vb(b)}vb(b+48|0)}vb(h)}vb(b+32|0);break x}v[22640]=0;h=Q(2,b+48|0,11887)|0;g=v[22640];v[22640]=0;if((g|0)==1){break S}v[22640]=0;R(156,b+32|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break R}v[22640]=0;U(3,b- -64|0,h|0,b+32|0);c=v[22640];v[22640]=0;if((c|0)==1){break Q}v[22640]=0;Q(155,d|0,b- -64|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break P}vb(b- -64|0);vb(b+32|0);vb(h);v[22640]=0;Q(155,d|0,f|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break v}}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break N}a=P()|0;O()|0;break O}a=P()|0;O()|0;vb(b- -64|0)}vb(b+32|0)}vb(h);break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break w}a=P()|0;O()|0;vb(b- -64|0)}vb(f)}vb(d);S(a|0);L()}Dc(i,d)}vb(f);vb(d);gb=b+112|0;gb=m+192|0;v[22640]=0;R(2039,a|0,e+32|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}d=Tb(e+32|0,9509);f=Wg(c,d);vb(d);if(f){c=b;US(e+32|0,v[b+24>>2]+1298292|0);fa:{ga:{ha:{if(!dd(e+32|0)){break ha}c=v[c+24>>2];v[22640]=0;c=WO(c);d=v[22640];v[22640]=0;if((d|0)==1){break fa}ia:{switch(c|0){case 0:v[22640]=0;R(2094,e+16|0,b|0);c=v[22640];v[22640]=0;if((c|0)!=1){Eb(e+32|0,e+16|0);vb(e+16|0);break ha}c=P()|0;O()|0;break b;case 1:v[22640]=0;R(2095,e+16|0,b|0);c=v[22640];v[22640]=0;if((c|0)!=1){Eb(e+32|0,e+16|0);vb(e+16|0);break ha}c=P()|0;O()|0;break b;case 2:if(dd(e+32|0)){v[22640]=0;R(2094,e+16|0,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break i}Eb(e+32|0,e+16|0);vb(e+16|0)}if(!dd(e+32|0)){break ha}v[22640]=0;R(2095,e+16|0,b|0);c=v[22640];v[22640]=0;if((c|0)!=1){Eb(e+32|0,e+16|0);vb(e+16|0);break ha}c=P()|0;O()|0;break b;case 3:if(dd(e+32|0)){v[22640]=0;R(2095,e+16|0,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break h}Eb(e+32|0,e+16|0);vb(e+16|0)}if(!dd(e+32|0)){break ha}v[22640]=0;R(2094,e+16|0,b|0);c=v[22640];v[22640]=0;if((c|0)!=1){Eb(e+32|0,e+16|0);vb(e+16|0);break ha}c=P()|0;O()|0;break b;case 4:v[22640]=0;R(2094,e+16|0,b|0);c=v[22640];v[22640]=0;ja:{ka:{if((c|0)!=1){v[22640]=0;R(2095,e|0,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break ja}if(dd(e+16|0)){break ka}v[22640]=0;Q(1183,e+32|0,e+16|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break ka}break d}c=P()|0;O()|0;break b}if(!dd(e)){v[22640]=0;Q(1183,e+32|0,e|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break d}}vb(e);vb(e+16|0);break ha}c=P()|0;O()|0;break c;case 5:break ia;default:break ha}}v[22640]=0;R(2094,e+16|0,b|0);c=v[22640];v[22640]=0;la:{if((c|0)!=1){v[22640]=0;R(2095,e|0,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break ga}if(dd(e)){break la}v[22640]=0;Q(1183,e+32|0,e|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break la}break f}c=P()|0;O()|0;break b}if(!dd(e+16|0)){v[22640]=0;Q(1183,e+32|0,e+16|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}}vb(e);vb(e+16|0)}v[22640]=0;U(2092,a|0,b|0,e+32|0);a=v[22640];v[22640]=0;if((a|0)==1){break fa}vb(e+32|0);break k}c=P()|0;O()|0;break e}c=P()|0;O()|0;break b}d=Tb(e+32|0,2564);f=Wg(c,d);vb(d);if(f){US(e+32|0,v[b+24>>2]+1298292|0);v[22640]=0;U(2092,a|0,b|0,e+32|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(e+32|0);break k}c=P()|0;O()|0;vb(e+32|0);break a}i=c;c=Tb(e+32|0,4385);d=Wg(i,c);vb(c);if(d){a=Kb(a);b=b+68|0;p=e,q=Sb(b),v[p+32>>2]=q;p=e,q=Wb(b),v[p+16>>2]=q;if(!Gb(e+32|0,e+16|0)){break k}c=1;while(1){b=v[e+32>>2];if(!(c&1)){v[22640]=0;Q(1917,a|0,18663)|0;c=v[22640];v[22640]=0;if((c|0)==1){break g}}v[22640]=0;Q(1183,a|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}v[e+32>>2]=v[e+32>>2]+12;c=0;if(Gb(e+32|0,e+16|0)){continue}break}break k}Tb(a,18693)}gb=e+48|0;return}c=P()|0;O()|0;vb(e+32|0);break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0;vb(a);break a}c=P()|0;O()|0;vb(e)}vb(e+16|0);break b}c=P()|0;O()|0;vb(e)}vb(e+16|0)}vb(e+32|0)}S(c|0);L()}function jZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-288|0;gb=e;vc(b);if(Mr(b,14880)){o=Kb(e+272|0);v[22640]=0;f=W(392,b|0,o|0,-1)|0;h=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((h|0)!=1){if(!f){break a}v[22640]=0;f=Q(406,b|0,e+264|0)|0;h=v[22640];v[22640]=0;s:{if((h|0)==1){break s}if(!f){break a}if(!JD(e+264|0)){break a}f=Uc(ID(e+264|0),jb);v[22640]=0;f=Q(228,b|0,f|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break s}if(!f){break a}if(!c){break b}v[22640]=0;R(407,a|0,4096);d=v[22640];v[22640]=0;if((d|0)==1){break s}v[22640]=0;Q(408,a+1298268|0,o|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break s}d=w[e+264|2];u[a+480188>>1]=32;u[a+480192>>1]=d;v[22640]=0;rh(a,1);d=v[22640];v[22640]=0;if((d|0)==1){break s}v[22640]=0;d=Q(2,e+112|0,6651)|0;f=v[22640];v[22640]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{if((f|0)!=1){Eb(a+1298304|0,d);vb(d);v[22640]=0;d=Q(2,e+112|0,4113)|0;f=v[22640];v[22640]=0;if((f|0)==1){break B}Eb(a+1298316|0,d);vb(d);v[22640]=0;_(410,e+56|0);d=v[22640];v[22640]=0;if((d|0)==1){break A}t[e+232|0]=w[e+264|1];d=w[e+264|0];v[22640]=0;t[e+16|0]=d;R(411,e+248|0,e+16|0);d=v[22640];v[22640]=0;if((d|0)==1){break z}v[22640]=0;Y(412,e+112|0,e+56|0,e+232|0,e+248|0);d=v[22640];v[22640]=0;if((d|0)==1){break y}Eb(a+1298328|0,e+112|0);vb(e+112|0);vb(e+248|0);Hb(e+56|0);v[a+1298364>>2]=5;if(w[e+264|0]<2){break u}u[e+112>>1]=8192;v[22640]=0;d=T(319,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break w}v[22640]=0;u[e+56>>1]=d;d=Ie(e+112|0,e+56|0);f=v[22640];v[22640]=0;if((f|0)==1){break w}v[a+480204>>2]=B(x[d>>1],1e4)>>>8;v[22640]=0;t[e+112|0]=1;d=T(353,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break v}v[22640]=0;t[e+56|0]=d;d=Bf(e+112|0,e+56|0);f=v[22640];v[22640]=0;if((f|0)==1){break v}v[a+480196>>2]=w[d|0];v[22640]=0;Q(350,b|0,3)|0;d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;d=T(319,b|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){break t}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break x}b=P()|0;O()|0;vb(e+248|0)}Hb(e+56|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}t[e+112|0]=32;v[22640]=0;d=T(353,b|0)|0;f=v[22640];v[22640]=0;C:{D:{if((f|0)==1){break D}v[22640]=0;t[e+56|0]=d;d=Bf(e+112|0,e+56|0);f=v[22640];v[22640]=0;if((f|0)==1){break D}v[a+480204>>2]=B(w[d|0],1e4);v[22640]=0;t[e+112|0]=1;d=T(353,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break C}v[22640]=0;t[e+56|0]=d;d=Bf(e+112|0,e+56|0);f=v[22640];v[22640]=0;if((f|0)==1){break C}v[a+480196>>2]=w[d|0];v[22640]=0;d=T(353,b|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){break t}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[a+480208>>2]=d>>>2&16|12;n=nc(e+248|0);m=nc(e+232|0);E:{F:{G:{H:{I:{J:{if(!x[a+480192>>1]){break J}j=1;h=e+88|1;p=e+112|12;while(1){v[22640]=0;f=W(415,a|0,j&65535,0)|0;d=v[22640];v[22640]=0;K:{L:{M:{if((d|0)==1){break M}if(!f){break J}v[22640]=0;d=W(393,b|0,f+492|0,-1)|0;i=v[22640];v[22640]=0;if((i|0)==1){break M}if(!d){break J}v[22640]=0;i=T(353,b|0)|0;d=v[22640];v[22640]=0;N:{O:{P:{Q:{R:{if((d|0)!=1){Qb(e+112|0,0,120);if(!i){break K}if(w[e+264|0]){v[22640]=0;d=Q(416,b|0,e+112|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break R}if(!d){break K}}if(!w[e+264|0]){d=Wd(e+104|0,p,96);v[22640]=0;g=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=g;U(237,e+56|0,b|0,e+8|0);d=v[22640];v[22640]=0;if((d|0)==1){break Q}if(!xb(e+56|0)){break K}}g=f+236|0;d=0;while(1){l=w[(e+112|0)+d|0];k=x[a+480190>>1];r=sd(g,d),s=(k+l|0)+1|0,u[r>>1]=s;d=d+1|0;if((d|0)!=120){continue}break}v[22640]=0;d=f+48|0;U(417,e+16|0,d|0,b|0);g=v[22640];v[22640]=0;if((g|0)==1){break P}v[22640]=0;g=f+68|0;U(417,e+40|0,g|0,b|0);l=v[22640];v[22640]=0;if((l|0)==1){break P}v[22640]=0;l=f+88|0;U(417,e+96|0,l|0,b|0);k=v[22640];v[22640]=0;if((k|0)==1){break P}v[22640]=0;R(418,b|0,e+88|0);k=v[22640];v[22640]=0;if((k|0)==1){break O}v[f>>2]=(w[h|0]|w[h+1|0]<<8)&4095;f=w[h|0]|w[h+1|0]<<8;Tv(e+88|0,d,0);Tv(e+88|0,g,1);Tv(e+88|0,l,2);r=e,s=Sb(d),v[r+56>>2]=s;r=e,s=Wb(d),v[r+80>>2]=s;if(Gb(e+56|0,e+80|0)){break N}break L}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}while(1){S:{d=v[e+56>>2];t[e+76|0]=64;k=w[d+2|0];v[22640]=0;t[e+79|0]=((k<<6)- -64>>>0)/127;k=ac(e+76|0,e+79|0);q=v[22640];v[22640]=0;if((q|0)==1){break S}t[d+2|0]=w[k|0];Xg(e+56|0);if(Gb(e+56|0,e+80|0)){continue}break L}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}r=e,s=Sb(g),v[r+56>>2]=s;r=e,s=Wb(g),v[r+80>>2]=s;T:{if(!Gb(e+56|0,e+80|0)){break T}while(1){U:{d=v[e+56>>2];t[e+76|0]=64;g=w[d+2|0];v[22640]=0;t[e+79|0]=((g<<6)+128>>>0)/255;g=ac(e+76|0,e+79|0);k=v[22640];v[22640]=0;if((k|0)==1){break U}t[d+2|0]=w[g|0];Xg(e+56|0);if(Gb(e+56|0,e+80|0)){continue}break T}break}b=P()|0;O()|0;break d}r=e,s=Sb(l),v[r+56>>2]=s;r=e,s=Wb(l),v[r+80>>2]=s;if(Gb(e+56|0,e+80|0)){l=1<<(f>>>12&3);while(1){k=v[e+56>>2];d=t[k+2|0];d=mqa(d^-128,d>>31^-1,l,0);g=jb;f=g;V:{if((f|0)>-1?1:(f|0)>=-1?d>>>0>=4294967292:0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break V}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}r=k,s=zc(d,f)^128,t[r+2|0]=s;Xg(e+56|0);if(Gb(e+56|0,e+80|0)){continue}break}}d=x[a+480190>>1]+1|0;u[e+76>>1]=d;W:{X:{Y:{Z:{g=d&65535;if(g>>>0<=3999){d=0;f=0;while(1){v[22640]=0;W(393,b|0,((g<<5)+a|0)+946304|0,-1)|0;g=v[22640];v[22640]=0;if((g|0)==1){break Z}v[22640]=0;R(419,b|0,e+56|0);g=v[22640];v[22640]=0;if((g|0)==1){break Y}v[22640]=0;R(420,e+56|0,(B(x[e+76>>1]+f|0,104)+a|0)+484380|0);f=v[22640];v[22640]=0;if((f|0)==1){break Y}f=w[e+88|0];g=w[e+75|0];v[22640]=0;u[e+80>>1]=f|d<<8&32512|((g&3)!=0)<<15;R(421,m|0,e+80|0);f=v[22640];v[22640]=0;if((f|0)==1){break X}d=d+1|0;f=d&65535;if(i>>>0<=f>>>0){break W}g=x[e+76>>1]+f|0;if(g>>>0<=3999){continue}break}}v[22640]=0;Q(350,b|0,20)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break W}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[22640]=0;R(421,n|0,e+76|0);d=v[22640];v[22640]=0;if((d|0)==1){break I}v[e+56>>2]=3999;d=x[a+480190>>1];v[22640]=0;v[e+80>>2]=d+i;d=ld(e+56|0,e+80|0);f=v[22640];v[22640]=0;if((f|0)==1){break H}u[a+480190>>1]=v[d>>2]}j=j+1|0;if(x[a+480192>>1]>=(j&65535)>>>0){continue}break}}d=Kb(e+112|0);v[22640]=0;f=W(392,b|0,d|0,-1)|0;h=v[22640];v[22640]=0;if((h|0)==1){break n}if(f){v[22640]=0;U(13,e+56|0,7,d|0);f=v[22640];v[22640]=0;if((f|0)==1){break E}Eb(a+1298280|0,e+56|0);vb(e+56|0)}vb(d);d=0;while(1){v[22640]=0;f=(d<<5)+a|0;Se(f+480280|0);h=v[22640];v[22640]=0;if((h|0)==1){break G}v[22640]=0;U(395,b|0,f+480289|0,-1);f=v[22640];v[22640]=0;if((f|0)==1){break G}d=d+1|0;if((d|0)!=32){continue}break}v[22640]=0;d=Q(423,b|0,e+40|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break l}if(!d){break i}if((w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))>>>0<12){break m}d=w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24);v[22640]=0;d=Q(228,b|0,d-11|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break l}if(d){break F}break m}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[e+96>>2]=(w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24))-11;j=nc(e+112|0);v[22640]=0;W(398,b|0,j|0,v[e+96>>2])|0;d=v[22640];v[22640]=0;if((d|0)==1){break p}v[22640]=0;v[e+56>>2]=50529027;d=Fb(e+96|0,e+56|0);f=v[22640];v[22640]=0;if((f|0)==1){break q}v[e+88>>2]=B(v[d>>2],85);h=Kb(e+56|0);d=e+40|4;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[22640]=0;v[e+16>>2]=d;d=Fb(e+88|0,e+16|0);f=v[22640];v[22640]=0;if((f|0)==1){break r}d=v[d>>2];v[22640]=0;R(102,h|0,d|0);d=v[22640];v[22640]=0;if((d|0)==1){break r}if(v[e+96>>2]){f=0;while(1){_:{i=w[kc(j,f)|0];d=f+1|0;if(!((i|0)!=255|v[e+96>>2]-d>>>0<2)){d=t[kc(j,d)|0];i=w[kc(j,f+2|0)|0];r=e,s=df(h),v[r+16>>2]=s;Fd(e+32|0,e+16|0);v[22640]=0;ca(399,h|0,v[e+32>>2],i|0,d|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){d=f+3|0;break _}break r}v[22640]=0;R(103,h|0,i<<24>>24);f=v[22640];v[22640]=0;if((f|0)!=1){break _}break r}f=d;if(y[e+96>>2]>d>>>0){continue}break}}v[22640]=0;Y(400,e+16|0,5,7,h|0);d=v[22640];v[22640]=0;$:{if((d|0)!=1){Eb(h,e+16|0);vb(e+16|0);d=zb(Jb(h));f=Ab(h);v[22640]=0;ga(401,a+1298292|0,d|0,f|0,74,0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break $}vb(h);gc(j);break m}break r}break r}break n}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;vb(h);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0}gc(j);break d}b=P()|0;O()|0;vb(d);break d}d=Rb(a+484360|0);f=e+264|5;f=w[f|0]|w[f+1|0]<<8;v[22640]=0;ga(402,d|0,b|0,f|0,65535,65535)|0;d=v[22640];v[22640]=0;if((d|0)==1){break l}j=c&1;if(j){d=e+264|3;d=w[d|0]|w[d+1|0]<<8;v[22640]=0;R(364,a+484344|0,d|0);d=v[22640];v[22640]=0;if((d|0)==1){break l}}f=e+264|3;aa:{if(!(w[f|0]|w[f+1|0]<<8)){break aa}h=a+484344|0;d=0;while(1){v[22640]=0;i=Q(228,b|0,4)|0;g=v[22640];v[22640]=0;ba:{if((g|0)!=1){if(i){break ba}break aa}b=P()|0;O()|0;break d}v[22640]=0;i=T(229,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break f}v[22640]=0;U(320,e+112|0,b|0,i|0);i=v[22640];v[22640]=0;if((i|0)==1){break g}ca:{if(!j){break ca}v[22640]=0;i=T(353,e+112|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break e}v[22640]=0;Q(350,e+112|0,1)|0;g=v[22640];v[22640]=0;if((g|0)==1){break e}v[22640]=0;i=W(365,h|0,d&65535,i+1|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break e}if(!i){break ca}v[22640]=0;U(396,e+112|0,e+56|0,-1);i=v[22640];v[22640]=0;if((i|0)==1){break e}i=_b(h,d);v[22640]=0;R(397,i|0,e+56|0);i=v[22640];v[22640]=0;if((i|0)==1){break e}i=_b(h,d);v[22640]=0;U(404,i|0,1,e+112|0);i=v[22640];v[22640]=0;if((i|0)==1){break e}}yb(e+112|0);d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}if(!(c&2)){break i}if(!x[a+480190>>1]){break j}d=0;while(1){if(w[rc(m,d)|0]){c=d+1|0}else{c=d+1|0;f=B(c,104)+a|0;d=Pc(e+112|0,u[f+484414>>1]&1?16:8,1,0,u[rc(m,d)>>1]>-1?0:6);v[22640]=0;W(363,d|0,f+484380|0,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break k}}d=c;if(d>>>0<x[a+480190>>1]){continue}break}break j}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}if(!x[a+480190>>1]){break i}b=0;while(1){c=w[rc(m,b)|0];da:{if(!c){break da}c=c-1&65535;if(sc(n)>>>0<=c>>>0){break da}c=(w[rc(m,b)+1|0]&127)+x[rc(n,c)>>1]&65535;if(c>>>0>x[a+480190>>1]){break da}f=B(c,104);d=(f+a|0)+484380|0;if(!Ld(d)){break da}h=a+484380|0;c=h+B(b+1|0,104)|0;f=f+h|0;u[c+34>>1]=x[c+34>>1]&65534|u[f+34>>1]&1;v[c>>2]=v[d>>2];v[22640]=0;h=T(424,c|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break h}if(!h){break da}hc(zb(v[c+20>>2]),zb(v[f+20>>2]),Yi(d))}b=b+1|0;if(b>>>0<x[a+480190>>1]){continue}break}}Ue(m);Ue(n);break b}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(e+112|0)}Ue(m);Ue(n)}vb(o);S(b|0);L()}d=1}vb(o)}gb=e+288|0;return d|0}function tpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=gb-352|0;gb=e;vc(b);f=e+328|0;g=AD(b,f);if(!g){yD(f)}a:{b:{c:{d:{e:{f:{g:{if(!g){break g}if(!TX(e+328|0)){break g}if(!Pb(b,Uc(72,0))){break g}if(!c){d=1;break g}Gd(a,1);v[a+480208>>2]=v[a+480208>>2]&-25231361|16842752;d=w[e+337|0];u[a+480190>>1]=63;u[a+480188>>1]=d;h:{if(d){d=0;while(1){Zt(a,d&65535);u[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}if(!x[a+480190>>1]){break h}}d=1;f=1;while(1){g=(B(d,104)+a|0)+484380|0;td(g,1);h=(e+256|0)+d|0;d=de(b);t[h|0]=d;if(d<<24>>24>=0){A=g,C=lE(b)<<1,v[A>>2]=C}f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}KD(b,a+1298268|0,-1);g=e+248|0;f=gb-32|0;gb=f;d=b;i:{if(Pb(d,8)){Hp(f+24|0,g);g=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=g;gd(f+16|0,d,f+8|0);break i}t[f+16|0]=0;li(g,8,f+16|0)}gb=f+32|0;m=nc(e+232|0);j:{if(w[e+338|0]|w[e+339|0]<<8){f=w[e+338|0]|w[e+339|0]<<8;g=w[e+337|0];d=0;v[22640]=0;f=W(523,b|0,m|0,B(f,g)<<1)|0;g=v[22640];v[22640]=0;if((g|0)==1){f=P()|0;O()|0;break a}if(!f){break j}}nn(e+224|0,v[m>>2],pc(m)>>>1|0);l=nc(e+208|0);k:{l:{m:{n:{o:{p:{if(!(w[e+340|0]|w[e+341|0]<<8)){break p}d=w[e+340|0]|w[e+341|0]<<8;f=0;v[22640]=0;R(524,l|0,d<<8);d=v[22640];v[22640]=0;if((d|0)==1){break o}if(!(w[e+340|0]|w[e+341|0]<<8)){break p}while(1){v[e+136>>2]=(w[e+340|0]|w[e+341|0]<<8)-f;v[22640]=0;v[e+160>>2]=2e3;d=ld(e+136|0,e+160|0);g=v[22640];v[22640]=0;q:{if((g|0)!=1){g=v[d>>2];d=nc(e+136|0);v[22640]=0;g=W(523,b|0,d|0,g<<8)|0;h=v[22640];v[22640]=0;if((h|0)==1){break c}if(g){break q}gc(d);d=0;break k}f=P()|0;O()|0;break b}A=e,C=Wb(l),v[A+160>>2]=C;Fd(e+200|0,e+160|0);g=Sb(d);h=Wb(d);v[22640]=0;Y(525,l|0,v[e+200>>2],g|0,h|0);g=v[22640];v[22640]=0;if((g|0)==1){break c}gc(d);f=f+2e3&65535;if(f>>>0<(w[e+340|0]|w[e+341|0]<<8)>>>0){continue}break}}v[22640]=0;be(e+184|0,l);d=v[22640];v[22640]=0;if((d|0)==1){break m}d=v[e+188>>2];v[e+64>>2]=v[e+184>>2];v[e+68>>2]=d;Lh(e+192|0,e- -64|0);p=a+484360|0;d=Rb(p);f=w[e+338|0]|w[e+339|0]<<8;v[22640]=0;R(527,d|0,f|0);d=v[22640];v[22640]=0;if((d|0)==1){break m}if(!(w[e+338|0]|w[e+339|0]<<8)){break l}q=a+484344|0;s=c&1;h=0;while(1){r:{A=rc(Rb(p),h),C=h,u[A>>1]=C;s:{if(!s){break s}v[22640]=0;r=h&65535;d=W(365,q|0,r|0,64)|0;f=v[22640];v[22640]=0;if((f|0)==1){break r}j=0;f=x[a+480188>>1];if(!(d&(f|0)!=0)){break s}while(1){d=rc(e+224|0,B(f&65535,h)+j|0);f=w[d|0]|w[d+1|0]<<8;t:{if(f>>>0>=(w[e+340|0]|w[e+341|0]<<8)>>>0){f=x[a+480188>>1];break t}d=_b(q,h);v[22640]=0;d=Tc(d,0,j&65535);g=v[22640];v[22640]=0;if((g|0)==1){break n}i=0;y=0-j|0;z=f<<8;while(1){Wd(e+136|0,v[e+192>>2]+((i<<2)+z|0)|0,4);n=w[kc(e+136|0,0)|0]&63;t[d|0]=n?n+48|0:0;f=kc(e+136|0,0);A=d,C=w[kc(e+136|0,1)|0]<<2&60|w[f|0]>>>6,t[A+1|0]=C;g=w[kc(e+136|0,1)|0];o=w[kc(e+136|0,2)|0];f=kc(e+136|0,2);k=w[kc(e+136|0,3)|0];f=k<<4|w[f|0]>>>4;u[e+182>>1]=f;g=o<<2&60|g>>>6;u:{if(!(w[lc(e+248|0,g>>>3|0)|0]>>>(g&7)&1)|!(f?1:g)){break u}t[d+5|0]=f;t[d+3|0]=g;o=k>>>4|0;t[d+4|0]=o;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{switch(g|0){case 0:case 1:case 2:case 32:case 33:case 34:t[d+3|0]=g&15;v[22640]=0;Mf(d);f=v[22640];v[22640]=0;if((f|0)==1){break G}if(!w[d+4|0]){break u}t[d+2|0]=g>>>0<32?3:4;break u;case 3:case 4:case 5:case 6:case 7:case 12:v[22640]=0;Mf(d);f=v[22640];v[22640]=0;if((f|0)==1){break G}break u;case 9:t[d+3|0]=10;A=d,C=di(f>>>1|0),t[A+5|0]=C;break u;case 50:break w;case 48:break x;case 43:break y;case 47:break z;case 17:case 18:case 26:case 27:break A;case 22:case 25:case 28:case 29:case 30:break B;case 16:case 19:case 20:case 21:case 23:case 31:break C;case 13:break D;case 11:case 15:break E;case 10:case 42:break H;default:break v}}if(f>>>0>254){break F}t[d+3|0]=g&15;v[22640]=0;Mf(d);f=v[22640];v[22640]=0;if((f|0)!=1){break u}}f=P()|0;O()|0;break b}t[d+3|0]=19;t[d+5|0]=o|(g>>>0<32?16:32);g=k&15;if(g){t[d+2|0]=3;t[d+4|0]=g;break u}t[d+2|0]=4;t[d+4|0]=f&15;break u}t[d+3|0]=(g|0)==11?12:16;A=d,C=wv(f),t[A+5|0]=C;break u}t[d+3|0]=14;if((f&255)>>>0<64){break u}t[d+5|0]=0;break u}t[d+3|0]=19;t[d+5|0]=f&15|g<<4;break u}t[d+3|0]=19;v[22640]=0;u[e+160>>1]=15;f=Oc(e+182|0,e+160|0);k=v[22640];v[22640]=0;if((k|0)!=1){t[d+5|0]=w[f|0]|g<<4;break u}f=P()|0;O()|0;break b}t[d+3|0]=19;if(f&255){t[d+5|0]=f&15|((g|0)==17?16:(g|0)==26?16:32);if(!(k&240)){break u}t[d+2|0]=g>>>0>25?6:5;break u}t[d+5|0]=o|(g>>>0>25?-80:-96);break u}if(!f){break v}t[d+3|0]=17;v[e+160>>2]=8;v[22640]=0;v[e+176>>2]=f+4;f=Nf(e+160|0,e+176|0);g=v[22640];v[22640]=0;if((g|0)!=1){A=d,C=di(v[f>>2]/8|0),t[A+5|0]=C;break u}f=P()|0;O()|0;break b}t[d+3|0]=14;g=x[a+480188>>1];if(!g){break u}n=B(y,6)+d|0;f=0;while(1){k=n+B(f,6)|0;if(!w[k+3|0]){t[k+3|0]=12;A=k,C=wv(r),t[A+5|0]=C;g=x[a+480188>>1]}f=f+1|0;if(g>>>0>f>>>0){continue}break}break u}t[d+3|0]=9;g=f&7;if(g){t[d+5|0]=w[g+28953|0];break u}g=f>>>4|0;if((g|0)==128){break v}t[d+5|0]=g;if(!(f&2048)){t[d+5|0]=g^128;break u}t[d+5|0]=g^-1;break u}t[d+5|0]=0;t[d+3|0]=0;if(!n){t[d|0]=255;break u}t[d+3|0]=25;break u}t[d+3|0]=0}f=x[a+480188>>1];d=B(f,6)+d|0;i=i+1|0;if((i|0)!=64){continue}break}}j=j+1|0;if(j>>>0<(f&65535)>>>0){continue}break}}h=h+1|0;if(h>>>0<(w[e+338|0]|w[e+339|0]<<8)>>>0){continue}break l}break}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}if(x[a+480190>>1]){j=c&2;d=1;f=1;while(1){v[22640]=0;c=w[(e+256|0)+d|0];W(354,b|0,((d<<5)+a|0)+946304|0,c&63)|0;g=v[22640];v[22640]=0;I:{J:{K:{L:{M:{N:{if((g|0)!=1){if(c<<24>>24<=-1){break I}v[22640]=0;g=T(360,b|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break d}c=B(d,104)+a|0;d=c+484392|0;v[d>>2]=g<<1;v[22640]=0;g=T(360,b|0)|0;h=v[22640];v[22640]=0;O:{if((h|0)!=1){g=g<<1;if(g>>>0>=3){v[c+484396>>2]=g+v[d>>2];d=c+484414|0;u[d>>1]=x[d>>1]|8}v[22640]=0;d=T(353,b|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){break O}break d}f=P()|0;O()|0;break b}u[c+484410>>1]=d<<2;v[22640]=0;d=T(353,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break d}t[c+484417|0]=d<<4;c=c+484380|0;if(!v[c>>2]){break I}v[22640]=0;h=T(353,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break L}d=0;P:{Q:{R:{S:{switch(h|0){case 0:if(!j){break Q}g=nc(e+160|0);h=v[c>>2];v[22640]=0;h=Q(228,b|0,h|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break N}if(!h){break R}d=v[c>>2];v[22640]=0;W(528,b|0,g|0,d|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break N}A=e,C=Sb(g),v[A+136>>2]=C;A=e,C=Wb(g),v[A+176>>2]=C;if(Gb(e+136|0,e+176|0)){break M}break K;case 1:g=nc(e+160|0);d=v[c>>2];v[22640]=0;U(529,e+136|0,b|0,d|0);d=v[22640];v[22640]=0;T:{U:{V:{W:{if((d|0)!=1){lp(g,e+136|0);gc(e+136|0);if(!j){break V}v[22640]=0;be(e+112|0,g);d=v[22640];v[22640]=0;if((d|0)!=1){d=Sd(e+104|0);v[22640]=0;h=v[e+116>>2];v[e+40>>2]=v[e+112>>2];v[e+44>>2]=h;h=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=h;d=W(530,e+136|0,e+40|0,e+32|0)|0;h=v[22640];v[22640]=0;if((h|0)!=1){break W}}f=P()|0;O()|0;break T}f=V(27860)|0;if((O()|0)!=(ea(27860)|0)){break T}Z(f|0)|0;d=0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break P}f=P()|0;O()|0;break T}h=Pc(e+176|0,8,1,0,2);v[22640]=0;W(363,h|0,c|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break U}yb(d)}gc(g);break I}f=P()|0;O()|0;yb(d)}gc(g);break b;case 2:case 3:if(j){d=Pc(e+136|0,(h|0)==2?8:16,1,0,0);v[22640]=0;W(363,d|0,c|0,b|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break I}f=P()|0;O()|0;break b}c=v[c>>2];v[22640]=0;Q(350,b|0,B(c,h-1|0)|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break I}break L;case 4:case 5:break S;default:break k}}g=nc(e+160|0);d=v[c>>2];v[22640]=0;U(531,e+136|0,b|0,d|0);d=v[22640];v[22640]=0;X:{Y:{Z:{if((d|0)!=1){lp(g,e+136|0);gc(e+136|0);if(j){_:{if((h|0)!=5){break _}A=e,C=Sb(g),v[A+136>>2]=C;A=e,C=Wb(g),v[A+176>>2]=C;if(!Gb(e+136|0,e+176|0)){break _}while(1){i=v[e+136>>2];d=zb(w[i|0]);A=i,C=zb((d^w[(d>>>7|0)+28961|0])&255),t[A|0]=C;Me(e+136|0);if(Gb(e+136|0,e+176|0)){continue}break}}v[22640]=0;be(e+96|0,g);d=v[22640];v[22640]=0;if((d|0)==1){break Z}d=Sd(e+88|0);v[22640]=0;i=v[e+100>>2];v[e+56>>2]=v[e+96>>2];v[e+60>>2]=i;i=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=i;d=W(530,e+136|0,e+56|0,e+48|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break Z}h=(h|0)==5;h=Pc(e+176|0,h?16:8,1,0,h?17:1);v[22640]=0;W(363,h|0,c|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break Y}yb(d)}gc(g);break I}f=V(27860)|0;if((O()|0)!=(ea(27860)|0)){break X}Z(f|0)|0;d=0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)==1){f=P()|0;O()|0;break X}gc(g);break k}f=P()|0;O()|0;break X}f=P()|0;O()|0;yb(d)}gc(g);break b}gc(g);break k}c=v[c>>2];v[22640]=0;Q(350,b|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break L}break I}gc(g);break k}f=P()|0;O()|0;break b}f=P()|0;O()|0;break J}while(1){h=v[e+136>>2];d=zb(w[h|0]);A=h,C=zb((d<<7|(d^-1)<<24>>>25)&255),t[A|0]=C;Me(e+136|0);if(Gb(e+136|0,e+176|0)){continue}break}break K}f=P()|0;O()|0;break b}v[22640]=0;be(e+128|0,g);d=v[22640];v[22640]=0;$:{aa:{if((d|0)==1){break aa}d=Sd(e+120|0);v[22640]=0;h=v[e+132>>2];v[e+24>>2]=v[e+128>>2];v[e+28>>2]=h;h=v[d+4>>2];v[e+16>>2]=v[d>>2];v[e+20>>2]=h;d=W(530,e+136|0,e+24|0,e+16|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break aa}h=Pc(e+176|0,16,1,0,17);v[22640]=0;W(363,h|0,c|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break $}yb(d);gc(g);break I}f=P()|0;O()|0;break J}f=P()|0;O()|0;yb(d)}gc(g);break b}f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}ba:{ca:{da:{ea:{fa:{ga:{ha:{d=w[e+342|0]|w[e+343|0]<<8|w[e+344|0]<<16;if(d){c=nc(e+160|0);v[22640]=0;b=W(523,b|0,c|0,d|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break f}if(!b){break fa}v[22640]=0;be(e+80|0,c);b=v[22640];v[22640]=0;if((b|0)==1){break ha}b=Sd(e+72|0);v[22640]=0;f=v[e+84>>2];v[e+8>>2]=v[e+80>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;b=W(530,e+136|0,e+8|0,e|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break ha}v[22640]=0;ca(532,a+1298292|0,b|0,d|0,1)|0;d=v[22640];v[22640]=0;if((d|0)==1){break ga}yb(b);gc(c)}v[22640]=0;_(533,e+160|0);b=v[22640];v[22640]=0;if((b|0)==1){break ea}v[22640]=0;U(348,e+136|0,e+160|0,e+336|0);b=v[22640];v[22640]=0;if((b|0)==1){break da}Eb(a+1298304|0,e+136|0);vb(e+136|0);Hb(e+160|0);v[22640]=0;b=Q(2,e+136|0,7422)|0;c=v[22640];v[22640]=0;if((c|0)==1){break ca}Eb(a+1298316|0,b);vb(b);v[22640]=0;b=Q(2,e+136|0,2197)|0;c=v[22640];v[22640]=0;if((c|0)==1){break ba}Eb(a+1298328|0,b);vb(b);v[a+1298364>>2]=2;d=1;break k}f=P()|0;O()|0;break e}f=P()|0;O()|0;yb(b);break e}gc(c);d=0;break k}f=P()|0;O()|0;break b}f=P()|0;O()|0;Hb(e+160|0);break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}gc(l)}gc(m)}gb=e+352|0;return d|0}f=P()|0;O()|0}gc(c);break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;gc(d)}gc(l)}gc(m);S(f|0);L()}function VZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;o=Fh(b,11194);a:{if(!o){break a}if(!Pb(b,6)){break a}while(1){b:{k=og(b);c:{if((k|0)==(An(11044)|0)){break c}i=w[18669]|w[18670]<<8|(w[18671]<<16|w[18672]<<24);if(!(k&1616928864)|k&-2139062144){break c}if((i|0)!=(k|0)){break b}}lg(b,4);break a}l=1;q=Kg(b);if(x[a+480192>>1]){while(1){j=v[(((l&65535)<<2)+a|0)+900380>>2];if(j){d:{i=q;m=b;p=k;if((An(13864)|0)==(k|0)){Yb(m,i);break d}e=p;c=i;d=m;g=0;h=gb-48|0;gb=h;e:{f:{g:{h:{i:{j:{k:{l:{m:{f=j;n:{if(!f){break n}o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((e|0)<=1347628589){if((e|0)<=1297100333){if((e|0)<=1179931727){if((e|0)<=1145263149){if((e|0)==1095062094){break y}if((e|0)==1095126087){break v}if((e|0)!=1129524782|c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+23|0]=s;g=1;break n}if((e|0)<=1179463213){if((e|0)==1145263150){break N}if((e|0)!=1145979182|c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+18|0]=s;g=1;break n}if((e|0)==1179463214){break B}if((e|0)!=1179594286|c>>>0>4){break n}if(!Pb(d,c)){break n}r=f,s=cm(d,c),v[r>>2]=s;g=1;break n}if((e|0)<=1229345325){if((e|0)==1179931728){break o}if((e|0)==1196830254){break X}if((e|0)!=1229341486|c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+21|0]=s;g=1;break n}if((e|0)<=1296182829){if((e|0)==1229345326){break K}if((e|0)!=1264266798|c>>>0>256){break n}e=f+236|0;rd(h+24|0,d,c);d=0;while(1){v[22640]=0;c=T(339,h+24|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break F}r=sd(e,d),s=c,u[r>>1]=s;d=d+1|0;if(d>>>0<128){continue}break}yb(h+24|0);g=1;break n}if((e|0)==1296182830){break J}if((e|0)!=1296248366|c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+31|0]=s;g=1;break n}if((e|0)<=1346720333){if((e|0)<=1313692461){if((e|0)==1297100334){break I}if((e|0)==1297110852){break t}if((e|0)!=1298747438|c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+34|0]=s;g=1;break n}if((e|0)<=1345203757){if((e|0)==1313692462){break G}if((e|0)!=1313751342|c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+16|0]=s;g=1;break n}if((e|0)==1345203758){break W}if((e|0)!=1346711086){break n}v[h+24>>2]=240;r=h,s=cm(d,c),v[r+8>>2]=s;hh(f+68|0,v[Fb(h+24|0,h+8|0)>>2]);g=1;break n}if((e|0)<=1347179309){if((e|0)<=1346784326){if((e|0)==1346720334){break z}if((e|0)!=1346722606){break n}rd(h+24|0,d,c);d=0;v[22640]=0;c=ii(f,1);e=v[22640];v[22640]=0;if((e|0)==1){break k}if(Nb(c)){while(1){v[22640]=0;e=T(341,h+24|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break k}r=Mb(c,d),s=e,t[r+2|0]=s;d=d+1|0;if(Nb(c)>>>0>d>>>0){continue}break}}yb(h+24|0);g=1;break n}if((e|0)==1346784327){break w}if((e|0)!=1347175726|c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+82|0]=s;g=1;break n}if((e|0)<=1347441453){if((e|0)==1347179310){break T}if((e|0)!=1347437358|c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+27|0]=s;g=1;break n}if((e|0)==1347441454){break H}if((e|0)!=1347443502){break n}rd(h+24|0,d,c);d=0;v[22640]=0;c=ii(f,1);e=v[22640];v[22640]=0;if((e|0)==1){break h}if(Nb(c)){while(1){v[22640]=0;e=T(339,h+24|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break h}r=Mb(c,d),s=e,u[r>>1]=s;d=d+1|0;if(Nb(c)>>>0>d>>>0){continue}break}}yb(h+24|0);g=1;break n}if((e|0)<=1447374381){if((e|0)<=1349078084){if((e|0)<=1347831111){if((e|0)<=1347634477){if((e|0)==1347628590){break M}if((e|0)!=1347633710|c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+83|0]=s;g=1;break n}if((e|0)==1347634478){break S}if((e|0)!=1347703884){break n}r=f,s=B(Rr(d,c),1e4)+(y[f+40>>2]%1e4|0)|0,v[r+40>>2]=s;g=1;break n}if((e|0)<=1349076269){if((e|0)==1347831112){break A}if((e|0)!=1347833672|c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+36|0]=s;g=1;break n}if((e|0)==1349076270){break q}if((e|0)!=1349076315){break n}rd(h+24|0,d,c);d=0;v[22640]=0;c=ii(f,2);e=v[22640];v[22640]=0;if((e|0)==1){break l}if(Nb(c)){while(1){v[22640]=0;e=T(341,h+24|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break l}r=Mb(c,d),s=e,t[r+2|0]=s;d=d+1|0;if(Nb(c)>>>0>d>>>0){continue}break}}yb(h+24|0);g=1;break n}if((e|0)<=1349079873){if((e|0)==1349078085){break Q}if((e|0)==1349078099){break R}if((e|0)!=1349079131){break n}rd(h+24|0,d,c);d=0;v[22640]=0;c=ii(f,2);e=v[22640];v[22640]=0;if((e|0)==1){break i}if(Nb(c)){while(1){v[22640]=0;e=T(339,h+24|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break i}r=Mb(c,d),s=e,u[r>>1]=s;d=d+1|0;if(Nb(c)>>>0>d>>>0){continue}break}}yb(h+24|0);g=1;break n}Y:{switch(e-1349079874|0){case 1:case 2:break n;case 3:break O;case 0:break P;default:break Y}}if((e|0)==1378758190){break s}if((e|0)!=1381183022|c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+24|0]=s;g=1;break n}if((e|0)<=1448226349){if((e|0)<=1447447622){if((e|0)==1447374382){break r}if((e|0)==1447383630){break x}if((e|0)!=1447385902){break n}rd(h+24|0,d,c);d=0;v[22640]=0;c=ii(f,0);e=v[22640];v[22640]=0;if((e|0)==1){break j}if(Nb(c)){while(1){v[22640]=0;e=T(341,h+24|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break j}r=Mb(c,d),s=e,t[r+2|0]=s;d=d+1|0;if(Nb(c)>>>0>d>>>0){continue}break}}yb(h+24|0);g=1;break n}if((e|0)<=1447842605){if((e|0)==1447447623){break u}if((e|0)!=1447839022|c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+62|0]=s;g=1;break n}if((e|0)==1447842606){break V}if((e|0)!=1448106798){break n}rd(h+24|0,d,c);d=0;v[22640]=0;c=ii(f,0);e=v[22640];v[22640]=0;if((e|0)==1){break g}if(Nb(c)){while(1){v[22640]=0;e=T(339,h+24|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break g}r=Mb(c,d),s=e,u[r>>1]=s;d=d+1|0;if(Nb(c)>>>0>d>>>0){continue}break}}yb(h+24|0);g=1;break n}if((e|0)<=1448297773){if((e|0)==1448226350){break C}if((e|0)==1448291886){break L}if((e|0)!=1448297006|c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+63|0]=s;g=1;break n}if((e|0)<=1718508333){if((e|0)==1448297774){break U}if((e|0)!=1682320942|c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+15|0]=s;g=1;break n}if((e|0)==1718508334){break D}if((e|0)!=1851469358|c>>>0>32){break n}rd(h+24|0,d,c);e=Kb(h+8|0);if(c){d=0;while(1){v[22640]=0;g=T(342,h+24|0)|0;n=v[22640];v[22640]=0;if((n|0)==1){break E}v[22640]=0;R(343,e|0,g|0);g=v[22640];v[22640]=0;if((g|0)==1){break E}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[22640]=0;Q(333,f+492|0,e|0)|0;c=v[22640];v[22640]=0;g=1;if((c|0)==1){break E}vb(e);yb(h+24|0);break n}if(c>>>0>4){break n}if(!Pb(d,c)){break n}r=f,s=cm(d,c),v[r+4>>2]=s;g=1;break n}if(c>>>0>4){break n}if(!Pb(d,c)){break n}r=f,s=cm(d,c),v[r+8>>2]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+61|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f- -64|0,s=ud(d,c),t[r|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+81|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+84|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+101|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+102|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+103|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+104|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+17|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+19|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+20|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+22|0]=s;g=1;break n}if(c>>>0>2){break n}if(!Pb(d,c)){break n}r=f,s=Rr(d,c),u[r+28>>1]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+30|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=HE(d,c),t[r+26|0]=s;g=1;break n}if(c>>>0>128){break n}e=f+108|0;rd(h+24|0,d,c);d=0;while(1){v[22640]=0;c=T(341,h+24|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break p}r=lc(e,d),s=c,t[r|0]=s;d=d+1|0;if(d>>>0<128){continue}break}yb(h+24|0);g=1;break n}d=P()|0;O()|0;break f}d=P()|0;O()|0;vb(e);break f}if(c>>>0>32){break n}rd(h+24|0,d,c);e=Kb(h+8|0);if(c){d=0;while(1){v[22640]=0;g=T(342,h+24|0)|0;n=v[22640];v[22640]=0;if((n|0)==1){break m}v[22640]=0;R(343,e|0,g|0);g=v[22640];v[22640]=0;if((g|0)==1){break m}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[22640]=0;Q(333,f+524|0,e|0)|0;c=v[22640];v[22640]=0;g=1;if((c|0)!=1){vb(e);yb(h+24|0);break n}break m}if(c>>>0>2){break n}if(!Pb(d,c)){break n}r=f,s=Rr(d,c),u[r+12>>1]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+25|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+35|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+105|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+85|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+65|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+100|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+80|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=ud(d,c),t[r+60|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Pb(d,c)){break n}r=f,s=HE(d,c),t[r+33|0]=s;g=1;break n}g=1;c=cm(d,c);if(!wp(c)){break n}t[f+14|0]=c;break n}v[h+24>>2]=240;r=h,s=cm(d,c),v[r+8>>2]=s;hh(f+48|0,v[Fb(h+24|0,h+8|0)>>2]);g=1;break n}v[h+24>>2]=240;r=h,s=cm(d,c),v[r+8>>2]=s;hh(f+88|0,v[Fb(h+24|0,h+8|0)>>2]);g=1;break n}d=P()|0;O()|0;break f}c=Rr(d,c);d=v[f+40>>2];v[f+40>>2]=d-((d>>>0)%1e4|0)+(c>>>0)%1e4;g=1}gb=h+48|0;break e}d=P()|0;O()|0;vb(e);break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0}yb(h+24|0);S(d|0);L()}if(!g){Yb(m,i);break d}if((An(13869)|0)==(p|0)){i=w[j+15|0];t[j+15|0]=0;t[j+100|0]=w[j+100|0]&224|(i>>>5&4|i>>>6&1);t[j+60|0]=i>>>1&2|(i<<1&4|(w[j+60|0]&240|i&1));t[j+80|0]=w[j+80|0]&240|(i>>>4&2|(i>>>2&4|i>>>3&1))}}}l=l+1|0;if(x[a+480192>>1]>=(l&65535)>>>0){continue}break}}if(Pb(b,6)){continue}break}}return o|0}function hfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;f=gb-48|0;gb=f;b=v[a+1074308>>2];if(!(b>>>0>18285125|(b|0)==18284544)){Yf(a+1074312|0,0)}h=a+1074312|0;Db(f+32|0,h,0);if(Cb(f+32|0)){q=(v[a+480180>>2]&16777248)!=0}Db(f+32|0,h,0);if(Cb(f+32|0)){E=v[a+480180>>2]==4}k=a+1074308|0;b=v[k>>2];if(b>>>0<=18874367){c=1;e=!q;a:{if(!x[a+480192>>1]){break a}while(1){b:{b=v[(((c&65535)<<2)+a|0)+900380>>2];if(!b){break b}v[f+32>>2]=B(w[b+20|0],100)>>>6;v[f+16>>2]=100;F=b,G=v[Fb(f+32|0,f+16|0)>>2],t[F+20|0]=G;if(!(e|y[k>>2]<18350080)){break b}j=t[b+26|0];t[b+26|0]=(((j|0)>-1?1:-1)+j|0)/2;if(!(e|y[k>>2]<18285314)){break b}NS(ii(b,2),4,v[a+480180>>2]);j=v[a+1074308>>2];if(j>>>0>=18284544){if(j>>>0>18285135){break b}c:{if(!w[b+34|0]){break c}if(!Fj(b)){break c}Ob(h,2,1)}if(y[k>>2]>18285135){break b}}if(!(w[b+24|0]|(w[b+23|0]|(w[b+19|0]|w[b+20|0])))){break b}Ob(h,1,1);break a}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}d:{if(!(v[a+480180>>2]&16777248)){break d}b=1;if(!(e|y[k>>2]<18285314)|!x[a+480190>>1]){break d}while(1){c=B(b&65535,104)+a|0;e=c+484419|0;if(!(w[e|0]|!(w[c+484421|0]|w[c+484420|0]))){t[e|0]=255}b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break}}b=a+901404|0;c=b;d=XS(b);if((d|0)!=(b|0)){while(1){b=c;i=b+32|0;while(1){e=w[b|0];e:{f:{if((e-97&255)>>>0<=5){j=e-32|0;break f}j=99;g:{if(e>>>0<=106){if(e-88>>>0<2){break g}if((e|0)==75){break f}break e}if(e-120>>>0<2){break g}if((e|0)==107){break f}break e}j=122}t[b|0]=j}b=b+1|0;if((i|0)!=(b|0)){continue}break}c=c+32|0;if((d|0)!=(c|0)){continue}break}}b=v[a+1074308>>2]}h:{if(!x[a+480192>>1]|(!(v[a+480180>>2]&16777252)|((b|0)==18874368|b>>>0>18874895))){break h}b=1;c=0;while(1){i:{e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(w[e+31|0]?e:0)){b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}if(c){break i}break h}t[e+33|0]=13;c=1;b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}}break}Ob(h,3,1)}b=v[k>>2];j:{if(!(v[a+480180>>2]&16777248)|(b>>>0>19006225|(b|0)==19005440)){break j}Db(f+32|0,h,0);if(!Cb(f+32|0)){Db(f+16|0,h,1);if(!Cb(f+16|0)){break j}}if(!x[a+480192>>1]){break j}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|!w[c+19|0]|!(t[c+80|0]&1))){t[c+19|0]=0}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}k:{l:{m:{if(y[k>>2]<=19007232){c=a+946300|0;b=a+906300|0;while(1){e=b+80|0;bP(f+16|0,e);v[22640]=0;Y(400,f+32|0,0,8,f+16|0);j=v[22640];v[22640]=0;if((j|0)==1){break l}vb(f+16|0);v[22640]=0;Gv(e,f+32|0);e=v[22640];v[22640]=0;if((e|0)==1){break m}vb(f+32|0);b=b+160|0;if((c|0)!=(b|0)){continue}break}}n:{o:{p:{q:{if(v[a+480180>>2]!=4){break q}b=v[k>>2];if(b>>>0<19007257){break o}if(b>>>0>19071235){break p}if(w[a+1074368|0]!=4){break q}Xz(a,5)}b=v[k>>2]}if((b|0)==19202048|b>>>0>19202054){break n}}if(!x[a+480192>>1]){break n}c=1;while(1){j=(((c&65535)<<2)+a|0)+900380|0;b=v[j>>2];r:{if(!b|!w[b+20|0]|!w[b+31|0]){break r}b=b+236|0;e=Cu(b);if((b|0)!=(e|0)){while(1){if(x[b>>1]){break r}b=b+2|0;if((e|0)!=(b|0)){continue}break}}t[v[j>>2]+20|0]=0}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}b=v[k>>2];if(b>>>0<=19267583){if(x[a+480192>>1]){b=1;e=!q;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];s:{if(!c){break s}j=t[c+26|0];t[c+26|0]=(((j|0)>-1?1:-1)+j|0)/2;if(!(e|y[k>>2]<18350080)){break s}t[c+19|0]=w[c+19|0]+3>>>2}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=v[k>>2]}t:{if(!x[a+480192>>1]|b>>>0>19398673){break t}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+65|0]==255)){Ob(h,94,1);break t}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}u:{if(!x[a+480192>>1]|y[k>>2]>19399427){break u}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+36|0]>1)){Ob(h,101,1);break u}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=gb-16|0;gb=b;u[f+12>>1]=0;v[f+8>>2]=a;Db(b+8|0,a+1074312|0,0);F=f,G=Cb(b+8|0),t[F+14|0]=G;gb=b+16|0;b=v[f+12>>2];v[f>>2]=v[f+8>>2];v[f+4>>2]=b;c=gb-16|0;gb=c;o=a+484344|0;j=Oe(o);b=v[f+4>>2];e=v[f>>2];v[c>>2]=e;v[c+4>>2]=b;v[c+8>>2]=e;v[c+12>>2]=b;b=c;e=gb-32|0;gb=e;A=j-1&65535;v:{if(Oe(o)>>>0>A>>>0){r=v[b>>2];s=v[b+4>>2];while(1){b=z&65535;if(hi($e(o,b))){d=Sb($e(o,b));i=Wb($e(o,b));b=e;v[b+24>>2]=r;v[b+28>>2]=s;v[b+8>>2]=r;v[b+12>>2]=s;j=b+8|0;m=gb-16|0;gb=m;v[m>>2]=i;v[m+8>>2]=d;if(Gb(m+8|0,m)){while(1){d=v[m+8>>2];b=j;n=x[b+4>>1];i=n+1|0;u[b+4>>1]=i;if(x[v[b>>2]+480188>>1]<=(i&65535)>>>0){u[b+4>>1]=0}w:{if(xg(d)){break w}g=v[b>>2];i=v[g+1074308>>2];x:{y:{z:{A:{B:{C:{D:{p=v[g+480180>>2];E:{F:{if((p|0)==2){if(i>>>0>18415615){break F}if(w[d+3|0]!=23){break E}vf(d+5|0,64);break E}G:{H:{I:{if(p&16777248){J:{if(i>>>0>=18285314){if(w[b+6|0]){break J}if(i>>>0>=18874368){break I}}K:{switch(w[d+3|0]-20|0){case 3:vf(d+5|0,128);break J;case 0:break K;default:break J}}g=w[d+5|0];if((g|0)!=208){if((g|0)!=192){break J}t[d|0]=254;t[d+3|0]=0;break J}t[d+3|0]=0}L:{M:{N:{if(i>>>0>=18350080){if(w[b+6|0]){break N}if(i>>>0>=18874368){break I}}g=w[d+3|0];if(g>>>0>29){break M}l=1;if(!(1<<g&536873152)){break M}break L}if(i>>>0>=18874368){break I}g=w[d+3|0]}l=0}g=g&255;g=(g|0)==24|(g|0)==22|l;break H}if((p|0)!=4){break F}O:{P:{Q:{R:{S:{if(i>>>0<18285314){break S}g=!w[b+6|0]&i>>>0<18874368;if(g){break S}if(i>>>0>19137025){break z}if(!(w[d+3|0]!=23|w[d+5|0]<65)){t[d+3|0]=0}if(!(g|i>>>0<18415616)){break R}}if(w[d+3|0]!=10|w[d+2|0]!=11){break Q}t[d+3|0]=0;break Q}if(i>>>0>18874639){break P}}if(w[d+2|0]!=11|w[d+3|0]!=4){break O}g=w[d+4|0];if(!(w[b+6|0]?1:g)){break O}l=w[d+5|0];if(!l){break O}t[d+2|0]=0;F=d,G=wv(l+(g<<4)|0),t[F+5|0]=G;break O}if(i>>>0>19007240){break z}}if(w[d+5|0]|w[d+3|0]!=16){break F}g=d+3|0;break G}g=0}T:{if(!g){break T}l=w[d+5|0];g=l&15;if(!g|(g|0)==15){break T}l=l&240;if(!l|(l|0)==240){break T}t[d+5|0]=w[d+3|0]==24?l:g}if(i>>>0>19005699){break z}if((i|0)==19005440){break D}if(w[b+6|0]|(!x[v[b>>2]+480192>>1]|x[v[b>>2]+480192>>1]>=w[d+1|0])){break F}t[d+2|0]=1;g=d+4|0}t[g|0]=0}if(i>>>0>18874367){break z}}C=w[d+5|0]&240;D=(C|0)==96;g=w[d+3|0];l=D&(g|0)==20;if(D?(g|0)==28:0){if(!w[b+6|0]|(p|0)!=4){break C}b=l|i>>>0<18350080}else{b=0-l|0}if(!(b&1)|!n){break A}break B}g=d+2|0;b=w[d+2|0];if((b|0)==8){break y}break x}if(!n){break z}}b=d+B(0-n|0,6)|0;while(1){if(!((w[b+3|0]|8)!=28|(w[b+5|0]&240)!=96)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}g=w[d+3|0]}if(!n|((g&255)!=20|(C|0)!=224)){break z}b=d+B(0-n|0,6)|0;while(1){if(!(w[b+3|0]!=20|(w[b+5|0]&240)!=224)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}}g=d+2|0;b=w[d+2|0];if((b|0)!=8){break x}if((i|0)==19333120|i>>>0>19333174){break w}}U:{V:{W:{X:{b=w[d+3|0];switch(b-5|0){case 0:break V;case 2:break X;case 1:break w;default:break W}}if(!w[d+4|0]){break U}t[d+3|0]=11;break w}if((b|0)!=26){break w}}i=w[d+5|0];if(!(i&15)){t[d+3|0]=5;t[d+5|0]=i|w[d+4|0]&15;break U}Y:{switch(b-5|0){case 1:break w;case 0:case 2:break U;default:break Y}}if((b|0)!=26){break w}}t[g|0]=0;break w}if(!(w[d+3|0]|((p|0)==16777216|(b|0)!=15))){t[d+2|0]=0;t[d+3|0]=10;t[d+5|0]=w[d+4|0]<<3;break w}if(w[d+3|0]!=10|i>>>0>19922963|(b|0)!=15){break w}if(w[d+4|0]?w[d+5|0]:1){t[g|0]=0;break w}t[d+3|0]=0}Wj(m+8|0);if(Gb(m+8|0,m)){continue}break}}b=v[j+4>>2];v[e+16>>2]=v[j>>2];v[e+20>>2]=b;gb=m+16|0}z=z+1|0;if((z&65535)>>>0<=A>>>0){continue}break}v[f+32>>2]=r;v[f+36>>2]=s;break v}j=v[b+4>>2];v[f+32>>2]=v[b>>2];v[f+36>>2]=j}gb=e+32|0;gb=c+16|0;b=v[a+1074308>>2];c=b>>>0<19267584;Z:{if(c&q){Ob(h,8,(b|0)==18284544|b>>>0>18285313);b=48600;while(1){c=v[k>>2];e=v[b+4>>2];Ob(h,v[b>>2],c>>>0>=e>>>0|(c|0)==(e&-65536));b=b+8|0;if((b|0)!=48936){continue}break}break Z}if(!(c&E)){break Z}Ob(h,8,b>>>0>18285313);b=48952;while(1){Ob(h,v[b>>2],y[k>>2]>=y[b+4>>2]);b=b+8|0;if((b|0)!=49184){continue}break}}_:{if(v[a+480180>>2]&16777248){b=49184;while(1){c=v[k>>2];e=v[b+4>>2];j=e&-65536;if(!(c>>>0<=j>>>0|c>>>0>=e>>>0?c>>>0>=j>>>0:0)){Yf(h,v[b>>2])}b=b+8|0;if((b|0)!=49232){continue}break}break _}if(v[a+480180>>2]==4){b=49232;while(1){if(y[k>>2]<y[b+4>>2]){Yf(h,v[b>>2])}b=b+8|0;if((b|0)!=49296){continue}break}break _}if(v[a+480180>>2]!=2){break _}b=49296;while(1){if(y[k>>2]<y[b+4>>2]){Yf(h,v[b>>2])}b=b+8|0;if((b|0)!=49376){continue}break}}$:{if(v[a+480180>>2]==4){b=v[k>>2];if(b>>>0>18415615){break $}Ob(h,98,1)}b=v[k>>2]}if(b-19333159>>>0<=33){b=0;while(1){c=b+77|0;Db(f+32|0,h,c);Ob(h,b+86|0,Cb(f+32|0));Yf(h,c);b=b+1|0;if((b|0)!=5){continue}break}b=v[k>>2]}c=8;aa:{if(b>>>0>=18284544){if(b>>>0>18874627){break aa}c=6;if((b|0)==18874368){break aa}}Ob(h,c,1);b=v[k>>2]}ba:{if(w[a+480208|0]&16){if(b>>>0<=19136511){Yf(h,7);break ba}if(!(v[a+480180>>2]&16777248)|b>>>0>19267583){break ba}Ob(h,7,1);break ba}if((b|0)==19922944|b>>>0>19922997){break ba}Yf(h,7)}Db(f+32|0,h,31);ca:{if(!Cb(f+32|0)){break ca}b=v[k>>2];if(!x[a+480192>>1]|(b>>>0<19071234|b>>>0>19398722)){break ca}b=1;while(1){da:{c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break da}e=w[c+65|0];if(!(w[c+60|0]&4)|(e|0)==255|e>>>0<=w[c- -64|0]){break da}Ob(h,97,1);break ca}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}ea:{if(!(v[a+480180>>2]&16777218)|!x[a+480190>>1]){break ea}b=1;while(1){if(!(w[(B(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break ea}break}fa:{ga:{ha:{if(!(!x[a+480192>>1]|v[a+480180>>2]!=16777216)){b=v[k>>2];if(b>>>0<19398688){break ga}if(b>>>0>19464277){break ha}Ob(h,109,1)}b=v[k>>2]}if((b|0)==19922944|b>>>0>19922996){break fa}}Yf(h,111)}if(!(v[a+480180>>2]!=2|y[a+1074308>>2]>19464191)){Ob(h,108,1);break ea}if(v[a+480180>>2]==2){break ea}Yf(h,108)}gb=f+48|0;return}a=P()|0;O()|0;vb(f+32|0);break k}a=P()|0;O()|0;vb(f+16|0)}S(a|0);L()}function Gpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;f=gb+-64|0;gb=f;vc(a);a:{b:{if(b>>>0<=2){C=f,D=de(a),t[C+56|0]=D;Yb(a,2);b=f+56|2;e=Kg(a);t[b|0]=e;t[b+1|0]=e>>>8;b=f+56|4;e=og(a);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;break b}Dr(a,f+56|0);if(b>>>0>5){break a}}t[f+56|1]=0}c:{m=d+484344|0;b=f+56|2;r=Jd(w[b|0]|w[b+1|0]<<8,1,1024);l=Zy(m,r,0);if((l|0)!=65535){i=Pf(_b(m,l),0);u[f>>1]=x[d+480188>>1]-1;u[f+40>>1]=w[f+56|0];s=x[Oc(f,f+40|0)>>1];e=s+1|0;if(x[d+480188>>1]>(e&65535)>>>0){b=e&65535;while(1){t[i+B(b,6)|0]=254;b=b+1|0;if(b>>>0<x[d+480188>>1]){continue}break}}t[c+13|0]=w[f+56|1]>>>4;b=w[c+12|0];t[f|0]=0;o=Dv(f+40|0,e,f);if(r){b=(b|0)!=0;while(1){d:{e:{if(!w[kc(o,0)|0]){v[22640]=0;e=T(353,a|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break c}e=e<<24>>24;if((e|0)<=-1){v[22640]=0;i=T(353,a|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}C=kc(o,0),D=i,t[C|0]=D}y=0;t[f|0]=0;g=e&63;f:{g:{if(!g){break g}v[22640]=0;e=T(353,a|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break c}t[f|0]=e;i=0;h:{switch(g-1|0){case 0:t[c+12|0]=0;v[22640]=0;t[f+36|0]=1;b=Bf(f+36|0,f);e=v[22640];v[22640]=0;if((e|0)!=1){t[c+14|0]=w[b|0];t[c+15|0]=0;b=1;break f}break c;case 1:if(!e){break f}t[c+15|0]=e;b=1;t[c+12|0]=1;i=w[c+13|0];if(!i){break g}t[c+14|0]=B(B(e,i),15);break g;case 2:t[c+13|0]=e>>>4;if(e>>>0>=16){b=w[c+12|0]!=0;break f}t[c+12|0]=0;break f;case 3:i=e;break f;case 5:if(!e){break f}i=(w[c+12|0]?15:14)+c|0;b=w[i|0];t[i|0]=b>>>0<256-e>>>0?b+e|0:-1;b=1;break g;case 6:break h;default:break f}}if(!e){break f}b=1;g=(w[c+12|0]?15:14)+c|0;i=w[g|0];t[g|0]=i>>>0>e+1>>>0?i-e|0:1}i=0}v[f+36>>2]=0;v[f+32>>2]=0;if(b&1){break e}break d}i=0;e=kc(o,0);t[e|0]=w[e|0]-1;v[f+36>>2]=0;v[f+32>>2]=0;y=0;if(!(b&1)){break d}}b=w[c+12|0];e=w[c+13|0];if(e?0:b){break d}i:{if(b){v[f>>2]=1;b=w[c+15|0];v[22640]=0;v[f+28>>2]=B(b,e)<<1;b=Nf(f,f+28|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}e=v[b>>2];break i}e=B(w[c+14|0],30)+30|0}b=255;j:{while(1){g=B(b,e);if(g-1536>>>0<10752){e=g;break j}g=b>>>0>1;b=b-1|0;if(g){continue}break}b=0}v[f+36>>2]=b;v[f+32>>2]=(e|0)/48;Qd(f+32|0,32,255);v[22640]=0;v[f>>2]=1;b=Nf(f,f+36|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}t[c+16|0]=v[b>>2];y=1}b=_b(m,l);v[22640]=0;b=Tc(b,k,1);e=v[22640];v[22640]=0;if((e|0)==1){break c}if(s){z=k-1|0;h=1;p=1;while(1){k:{l:{m:{n:{if(!w[kc(o,h)|0]){v[22640]=0;j=T(353,a|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break c}if(j&128){v[22640]=0;e=T(353,a|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}C=kc(o,h),D=e,t[C|0]=D}A=1;if(j&64){v[22640]=0;e=T(353,a|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}t[b+1|0]=e;A=!e}if(!(j&32)){e=w[b|0];break n}v[22640]=0;e=T(353,a|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}t[b|0]=e;if((e-1&255)>>>0<=107){e=pn(e+24|0);t[b|0]=e;C=_c(c,h),D=e,t[C+1|0]=D;break n}if((e+127&255)>>>0<=107){e=pn((e&127)+24|0);t[b|0]=e;C=_c(c,h),D=e,t[C|0]=D;t[b|0]=0;break m}if((e|0)!=255){break n}t[b|0]=254;break l}e=kc(o,h);t[e|0]=w[e|0]-1;break k}if(e&255){break l}}if(!w[b+1|0]){break l}e=w[_c(c,h)+1|0];t[b+1|0]=0;t[b|0]=e}v[22640]=0;e=ce(b);g=v[22640];v[22640]=0;if((g|0)==1){break c}if(e){C=_c(c,h),D=0,t[C+5|0]=D}t[f+28|0]=0;t[f+27|0]=0;t[f+26|0]=0;t[f+25|0]=0;t[f+24|0]=0;t[f+23|0]=0;if(j&16){t[b+2|0]=1;v[22640]=0;e=T(353,a|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}t[b+4|0]=e+2>>>2}o:{if(!(j&8)){break o}v[22640]=0;e=T(353,a|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}v[22640]=0;t[f+28|0]=e;e=T(353,a|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}t[f+25|0]=e;p:{q:{r:{s:{t:{u:{v:{w:{g=w[f+28|0];switch(g-1|0){case 0:break q;case 9:break r;case 5:case 6:case 7:case 8:break s;case 4:break t;case 3:break u;case 2:break v;case 1:break w;default:break p}}t[b|0]=255;break p}C=b,D=w[_c(c,h)+1|0],t[C|0]=D;C=_c(c,h),D=0,t[C+5|0]=D;break p}e=Cv(e,w[c+16|0]);t[f+25|0]=e;x:{if(e){t[f+28|0]=20;t[f+25|0]=e|208;break x}t[f+28|0]=0}if(w[b|0]){break o}C=b,D=w[_c(c,h)+1|0],t[C|0]=D;C=_c(c,h),D=0,t[C+5|0]=D;break o}t[f|0]=1;e=Cv(e,w[c+16|0]);v[22640]=0;t[f+22|0]=e;e=Bf(f,f+22|0);g=v[22640];v[22640]=0;if((g|0)!=1){t[f+25|0]=w[e|0];t[f+28|0]=15;C=_c(c,h),D=0,t[C+5|0]=D;break o}break c}y:{if(!k){break y}if((g|0)==w[_c(c,h)+4|0]){break y}e=_b(m,l);v[22640]=0;g=Be(f,20,(w[f+28|0]+122|160)&255);n=v[22640];v[22640]=0;if((n|0)==1){break c}g=op(np(Qe(g,z),p&65535));v[22640]=0;e=Q(458,e|0,g|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}if(!e){break y}C=_c(c,h),D=w[f+28|0],t[C+4|0]=D}t[f+28|0]=10;if(!w[b|0]){C=b,D=w[_c(c,h)+1|0],t[C|0]=D}C=_c(c,h),D=0,t[C+5|0]=D;break o}t[f+28|0]=20;C=f,D=w[_c(c,h)+5|0]?-98:-97,t[C+25|0]=D;e=_c(c,h);t[e+5|0]=w[e+5|0]^1;break o}t[b|0]=254}t[f+28|0]=0}n=0;e=0;z:{if(!(j&4)){break z}v[22640]=0;e=T(353,a|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}v[22640]=0;t[f+27|0]=e;e=T(353,a|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}t[f+24|0]=e;g=f;A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{q=w[f+27|0];switch(q-1|0){case 11:break C;case 10:break D;case 7:case 8:case 9:break E;case 6:break F;case 5:break G;case 3:case 4:break H;case 2:break I;case 1:break J;case 0:break K;default:break B}}v[22640]=0;gt(f,e<<24>>24<<3,128);e=v[22640];v[22640]=0;if((e|0)==1){break c}v[22640]=0;e=ce(b);g=v[22640];v[22640]=0;if((g|0)==1){break c}if(e){C=b,D=pn(v[f>>2]+w[b|0]|0),t[C|0]=D}t[f+27|0]=35;t[f+24|0]=w[f+4|0]^128;e=0;break z}e=Cv(e,w[c+16|0]);t[f+24|0]=e;if(e){t[f+27|0]=20;t[f+24|0]=e|208;e=1;break z}t[f+27|0]=0;e=1;break z}e=1;break A}g=w[c+16|0];v[22640]=0;e=aD(e,g,1);g=v[22640];v[22640]=0;if((g|0)==1){break c}t[f+24|0]=e;t[f+27|0]=w[f+27|0]==4?2:3;e=1;break z}if(!w[b|0]){C=b,D=w[_c(c,h)|0],t[C|0]=D;e=w[f+24|0]}g=w[c+16|0];v[22640]=0;e=aD(e&255,g,0);g=v[22640];v[22640]=0;if((g|0)==1){break c}t[f+27|0]=4;t[f+24|0]=e;e=1;break z}C=b,D=pn(e+25|0),t[C|0]=D;t[f+24|0]=255;t[f+27|0]=4;e=1;break z}L:{if(!k){break L}if((q|0)==w[_c(c,h)+2|0]){break L}e=_b(m,l);v[22640]=0;g=Be(f,20,(w[f+27|0]-8|48)&255);q=v[22640];v[22640]=0;if((q|0)==1){break c}g=op(np(Qe(g,z),p&65535));v[22640]=0;e=Q(458,e|0,g|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}if(!e){break L}C=_c(c,h),D=w[f+27|0],t[C+2|0]=D}t[f+27|0]=5;e=w[c+16|0];v[22640]=0;e=Bv(w[f+24|0],e);g=v[22640];v[22640]=0;if((g|0)==1){break c}t[f+24|0]=e;e=1;break z}e=nY(e,w[c+16|0]);t[f+27|0]=18;t[f+24|0]=e;e=1;break z}e=Cv(e,w[c+16|0]);t[f+24|0]=e;if(e){t[f+27|0]=20;t[f+24|0]=e|192;e=1;break z}t[f+27|0]=0;t[b|0]=254;e=1;break z}e=0}t[g+27|0]=e}M:{if(!(j&2)){break M}v[22640]=0;g=T(353,a|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break c}v[22640]=0;t[f+26|0]=g;g=T(353,a|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break c}t[f+23|0]=g;N:{O:{P:{Q:{R:{S:{T:{j=w[f+26|0];switch(j-1|0){case 9:break O;case 7:case 8:break P;case 6:break Q;case 3:case 4:case 5:break R;case 2:break S;case 0:case 1:break T;default:break N}}h=w[c+16|0];v[22640]=0;g=$C(g,h,(j|0)==1);h=v[22640];v[22640]=0;if((h|0)==1){break c}t[f+26|0]=11;t[f+23|0]=g;n=1;break M}g=nY(g,w[c+16|0]);t[f+26|0]=18;t[f+23|0]=g;n=1;break M}U:{if(!k){break U}if((j|0)==w[_c(c,h)+3|0]){break U}g=_b(m,l);v[22640]=0;j=Be(f,20,(w[f+26|0]-4|64)&255);n=v[22640];v[22640]=0;if((n|0)==1){break c}j=op(np(Qe(j,z),p&65535));v[22640]=0;g=Q(458,g|0,j|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break c}if(!g){break U}C=_c(c,h),D=w[f+26|0],t[C+3|0]=D}t[f+26|0]=8;g=w[c+16|0];v[22640]=0;g=Bv(w[f+23|0],g);h=v[22640];v[22640]=0;if((h|0)==1){break c}t[f+23|0]=g;n=1;break M}t[f+26|0]=9;break M}h=w[c+16|0];v[22640]=0;g=$C(g,h,(j|0)==8);h=v[22640];v[22640]=0;if((h|0)==1){break c}t[f+26|0]=29;t[f+23|0]=g;n=1;break M}t[f+26|0]=27;h=w[c+16|0];v[22640]=0;g=Bv(g,h);h=v[22640];v[22640]=0;if((h|0)==1){break c}t[f+23|0]=g;n=1;break M}t[f+26|0]=0}if(e){mY(b,k,x[d+480188>>1],w[f+27|0],f+24|0)}if(n){mY(b,k,x[d+480188>>1],w[f+26|0],f+23|0)}V:{if(!A){break V}v[22640]=0;e=ce(b);g=v[22640];v[22640]=0;if((g|0)==1){break c}if(!e){break V}e=w[f+27|0];if(!e){t[f+24|0]=255;t[f+27|0]=4;break V}if(w[f+26|0]|(e|0)==4){break V}t[f+23|0]=255;t[f+26|0]=4}W:{if(w[b+2|0]!=1){break W}X:{if(!w[f+27|0]){t[f+27|0]=13;t[f+24|0]=w[b+4|0];break X}if(w[f+26|0]){break W}t[f+26|0]=13;t[f+23|0]=w[b+4|0]}t[b+2|0]=0}v[22640]=0;so(f,f+27|0,f+24|0,f+26|0,f+23|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}Y:{if(w[b+2|0]){break Y}e=w[f+27|0];if(!e){break Y}t[b+2|0]=e;t[b+4|0]=w[f+24|0]}Z:{if(w[f+28|0]){v[22640]=0;so(f,f+26|0,f+23|0,f+28|0,f+25|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}_:{if(w[b+2|0]){break _}e=w[f+26|0];if(!e){break _}t[b+2|0]=e;t[b+4|0]=w[f+23|0]}h=f+25|0;e=w[f+28|0];break Z}h=f+23|0;e=w[f+26|0];if(!e){break k}}t[b+3|0]=e;t[b+5|0]=w[h|0]}b=b+6|0;p=p+1|0;h=p&65535;if(s>>>0>=h>>>0){continue}break}}$:{if(!y){break $}b=_b(m,l);v[22640]=0;e=Be(f,17,w[f+32|0]);g=v[22640];v[22640]=0;if((g|0)==1){break c}e=Eh(np(Qe(e,k),0));v[22640]=0;Q(458,b|0,e|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}b=_b(m,l);v[22640]=0;e=Be(f,16,w[f+36|0]);g=v[22640];v[22640]=0;if((g|0)!=1){e=Eh(Qe(e,k));v[22640]=0;Q(458,b|0,e|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break $}}break c}aa:{if(!(i&240)){break aa}b=_b(m,l);v[22640]=0;e=Be(f,20,i>>>4|224);g=v[22640];v[22640]=0;if((g|0)!=1){e=lY(Qe(e,k));v[22640]=0;Q(458,b|0,e|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break aa}}break c}ba:{b=i&15;if(!b){break ba}e=w[c+16|0];i=_b(m,l);b=Jd((B(b,e)>>>0)/15&255,1,15);v[22640]=0;b=Be(f,20,b|96);e=v[22640];v[22640]=0;if((e|0)!=1){b=lY(Qe(b,k));v[22640]=0;Q(458,i|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break ba}}break c}b=0;k=k+1|0;if((r|0)!=(k|0)){continue}break}}gc(o)}gb=f- -64|0;return l|0}a=P()|0;O()|0;gc(o);S(a|0);L()}function Wea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-784|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{if(!Hh(b,d+776|0)){break G}if(!WN(d+776|0)){break G}if(!iC(b,d+768|0)){break G}if(!VN(d+768|0)){break G}i=1313423693;g=w[d+768|0]|w[d+769|0]<<8|(w[d+770|0]<<16|w[d+771|0]<<24);if((g|0)!=1179012417){i=1414090313;if((g|0)!=538987841){break G}}l=Xi(d+744|0,b);j=eh(d+728|0);H:{if(!c){v[22640]=0;Y(1456,d+144|0,l|0,((g|0)==1179012417?1:2)|0,i|0);b=v[22640];v[22640]=0;if((b|0)!=1){break H}a=P()|0;O()|0;break a}v[22640]=0;U(1457,d+144|0,l|0,((g|0)==1179012417?1:2)|0);b=v[22640];v[22640]=0;if((b|0)==1){break r}}LU(j,d+144|0);Cd(d+144|0);v[22640]=0;U(1458,d+704|0,j|0,i|0);b=v[22640];v[22640]=0;if((b|0)==1){break s}v[22640]=0;b=T(307,d+704|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break q}h=0;I:{if(!b){break I}v[22640]=0;b=Q(1459,d+704|0,d+624|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break q}if(!b|!w[d+689|0]){break I}b=w[d+689|0];v[22640]=0;h=Q(228,d+704|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break q}if(!h|!c){break I}v[22640]=0;R(407,a|0,8388608);b=v[22640];v[22640]=0;if((b|0)==1){break q}v[a+480208>>2]=12;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+688|0]<<4^-1)&16;u[d+144>>1]=w[d+689|0];v[22640]=0;u[d+512>>1]=127;b=Oc(d+144|0,d+512|0);h=v[22640];v[22640]=0;if((h|0)==1){break c}u[a+480188>>1]=x[b>>1];v[a+480196>>2]=w[d+690|0];v[a+480204>>2]=B(w[d+691|0],1e4);v[a+480200>>2]=w[d+696|0]<<1;v[22640]=0;Q(194,a+1298304|0,((g|0)==1179012417?14062:14028)|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break q}v[22640]=0;b=Q(2,d+144|0,10637)|0;h=v[22640];v[22640]=0;if((h|0)==1){break d}Eb(a+1298316|0,b);vb(b);v[a+1298364>>2]=5;v[22640]=0;Hr(d+512|0,2,d+624|0);b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;R(377,d+144|0,d+512|0);b=v[22640];v[22640]=0;if((b|0)==1){break e}Eb(a+1298268|0,d+144|0);vb(d+144|0);if(x[a+480188>>1]){b=0;f=(g|0)==1179012417;while(1){v[22640]=0;i=(b<<5)+a|0;e=i+480280|0;Se(e);h=v[22640];v[22640]=0;J:{K:{L:{M:{N:{if((h|0)!=1){v[22640]=0;h=T(353,d+704|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break N}if(f){break M}if(h>>>0<129){break L}break K}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}if(h<<24>>24<=-1){break K}v[d+144>>2]=h<<2;v[22640]=0;v[d+512>>2]=256;h=ld(d+144|0,d+512|0);e=v[22640];v[22640]=0;if((e|0)!=1){u[i+480284>>1]=v[h>>2];break J}a=P()|0;O()|0;break b}u[i+480284>>1]=h<<1;break J}v[e>>2]=1024}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}b=gb-16|0;gb=b;v[b+12>>2]=1380209231;m=b,n=pY(Sb(j),Wb(j),b+12|0),v[m+8>>2]=n;m=b,n=Wb(j),v[m>>2]=n;h=Gb(b+8|0,b);gb=b+16|0;if(h){v[22640]=0;U(1458,d+144|0,j|0,1380209231);b=v[22640];v[22640]=0;if((b|0)==1){break f}v[22640]=0;b=T(353,d+144|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break g}h=Rb(a+484360|0);v[22640]=0;ga(540,h|0,d+144|0,b+1&255,255,254)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}yb(d+144|0)}if(c&1){u[d+56>>1]=0;v[22640]=0;U(1461,d+512|0,j|0,1414807888);b=v[22640];v[22640]=0;if((b|0)==1){break h}b=Ze(d+512|0);v[22640]=0;h=a+484344|0;R(364,h|0,b&65535);b=v[22640];v[22640]=0;if((b|0)==1){break k}m=d,n=Sb(d+512|0),v[m+576>>2]=n;m=d,n=Wb(d+512|0),v[m+88>>2]=n;if(Gb(d+576|0,d+88|0)){i=(g|0)!=1179012417;while(1){b=Je(d+144|0,v[d+576>>2]);v[22640]=0;f=T(353,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break j}v[22640]=0;u[d+496>>1]=f;f=T(229,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break j}v[22640]=0;U(320,d+600|0,b|0,f|0);f=v[22640];v[22640]=0;if((f|0)==1){break j}f=v[d+612>>2];v[d+8>>2]=v[d+608>>2];v[d+12>>2]=f;v[d+16>>2]=v[d+616>>2];v[22640]=0;f=v[d+604>>2];v[d>>2]=v[d+600>>2];v[d+4>>2]=f;Y(1462,d|0,x[d+496>>1],i|0,a|0);f=v[22640];v[22640]=0;if((f|0)==1){break j}v[22640]=0;f=Ie(d+56|0,d+496|0);e=v[22640];v[22640]=0;if((e|0)==1){break j}u[d+56>>1]=x[f>>1];yb(b);Ah(d+576|0);if(Gb(d+576|0,d+88|0)){continue}break}}if(x[d+56>>1]){b=0;while(1){v[22640]=0;i=b&65535;f=ke(h,i);e=v[22640];v[22640]=0;O:{if((e|0)!=1){if(f){break O}v[22640]=0;W(365,h|0,i|0,64)|0;i=v[22640];v[22640]=0;if((i|0)!=1){break O}}a=P()|0;O()|0;break i}b=b+1|0;if(x[d+56>>1]>(b&65535)>>>0){continue}break}}fd(d+512|0)}P:{if((g|0)==1179012417){v[22640]=0;U(1461,d+88|0,j|0,1414745673);b=v[22640];v[22640]=0;if((b|0)==1){break E}m=d,n=Sb(d+88|0),v[m+128>>2]=n;m=d,n=Wb(d+88|0),v[m+40>>2]=n;Q:{if(Gb(d+128|0,d+40|0)){h=c&2;i=d+520|0;f=d+144|1;while(1){c=Je(d+576|0,v[d+128>>2]);v[22640]=0;b=Q(1463,c|0,d+144|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break Q}R:{if(!b){break R}b=w[f|0];if((b|0)==255){break R}v[22640]=0;b=W(415,a|0,b+1|0,0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break D}if(!b){break R}g=x[a+480190>>1];v[22640]=0;U(1464,d+144|0,b|0,g|0);b=v[22640];v[22640]=0;if((b|0)==1){break D}b=0;if(!w[d+174|0]){break R}while(1){S:{if(!ei(a)){break S}v[22640]=0;g=Q(1465,c|0,d+512|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break C}if(!g){break S}g=x[a+480190>>1]+1|0;u[a+480190>>1]=g;if((w[d+512|0]|w[d+513|0]<<8|(w[d+514|0]<<16|w[d+515|0]<<24))!=1347240275){break S}v[22640]=0;Hk(d+496|0,2,i);e=v[22640];v[22640]=0;T:{U:{V:{if((e|0)==1){break V}v[22640]=0;R(377,d+56|0,d+496|0);e=v[22640];v[22640]=0;if((e|0)==1){break V}v[22640]=0;g=g&65535;Q(333,((g<<5)+a|0)+946304|0,d+56|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break U}vb(d+56|0);v[22640]=0;g=(B(g,104)+a|0)+484380|0;U(1466,d+512|0,d+144|0,g|0);e=v[22640];v[22640]=0;if((e|0)==1){break m}if(!h){break T}e=d+550|0;Pc(d+56|0,(w[e|0]|w[e+1|0]<<8)&4?16:8,1,0,0);v[22640]=0;W(363,d+56|0,g|0,c|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){break S}a=P()|0;O()|0;break l}a=P()|0;O()|0;break l}a=P()|0;O()|0;vb(d+56|0);break l}g=Yi(g);v[22640]=0;Q(350,c|0,g|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break m}}b=b+1|0;if(b>>>0<w[d+174|0]){continue}break}}yb(c);Ah(d+128|0);if(Gb(d+128|0,d+40|0)){continue}break}}fd(d+88|0);break P}a=P()|0;O()|0;break l}v[22640]=0;U(1461,d+496|0,j|0,1179011410);b=v[22640];v[22640]=0;if((b|0)==1){break B}m=d,n=Sb(d+496|0),v[m+488>>2]=n;m=d,n=Wb(d+496|0),v[m+480>>2]=n;if(Gb(d+488|0,d+480|0)){g=c&2;h=d+512|4;c=d+80|4;i=d+144|5;while(1){f=Xi(d+576|0,v[d+488>>2]);v[22640]=0;b=T(229,d+576|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break A}W:{if((b|0)!=538986817){break W}v[22640]=0;b=Q(1467,d+576|0,d+472|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break z}if(!b|(w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24))!=1414745673){break W}v[22640]=0;b=Q(1468,d+576|0,d+144|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break y}if(!b){break W}b=w[i|0];if((b|0)==255){break W}v[22640]=0;b=W(415,a|0,b+1|0,0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break x}if(!b){break W}e=x[a+480190>>1];v[22640]=0;U(1469,d+144|0,b|0,e|0);b=v[22640];v[22640]=0;if((b|0)==1){break x}v[22640]=0;U(1457,d+512|0,f|0,2);b=v[22640];v[22640]=0;if((b|0)==1){break F}v[22640]=0;U(1461,d+128|0,d+512|0,1179011410);b=v[22640];v[22640]=0;if((b|0)==1){break w}Cd(d+512|0);m=d,n=Sb(d+128|0),v[m+120>>2]=n;m=d,n=Wb(d+128|0),v[m+112>>2]=n;X:{if(!Gb(d+120|0,d+112|0)){break X}Y:{while(1){b=Je(d+88|0,v[d+120>>2]);v[22640]=0;f=T(229,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break v}Z:{_:{if((f|0)!=538989377){break _}if(!ei(a)){break _}f=w[d+468|0]|w[d+469|0]<<8;e=f-1|0;t[d+468|0]=e;t[d+469|0]=e>>>8;if(!f){yb(b);break X}f=x[a+480190>>1]+1|0;u[a+480190>>1]=f;v[22640]=0;e=Q(1467,b|0,d+80|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break u}$:{if(!(!e|(w[d+80|0]|w[d+81|0]<<8|(w[d+82|0]<<16|w[d+83|0]<<24))!=1347240275)){e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22640]=0;U(320,d+56|0,b|0,e|0);e=v[22640];v[22640]=0;aa:{if((e|0)!=1){v[22640]=0;e=Q(1470,d+56|0,d+512|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break Z}if(!e){break Y}v[22640]=0;_e(d+24|0,2,h);e=v[22640];v[22640]=0;if((e|0)!=1){v[22640]=0;R(377,d+40|0,d+24|0);e=v[22640];v[22640]=0;if((e|0)!=1){break aa}}a=P()|0;O()|0;break p}a=P()|0;O()|0;break o}v[22640]=0;f=f&65535;Q(333,((f<<5)+a|0)+946304|0,d+40|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break t}vb(d+40|0);v[22640]=0;f=(B(f,104)+a|0)+484380|0;U(1471,d+512|0,d+144|0,f|0);e=v[22640];v[22640]=0;if((e|0)==1){break Z}if(!g){break $}e=w[d+512|0]|w[d+513|0]<<8|(w[d+514|0]<<16|w[d+515|0]<<24);v[22640]=0;Q(227,d+56|0,e+4|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break Z}e=d+552|0;Pc(d+40|0,(w[e|0]|w[e+1|0]<<8)&4?16:8,1,0,0);v[22640]=0;W(363,d+40|0,f|0,d+56|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){break $}a=P()|0;O()|0;break p}yb(b);break X}yb(d+56|0)}yb(b);Ah(d+120|0);if(Gb(d+120|0,d+112|0)){continue}break X}break}a=P()|0;O()|0;break p}yb(d+56|0);yb(b)}fd(d+128|0)}yb(d+576|0);Ah(d+488|0);if(Gb(d+488|0,d+480|0)){continue}break}}fd(d+496|0)}h=1}yb(d+704|0);Cd(j);yb(l)}gb=d+784|0;return h|0}a=P()|0;O()|0;break n}a=P()|0;O()|0;break b}a=P()|0;O()|0;break l}a=P()|0;O()|0;break l}a=P()|0;O()|0;break b}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;Cd(d+512|0);break n}a=P()|0;O()|0;break o}a=P()|0;O()|0;break o}a=P()|0;O()|0;vb(d+40|0);break p}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}yb(d+56|0)}yb(b);fd(d+128|0)}yb(d+576|0);fd(d+496|0);break b}a=P()|0;O()|0}yb(c);fd(d+88|0);break b}a=P()|0;O()|0;break i}a=P()|0;O()|0;yb(b)}fd(d+512|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+144|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}yb(d+704|0)}Cd(j);yb(l);S(a|0);L()}function pka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;i=gb-240|0;gb=i;a:{if(!Gu(a)){hc(i+80|0,a,128);nf(i+208|0,i+80|0,128,2);Bc(i+224|0,i+208|0);v[22640]=0;Q(333,b+492|0,i+224|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break a}vb(i+224|0)}u[c+34>>1]=x[c+34>>1]&65489;f=c;j=gb-48|0;gb=j;e=a;b:{if(!(w[e+128|0]==4|w[e+128|0]==8)){v[j+44>>2]=0;v[j+40>>2]=0;break b}t[j+40|0]=w[e+129|0];t[j+36|0]=100;g=w[ac(j+40|0,j+36|0)|0];v[j+44>>2]=g;t[j+36|0]=w[e+130|0];t[j+32|0]=100;l=w[ac(j+36|0,j+32|0)|0];v[j+40>>2]=l;c:{if(w[e+140|0]&16){h=Ib(w[e+150|0]|w[e+151|0]<<8)|g<<16;v[j+44>>2]=h;g=Ib(w[e+152|0]|w[e+153|0]<<8)|l<<16;v[j+40>>2]=g;p=+y[f>>2]*1.52587890625e-7;e=hr(p*+(h>>>0));v[j+44>>2]=e;v[j+36>>2]=v[f>>2]-e;s=j,z=hr(p*+(g>>>0)),v[s+32>>2]=z;s=j,z=v[Fb(j+36|0,j+32|0)>>2],v[s+40>>2]=z;break c}if(!Ld(f)){break c}o=(g<<7>>>0)/100|0;g=v[f>>2];e=g>>>7|0;h=B(o,e);v[j+44>>2]=h;v[j+36>>2]=g-h;v[j+32>>2]=B(e,(l<<7>>>0)/100|0);g=v[Fb(j+36|0,j+32|0)>>2];v[j+40>>2]=g;o=j;d:{if(t[f+34|0]&1){nn(j+24|0,v[f+20>>2],B(v[f>>2],bd(f)));l=bd(f);e=v[j+28>>2];v[j+8>>2]=v[j+24>>2];v[j+12>>2]=e;e=v[j+8>>2];e:{if(g){n=u[e+(B(h,l)<<1)>>1];f=e+(B(l,g+h|0)<<1)|0;k=0-l<<1;while(1){l=u[f>>1]-n|0;h=l>>31;e=g;if((h^h+l)>>>0<1536){break e}f=f+k|0;g=g-1|0;if(g){continue}break}}e=0}break d}bc(j+16|0,v[f+20>>2],B(v[f>>2],bd(f)));f=bd(f);e=v[j+20>>2];v[j>>2]=v[j+16>>2];v[j+4>>2]=e;e=v[j>>2];f:{if(g){n=0-f|0;k=t[e+B(f,h)|0];f=e+B(f,g+h|0)|0;while(1){l=t[f|0]-k|0;h=l>>31;e=g;if((h^h+l)>>>0<6){break f}f=f+n|0;g=g-1|0;if(g){continue}break}}e=0}}v[o+40>>2]=e}}v[i+224>>2]=v[j+44>>2];v[i+228>>2]=v[j+40>>2];gb=j+48|0;f=128;n=ec(i+224|0);if(!(!v[n>>2]|w[a+128|0]!=4)){u[c+34>>1]=x[c+34>>1]|2;v[c+4>>2]=v[i+224>>2];v[c+8>>2]=v[n>>2]+v[i+224>>2]}e=i;if(!(!w[a+134|0]|w[a+134|0]>199)){t[i+80|0]=w[a+134|0];t[i+208|0]=100;f=(w[ac(i+80|0,i+208|0)|0]<<7>>>0)/100|0}t[e+79|0]=f;t[i+80|0]=64;s=c,z=w[Bf(i+79|0,i+80|0)|0]>>>1|0,u[s+32>>1]=z;t[i+80|0]=64;s=b,z=w[ac(i+79|0,i+80|0)|0],v[s+4>>2]=z;v[c+24>>2]=40460;No(c,+t[a+139|0]*.08333333333333333+ +(0-w[a+143|0]|0)+ +t[a+138|0]*.0006510416666666666);t[b+34|0]=w[a+142|0]&2?2:1;if(w[a+142|0]&2){fm(b,127,1);em(b,0,1)}g:{if(!Ld(c)){break g}if(t[a+140|0]&1){b=d;e=c;h:{if(!Ld(e)){break h}f=v[e>>2];if(f>>>0<2){break h}i:{if((fj(e)|0)==4){h=v[e+20>>2];k=0;g=f>>>1|0;while(1){jc(h+(k<<2)|0,h+((k^-1)+f<<2)|0);k=k+1|0;if((g|0)!=(k|0)){continue}break}break i}if((fj(e)|0)==2){h=v[e+20>>2];k=0;g=f>>>1|0;while(1){zz(h+(k<<1)|0,h+((k^-1)+f<<1)|0);k=k+1|0;if((g|0)!=(k|0)){continue}break}break i}if((fj(e)|0)!=1){break h}h=v[e+20>>2];k=0;g=f>>>1|0;while(1){Dh(h+k|0,h+((k^-1)+f|0)|0);k=k+1|0;if((g|0)!=(k|0)){continue}break}}Zh(e,b,0)}}if(w[a+140|0]&4){b=d;e=c;j:{if(!Ld(e)){break j}f=v[e>>2];bd(e);h=0;g=B(bd(e),f);k:{if((ej(e)|0)==2){j=v[e+20>>2]+(h<<1)|0;f=0;h=g-h|0;if(h){while(1){g=j+(f<<1)|0;u[g>>1]=x[g>>1]^-1;f=f+1|0;if((h|0)!=(f|0)){continue}break}}break k}if((ej(e)|0)!=1){break j}j=h+v[e+20>>2]|0;f=0;h=g-h|0;if(h){while(1){g=f+j|0;t[g|0]=w[g|0]^-1;f=f+1|0;if((h|0)!=(f|0)){continue}break}}}Zh(e,b,0)}}if(!(!(w[a+141|0]?1:w[a+160|0]|w[a+170|0]==2)|t[c+34|0]&1)){e=Wq(v[c>>2],bd(c)<<1);if(!e){break g}b=e;h=B(v[c>>2],bd(c));g=v[c+20>>2];f=Yi(c);j=gb-16|0;gb=j;v[j+12>>2]=h;tc(j+12|0,f);k=v[j+12>>2];if(k){while(1){u[b>>1]=t[g|0]<<8;g=g+1|0;b=b+2|0;k=k-1|0;if(k){continue}break}v[j+12>>2]=-1}gb=j+16|0;u[c+34>>1]=x[c+34>>1]|1;PN(c,e,v[c>>2],d)}l:{if(t[a+141|0]>-1){break l}nn(i+80|0,v[c+20>>2],B(v[c>>2],bd(c)));if(t[a+141|0]>=0){break l}while(1){b=v[i+80>>2];e=v[i+84>>2];if((b|0)!=(e|0)){f=u[v[i+80>>2]>>1];while(1){f=ed(u[b>>1]-ed(f,1)|0,1);u[b>>1]=f;b=b+2|0;if((e|0)!=(b|0)){continue}break}}m=m+1|0;if((m|0)<(0-t[a+141|0]|0)){continue}break}}m:{if(w[a+170|0]!=2){break m}nn(i+80|0,v[c+20>>2],B(v[c>>2],bd(c)));f=w[a+171|0];g=w[a+172|0];e=w[a+171|0];b=0-(g>>>0<e>>>0)|0;e=g-e|0;l=b<<24|e>>>8;g=e<<24;h=yB(i+80|0);e=(h|0)/2|0;b=e;g=g+e|0;e=(e>>31)+l|0;g=zc(nqa(g,b>>>0>g>>>0?e+1|0:e,h,h>>31),jb);b=v[i+80>>2];j=v[i+84>>2];if((b|0)==(j|0)){break m}e=f<<24;l=e;f=e>>31;e=g;h=e>>31;while(1){g=u[b>>1];g=mqa(l,f,g,g>>31)+838860800|0;k=jb;s=b,z=zc(nqa(g,g>>>0<838860800?k+1|0:k,1677721600,0),jb),u[s>>1]=z;f=f+h|0;l=e+l|0;f=l>>>0<e>>>0?f+1|0:f;b=b+2|0;if((j|0)!=(b|0)){continue}break}}n:{if(!w[a+160|0]){break n}nn(i+208|0,v[c+20>>2],B(v[c>>2],bd(c)));j=w[a+162|0];h=w[a+163|0];if(w[a+161|0]>=2){g=w[a+164|0];e=w[a+162|0];b=0-(g>>>0<e>>>0)|0;e=g-e|0;k=b<<23|e>>>9;b=e<<23;f=yB(i+208|0);e=(f|0)/2|0;g=b+e|0;l=(e>>31)+k|0;q=zc(nqa(g,e>>>0>g>>>0?l+1|0:l,f,f>>31),jb)}if(w[a+161|0]>=2){g=w[a+165|0];e=w[a+163|0];b=0-(g>>>0<e>>>0)|0;e=g-e|0;k=b<<23|e>>>9;b=e<<23;l=yB(i+208|0);e=(l|0)/2|0;g=b+e|0;f=(e>>31)+k|0;r=zc(nqa(g,e>>>0>g>>>0?f+1|0:f,l,l>>31),jb)}b=v[i+208>>2];l=v[i+212>>2];if((b|0)==(l|0)){break n}f=j<<23;g=h<<23;j=(i+80|0)+((w[a+160|0]&2)<<2)|0;m=0;k=0;while(1){h=(u[b>>1]>>1)-k|0;v[i+88>>2]=h;e=(f|0)/8388608|0;m=ed(B(h,e),8)+m|0;v[i+84>>2]=m;e=ed(B(e,m),6)+k|0;k=ed(ed(B(e,(g|0)/8388608|0),6)+e|0,2);v[i+80>>2]=k;s=b,z=Sc(v[j>>2]),u[s>>1]=z;g=g+r|0;f=f+q|0;b=b+2|0;if((l|0)!=(b|0)){continue}break}}o:{if(t[a+141|0]<1){break o}nn(i+80|0,v[c+20>>2],B(v[c>>2],bd(c)));m=0;if(t[a+141|0]<=0){break o}while(1){b=v[i+80>>2];e=v[i+84>>2];if((b|0)!=(e|0)){f=u[v[i+80>>2]>>1];while(1){f=((u[b>>1]<<1)+f|0)/3|0;u[b>>1]=f;b=b+2|0;if((e|0)!=(b|0)){continue}break}}m=m+1|0;if((m|0)<t[a+141|0]){continue}break}}p:{if(t[c+34|0]&1){nn(i- -64|0,v[c+20>>2],B(v[c>>2],bd(c)));b=v[i+68>>2];v[i+32>>2]=v[i+64>>2];v[i+36>>2]=b;m=gb-16|0;gb=m;f=v[i+36>>2];h=gb-16|0;gb=h;v[h+4>>2]=v[i+32>>2];b=Fu(m+8|0,h+4|0,h+4|0);e=v[h+4>>2];q:{if((e|0)==(f|0)){break q}e=e+2|0;v[h+4>>2]=e;if((e|0)==(f|0)){break q}e=(Kj(e,v[b>>2])?0:4)+b|0;g=v[h+4>>2];v[e>>2]=g;k=g+2|0;if((f|0)==(k|0)){break q}e=b+4|0;while(1){g=g+4|0;v[h+4>>2]=g;if((f|0)==(g|0)){if(!Kj(k,v[b>>2])){b=e;if(Kj(k,v[e>>2])){break q}}v[b>>2]=k;break q}r:{s:{if(Kj(g,k)){if(Kj(v[h+4>>2],v[b>>2])){v[b>>2]=v[h+4>>2]}if(!Kj(k,v[e>>2])){break s}break r}if(Kj(k,v[b>>2])){v[b>>2]=k}if(Kj(v[h+4>>2],v[e>>2])){break r}k=v[h+4>>2]}v[e>>2]=k}g=v[h+4>>2];k=g+2|0;v[h+4>>2]=k;if((f|0)!=(k|0)){continue}break}}gb=h+16|0;v[m+4>>2]=0-u[v[m+8>>2]>>1];s=m,z=u[v[ec(m+8|0)>>2]>>1],v[s>>2]=z;e=v[Nf(m+4|0,m)>>2];t:{if((e|0)>=32767|!e){break t}f=v[i+32>>2];b=v[i+36>>2];if((f|0)==(b|0)){break t}while(1){u[f>>1]=(B(u[f>>1],32767)|0)/(e|0);f=f+2|0;if((b|0)!=(f|0)){continue}break}}break p}bc(i+56|0,v[c+20>>2],B(v[c>>2],bd(c)));b=v[i+60>>2];v[i+24>>2]=v[i+56>>2];v[i+28>>2]=b;m=gb-16|0;gb=m;f=v[i+28>>2];h=gb-16|0;gb=h;v[h+4>>2]=v[i+24>>2];b=Fu(m+8|0,h+4|0,h+4|0);e=v[h+4>>2];u:{if((e|0)==(f|0)){break u}e=e+1|0;v[h+4>>2]=e;if((e|0)==(f|0)){break u}e=(Jj(e,v[b>>2])?0:4)+b|0;g=v[h+4>>2];v[e>>2]=g;k=g+1|0;if((f|0)==(k|0)){break u}e=b+4|0;while(1){g=g+2|0;v[h+4>>2]=g;if((f|0)==(g|0)){if(!Jj(k,v[b>>2])){b=e;if(Jj(k,v[e>>2])){break u}}v[b>>2]=k;break u}v:{w:{if(Jj(g,k)){if(Jj(v[h+4>>2],v[b>>2])){v[b>>2]=v[h+4>>2]}if(!Jj(k,v[e>>2])){break w}break v}if(Jj(k,v[b>>2])){v[b>>2]=k}if(Jj(v[h+4>>2],v[e>>2])){break v}k=v[h+4>>2]}v[e>>2]=k}g=v[h+4>>2];k=g+1|0;v[h+4>>2]=k;if((f|0)!=(k|0)){continue}break}}gb=h+16|0;v[m+4>>2]=0-t[v[m+8>>2]];s=m,z=t[v[ec(m+8|0)>>2]],v[s>>2]=z;e=v[Nf(m+4|0,m)>>2];x:{if((e|0)>=127|!e){break x}f=v[i+24>>2];b=v[i+28>>2];if((f|0)==(b|0)){break x}while(1){t[f|0]=(B(t[f|0],127)|0)/(e|0);f=f+1|0;if((b|0)!=(f|0)){continue}break}}}gb=m+16|0;y:{if(w[a+134|0]<101|w[a+134|0]>199){break y}e=B(v[c>>2],bd(c));if(t[c+34|0]&1){b=v[c+20>>2];g=pd(i+48|0,b,b+(e<<1)|0);e=w[a+134|0];b=v[g+4>>2];v[i+16>>2]=v[g>>2];v[i+20>>2]=b;l=(3276800-(e<<14)|0)/100|0;b=v[i+16>>2];f=v[i+20>>2];if((b|0)!=(f|0)){g=0-l|0;j=32768-l|0;while(1){e=b;o=e;h=u[e>>1];z:{if((h|0)>(l|0)){e=j+((B(l,h-l|0)|0)/(j|0)|0)|0;break z}e=((B(l,h+l|0)|0)/(j|0)|0)-j|0;if((g|0)>(h|0)){break z}e=(B(h,j)|0)/(l|0)|0}s=o,z=Sc(e),u[s>>1]=z;b=b+2|0;if((f|0)!=(b|0)){continue}break}}break y}b=v[c+20>>2];g=pd(i+40|0,b,b+e|0);e=w[a+134|0];b=v[g+4>>2];v[i+8>>2]=v[g>>2];v[i+12>>2]=b;l=(3276800-(e<<14)|0)/100|0;b=v[i+8>>2];f=v[i+12>>2];if((b|0)!=(f|0)){g=0-l|0;j=32768-l|0;while(1){e=b;o=e;h=t[e|0]<<8;A:{if((h|0)>(l|0)){e=j+((B(l,h-l|0)|0)/(j|0)|0)|0;break A}e=((B(l,h+l|0)|0)/(j|0)|0)-j|0;if((g|0)>(h|0)){break A}e=(B(h,j)|0)/(l|0)|0}s=o,z=GV((e|0)/256|0),t[s|0]=z;b=b+1|0;if((f|0)!=(b|0)){continue}break}}}if(!v[n>>2]|(!w[a+131|0]|w[a+128|0]!=8)){break g}v[c+12>>2]=v[i+224>>2];v[c+16>>2]=v[n>>2]+v[i+224>>2];if(y[n>>2]>268435456/w[a+131|0]>>>0|y[c>>2]>268435456-B(v[n>>2],w[a+131|0])>>>0){break g}j=fj(c);f=v[i+224>>2];g=v[n>>2];e=w[a+131|0];h=v[c>>2]+B(v[n>>2],w[a+131|0])|0;b=Wq(h,j);if(!b){break g}e=f+B(g,e+1|0)|0;v[c>>2]=h;g=hc(b,zb(v[c+20>>2]),B(j,v[n>>2]+v[i+224>>2]|0));B:{if(!w[a+131|0]){break B}b=1;while(1){hc(g+B(j,v[i+224>>2]+B(v[n>>2],b)|0)|0,zb(v[c+20>>2])+B(j,v[i+224>>2])|0,B(j,v[n>>2]));if(w[a+131|0]<=b>>>0){break B}b=b+1|0;continue}}hc(g+B(e,j)|0,zb(v[c+20>>2])+B(j,v[n>>2]+v[i+224>>2]|0)|0,B(j,h-e|0));PN(c,g,v[c>>2],d)}gb=i+240|0;return}a=P()|0;O()|0;vb(i+224|0);S(a|0);L()}function AH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=C(0),L=0;d=gb-144|0;gb=d;D=Qb(d,0,144);v[D+76>>2]=-1;v[D+44>>2]=a;v[D+32>>2]=2426;v[D+84>>2]=a;E=c;j=gb-304|0;gb=j;e=D;d=b;a=w[b|0];a:{if(!a){break a}b:{c:{d:{e:{while(1){f:{g:{if(xm(a&255)){while(1){a=d;d=d+1|0;if(xm(w[a+1|0])){continue}break}xi(e,0,0);while(1){b=v[e+4>>2];h:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break h}b=jd(e)}if(xm(b)){continue}break}d=v[e+4>>2];if(v[e+104>>2]){d=d-1|0;v[e+4>>2]=d}b=d-v[e+8>>2]|0;d=b>>31;h=b;l=n+v[e+124>>2]|0;b=r+v[e+120>>2]|0;l=b>>>0<r>>>0?l+1|0:l;c=b;b=h+b|0;h=d+l|0;r=b;n=b>>>0<c>>>0?h+1|0:h;break g}i:{j:{k:{b=w[d|0];if((b|0)==37){a=w[d+1|0];if((a|0)==42){break k}if((a|0)!=37){break j}}xi(e,0,0);a=((b|0)==37)+d|0;b=v[e+4>>2];l:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break l}b=jd(e)}if((b|0)!=w[a|0]){if(v[e+104>>2]){v[e+4>>2]=v[e+4>>2]-1}if((b|0)>-1){break a}x=0;if(F){break a}break c}b=r+1|0;n=b>>>0<1?n+1|0:n;r=b;break g}m=0;a=d+2|0;break i}if(!(!Sh(a)|w[d+2|0]!=36)){a=w[d+1|0]-48|0;b=gb-16|0;v[b+12>>2]=E;a=a>>>0>1?((a<<2)+E|0)-4|0:E;v[b+8>>2]=a+4;m=v[a>>2];a=d+3|0;break i}m=v[E>>2];E=E+4|0;a=d+1|0}x=0;m:{if(!Sh(w[a|0])){d=0;break m}d=0;while(1){b=a+1|0;d=(w[a|0]+d|0)-48|0;if(Sh(w[a+1|0])){d=B(d,10);a=b;continue}else{a=b}break}}c=w[a|0];if((c|0)==109){o=0;x=(m|0)!=0;c=w[a+1|0];p=0;a=a+1|0}b=a;a=b+1|0;g=3;n:{o:{switch(c-65|0){case 39:c=b+2|0;b=w[b+1|0]==104;a=b?c:a;g=b?-2:-1;break n;case 43:c=b+2|0;b=w[b+1|0]==108;a=b?c:a;g=b?3:1;break n;case 51:case 57:g=1;break n;case 11:g=2;break n;case 41:break n;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break o;default:break d}}g=0;a=b}b=w[a|0];c=(b&47)==3;G=c?1:g;s=c?b|32:b;p:{if((s|0)==91){break p}q:{if((s|0)!=110){if((s|0)!=99){break q}d=(d|0)>1?d:1;break p}BH(m,G,r,n);break g}xi(e,0,0);while(1){b=v[e+4>>2];r:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break r}b=jd(e)}if(xm(b)){continue}break}b=v[e+4>>2];if(v[e+104>>2]){b=b-1|0;v[e+4>>2]=b}b=b-v[e+8>>2]|0;h=b>>31;g=b;b=n+v[e+124>>2]|0;c=r+v[e+120>>2]|0;b=c>>>0<r>>>0?b+1|0:b;n=c;c=g+c|0;h=b+h|0;r=c;n=c>>>0<n>>>0?h+1|0:h}k=d;i=d>>31;xi(e,d,i);b=v[e+104>>2];c=v[e+4>>2];s:{if(b>>>0>c>>>0){v[e+4>>2]=c+1;break s}if((jd(e)|0)<0){break d}b=v[e+104>>2]}if(b){v[e+4>>2]=v[e+4>>2]-1}b=16;t:{u:{v:{w:{x:{y:{z:{switch(s-88|0){default:b=s-65|0;if(b>>>0>6|!(1<<b&113)){break t}case 9:case 13:case 14:case 15:CI(j,e,G,0);b=v[e+4>>2]-v[e+8>>2]|0;if(v[e+120>>2]==(0-b|0)&v[e+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break b}if(!m){break t}b=v[j+8>>2];c=v[j+12>>2];d=v[j>>2];h=v[j+4>>2];switch(G|0){case 2:break v;case 1:break w;case 0:break x;default:break t};case 3:case 11:case 27:if((s&239)==99){Qb(j+32|0,-1,257);t[j+32|0]=0;if((s|0)!=115){break u}t[j+65|0]=0;t[j+46|0]=0;u[j+42>>1]=0;u[j+44>>1]=0;break u}c=w[a+1|0];h=(c|0)==94;Qb(j+32|0,h,257);t[j+32|0]=0;b=h?a+2|0:a+1|0;A:{B:{C:{a=w[(h?2:1)+a|0];if((a|0)!=45){if((a|0)==93){break C}g=(c|0)!=94;a=b;break A}g=(c|0)!=94;t[j+78|0]=g;break B}g=(c|0)!=94;t[j+126|0]=g}a=b+1|0}while(1){b=w[a|0];D:{if((b|0)!=45){if(!b){break d}if((b|0)!=93){break D}break u}b=45;c=w[a+1|0];if(!c|(c|0)==93){break D}h=a+1|0;a=w[a-1|0];E:{if(c>>>0<=a>>>0){b=c;break E}while(1){a=a+1|0;t[a+(j+32|0)|0]=g;b=w[h|0];if(b>>>0>a>>>0){continue}break}}a=h}t[(b+j|0)+33|0]=g;a=a+1|0;continue};case 23:b=8;break y;case 12:case 29:b=10;break y;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break t;case 0:case 24:case 32:break y;case 17:break z}}b=0}f=e;k=0;h=0;i=0;g=0;I=0;H=gb-16|0;gb=H;F:{G:{H:{I:{J:{K:{if(b>>>0<=36){while(1){c=v[f+4>>2];L:{if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break L}c=jd(f)}if(xm(c)){continue}break}M:{N:{switch(c-43|0){case 0:case 2:break N;default:break M}}I=(c|0)==45?-1:0;c=v[f+4>>2];if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break M}c=jd(f)}O:{if(!(b&-17|(c|0)!=48)){c=v[f+4>>2];P:{if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break P}c=jd(f)}if((c&-33)==88){b=16;c=v[f+4>>2];Q:{if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break Q}c=jd(f)}if(w[c+74225|0]<16){break J}if(!v[f+104>>2]){break G}v[f+4>>2]=v[f+4>>2]-1;break G}if(b){break O}b=8;break J}b=b?b:10;if(b>>>0>w[c+74225|0]){break O}if(v[f+104>>2]){v[f+4>>2]=v[f+4>>2]-1}xi(f,0,0);v[115121]=28;b=0;c=0;break F}if((b|0)!=10){break J}i=c-48|0;if(i>>>0<=9){b=0;while(1){k=b+i|0;b=v[f+4>>2];R:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;c=w[b|0];break R}c=jd(f)}i=c-48|0;if(!(i>>>0>9|k>>>0>429496728)){b=B(k,10);continue}break}}if(i>>>0>9){break K}q=mqa(k,0,10,0);l=jb;d=i;while(1){b=v[f+4>>2];S:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;c=w[b|0];break S}c=jd(f)}i=c-48|0;g=i>>>0>9;h=l;b=d+q|0;h=b>>>0<d>>>0?h+1|0:h;k=b;if((h|0)==429496729&b>>>0>=2576980378|h>>>0>429496729|g){break K}q=mqa(k,h,10,0);b=q;l=jb;g=l;d=i;if((g|0)==-1&(d^-1)>>>0>=b>>>0|(g|0)!=-1){continue}break}b=10;break I}v[115121]=28;b=0;c=0;break F}b=10;if(i>>>0<=9){break I}break H}if(b-1&b){g=w[c+74225|0];if(g>>>0<b>>>0){while(1){k=g+i|0;i=k>>>0>119304646;d=b;c=v[f+4>>2];T:{if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break T}c=jd(f)}g=w[c+74225|0];if(!(i|d>>>0<=g>>>0)){i=B(b,k);continue}break}}if(b>>>0<=g>>>0){break I}i=b;q=mqa(k,0,b,0);l=jb;d=g;if((l|0)==-1&(d^-1)>>>0<q>>>0){break I}while(1){h=l;c=d+q|0;h=c>>>0<d>>>0?h+1|0:h;k=c;c=v[f+4>>2];U:{if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break U}c=jd(f)}d=w[c+74225|0];if(d>>>0>=b>>>0){break I}pf(H,i,0,0,0,k,h,0,0);if(v[H+8>>2]|v[H+12>>2]){break I}q=mqa(k,h,i,0);g=q;l=jb;if((l|0)==-1&(d^-1)>>>0>=g>>>0|(l|0)!=-1){continue}break}break I}d=t[(B(b,23)>>>5&7)+74481|0];i=w[c+74225|0];if(i>>>0<b>>>0){while(1){k=g|i;g=k>>>0>134217727;h=b;c=v[f+4>>2];V:{if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break V}c=jd(f)}i=w[c+74225|0];if(!(g|h>>>0<=i>>>0)){g=k<<d;continue}break}h=0}if(b>>>0<=i>>>0){break I}g=d&31;if((d&63)>>>0>=32){l=0;q=-1>>>g|0}else{l=-1>>>g|0;q=(1<<g)-1<<32-g|-1>>>g}if(!l&k>>>0>q>>>0){break I}while(1){g=i&255;i=k;c=d;k=c&31;if((c&63)>>>0>=32){h=i<<k;c=0}else{h=(1<<k)-1&i>>>32-k|h<<k;c=i<<k}k=g|c;g=b;c=v[f+4>>2];W:{if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break W}c=jd(f)}i=w[c+74225|0];if(g>>>0<=i>>>0){break I}if((h|0)==(l|0)&k>>>0<=q>>>0|h>>>0<l>>>0){continue}break}}if(w[c+74225|0]>=b>>>0){break H}while(1){d=v[f+4>>2];X:{if(d>>>0<y[f+104>>2]){v[f+4>>2]=d+1;c=w[d|0];break X}c=jd(f)}if(w[c+74225|0]<b>>>0){continue}break}v[115121]=68;I=0;k=-1;h=-1}if(v[f+104>>2]){v[f+4>>2]=v[f+4>>2]-1}if((k|0)==-1&(h|0)==-1){if(!(I|1)){v[115121]=68;b=-2;c=-1;break F}}b=I;d=b^k;c=b;b=d-b|0;g=h;h=c>>31;c=(g^h)-((c>>>0>d>>>0)+h|0)|0;break F}xi(f,0,0);b=0;c=0}gb=H+16|0;d=v[e+4>>2]-v[e+8>>2]|0;if(v[e+120>>2]==(0-d|0)&v[e+124>>2]==(0-((d>>31)+((d|0)!=0)|0)|0)){break b}if(!(!m|(s|0)!=112)){v[m>>2]=b;break t}BH(m,G,b,c);break t}J=m,K=AI(d,h,b,c),z[J>>2]=K;break t}J=m,L=Yx(d,h,b,c),A[J>>3]=L;break t}v[m>>2]=d;v[m+4>>2]=h;v[m+8>>2]=b;v[m+12>>2]=c;break t}h=(s|0)==99;g=h?d+1|0:31;f=(G|0)!=1;Y:{if(!f){b=m;if(x){b=Ad(g<<2);if(!b){break e}}v[j+296>>2]=0;v[j+300>>2]=0;d=0;c=x;while(1){p=b;Z:{while(1){b=v[e+4>>2];_:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break _}b=jd(e)}if(!w[(b+j|0)+33|0]){break Z}t[j+27|0]=b;b=$p(j+28|0,j+27|0,1,j+296|0);if((b|0)==-2){continue}if((b|0)==-1){break f}if(p){v[(d<<2)+p>>2]=v[j+28>>2];d=d+1|0}if(!(c&(d|0)==(g|0))){continue}break}g=g<<1|1;b=Wp(p,g<<2);if(b){continue}break f}break}if(j+296|0?v[j+296>>2]:0){break f}o=0;break Y}if(x){d=0;b=Ad(g);if(!b){break e}while(1){o=b;while(1){b=v[e+4>>2];$:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break $}b=jd(e)}if(!w[(b+j|0)+33|0]){p=0;break Y}t[d+o|0]=b;d=d+1|0;if((g|0)!=(d|0)){continue}break}p=0;g=g<<1|1;b=Wp(o,g);if(b){continue}break}break d}d=0;if(m){while(1){b=v[e+4>>2];aa:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break aa}b=jd(e)}if(w[(b+j|0)+33|0]){t[d+m|0]=b;d=d+1|0;continue}else{p=0;o=m;break Y}}}while(1){b=v[e+4>>2];ba:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break ba}b=jd(e)}if(w[(b+j|0)+33|0]){continue}break}o=0;p=0}b=v[e+4>>2];if(v[e+104>>2]){b=b-1|0;v[e+4>>2]=b}c=b-v[e+8>>2]|0;b=c+v[e+120>>2]|0;l=v[e+124>>2]+(c>>31)|0;l=b>>>0<c>>>0?l+1|0:l;if(!(l|b)|((b|0)!=(k|0)|(i|0)!=(l|0)?(s|0)==99:0)){break b}ca:{if(!x){break ca}if(!f){v[m>>2]=p;break ca}v[m>>2]=o}if(h){break t}if(p){v[(d<<2)+p>>2]=0}if(!o){o=0;break t}t[d+o|0]=0}b=v[e+4>>2]-v[e+8>>2]|0;d=b>>31;h=b;n=n+v[e+124>>2]|0;b=r+v[e+120>>2]|0;n=b>>>0<r>>>0?n+1|0:n;c=b;b=h+b|0;n=d+n|0;n=b>>>0<c>>>0?n+1|0:n;r=b;F=((m|0)!=0)+F|0}d=a+1|0;a=w[a+1|0];if(a){continue}break a}break}o=0;break d}o=0;p=0}if(F){break b}}F=-1}if(!x){break a}Zb(o);Zb(p)}gb=j+304|0;gb=D+144|0;return F}function Nga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;j=gb-288|0;gb=j;f=gb-112|0;gb=f;g=j+104|0;h=Xi(g,c);v[22640]=0;i=T(251,g+20|0)|0;c=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((c|0)!=1){v[22640]=0;n=T(251,g+40|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break A}v[22640]=0;o=T(251,g+60|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break z}v[22640]=0;p=T(251,g+80|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break y}v[22640]=0;m=T(251,g+100|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break x}v[22640]=0;q=T(251,g+120|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break w}r=Ho(g+140|0);vc(g);v[g+172>>2]=1873739776;u[g+176>>1]=0;v[22640]=0;c=Q(1434,g|0,f+96|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break v}if(!c){break m}c=f+96|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1179011410){c=f+96|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1414744396){break m}}c=f+104|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1702257015?(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1163280727:0){break m}c=f+96|0;t[g+176|0]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))==1414744396;v[22640]=0;U(1435,f+80|0,h|0,2);c=v[22640];v[22640]=0;if((c|0)==1){break u}B:{if(Ch(f+80|0)>>>0<4){break B}c=Vt(f+80|0,1);if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1635017060){break B}if(!(dn(Vt(f+80|0,1))&1)){break B}if(dn(Vt(f+80|0,2))){break B}c=Vt(f+80|0,3);if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break B}v[22640]=0;Q(227,g|0,12)|0;c=v[22640];v[22640]=0;if((c|0)==1){break t}v[22640]=0;U(1435,f+32|0,h|0,1);c=v[22640];v[22640]=0;if((c|0)==1){break s}$N(f+80|0,f+32|0);an(f+32|0)}v[22640]=0;U(1436,f+56|0,f+80|0,544501094);c=v[22640];v[22640]=0;if((c|0)==1){break r}v[22640]=0;c=g+156|0;h=Q(1437,f+56|0,c|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break k}if(!h){break n}if((w[c|0]|w[c+1|0]<<8)==1){v[22640]=0;h=T(492,f+56|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break k}if((h|0)==4){break q}}if((w[c|0]|w[c+1|0]<<8)!=65534){break o}v[22640]=0;h=Q(1438,f+56|0,f+32|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break p}if(!h){break n}h=v[f+52>>2];v[f+8>>2]=v[f+48>>2];v[f+12>>2]=h;h=v[f+44>>2];v[f>>2]=v[f+40>>2];v[f+4>>2]=h;h=f+16|0;v[h>>2]=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);u[h+4>>1]=w[f+4|0]|w[f+5|0]<<8;u[h+6>>1]=w[f+6|0]|w[f+7|0]<<8;s=h,y=xA(w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24),w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24)),v[s+8>>2]=y;v[h+12>>2]=jb;u[g+172>>1]=v[h>>2];break o}c=P()|0;O()|0;break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;break d}c=P()|0;O()|0;break e}c=P()|0;O()|0;break f}c=P()|0;O()|0;break g}c=P()|0;O()|0;break h}c=P()|0;O()|0;break h}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}c=P()|0;O()|0;break i}v[22640]=0;h=T(339,f+56|0)|0;k=v[22640];v[22640]=0;C:{if((k|0)!=1){v[22640]=0;k=T(339,f+56|0)|0;l=v[22640];v[22640]=0;if((l|0)==1){break C}if((h|0)!=2|(k|0)!=1){break o}t[g+177|0]=1;break o}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}v[22640]=0;U(1436,f+32|0,f+80|0,1635017060);h=v[22640];v[22640]=0;D:{E:{F:{G:{H:{I:{if((h|0)!=1){od(i,f+32|0);yb(f+32|0);v[22640]=0;h=T(307,i|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break k}if(!h){v[22640]=0;U(1436,f+32|0,f+80|0,544039792);h=v[22640];v[22640]=0;if((h|0)==1){break I}od(i,f+32|0);yb(f+32|0)}v[22640]=0;U(1436,f+32|0,f+80|0,1952670054);h=v[22640];v[22640]=0;if((h|0)==1){break H}v[22640]=0;h=T(229,f+32|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break G}v[g+152>>2]=h;yb(f+32|0);if(v[g+152>>2]?(w[c|0]|w[c+1|0]<<8)==17:0){break D}if(!lz(g)){break D}if(Io(g)){c=Io(g);h=Ij(g);if((c>>>0)/(h>>>0)>>>0<lz(g)<<1>>>0){break F}}v[22640]=0;c=T(232,i|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break k}l=lz(g);break E}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;yb(f+32|0);break j}v[22640]=0;c=T(232,i|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break k}l=Io(g)}h=l;v[g+152>>2]=(c>>>0)/(h>>>0)}v[22640]=0;c=Q(1439,g|0,f+80|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break k}u[g+174>>1]=c;v[22640]=0;R(1440,g|0,f+80|0);c=v[22640];v[22640]=0;if((c|0)==1){break k}v[22640]=0;U(1436,f+32|0,f+80|0,1886221175);c=v[22640];v[22640]=0;if((c|0)==1){break l}od(m,f+32|0);yb(f+32|0)}yb(f+56|0);an(f+80|0)}gb=f+112|0;c=g;break a}c=P()|0;O()|0;break j}c=P()|0;O()|0}yb(f+56|0)}an(f+80|0)}an(r);yb(q)}yb(m)}yb(p)}yb(o)}yb(n)}yb(i)}yb(g);S(c|0);L()}v[22640]=0;g=T(1154,c|0)|0;f=v[22640];v[22640]=0;J:{K:{L:{M:{if((f|0)==1){break M}N:{O:{if(!g){break O}if(!Ij(c)){break O}if(Ij(c)>>>0>2){break O}if(!Pl(c)){v[22640]=0;g=_h(c);f=v[22640];v[22640]=0;if((f|0)==1){break M}if((g|0)!=85){break O}}if(Pl(c)>>>0<=31){v[22640]=0;g=_h(c);f=v[22640];v[22640]=0;if((f|0)==1){break M}if((g|0)==3){break O}}if(Pl(c)>>>0>64){break O}i=0;v[22640]=0;g=_h(c);f=v[22640];v[22640]=0;if((f|0)==1){break L}v[j+80>>2]=g;h=v[j+80>>2];g=36908;P:{while(1){f=g;l=f;if((h|0)==v[f>>2]){break P}g=g+4|0;if((g|0)!=36932){continue}break}l=36932}if((l|0)==36932){break N}v[22640]=0;Q(1149,a|0,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break M}v[22640]=0;g=Q(112,j+80|0,18693)|0;f=v[22640];v[22640]=0;Q:{R:{S:{T:{U:{V:{if((f|0)!=1){v[22640]=0;i=((b<<5)+a|0)+946304|0;Q(333,i|0,g|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break V}vb(g);v[22640]=0;g=B(b,104)+a|0;f=g+484380|0;R(352,f|0,0);h=v[22640];v[22640]=0;if((h|0)==1){break U}v[f>>2]=v[c+152>>2];v[g+484404>>2]=w[c+160|0]|w[c+161|0]<<8|(w[c+162|0]<<16|w[c+163|0]<<24);v[22640]=0;g=Dk(a);h=v[22640];v[22640]=0;if((h|0)==1){break U}v[22640]=0;Y(1156,c|0,f|0,g|0,i|0);g=v[22640];v[22640]=0;if((g|0)==1){break U}Je(j+80|0,c+20|0);g=Pc(j+72|0,8,Ij(c)>>>0>1?2:1,0,0);v[22640]=0;i=_h(c);h=v[22640];v[22640]=0;if((h|0)==1){break K}if((i|0)!=17){break T}if(Ij(c)>>>0>2){break T}tc(f,268435456);d=(B(b,104)+a|0)+484414|0;u[d>>1]=x[d>>1]|1;g=Ij(c);u[d>>1]=x[d>>1]&65471|((g|0)==2)<<6;i=0;v[22640]=0;d=T(424,f|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break K}if(!d){break R}d=v[(B(b,104)+a|0)+484400>>2];g=v[f>>2];b=Je(j+48|0,j+80|0);i=Io(c);h=Ij(c);v[22640]=0;m=v[b+12>>2];v[j+8>>2]=v[b+8>>2];v[j+12>>2]=m;v[j+16>>2]=v[b+16>>2];m=v[b+4>>2];v[j>>2]=v[b>>2];v[j+4>>2]=m;ha(1157,d|0,g|0,j|0,i|0,h|0);b=v[22640];v[22640]=0;if((b|0)==1){break K}v[22640]=0;Zh(f,a,0);b=v[22640];v[22640]=0;if((b|0)==1){break K}break S}a=P()|0;O()|0;break J}a=P()|0;O()|0;vb(g);break J}a=P()|0;O()|0;break J}v[22640]=0;i=_h(c);h=v[22640];v[22640]=0;if((h|0)==1){break K}if((i|0)==85){v[22640]=0;b=ga(770,a|0,b|0,j+80|0,0,1)|0;d=v[22640];v[22640]=0;if((d|0)==1){break Q}if(b){break S}i=0;v[22640]=0;a=v[22640];v[22640]=0;if((a|0)==1){break Q}break R}W:{if(jB(c)|!w[c+177|0]){break W}v[22640]=0;b=_h(c);i=v[22640];v[22640]=0;if((i|0)==1){break K}if((b|0)!=1){break W}if((Pl(c)|0)!=32){break W}if((Io(c)|0)!=Ij(c)<<2){break W}Vi(g,32);zf(g,13);v[22640]=0;W(363,g|0,f|0,j+80|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break S}break K}X:{if(jB(c)){break X}v[22640]=0;b=_h(c);i=v[22640];v[22640]=0;if((i|0)==1){break K}if((b|0)!=1){break X}if((Pl(c)|0)!=24){break X}if((Io(c)|0)!=Ij(c)<<2){break X}Vi(g,32);zf(g,14);v[22640]=0;W(363,g|0,f|0,j+80|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break K}break S}v[22640]=0;b=_h(c);i=v[22640];v[22640]=0;if((i|0)==1){break K}Y:{if((b|0)!=6){v[22640]=0;b=_h(c);i=v[22640];v[22640]=0;if((i|0)==1){break K}if((b|0)!=7){break Y}}Vi(g,16);v[22640]=0;b=_h(c);d=v[22640];v[22640]=0;if((d|0)==1){break K}zf(g,(b|0)==6?18:17);v[22640]=0;W(363,g|0,f|0,j+80|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break K}break S}i=(Pl(c)-1>>>3|0)-1|0;h=i<<3;b=h&31;Vi(g,(i>>>0<7?(h&63)>>>0>=32?4196360>>>b|0:((1<<b)-1&4196360)<<32-b|136321040>>>b:8)&255);if(Pl(c)>>>0<9){zf(g,1)}v[22640]=0;b=_h(c);i=v[22640];v[22640]=0;if((i|0)==1){break K}if((b|0)==3){zf(g,3)}if(d){eR(g)}v[22640]=0;W(363,g|0,f|0,j+80|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break K}}if(e){Je(j+24|0,c+100|0);od(e,j+24|0);yb(j+24|0)}b=v[a+480180>>2];v[22640]=0;U(1151,f|0,32,b|0);b=v[22640];v[22640]=0;i=1;if((b|0)==1){break K}v[22640]=0;Zh(f,a,0);a=v[22640];v[22640]=0;if((a|0)==1){break K}}yb(j+80|0);break N}break K}i=0}mT(c);gb=j+288|0;return i|0}a=P()|0;O()|0;break J}a=P()|0;O()|0;break J}a=P()|0;O()|0;yb(j+80|0)}mT(c);S(a|0);L()}function CK(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=gb-128|0;gb=h;v[h+124>>2]=c;a:{b:{if(g){Ge(h+112|0,f,32);v[22640]=0;W(733,h+96|0,f|0,32)|0;i=v[22640];v[22640]=0;if((i|0)!=1){break b}f=P()|0;O()|0;break a}Kb(h+112|0);Kb(h+96|0)}u[h+80>>1]=0;u[h+64>>1]=65535;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(At(h+124|0,h+80|0,h- -64|0)){i=b+24|0;b=v[i>>2];v[22640]=0;b=ke(b+484344|0,c&65535);j=v[22640];v[22640]=0;if((j|0)==1){break t}if(b){break u}}v[22640]=0;U(2101,a|0,h+112|0,h+96|0);a=v[22640];v[22640]=0;if((a|0)!=1){break p}f=P()|0;O()|0;break c}b=_b(v[i>>2]+484344|0,c);if(!(v[b+12>>2]>(d|0)?(d|0)>=0:0)){v[22640]=0;U(2101,a|0,h+112|0,h+96|0);a=v[22640];v[22640]=0;if((a|0)!=1){break p}break d}if(!(x[v[i>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){v[22640]=0;U(2101,a|0,h+112|0,h+96|0);a=v[22640];v[22640]=0;if((a|0)==1){break d}break p}v[22640]=0;c=Tc(b,d,e&65535);b=v[22640];v[22640]=0;if((b|0)==1){break h}Ye(h+112|0);Ye(h+96|0);v[22640]=0;b=ce(c);d=v[22640];v[22640]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{if((d|0)!=1){H:{I:{if(!b){if(!Tt(c)){break I}}b=v[i>>2];d=w[c+1|0];e=w[c|0];v[22640]=0;Y(2103,h- -64|0,b|0,e|0,d|0);d=v[22640];v[22640]=0;b=1;if((d|0)==1){break G}v[22640]=0;R(2039,h+80|0,h- -64|0);d=v[22640];v[22640]=0;if((d|0)!=1){break H}f=P()|0;O()|0;break D}b=0;v[22640]=0;Q(112,h+80|0,13874)|0;d=v[22640];v[22640]=0;if((d|0)==1){break F}}v[22640]=0;Q(1183,h+112|0,h+80|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break E}vb(h+80|0);if(b){vb(h- -64|0)}v[22640]=0;b=ce(c);d=v[22640];v[22640]=0;if((d|0)==1){break e}J:{if(b){v[22640]=0;Q(112,h+80|0,7294)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}break J}if(Tt(c)){v[22640]=0;Q(112,h+80|0,7604)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break J}break e}v[22640]=0;Q(112,h+80|0,13874)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}}v[22640]=0;Q(1183,h+96|0,h+80|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break C}vb(h+80|0);j=f-1|0;if(j>>>0<5){break v}v[22640]=0;b=Q(112,h+80|0,14878)|0;d=v[22640];v[22640]=0;if((d|0)==1){break B}v[22640]=0;Q(1183,h+112|0,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break A}vb(b);v[22640]=0;b=Q(112,h+80|0,14878)|0;d=v[22640];v[22640]=0;if((d|0)==1){break z}v[22640]=0;Q(1183,h+96|0,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break y}vb(b);b=c+1|0;K:{if(w[c+1|0]){v[22640]=0;R(754,h+80|0,b|0);d=v[22640];v[22640]=0;if((d|0)!=1){break K}break f}v[22640]=0;Q(112,h+80|0,13879)|0;d=v[22640];v[22640]=0;if((d|0)==1){break f}}v[22640]=0;Q(1183,h+112|0,h+80|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break x}vb(h+80|0);L:{if(w[b|0]){v[22640]=0;Q(112,h+80|0,8111)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break L}break g}v[22640]=0;Q(112,h+80|0,13879)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}}v[22640]=0;Q(1183,h+96|0,h+80|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break w}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(h+80|0);if(!b){break c}}vb(h- -64|0);break c}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;vb(h+80|0);break c}vb(h+80|0);if(j>>>0<8){break v}v[22640]=0;b=xg(c);d=v[22640];v[22640]=0;M:{N:{O:{P:{Q:{R:{S:{if((d|0)!=1){T:{if(b){v[22640]=0;b=Q(112,h+48|0,14878)|0;d=v[22640];v[22640]=0;if((d|0)==1){break S}v[22640]=0;e=Mq(c);d=v[22640];v[22640]=0;if((d|0)==1){break R}d=0;v[22640]=0;v[h+16>>2]=e&255;R(752,h+32|0,h+16|0);k=v[22640];v[22640]=0;e=1;if((k|0)==1){break R}v[22640]=0;U(2058,h+80|0,b|0,h+32|0);b=v[22640];v[22640]=0;if((b|0)!=1){break T}f=P()|0;O()|0;break j}if(w[c+2|0]){b=v[v[i>>2]+8>>2];d=w[c+2|0];v[22640]=0;b=hz(b,d);d=v[22640];v[22640]=0;if((d|0)==1){break N}v[22640]=0;b=W(733,h+48|0,1,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break N}e=0;v[22640]=0;R(754,h+32|0,c+4|0);k=v[22640];v[22640]=0;d=1;if((k|0)==1){break Q}v[22640]=0;U(2058,h+80|0,b|0,h+32|0);b=v[22640];v[22640]=0;if((b|0)!=1){break T}f=P()|0;O()|0;vb(h+32|0);break l}e=0;v[22640]=0;Q(112,h+80|0,13878)|0;b=v[22640];v[22640]=0;d=0;if((b|0)==1){break O}}v[22640]=0;Q(1183,h+112|0,h+80|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break P}vb(h+80|0);if(d){vb(h+32|0);vb(h+48|0)}if(e){vb(h+32|0);vb(h+48|0)}v[22640]=0;b=xg(c);d=v[22640];v[22640]=0;if((d|0)==1){break m}U:{if(b){v[22640]=0;Q(112,h+80|0,2580)|0;b=v[22640];v[22640]=0;if((b|0)==1){break m}break U}if(w[c+2|0]){v[22640]=0;Q(112,h+80|0,2576)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break U}break m}v[22640]=0;Q(112,h+80|0,13878)|0;b=v[22640];v[22640]=0;if((b|0)==1){break m}}v[22640]=0;Q(1183,h+96|0,h+80|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break M}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break i}f=P()|0;O()|0;break l}f=P()|0;O()|0;vb(h+80|0);if(!d){break k}vb(h+32|0);break l}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}vb(h+80|0);if(j>>>0<12){break v}v[22640]=0;b=Q(112,h+80|0,14878)|0;d=v[22640];v[22640]=0;V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{if((d|0)!=1){v[22640]=0;Q(1183,h+112|0,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break ba}vb(b);v[22640]=0;b=Q(112,h+80|0,14878)|0;d=v[22640];v[22640]=0;if((d|0)==1){break aa}v[22640]=0;Q(1183,h+96|0,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break $}vb(b);v[22640]=0;b=xg(c);d=v[22640];v[22640]=0;if((d|0)==1){break _}ca:{if(b){b=0;v[22640]=0;d=Eo(c);e=v[22640];v[22640]=0;if((e|0)!=1){v[22640]=0;v[h+28>>2]=d&4095;R(2105,h+80|0,h+28|0);d=v[22640];v[22640]=0;if((d|0)!=1){break ca}}f=P()|0;O()|0;break c}if(w[c+3|0]){b=v[v[i>>2]+8>>2];d=w[c+3|0];v[22640]=0;b=gz(b,d);d=v[22640];v[22640]=0;if((d|0)==1){break Z}v[22640]=0;d=W(733,h+16|0,1,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break Z}v[22640]=0;R(754,h|0,c+5|0);e=v[22640];v[22640]=0;b=1;if((e|0)==1){break Y}v[22640]=0;U(2058,h+80|0,d|0,h|0);d=v[22640];v[22640]=0;if((d|0)!=1){break ca}f=P()|0;O()|0;vb(h);break n}b=0;v[22640]=0;Q(112,h+80|0,13874)|0;d=v[22640];v[22640]=0;if((d|0)==1){break W}}v[22640]=0;Q(1183,h+112|0,h+80|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break X}vb(h+80|0);if(b){vb(h);vb(h+16|0)}v[22640]=0;b=xg(c);d=v[22640];v[22640]=0;if((d|0)==1){break o}da:{if(b){v[22640]=0;Q(112,h+80|0,8409)|0;b=v[22640];v[22640]=0;if((b|0)==1){break o}break da}if(w[c+3|0]){v[22640]=0;Q(112,h+80|0,8409)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break da}break o}v[22640]=0;Q(112,h+80|0,13874)|0;b=v[22640];v[22640]=0;if((b|0)==1){break o}}v[22640]=0;Q(1183,h+96|0,h+80|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break V}f=P()|0;O()|0;vb(h+80|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break n}f=P()|0;O()|0;vb(h+80|0);if(!b){break c}vb(h);break n}f=P()|0;O()|0;break c}vb(h+80|0);if(!f){break q}}ea:{fa:{if(Ab(h+112|0)>>>0>f>>>0){v[22640]=0;Y(188,h+80|0,h+112|0,0,f|0);b=v[22640];v[22640]=0;if((b|0)!=1){break fa}f=P()|0;O()|0;break c}if(g){b=Ab(h+112|0);v[22640]=0;b=W(733,h+80|0,f-b|0,32)|0;c=v[22640];v[22640]=0;if((c|0)==1){break s}v[22640]=0;Q(1183,h+112|0,b|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){f=P()|0;O()|0;vb(b);break c}vb(b);if(Ab(h+96|0)>>>0>f>>>0){break r}break ea}if(Ab(h+96|0)>>>0<=f>>>0){break q}break r}Eb(h+112|0,h+80|0);vb(h+80|0);if(Ab(h+96|0)>>>0>f>>>0){break r}if(!g){break q}}b=Ab(h+96|0);v[22640]=0;b=W(733,h+80|0,f-b|0,32)|0;c=v[22640];v[22640]=0;ga:{if((c|0)!=1){v[22640]=0;Q(1183,h+96|0,b|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break ga}vb(b);break q}f=P()|0;O()|0;break c}f=P()|0;O()|0;vb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}v[22640]=0;Y(188,h+80|0,h+96|0,0,f|0);b=v[22640];v[22640]=0;if((b|0)!=1){Eb(h+96|0,h+80|0);vb(h+80|0);break q}f=P()|0;O()|0;break c}v[22640]=0;U(2101,a|0,h+112|0,h+96|0);a=v[22640];v[22640]=0;if((a|0)==1){break h}}vb(h+96|0);vb(h+112|0);gb=h+128|0;return}f=P()|0;O()|0;break c}vb(h+16|0);break c}f=P()|0;O()|0;break c}vb(h+48|0)}if(!e){break c}}vb(h+32|0)}vb(h+48|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}vb(h+96|0)}vb(h+112|0);S(f|0);L()}function Ala(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=gb-304|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!Tu(b,d+208|0)){break j}if(!QU(d+208|0)){break j}if(!Pb(b,Uc(PU(d+208|0),jb))){break j}if(!c){n=1;break j}if(!Xc(b,w[d+208|4])){break j}Gd(a,268435456);wg(a);v[a+480208>>2]=4;e=Tb(d+88|0,12489);Eb(a+1298304|0,e);vb(e);e=Tb(d+88|0,7608);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;nf(d+16|0,d+208|6,48,3);Bc(d+88|0,d+16|0);Eb(a+1298268|0,d+88|0);vb(d+88|0);u[a+480188>>1]=w[d+262|0]+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];if(w[d+262|0]){e=0;while(1){u[((e<<5)+a|0)+480284>>1]=B(w[(d+e|0)+268|0],17);e=e+1|0;if(e>>>0<w[d+262|0]){continue}break}}u[a+480190>>1]=w[d+300|0];e=w[d+302|0]|w[d+303|0]<<8;l=d+192|0;i=mh(l);k:{if(!e){break k}v[22640]=0;R(860,l|0,e|0);h=v[22640];v[22640]=0;if((h|0)!=1){v[22640]=0;lr(l,e);e=v[22640];v[22640]=0;if((e|0)!=1){break k}}a=P()|0;O()|0;ai(i);S(a|0);L()}e=w[d+302|0]|w[d+303|0]<<8;v[22640]=0;U(853,b|0,l|0,e|0);e=v[22640];v[22640]=0;if((e|0)==1){break i}s=nc(d+176|0);o=nc(d+160|0);e=w[d+301|0];v[22640]=0;W(584,b|0,s|0,e|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break f}i=w[d+300|0];e=0;v[22640]=0;W(584,b|0,o|0,i|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break f}if(w[d+300|0]){p=c&2;q=d+88|4;m=d+126|0;r=d+88|6;while(1){v[22640]=0;i=e;e=e+1|0;h=B(e,104)+a|0;g=h+484380|0;R(352,g|0,0);f=v[22640];v[22640]=0;l:{m:{if((f|0)!=1){f=Mb(o,i);if(!(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){break l}f=Mb(o,i);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[22640]=0;f=Q(227,b|0,f|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break c}if(!f){break l}v[22640]=0;f=Q(854,b|0,d+88|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break c}if(!f){break l}v[22640]=0;_e(d+72|0,2,r);f=v[22640];v[22640]=0;if((f|0)!=1){v[22640]=0;R(377,d+16|0,d+72|0);f=v[22640];v[22640]=0;if((f|0)!=1){break m}}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}v[22640]=0;Q(333,((e<<5)+a|0)+946304|0,d+16|0)|0;f=v[22640];v[22640]=0;n:{o:{p:{q:{r:{if((f|0)!=1){vb(d+16|0);v[22640]=0;Gk(d+72|0,2,m);f=v[22640];v[22640]=0;if((f|0)==1){break r}v[22640]=0;R(377,d+16|0,d+72|0);f=v[22640];v[22640]=0;if((f|0)==1){break r}v[22640]=0;Q(335,h+484423|0,d+16|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break q}vb(d+16|0);if(w[d+138|0]<=15){f=h+484414|0;u[f>>1]=x[f>>1]|32;u[h+484408>>1]=B(w[d+138|0],17)}t[d+16|0]=w[d+139|0];v[22640]=0;t[d+72|0]=64;f=ac(d+16|0,d+72|0);k=v[22640];v[22640]=0;if((k|0)==1){break p}u[h+484412>>1]=w[f|0];v[h+484404>>2]=w[d+141|0]|w[d+142|0]<<8;f=h+484384|0;v[f>>2]=w[d+147|0]|w[d+148|0]<<8|(w[d+149|0]<<16|w[d+150|0]<<24);k=h+484388|0;v[k>>2]=w[d+151|0]|w[d+152|0]<<8|(w[d+153|0]<<16|w[d+154|0]<<24);v[g>>2]=w[d+155|0]|w[d+156|0]<<8|(w[d+157|0]<<16|w[d+158|0]<<24);if(t[d+140|0]&1){break o}n=v[f>>2];f=v[k>>2];break n}e=P()|0;O()|0;vb(d+16|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(d+16|0);break b}e=P()|0;O()|0;break b}n=v[f>>2]>>>1|0;v[f>>2]=n;f=v[k>>2]>>>1|0;v[k>>2]=f;v[g>>2]=v[g>>2]>>>1}s:{if(f>>>0<=n>>>0){break s}h=h+484414|0;u[h>>1]=x[h>>1]|2;if(!(w[d+140|0]&2)){break s}u[h>>1]=x[h>>1]|4}v[22640]=0;wk(g);h=v[22640];v[22640]=0;if((h|0)==1){break c}if(!p){break l}i=Mb(o,i);i=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);h=w[q|0];v[22640]=0;Q(227,b|0,h+i|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break c}i=Pc(d+16|0,t[d+140|0]&1?16:8,1,0,1);v[22640]=0;W(363,i|0,g|0,b|0)|0;i=v[22640];v[22640]=0;if((i|0)!=1){break l}e=P()|0;O()|0;break b}if(w[d+300|0]>e>>>0){continue}break}}n=1;t:{if(!(c&1)){break t}v[d+68>>2]=0;f=a+484360|0;sn(Rb(f));F=d,G=Sb(l),v[F+64>>2]=G;F=d,G=Wb(l),v[F+56>>2]=G;k=a+484344|0;if(Gb(d- -64|0,d+56|0)){r=d+88|5;p=d+88|4;while(1){i=v[d- -64>>2];c=i;u:{if(w[c+3|0]>=w[d+301|0]|w[c+2|0]>w[d+262|0]){break u}c=Mb(s,w[c+3|0]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22640]=0;c=Q(227,b|0,c|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break g}if(!c){break u}v[22640]=0;R(857,b|0,d+88|0);c=v[22640];v[22640]=0;if((c|0)==1){break h}if(!w[p|0]){break u}c=w[i|0]|w[i+1|0]<<8;e=w[i|0]|w[i+1|0]<<8;t[d+16|0]=w[r|0];h=w[d+262|0];g=w[i+2|0];v[22640]=0;t[d+72|0]=h-g;h=ac(d+16|0,d+72|0);g=v[22640];v[22640]=0;if((g|0)==1){break d}q=w[h|0];h=w[i|0]|w[i+1|0]<<8;g=w[p|0];v[22640]=0;v[d+52>>2]=g+h;h=Jc(d+68|0,d+52|0);g=v[22640];v[22640]=0;if((g|0)==1){break e}v[d+68>>2]=v[h>>2];v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;if(!w[p|0]){break u}y=c>>>6|0;e=e&63;A=0;while(1){v:{w:{x:{y:{z:{A:{B:{h=e>>>0>63;y=h+y|0;c=y&65535;if(sc(Rb(f))>>>0<=c>>>0){g=Rb(f);v[22640]=0;R(527,g|0,y+1&65535);g=v[22640];v[22640]=0;if((g|0)==1){break B}v[22640]=0;g=W(564,k|0,64,0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break B}F=rc(Rb(f),c),G=g,u[F>>1]=G}m=x[rc(Rb(f),c)>>1];v[22640]=0;c=ke(k,m);g=v[22640];v[22640]=0;if((g|0)==1){break z}if(!c){break u}c=_b(k,m);g=w[i+2|0];v[22640]=0;z=h?0:e;e=Tc(c,z,g);c=v[22640];v[22640]=0;if((c|0)==1){break w}h=0;if(q){break A}break x}e=P()|0;O()|0;break b}while(1){v[22640]=0;R(858,d+72|0,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break y}g=md(d+72|0);D=Re(d+72|0);C=aj(d+72|0);E=ec(d+72|0);j=0;c=w[d+72|0];if((c-1&255)>>>0<=142){j=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[(d+16|0)+h|0]=j}t[e|0]=j;c=w[g|0];t[e+2|0]=1;t[e+1|0]=c;c=w[D|0];C:{if((c|0)!=255){t[e+4|0]=c;break C}t[e+2|0]=0}c=w[C|0];D:{if(c>>>0>22){break D}t[e+3|0]=w[c+33680|0];g=w[E|0];t[e+5|0]=g;c=e+5|0;E:{switch(w[C|0]-4|0){case 3:t[c|0]=g&3|64;break D;case 4:t[c|0]=g&3|48;break D;case 7:if(Nb(l)>>>0<=g>>>0){break D}j=c;c=Mb(l,g);g=w[c|0]|w[c+1|0]<<8;t[j|0]=g>>>6;c=_b(k,m);j=x[a+480188>>1];v[22640]=0;c=Tc(c,z,j-1&65535);j=v[22640];v[22640]=0;if((j|0)!=1){t[c+3|0]=14;t[c+5|0]=g&63;break D}e=P()|0;O()|0;break b;case 8:t[c|0]=v[d+52>>2]>>>6;c=_b(k,m);g=x[a+480188>>1];v[22640]=0;c=Tc(c,z,g-1&65535);g=v[22640];v[22640]=0;if((g|0)!=1){t[c+3|0]=14;t[c+5|0]=w[d+52|0]&63;break D}e=P()|0;O()|0;break b;case 10:t[c|0]=g&15|128;break D;case 12:v[22640]=0;t[d+15|0]=15;g=ac(c,d+15|0);j=v[22640];v[22640]=0;if((j|0)!=1){t[c|0]=w[g|0]|208;break D}e=P()|0;O()|0;break b;case 13:v[22640]=0;t[d+15|0]=15;g=ac(c,d+15|0);j=v[22640];v[22640]=0;if((j|0)!=1){t[c|0]=w[g|0]|192;break D}e=P()|0;O()|0;break b;case 14:v[22640]=0;t[d+15|0]=15;g=ac(c,d+15|0);j=v[22640];v[22640]=0;if((j|0)!=1){t[c|0]=w[g|0]|224;break D}e=P()|0;O()|0;break b;case 0:case 16:case 17:if(!(g&15)){break D}j=g&240;if(!j|(j|0)==240){break D}t[c|0]=g|15;break D;case 9:case 18:break E;default:break D}}if(j&255){break D}t[e|0]=w[(d+16|0)+h|0]}e=e+6|0;h=h+1|0;if((q|0)!=(h|0)){continue}break}break x}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}if(q>>>0>=w[r|0]){break v}c=w[r|0];v[22640]=0;Q(350,b|0,B(c-q|0,5)|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break v}}e=P()|0;O()|0;break b}e=z+1|0;A=A+1|0;if(A>>>0<w[p|0]){continue}break}}Fg(d- -64|0);if(Gb(d- -64|0,d+56|0)){continue}break}}F:{a=v[d+68>>2];b=a&63;if(!b){break F}c=Rb(f);v[22640]=0;a=a>>>6|0;c=Q(497,c|0,a&65535)|0;e=v[22640];v[22640]=0;if((e|0)!=1){if(!c){break F}a=_b(k,x[rc(Rb(f),a&65535)>>1]);v[22640]=0;ca(859,a|0,b|0,0,1)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break F}}e=P()|0;O()|0;break b}a=Rb(f);F=d,G=Sb(a),v[F+88>>2]=G;F=d,G=Wb(a),v[F+16>>2]=G;if(!Gb(d+88|0,d+16|0)){break t}h=65535;while(1){a=v[d+88>>2];if(x[a>>1]==65535){G:{if((h&65535)!=65535){break G}v[22640]=0;h=W(564,k|0,64,0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break G}e=P()|0;O()|0;break b}u[a>>1]=h}mf(d+88|0);if(Gb(d+88|0,d+16|0)){continue}break}}bi(o);bi(s);ai(l)}gb=d+304|0;return n|0}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}bi(o);bi(s)}ai(l);S(e|0);L()}function Sla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0;e=gb-1312|0;gb=e;vc(b);f=gb-32|0;gb=f;WU(f+24|0,e+200|0);m=xb(f+24|0);l=v[f+28>>2];d=v[f+24>>2];v[f+8>>2]=d;v[f+12>>2]=l;v[f>>2]=d;v[f+4>>2]=l;d=b;fc(f+16|0,b,f);l=xb(f+16|0);if((l|0)==(m|0)){Yb(d,xb(f+24|0))}gb=f+32|0;a:{if((l|0)!=(m|0)){break a}if(!ZU(e+200|0)){break a}if(!Pb(b,Uc(YU(e+200|0),jb))){break a}if(!c){p=1;break a}vc(b);d=Xi(e+200|0,b);v[22640]=0;R(833,e+184|0,d|0);b=v[22640];v[22640]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){yb(d);v[22640]=0;U(834,e+168|0,e+184|0,1196314451);b=v[22640];v[22640]=0;if((b|0)!=1){v[22640]=0;U(834,e+152|0,e+184|0,1280331091);b=v[22640];v[22640]=0;if((b|0)!=1){if($c(e+168|0)){break g}if($c(e+152|0)){break g}v[22640]=0;R(407,a|0,1);b=v[22640];v[22640]=0;j:{if((b|0)==1){break j}v[22640]=0;wg(a);b=v[22640];v[22640]=0;if((b|0)==1){break j}v[a+480188>>2]=4;v[a+480208>>2]=16842752;D=e,E=Sb(e+152|0),v[D+16>>2]=E;D=e,E=Wb(e+152|0),v[D+112>>2]=E;if(!Gb(e+16|0,e+112|0)){break i}l=c&2;k:{l:{while(1){f=v[e+16>>2];if(!ei(a)){break i}b=x[a+480190>>1]+1|0;u[a+480190>>1]=b;v[22640]=0;i=B(b&65535,104)+a|0;m=i+484380|0;R(352,m|0,1);b=v[22640];v[22640]=0;m:{n:{if((b|0)!=1){v[22640]=0;d=Q(835,f|0,e+200|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break n}if(!d){break h}if(Wu(e+200|0)){break m}break h}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}v[22640]=0;d=Q(112,e+48|0,e+200|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){b=x[a+480190>>1];v[22640]=0;Q(333,((b<<5)+a|0)+946304|0,d|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break l}vb(d);b=w[e+236|0]|w[e+237|0]<<8|(w[e+238|0]<<16|w[e+239|0]<<24);v[m>>2]=b;v[i+484388>>2]=b;v[i+484384>>2]=w[e+232|0]|w[e+233|0]<<8|(w[e+234|0]<<16|w[e+235|0]<<24);u[i+484410>>1]=255;b=i+484414|0;u[b>>1]=x[b>>1]|2;if(l){b=Pc(e+48|0,8,1,0,0);v[22640]=0;W(363,b|0,m|0,f|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break k}}Ah(e+16|0);if(Gb(e+16|0,e+112|0)){continue}break i}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(d);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break d}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d);break b}D=e,E=Sb(e+168|0),v[D+144>>2]=E;D=e,E=Wb(e+168|0),v[D+136>>2]=E;n=a+484360|0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if(!Gb(e+144|0,e+136|0)){break B}r=a+484344|0;p=1;C=c&1;m=e+1292|0;l=e+1296|0;k=e+1288|0;s=e+1286|0;y=a+484380|0;c=1;while(1){d=v[e+144>>2];if(!(c&1)){v[22640]=0;c=T(445,n|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break w}if(!c){break B}}sn(Rb(n));v[22640]=0;c=Q(836,d|0,e+200|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break v}if(!c|(w[s|0]|w[s+1|0]<<8)|(!(w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24))|(w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24))>>>0>4)){break h}c=Rb(n);v[22640]=0;U(6,e+48|0,5,e+200|0);b=v[22640];v[22640]=0;if((b|0)==1){break o}v[22640]=0;R(446,c|0,e+48|0);b=v[22640];v[22640]=0;if((b|0)==1){break p}vb(e+48|0);C:{if(C){b=l;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[22640]=0;U(320,e+112|0,d|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break C}break f}v[22640]=0;T(251,e+112|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break f}}Qb(e+48|0,0,64);j=1;z=1;D:{E:{while(1){v[22640]=0;f=(B(j,34)+e|0)+166|0;d=f+32|0;R(837,e|0,d|0);b=v[22640];v[22640]=0;if((b|0)==1){break u}F:{if(!w[v[e>>2]]){break F}c=w[f- -64|0];if(c>>>0>15){break E}b=w[f+65|0];if(b>>>0>64){break E}if(!Wu(d)){break E}if(!x[a+480190>>1]){break F}o=b<<2;h=c<<4;c=1;i=0;b=1;while(1){v[22640]=0;R(838,e+16|0,e|0);d=v[22640];v[22640]=0;G:{H:{if((d|0)!=1){v[22640]=0;f=Q(839,e+16|0,((c<<5)+a|0)+946304|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break H}vb(e+16|0);if(f){break G}D=sd(e+48|0,j),E=b,u[D>>1]=E;f=B(c,104)+a|0;d=f+484410|0;c=x[d>>1];if((c|0)!=255){i=b;if(w[f+484417|0]!=(h&255)|(c|0)!=(o|0)){break G}}t[f+484417|0]=h;u[d>>1]=o;break F}a=P()|0;O()|0;break q}a=P()|0;O()|0;vb(e+16|0);break q}b=b+1|0;c=b&65535;if(c>>>0<=x[a+480190>>1]){continue}break}i=i&65535;if(!i){break F}if(!ei(a)){break F}b=x[a+480190>>1]+1|0;u[a+480190>>1]=b;D=sd(e+48|0,j),E=b,u[D>>1]=E;b=x[a+480190>>1];v[22640]=0;d=B(b,104);f=d+y|0;Ol(f);b=v[22640];v[22640]=0;if((b|0)==1){break t}c=B(i,104)+y|0;Zo(f,c);b=a+d|0;u[b+484410>>1]=o;t[b+484417|0]=h;v[22640]=0;Q(764,f|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break t}b=a+946304|0;d=b+(x[a+480190>>1]<<5)|0;c=b+(i<<5)|0;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;b=v[c+28>>2];v[d+24>>2]=v[c+24>>2];v[d+28>>2]=b;b=v[c+20>>2];v[d+16>>2]=v[c+16>>2];v[d+20>>2]=b;b=v[c+12>>2];v[d+8>>2]=v[c+8>>2];v[d+12>>2]=b}z=j>>>0<31;j=j+1|0;if((j|0)!=32){continue}break}f=0;v[e+40>>2]=0;v[e+32>>2]=0;v[e+36>>2]=0;v[e+24>>2]=0;v[e+28>>2]=0;v[e+16>>2]=0;v[e+20>>2]=0;A=w[k|0]|w[k+1|0]<<8;c=64;q=65535;j=0;while(1){I:{if(!j){v[22640]=0;d=Q(228,e+112|0,1)|0;b=v[22640];v[22640]=0;if((b|0)==1){break A}if(!d){break I}}c=c+1|0;if(c>>>0>=64){v[22640]=0;q=W(564,r|0,64,0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break A}if((q|0)==65535){break D}c=0;b=Rb(n);v[22640]=0;R(729,b|0,q|0);b=v[22640];v[22640]=0;if((b|0)==1){break A}}b=_b(r,q&65535);v[22640]=0;b=Tc(b,c,0);d=v[22640];v[22640]=0;if((d|0)==1){break s}if(!A){continue}d=0;i=0;while(1){g=(e+16|0)+B(d,7)|0;d=w[g+6|0];J:{if(d){t[g+6|0]=d-1;d=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=d;t[b+5|0]=d>>>8;d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=d;t[b+1|0]=d>>>8;t[b+2|0]=d>>>16;t[b+3|0]=d>>>24;j=j-1|0;break J}v[22640]=0;h=Q(228,e+112|0,1)|0;d=v[22640];v[22640]=0;if((d|0)==1){break r}if(!h){break J}d=m;if(v[e+120>>2]==(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))){h=Rb(n);d=Rb(n);v[22640]=0;f=T(493,d|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break r}af(h,f);f=c}v[22640]=0;h=T(353,e+112|0)|0;d=v[22640];v[22640]=0;K:{if((d|0)!=1){d=h<<24>>24;if((d|0)>-1){break K}h=d&127;t[g+6|0]=h;d=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=d;t[b+5|0]=d>>>8;d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=d;t[b+1|0]=d>>>8;t[b+2|0]=d>>>16;t[b+3|0]=d>>>24;j=h+j|0;break J}a=P()|0;O()|0;break q}if((d-1&255)>>>0<=35){t[b|0]=d+48}v[22640]=0;h=T(353,e+112|0)|0;d=v[22640];v[22640]=0;L:{M:{if((d|0)!=1){D=b,E=w[sd(e+48|0,h&31)|0],t[D+1|0]=E;if(!(h&128)){break M}t[b+3|0]=w[g+3|0];t[b+5|0]=w[g+5|0];break L}a=P()|0;O()|0;break q}v[22640]=0;R(431,e|0,e+112|0);d=v[22640];v[22640]=0;N:{if((d|0)!=1){h=md(e);d=e;o=w[e|0];if(o>>>0>19){break L}t[b+3|0]=w[(o<<1)+33632|0];h=w[h|0];t[b+5|0]=h;if((o|0)!=18|h>>>0<32){break N}t[b+3|0]=17;break L}a=P()|0;O()|0;break q}d=w[d|0];if(819137>>>d&1){break L}t[b+5|0]=w[(d<<1)+33633|0]|h&15}d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[g|0]=d;t[g+1|0]=d>>>8;t[g+2|0]=d>>>16;t[g+3|0]=d>>>24;d=w[b+4|0]|w[b+5|0]<<8;t[g+4|0]=d;t[g+5|0]=d>>>8}b=b+6|0;i=i+1|0;d=i&65535;if(A>>>0>d>>>0){continue}break}continue}break}if(!f&c>>>0>62){break D}b=q&65535;if((b|0)==65535){break D}i=_b(r,b);v[22640]=0;d=Be(e,14,f&255);b=v[22640];v[22640]=0;if((b|0)!=1){b=Eh(Qe(d,c));v[22640]=0;Q(458,i|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break D}}a=P()|0;O()|0;break q}p=0}yb(e+112|0);if(z){break g}Ah(e+144|0);c=0;if(Gb(e+144|0,e+136|0)){continue}break}}v[22640]=0;Pi(n,0);b=v[22640];v[22640]=0;if((b|0)==1){break z}v[22640]=0;c=Q(2,e+200|0,3530)|0;b=v[22640];v[22640]=0;if((b|0)==1){break y}Eb(a+1298304|0,c);vb(c);v[22640]=0;c=Q(2,e+200|0,3832)|0;b=v[22640];v[22640]=0;p=1;if((b|0)==1){break x}Eb(a+1298316|0,c);vb(c);v[a+1298364>>2]=5;break g}a=P()|0;O()|0;break q}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0}yb(e+112|0);break e}a=P()|0;O()|0;vb(e+48|0);break e}a=P()|0;O()|0;break e}p=0}fd(e+152|0);fd(e+168|0);Cd(e+184|0);break a}a=P()|0;O()|0}fd(e+152|0)}fd(e+168|0)}Cd(e+184|0)}S(a|0);L()}gb=e+1312|0;return p|0}function __(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=gb-1504|0;gb=d;vc(b);ls(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!Kw(b,d+1480|0)){break n}if(!XF(d+1480|0)){break n}if(!c){i=1;break n}E=d+1498|0;c=E;if(!ks(b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break n}c=E;y=d+1492|0;if(!ks(b,(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+((w[y|0]|w[y+1|0]<<8)<<2)|0)){break n}Jw(a);H=d,I=Iw(),v[H+104>>2]=I;Hw(hj(a)+32|0,d+104|0);js(d+104|0);n=v[hj(a)+32>>2];c=d+1494|0;v[d+1476>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);H=d,I=hm(b),v[H+1216>>2]=I;v[d+1176>>2]=214748364;H=d,I=B(v[Fb(d+1216|0,d+1176|0)>>2],20),v[H+104>>2]=I;Ys(n,v[Fb(d+1476|0,d+104|0)>>2]);Qb(d+1216|0,0,256);C=ad(d+1200|0);o:{if(w[y|0]|w[y+1|0]<<8){k=d+1176|4;l=d+1192|0;D=d+1194|0;r=d+1190|0;j=d+1188|0;while(1){c=E;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[22640]=0;c=Q(227,b|0,c+(F<<2)|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break m}i=0;if(!c){break o}v[22640]=0;c=Q(228,b|0,4)|0;g=v[22640];v[22640]=0;if((g|0)==1){break m}if(!c){break o}v[22640]=0;g=T(229,b|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break l}v[22640]=0;c=Q(227,b|0,g|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break l}if(!c){break o}v[22640]=0;c=Q(230,b|0,d+1176|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break k}if(!c){break o}c=w[j|0]|w[j+1|0]<<8;v[22640]=0;c=W(231,b|0,C|0,c|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break k}if(!c){break o}c=w[j|0]|w[j+1|0]<<8?v[C>>2]:0;e=w[j|0]|w[j+1|0]<<8;v[22640]=0;f=T(232,b|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break j}g=g+20|0;if(f>>>0<=g+(e<<3)>>>0){break o}e=g+((w[j|0]|w[j+1|0]<<8)<<3)|0;p:{if(!(t[r|0]&1)){f=0;if(!(w[j|0]|w[j+1|0]<<8)){break p}while(1){if(!c){break o}v[22640]=0;g=W(233,c|0,n|0,v[d+1476>>2])|0;h=v[22640];v[22640]=0;if((h|0)==1){break i}if(!g){break o}v[22640]=0;g=Q(227,b|0,e|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break i}if(!g){break o}g=c;h=c+4|0;h=Wd(d+1168|0,kc(n,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24));v[22640]=0;o=v[h+4>>2];v[d+32>>2]=v[h>>2];v[d+36>>2]=o;U(234,d+104|0,b|0,d+32|0);h=v[22640];v[22640]=0;if((h|0)==1){break h}if((xb(d+104|0)|0)!=(w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24))){break o}c=c+8|0;f=f+1|0;if(f>>>0<(w[j|0]|w[j+1|0]<<8)>>>0){continue}break}break p}q:{r:{s:{t:{u:{if(w[r|0]&4){if(!c){break o}v[22640]=0;g=W(233,c|0,n|0,v[d+1476>>2])|0;f=v[22640];v[22640]=0;if((f|0)==1){break g}if(!g){break o}g=kc(n,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));A=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);o=w[D|0]|w[D+1|0]<<8;f=w[l|0]|w[l+1|0]<<8;v[22640]=0;e=Q(227,b|0,e+f|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break f}if(!e){break o}e=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22640]=0;e=Q(228,b|0,e-f|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break f}if(!e){break o}e=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);f=w[l|0]|w[l+1|0]<<8;v[22640]=0;U(235,d+80|0,b|0,e-f|0);e=v[22640];v[22640]=0;if((e|0)==1){break b}q=$k(d+104|0,d+80|0);yb(d+80|0);p=0;z=0;h=0;v:{w:{x:{if(!(w[j|0]|w[j+1|0]<<8)){break x}while(1){y:{v[22640]=0;f=Q(236,q|0,o+1|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break y}e=o&15;u=x[(e<<1)+27872>>1];z:{A:{if(u>>>0<=f>>>0){v[22640]=0;e=w[e+27952|0];m=Q(236,q|0,e|0)|0;s=v[22640];v[22640]=0;if((s|0)==1){break y}e=m+(f-u<<e)|0;if((e|0)!=(o|0)){o=e&15;break z}v[22640]=0;e=Q(236,q|0,4)|0;f=v[22640];v[22640]=0;if((f|0)==1){break y}if((e|0)==15){v[22640]=0;e=Q(236,q|0,1)|0;f=v[22640];v[22640]=0;if((f|0)==1){break y}f=65535;if(!e){break A}yb(d+104|0);break p}f=e+65520|0}if(f>>>0>65535){break z}}e=f&1?0-(f+1>>>1|0)|0:f>>>1|0;u=g+h|0;s=u;B:{if(w[r|0]&2){z=e+z|0;e=z;break B}e=w[r+1|0]&2?e:e^32768}f=e>>>8|0;m=(w[r|0]|w[r+1|0]<<8)&1024;t[s+1|0]=m?e:f;t[u|0]=m?f:e;h=h+2|0}if(h>>>0>=A>>>0){p=p+1|0;if(p>>>0>=(w[j|0]|w[j+1|0]<<8)>>>0){break s}v[22640]=0;g=(p<<3)+c|0;e=W(233,g|0,n|0,v[d+1476>>2])|0;f=v[22640];v[22640]=0;if((f|0)==1){break y}if(!e){break u}A=w[g+4|0]|w[g+5|0]<<8|(w[g+6|0]<<16|w[g+7|0]<<24);h=0;g=kc(n,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))}if((w[j|0]|w[j+1|0]<<8)>>>0>p>>>0){continue}break x}break}i=V(27860)|0;if((O()|0)!=(ea(27860)|0)){break v}Z(i|0)|0;v[22640]=0;X(20);c=v[22640];v[22640]=0;if((c|0)==1){break w}}yb(d+104|0);break p}i=P()|0;O()|0}yb(d+104|0);break a}if(!c){break o}v[22640]=0;g=W(233,c|0,n|0,v[d+1476>>2])|0;f=v[22640];v[22640]=0;if((f|0)==1){break e}if(!g){break o}z=kc(n,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));A=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);o=w[D|0]|w[D+1|0]<<8;if((w[l|0]|w[l+1|0]<<8)>>>0>256){break o}v[22640]=0;g=Q(227,b|0,e|0)|0;e=v[22640];v[22640]=0;C:{D:{if((e|0)!=1){if(!g){break o}g=Wd(d+72|0,d+1216|0,w[l|0]|w[l+1|0]<<8);v[22640]=0;e=v[g+4>>2];v[d+40>>2]=v[g>>2];v[d+44>>2]=e;U(237,d+104|0,b|0,d+40|0);g=v[22640];v[22640]=0;if((g|0)==1){break D}if(xb(d+104|0)>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){break o}g=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[22640]=0;g=Q(228,b|0,g-e|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){break C}}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}if(!g){break o}g=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[22640]=0;U(235,d+80|0,b|0,g-e|0);g=v[22640];v[22640]=0;if((g|0)==1){break c}q=$k(d+104|0,d+80|0);yb(d+80|0);g=0;h=0;p=0;E:{F:{G:{if(!(w[j|0]|w[j+1|0]<<8)){break G}while(1){H:{v[22640]=0;f=Q(236,q|0,o+1|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break H}G=h+z|0;m=o&7;s=w[m+27904|0];I:{J:{if(s>>>0<=f>>>0){v[22640]=0;m=w[m+27912|0];u=Q(236,q|0,m|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break H}f=u+(f-s<<m)|0;if((f|0)!=(o|0)){o=f&7;break I}v[22640]=0;f=Q(236,q|0,3)|0;m=v[22640];v[22640]=0;if((m|0)==1){break H}if((f|0)==7){v[22640]=0;f=Q(236,q|0,1)|0;m=v[22640];v[22640]=0;if((m|0)==1){break H}if(f){break r}e=d+1471|0;break J}f=f+248|0}if(f>>>0>255){break I}e=(d+1216|0)+f|0}e=w[e|0];f=e+g|0;s=e;e=(w[r|0]|w[r+1|0]<<8)&2;t[G|0]=e?f:s;g=e?f:g;h=h+1|0}if(h>>>0>=A>>>0){p=p+1|0;if(p>>>0>=(w[j|0]|w[j+1|0]<<8)>>>0){break q}v[22640]=0;e=(p<<3)+c|0;f=W(233,e|0,n|0,v[d+1476>>2])|0;h=v[22640];v[22640]=0;if((h|0)==1){break H}if(!f){break t}A=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);z=kc(n,w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));h=0}if((w[j|0]|w[j+1|0]<<8)>>>0>p>>>0){continue}break G}break}i=V(27860)|0;if((O()|0)!=(ea(27860)|0)){break E}Z(i|0)|0;v[22640]=0;X(20);c=v[22640];v[22640]=0;if((c|0)==1){break F}}yb(d+104|0);break p}i=P()|0;O()|0}yb(d+104|0);break a}yb(d+104|0);break o}yb(d+104|0);break o}yb(d+104|0);break p}yb(d+104|0);break p}yb(d+104|0)}F=F+1|0;if(F>>>0<(w[y|0]|w[y+1|0]<<8)>>>0){continue}break}}v[22640]=0;be(d+56|0,n);b=v[22640];v[22640]=0;if((b|0)==1){break d}b=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=b;Lh(d- -64|0,d+24|0);b=Sd(d+48|0);v[22640]=0;c=v[d+68>>2];v[d+16>>2]=v[d+64>>2];v[d+20>>2]=c;c=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=c;b=W(239,d+104|0,d+16|0,d+8|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break d}od(hj(a)+12|0,b);yb(b);i=1}hs(C)}gb=d+1504|0;return i|0}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0;break a}i=P()|0;O()|0}hs(C);S(i|0);L()}function $E(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;k=gb-336|0;gb=k;m=h;n=i&65535;o=d;q=e&65535;t=(e^i)&-2147483648;B=i>>>16&32767;F=e>>>16&32767;a:{b:{if(B-1>>>0<32766?F-1>>>0<=32765:0){break b}u=e&2147483647;l=u;j=d;if(!(!j&(l|0)==2147418112?!(b|c):l>>>0<2147418112)){G=d;t=e|32768;break a}u=i&2147483647;e=u;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){G=h;t=i|32768;b=f;c=g;break a}if(!(b|j|(l^2147418112|c))){if(!(d|f|(e^2147418112|g))){b=0;c=0;t=2147450880;break a}t=t|2147418112;b=0;c=0;break a}if(!(d|f|(e^2147418112|g))){b=0;c=0;break a}if(!(b|j|(c|l))){b=!(d|f|(e|g));G=b?0:G;t=b?2147450880:t;b=0;c=0;break a}if(!(d|f|(e|g))){t=t|2147418112;b=0;c=0;break a}if((l|0)==65535|l>>>0<65535){i=b;d=!(o|q);h=d<<6;j=E(d?b:o)+32|0;b=E(d?c:q);b=h+((b|0)==32?j:b)|0;If(k+320|0,i,c,o,q,b-15|0);p=16-b|0;o=v[k+328>>2];q=v[k+332>>2];c=v[k+324>>2];b=v[k+320>>2]}if(e>>>0>65535){break b}d=!(m|n);e=d<<6;h=E(d?f:m)+32|0;d=E(d?g:n);d=e+((d|0)==32?h:d)|0;If(k+304|0,f,g,m,n,d-15|0);p=(d+p|0)-16|0;m=v[k+312>>2];n=v[k+316>>2];f=v[k+304>>2];g=v[k+308>>2]}e=n|65536;D=e;u=m;d=m;j=e<<15|d>>>17;d=d<<15|g>>>17;h=0-d|0;e=j;i=1963258675-(j+((d|0)!=0)|0)|0;pf(k+288|0,d,j,0,0,h,i,0,0);j=v[k+296>>2];pf(k+272|0,0-j|0,0-(v[k+300>>2]+((j|0)!=0)|0)|0,0,0,h,i,0,0);h=v[k+280>>2];i=h<<1|v[k+276>>2]>>>31;h=v[k+284>>2]<<1|h>>>31;pf(k+256|0,i,h,0,0,d,e,0,0);j=h;h=v[k+264>>2];pf(k+240|0,i,j,0,0,0-h|0,0-(v[k+268>>2]+((h|0)!=0)|0)|0,0,0);h=v[k+248>>2];l=v[k+252>>2]<<1|h>>>31;i=h<<1|v[k+244>>2]>>>31;h=l;pf(k+224|0,i,h,0,0,d,e,0,0);h=v[k+232>>2];pf(k+208|0,i,l,0,0,0-h|0,0-(v[k+236>>2]+((h|0)!=0)|0)|0,0,0);h=v[k+216>>2];i=h<<1|v[k+212>>2]>>>31;h=v[k+220>>2]<<1|h>>>31;pf(k+192|0,i,h,0,0,d,e,0,0);j=h;h=v[k+200>>2];pf(k+176|0,i,j,0,0,0-h|0,0-(v[k+204>>2]+((h|0)!=0)|0)|0,0,0);j=d;h=v[k+184>>2];l=v[k+188>>2]<<1|h>>>31;d=h<<1|v[k+180>>2]>>>31;i=d-1|0;l=l-(d>>>0<1)|0;pf(k+160|0,j,e,0,0,i,l,0,0);e=f;pf(k+144|0,e<<15,g<<15|e>>>17,0,0,i,l,0,0);h=v[k+172>>2];n=v[k+160>>2];e=v[k+152>>2];d=n+e|0;m=v[k+164>>2];j=m+v[k+156>>2]|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=j;n=(m|0)==(j|0)&n>>>0>e>>>0|j>>>0<m>>>0;m=n+v[k+168>>2]|0;j=h;j=m>>>0<n>>>0?j+1|0:j;h=m;m=!d&e>>>0>1|(d|0)!=0;h=h+m|0;j=h>>>0<m>>>0?j+1|0:j;pf(k+112|0,i,l,0,0,0-h|0,0-(((h|0)!=0)+j|0)|0,0,0);pf(k+128|0,1-e|0,0-((e>>>0>1)+d|0)|0,0,0,i,l,0,0);P=(F-B|0)+p|0;e=v[k+116>>2];z=e;d=v[k+112>>2];j=e<<1|d>>>31;m=d<<1;n=j;e=j;i=v[k+140>>2];H=i;h=v[k+136>>2];j=i<<1|h>>>31;i=h<<1|v[k+132>>2]>>>31;d=i+m|0;l=e+j|0;l=d>>>0<i>>>0?l+1|0:l;i=d;d=l;e=i;j=d-(e>>>0<13927)|0;e=e-13927|0;l=j;I=j;h=0;p=h;j=q|65536;B=j;F=o;w=(j&2147483647)<<1|o>>>31;A=mqa(l,h,w,0);h=jb;r=A;s=h;h=c;L=(h&2147483647)<<1|b>>>31;J=L;x=0;l=(d|0)==(l|0)&e>>>0<i>>>0|d>>>0>l>>>0;m=(d|0)==(n|0)&i>>>0<m>>>0|d>>>0<n>>>0;d=v[k+120>>2];j=v[k+124>>2]<<1|d>>>31;i=H>>>31|0;d=i+(d<<1|z>>>31)|0;j=d>>>0<i>>>0?j+1|0:j;h=d;d=m+d|0;j=d>>>0<h>>>0?j+1|0:j;i=d;d=l+d|0;h=d>>>0<i>>>0?j+1|0:j;i=d-1|0;C=h-(d>>>0<1)|0;m=0;h=mqa(J,x,C,m);d=h+r|0;j=jb+s|0;j=d>>>0<h>>>0?j+1|0:j;h=j;r=(s|0)==(j|0)&d>>>0<r>>>0|j>>>0<s>>>0;j=0;A=j;z=j;R=0;j=o;Q=c>>>31|0;J=Q|j<<1;M=0;q=mqa(i,z,J,M);l=q+d|0;j=jb+h|0;j=l>>>0<q>>>0?j+1|0:j;n=l;q=j;j=(h|0)==(j|0)&d>>>0>l>>>0|h>>>0>j>>>0;d=j+r|0;h=0;h=d>>>0<j>>>0?1:h;l=mqa(w,K,C,m);d=l+d|0;j=jb+h|0;h=d>>>0<l>>>0?j+1|0:j;o=mqa(w,K,i,z);l=jb;s=d;z=mqa(C,m,J,M);d=z+o|0;j=jb+l|0;j=d>>>0<z>>>0?j+1|0:j;r=d;d=j;j=(l|0)==(j|0)&o>>>0>r>>>0|j>>>0<l>>>0;o=s+d|0;l=h+j|0;l=o>>>0<d>>>0?l+1|0:l;s=o;o=0;d=o+n|0;j=q+r|0;j=d>>>0<o>>>0?j+1|0:j;h=j;o=(q|0)==(j|0)&n>>>0>d>>>0|j>>>0<q>>>0;q=s+o|0;j=l;N=q;l=o>>>0>q>>>0?j+1|0:j;s=d;n=h;o=b<<1;q=c<<1|b>>>31;O=o&-2;r=mqa(i,A,O,0);h=jb;z=e;e=mqa(e,0,J,M);d=e+r|0;j=jb+h|0;j=d>>>0<e>>>0?j+1|0:j;r=(h|0)==(j|0)&d>>>0<r>>>0|h>>>0>j>>>0;h=d;e=j;S=r;H=mqa(I,p,L,x);d=H+d|0;j=jb+j|0;j=d>>>0<H>>>0?j+1|0:j;H=d;r=d;d=j;j=(j|0)==(e|0)&h>>>0>r>>>0|e>>>0>j>>>0;e=S+j|0;h=0;h=e>>>0<j>>>0?1:h;r=e;e=s+e|0;j=h+n|0;j=e>>>0<r>>>0?j+1|0:j;r=e;h=e;e=j;n=(j|0)==(n|0)&h>>>0<s>>>0|j>>>0<n>>>0;h=n+N|0;j=l;N=h;n=h>>>0<n>>>0?j+1|0:j;K=mqa(w,K,z,T);w=jb;l=mqa(C,m,O,U);h=l+K|0;j=jb+w|0;j=h>>>0<l>>>0?j+1|0:j;C=h;l=mqa(L,x,i,A);i=h+l|0;h=j;j=j+jb|0;j=i>>>0<l>>>0?j+1|0:j;m=i;A=mqa(I,p,J,M);i=i+A|0;l=j+jb|0;l=i>>>0<A>>>0?l+1|0:l;A=i;i=l;l=0;s=(i|0)==(j|0)&A>>>0<m>>>0|i>>>0<j>>>0;m=(h|0)==(j|0)&C>>>0>m>>>0|h>>>0>j>>>0;j=m+((h|0)==(w|0)&K>>>0>C>>>0|h>>>0<w>>>0)|0;h=0;m=s+j|0;j=m;h=r+i|0;j=(j|l)+e|0;j=h>>>0<i>>>0?j+1|0:j;s=h;m=j;h=(e|0)==(j|0)&h>>>0<r>>>0|e>>>0>j>>>0;e=h+N|0;j=n;C=e;n=e>>>0<h>>>0?j+1|0:j;r=s;w=H;I=mqa(I,p,O,U);p=jb;h=mqa(L,x,z,T);e=h+I|0;j=jb+p|0;j=e>>>0<h>>>0?j+1|0:j;l=j;j=0;h=(l|0)==(p|0)&e>>>0<I>>>0|l>>>0<p>>>0;e=l+w|0;j=(h|j)+d|0;j=e>>>0<l>>>0?j+1|0:j;h=e;s=(d|0)==(j|0)&h>>>0<w>>>0|d>>>0>j>>>0;l=j+A|0;p=0;i=p+h|0;d=i;l=d>>>0<p>>>0?l+1|0:l;e=(j|0)==(l|0)&d>>>0<h>>>0|j>>>0>l>>>0;d=s+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+r|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;i=(m|0)==(j|0)&d>>>0<r>>>0|j>>>0<m>>>0;h=i+C|0;l=n;l=h>>>0<i>>>0?l+1|0:l;i=l;c:{if((i|0)==131071|i>>>0<131071){j=F;l=B<<1|j>>>31;F=Q|j<<1;B=l|R;pf(k+80|0,d,e,h,i,f,g,u,D);l=b<<17;b=0;c=v[k+88>>2];m=b-c|0;j=v[k+80>>2];n=v[k+84>>2];p=(j|0)!=0|(n|0)!=0;x=m-p|0;p=(l-(v[k+92>>2]+(b>>>0<c>>>0)|0)|0)-(m>>>0<p>>>0)|0;m=0-j|0;n=0-(((j|0)!=0)+n|0)|0;b=P+16382|0;break c}d=(e&1)<<31|d>>>1;j=h<<31|e>>>1;e=j;h=(i&1)<<31|h>>>1;i=i>>>1|0;pf(k+96|0,d,j,h,i,f,g,u,D);o=0;m=v[k+104>>2];n=o-m|0;j=v[k+96>>2];q=v[k+100>>2];p=(j|0)!=0|(q|0)!=0;x=n-p|0;p=((b<<16)-(v[k+108>>2]+(m>>>0>o>>>0)|0)|0)-(n>>>0<p>>>0)|0;m=0-j|0;n=0-(((j|0)!=0)+q|0)|0;o=b;q=c;b=P+16383|0}if((b|0)>=32767){t=t|2147418112;b=0;c=0;break a}d:{if((b|0)>=1){c=x;j=p<<1|c>>>31;x=c<<1|n>>>31;p=j;o=h;q=i&65535|b<<16;b=m;j=n<<1|b>>>31;b=b<<1;break d}if((b|0)<=-113){b=0;c=0;break a}lm(k- -64|0,d,e,h,i,1-b|0);If(k+48|0,o,q,F,B,b+112|0);d=v[k+64>>2];e=v[k+68>>2];o=v[k+72>>2];q=v[k+76>>2];pf(k+32|0,f,g,u,D,d,e,o,q);c=v[k+40>>2];i=c<<1;c=v[k+44>>2]<<1|c>>>31;m=v[k+36>>2];h=m;b=v[k+56>>2];m=h>>>31|i;i=b-m|0;l=v[k+60>>2]-((b>>>0<m>>>0)+c|0)|0;c=v[k+32>>2];h=h<<1|c>>>31;c=c<<1;B=v[k+52>>2];j=B;b=v[k+48>>2];j=(h|0)==(j|0)&c>>>0>b>>>0|h>>>0>j>>>0;x=i-j|0;p=l-(i>>>0<j>>>0)|0;i=b;b=i-c|0;j=B-((c>>>0>i>>>0)+h|0)|0}pf(k+16|0,f,g,u,D,3,0,0,0);pf(k,f,g,u,D,5,0,0,0);i=d;c=e;l=f;f=g;r=o;m=0;h=j+m|0;n=d&1;d=b+n|0;h=d>>>0<b>>>0?h+1|0:h;o=d;g=h;l=(h|0)==(f|0)&d>>>0>l>>>0|f>>>0<h>>>0;d=(h|0)==(m|0)&n>>>0>d>>>0|h>>>0<m>>>0;b=d+x|0;j=p;j=b>>>0<d>>>0?j+1|0:j;h=b;f=j;d=(h|0)==(u|0)&(j|0)==(D|0)?l:(D|0)==(j|0)&h>>>0>u>>>0|j>>>0>D>>>0;b=i+d|0;j=e;j=b>>>0<d>>>0?j+1|0:j;d=b;b=j;e=(j|0)==(c|0)&d>>>0<i>>>0|c>>>0>j>>>0;c=r+e|0;j=q;i=c;j=i>>>0<e>>>0?j+1|0:j;c=j;e=d;l=i;d=v[k+20>>2];m=(d|0)==(g|0)&y[k+16>>2]<o>>>0|d>>>0<g>>>0;d=v[k+28>>2];i=v[k+24>>2];i=j>>>0<2147418112&((h|0)==(i|0)&(d|0)==(f|0)?m:(d|0)==(f|0)&i>>>0<h>>>0|d>>>0<f>>>0);d=e+i|0;j=b;j=d>>>0<i>>>0?j+1|0:j;i=d;d=j;e=(j|0)==(b|0)&e>>>0>i>>>0|b>>>0>j>>>0;b=l+e|0;j=c;j=b>>>0<e>>>0?j+1|0:j;e=j;l=b;b=v[k+4>>2];g=(b|0)==(g|0)&y[k>>2]<o>>>0|b>>>0<g>>>0;b=v[k+12>>2];c=v[k+8>>2];c=j>>>0<2147418112&((c|0)==(h|0)&(b|0)==(f|0)?g:(b|0)==(f|0)&c>>>0<h>>>0|b>>>0<f>>>0);b=c+i|0;j=d;j=b>>>0<c>>>0?j+1|0:j;c=j;f=(d|0)==(j|0)&b>>>0<i>>>0|d>>>0>j>>>0;d=l+f|0;j=e;G=d|G;t=t|(d>>>0<f>>>0?j+1|0:j)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=G;v[a+12>>2]=t;gb=k+336|0}function OZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;f=gb-176|0;gb=f;vc(b);a:{b:{c:{d:{e:{if(!oE(b,f+128|0)){break e}if(!pE(f+128|0)){break e}if(!c){m=1;break e}Gd(a,2048);wg(a);d=gb-16|0;gb=d;e=Tb(d,1075);Dc(f+112|0,e);vb(e);gb=d+16|0;v[22640]=0;k=f+128|3;U(348,f+32|0,f+112|0,k|0);d=v[22640];v[22640]=0;f:{g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){Eb(a+1298304|0,f+32|0);vb(f+32|0);Hb(f+112|0);d=Tb(f+32|0,8405);Eb(a+1298316|0,d);vb(d);v[a+1298364>>2]=5;u[a+480188>>1]=w[f+168|0];u[a+480190>>1]=w[f+164|0];_e(f+112|0,2,f+128|4);Bc(f+32|0,f+112|0);Eb(a+1298268|0,f+32|0);vb(f+32|0);if(w[k|0]<=9){u[a+480188>>1]=4;lg(b,1);rh(a,1)}d=w[k|0];n:{if(w[k|0]>=11){e=d>>>0>11?32:16;d=0;while(1){h=((d<<5)+a|0)+480284|0;i=hE(b)<<1;i=(i|0)>-128?i:-128;o:{if((i|0)<129){d=i+128|0;break o}v[((d<<5)+a|0)+480280>>2]=256;d=128}u[h>>1]=d;g=g+1|0;d=g&65535;if(e>>>0>d>>>0){continue}break}break n}if((d|0)!=10){break n}d=f+32|0;e=gb-32|0;gb=e;g=b;p:{if(Pb(b,16)){Zv(e+24|0,d);d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;gd(e+16|0,g,e+8|0);break p}g=gb-16|0;gb=g;j=d+16|0;while(1){Kf(d);d=d+1|0;if((j|0)!=(d|0)){continue}break}gb=g+16|0}gb=e+32|0;d=0;while(1){u[((d<<5)+a|0)+480284>>1]=t[(f+32|0)+d|0]&1?64:192;d=d+1|0;if((d|0)!=16){continue}break}}q:{if(w[k|0]>=13){bw(f+32|0,b);e=md(f+32|0);g=a;d=w[f+32|0];if(d>>>0<32){t[f+32|0]=125;d=125}v[g+480204>>2]=B(d,1e4);v[a+480196>>2]=w[e|0];break q}v[a+480196>>2]=6;v[a+480204>>2]=125e4}g=a+484360|0;yf(Rb(g),w[f+165|0]);n=nc(f+112|0);q=v[b+8>>2];r=w[k|0];r:{if(w[k|0]<14){break r}d=w[f+165|0];v[22640]=0;R(349,n|0,d|0);d=v[22640];v[22640]=0;if((d|0)!=1){break r}b=P()|0;O()|0;break b}s:{if(w[f+165|0]){d=0;while(1){z=rc(Rb(g),d),A=d,u[z>>1]=A;if(w[k|0]>=14){v[22640]=0;e=T(319,b|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break s}z=rc(n,d),A=e,u[z>>1]=A}e=x[a+480188>>1];v[22640]=0;Q(350,b|0,e<<1)|0;e=v[22640];v[22640]=0;if((e|0)==1){break s}d=d+1|0;if(d>>>0<w[f+165|0]){continue}break}}d=x[a+480190>>1];v[22640]=0;v[f+32>>2]=0;o=W(351,f+96|0,d|0,f+32|0)|0;d=v[22640];v[22640]=0;g=1;if((d|0)!=1){v[f+92>>2]=0;t:{if(x[a+480190>>1]){j=1;while(1){v[22640]=0;e=B(g,104)+a|0;i=e+484380|0;R(352,i|0,0);d=v[22640];v[22640]=0;if((d|0)==1){break t}v[22640]=0;l=T(353,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}v[22640]=0;W(354,b|0,((g<<5)+a|0)+946304|0,32)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}v[22640]=0;W(355,b|0,e+484423|0,13)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}v[22640]=0;d=T(229,b|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break d}m=g-1|0;z=Mb(o,m),A=d,v[z>>2]=A;u:{if(w[k|0]<=9){v[22640]=0;g=T(319,b|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break u}break d}v[22640]=0;g=T(229,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}}v[i>>2]=g;v[22640]=0;d=T(319,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break d}v[e+484404>>2]=d;v[22640]=0;d=T(353,b|0)|0;g=v[22640];v[22640]=0;v:{w:{x:{if((g|0)!=1){t[f+32|0]=d;v[22640]=0;t[f+80|0]=64;d=ac(f+32|0,f+80|0);g=v[22640];v[22640]=0;if((g|0)==1){break x}u[e+484410>>1]=w[d|0]<<2;if(w[k|0]>9){break w}v[22640]=0;d=T(319,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break d}v[e+484384>>2]=d;v[22640]=0;d=T(319,b|0)|0;break v}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[22640]=0;d=T(229,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break d}v[e+484384>>2]=d;v[22640]=0;d=T(229,b|0)|0}g=v[22640];v[22640]=0;if((g|0)==1){break d}g=e+484388|0;v[g>>2]=d;if(l){l=e+484384|0;y:{if(!(d>>>0<=v[l>>2]+2>>>0|d>>>0>y[i>>2])){d=e+484414|0;u[d>>1]=x[d>>1]|2;break y}v[g>>2]=0;v[l>>2]=0}d=Mb(o,m);v[22640]=0;d=Jc(f+92|0,d);g=v[22640];v[22640]=0;if((g|0)==1){break d}v[f+92>>2]=v[d>>2]}j=j+1|0;g=j&65535;if(g>>>0<=x[a+480190>>1]){continue}break}}j=nc(f+80|0);d=w[f+166|0]|w[f+167|0]<<8;v[22640]=0;m=W(358,b|0,j|0,d|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break m}if(!m){break f}g=0;if(!$c(j)){g=Sb(j);e=Wb(j);d=gb-32|0;gb=d;v[d+16>>2]=e;v[d+24>>2]=g;z:{if(!Gb(d+24|0,d+16|0)){break z}v[d>>2]=g;e=mf(d);if(!Gb(e,d+16|0)){break z}while(1){if(bE(v[d+24>>2],v[e>>2])){g=v[d>>2];v[d+24>>2]=g}if(Gb(mf(e),d+16|0)){continue}break}}gb=d+32|0;v[f+32>>2]=g;d=v[f+32>>2];g=w[d|0]|w[d+1|0]<<8}v[22640]=0;e=g;l=Q(359,f- -64|0,e|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){if(e){d=0;while(1){v[22640]=0;i=T(360,b|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break l}v[22640]=0;U(320,f+32|0,b|0,B(i,3)|0);i=v[22640];v[22640]=0;if((i|0)==1){break l}od(Hg(l,d),f+32|0);yb(f+32|0);d=d+1|0;if((e|0)!=(d|0)){continue}break}}if(c&2){s=Pc(f+24|0,8,1,0,1);v[22640]=0;i=Q(361,f+32|0,o|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break j}d=Sb(i);e=Wb(i);v[22640]=0;jE(d,e);d=v[22640];v[22640]=0;if((d|0)==1){break k}h=Sb(i);p=Wb(i);d=gb-32|0;gb=d;v[d+16>>2]=p;v[d+24>>2]=h;e=gb-32|0;gb=e;v[e+16>>2]=p;v[e+24>>2]=h;A:{B:{if(!Gb(e+24|0,e+16|0)){break B}v[e+8>>2]=v[e+24>>2];if(!Gb(Xg(e+8|0),e+16|0)){break B}while(1){if(Jk(v[e+24>>2],v[e+8>>2])){h=v[e+24>>2];break A}v[e+24>>2]=v[e+8>>2];if(Gb(Xg(e+8|0),e+16|0)){continue}break}}h=v[e+16>>2]}gb=e+32|0;v[d+24>>2]=h;if(Gb(d+24|0,d+16|0)){v[d>>2]=v[d+24>>2];Xg(d);if(Gb(Xg(d),d+16|0)){while(1){if(!Jk(v[d+24>>2],v[d>>2])){e=v[v[d>>2]>>2];z=v[Xg(d+24|0)>>2],A=e,v[z>>2]=A}if(Gb(Xg(d),d+16|0)){continue}break}}Xg(d+24|0)}gb=d+32|0;v[f+16>>2]=v[d+24>>2];z=f,A=Sb(i),v[z+8>>2]=A;C:{if(!Gb(f+8|0,f+16|0)){break C}while(1){v[22640]=0;d=Q(228,b|0,1)|0;e=v[22640];v[22640]=0;D:{if((e|0)!=1){if(!d){break C}d=0;if(!x[a+480190>>1]){break D}while(1){v[22640]=0;e=Q(228,b|0,1)|0;h=v[22640];v[22640]=0;if((h|0)==1){break k}if(!e){break D}e=d+1|0;if(v[v[f+8>>2]>>2]!=v[Mb(o,d)>>2]){d=e;if(d>>>0>=x[a+480190>>1]){break D}continue}break}v[22640]=0;W(363,s|0,(B(e,104)+a|0)+484380|0,b|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break D}break k}break k}iE(f+8|0);if(Gb(f+8|0,f+16|0)){continue}break}}Lc(i)}if(!(c&1)){break g}d=w[f+165|0];c=0;v[22640]=0;i=a+484344|0;R(364,i|0,d|0);d=v[22640];v[22640]=0;E:{if((d|0)!=1){if(!w[f+165|0]){break g}p=q+((r>>>0>13)<<1)|0;while(1){F:{if(sc(n)>>>0<=c>>>0){d=64}else{d=x[rc(n,c)>>1]}v[22640]=0;d=W(365,i|0,c&65535,d|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break E}G:{if(d){d=x[a+480188>>1];e=w[k|0];v[22640]=0;Q(227,b|0,p+B(((e>>>0>13)<<1)+(d<<1)|0,c)|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break E}e=nc(f+32|0);d=x[a+480188>>1];v[22640]=0;d=W(358,b|0,e|0,d|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break G}H:{if(!d){break H}d=0;if(!x[a+480188>>1]){break H}while(1){I:{h=rc(e,d);if(!(w[h|0]|w[h+1|0]<<8)){break I}h=rc(e,d);if((w[h|0]|w[h+1|0]<<8)>>>0>(w[f+166|0]|w[f+167|0]<<8)>>>0){break I}h=rc(e,d);h=rc(j,(w[h|0]|w[h+1|0]<<8)-1|0);h=w[h|0]|w[h+1|0]<<8;if(!h|g>>>0<h>>>0){break I}q=_b(i,c);h=Hg(l,h-1&65535);v[22640]=0;U(366,q|0,d&65535,h|0);h=v[22640];v[22640]=0;if((h|0)!=1){break I}break F}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}Lk(e)}c=c+1|0;if(c>>>0>=w[f+165|0]){break g}continue}}break}b=P()|0;O()|0;Lk(e);break i}b=P()|0;O()|0;break i}b=P()|0;O()|0;break i}b=P()|0;O()|0;break h}b=P()|0;O()|0;break c}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;Hb(f+112|0);break a}b=P()|0;O()|0;break h}b=P()|0;O()|0;break i}b=P()|0;O()|0;Lc(i);break i}b=P()|0;O()|0}fd(l)}Lk(j);break c}fd(l)}Lk(j);Lc(o);Ue(n)}gb=f+176|0;return m|0}b=P()|0;O()|0}Lc(o)}Ue(n)}S(b|0);L()}function Roa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=gb-256|0;gb=d;vc(b);f=gb-32|0;gb=f;i=d+96|0;uX(f+24|0,i);j=xb(f+24|0);e=v[f+28>>2];k=v[f+24>>2];v[f+8>>2]=k;v[f+12>>2]=e;v[f>>2]=k;v[f+4>>2]=e;e=b;fc(f+16|0,e,f);k=xb(f+16|0);if((k|0)==(j|0)){Yb(e,xb(f+24|0))}gb=f+32|0;e=(j|0)==(k|0);if(!e){tX(i)}a:{b:{c:{d:{if(!e){break d}if(!vX(d+96|0)){break d}if(!c){g=1;break d}Gd(a,v[((w[d+212|0]|w[d+213|0]<<8)<<2)+28992>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;e=Tb(d+16|0,10491);Eb(a+1298304|0,e);vb(e);e=Tb(d+16|0,7639);Eb(a+1298316|0,e);vb(e);e=gb-16|0;gb=e;f=Tb(e,1498);Dc(d+80|0,f);vb(f);gb=e+16|0;v[22640]=0;Y(389,d+16|0,d+80|0,d+175|0,d+172|0);e=v[22640];v[22640]=0;e:{f:{if((e|0)!=1){Eb(a+1298328|0,d+16|0);vb(d+16|0);Hb(d+80|0);Vc(a+1298352|0,((w[d+212|0]|w[d+213|0]<<8)<<2)+29040|0);Vc(a+1298340|0,v[((w[d+212|0]|w[d+213|0]<<8)<<2)+29088>>2]);v[a+1298364>>2]=5;_e(d+80|0,2,d+96|4);Bc(d+16|0,d+80|0);Eb(a+1298268|0,d+16|0);vb(d+16|0);_e(d+80|0,2,d+132|0);Bc(d+16|0,d+80|0);g:{if(xr(d+16|0,6910)){v[22640]=0;U(13,d+80|0,5,d+16|0);e=v[22640];v[22640]=0;if((e|0)==1){break g}Eb(a+1298280|0,d+80|0);vb(d+80|0)}vb(d+16|0);u[a+480188>>1]=32;e=0;h:{while(1){g=(e<<5)+a|0;j=g+480280|0;Se(j);i:{f=d+e|0;if(w[f+177|0]<=15){v[d+16>>2]=w[f+177|0]<<4|8;v[d+80>>2]=256;q=g+480284|0,r=v[ld(d+16|0,d+80|0)>>2],u[q>>1]=r;break i}if(w[f+177|0]==16){u[g+480284>>1]=128;v[j>>2]=256;break i}if(w[f+177|0]!=255){break i}u[a+480188>>1]=e;break h}e=e+1|0;if((e|0)!=32){continue}break}e=x[a+480188>>1]}g=0;if(!(e&65535)){break d}v[d+16>>2]=w[d+209|0]<<2;v[d+80>>2]=256;q=a,r=v[Fb(d+16|0,d+80|0)>>2],v[q+480200>>2]=r;v[a+480196>>2]=w[d+210|0];v[a+480204>>2]=B(w[d+211|0],1e4);if(Xc(b,w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))){hp(Rb(a+484360|0),b,w[d+218|0]+1|0,255,254)}if(!Xc(b,w[d+224|0]|w[d+225|0]<<8|(w[d+226|0]<<16|w[d+227|0]<<24))){break d}u[a+480190>>1]=w[d+232|0]+1;k=d+48|0;e=1;j=1;while(1){g=gb-32|0;gb=g;h=d+16|0;bc(g+24|0,h,62);i=xb(g+24|0);f=v[g+28>>2];l=v[g+24>>2];v[g+8>>2]=l;v[g+12>>2]=f;v[g>>2]=l;v[g+4>>2]=f;f=b;fc(g+16|0,f,g);l=xb(g+16|0);if((l|0)==(i|0)){Yb(f,xb(g+24|0))}gb=g+32|0;f=(i|0)==(l|0);if(!f){Qb(h,0,62)}if(f){f=B(e,104)+a|0;g=f+484380|0;td(g,0);_e(d,2,d+16|0);Bc(d+80|0,d);v[22640]=0;Q(333,((e<<5)+a|0)+946304|0,d+80|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}vb(d+80|0);Gk(d,2,k);Bc(d+80|0,d);v[22640]=0;Q(335,f+484423|0,d+80|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break c}vb(d+80|0);e=f+484404|0;v[e>>2]=w[d+74|0]|w[d+75|0]<<8;j:{if(!fp(a)){break j}i=v[e>>2];e=0;while(1){if((i|0)==x[(e<<1)+29136>>1]){t[f+484417|0]=e<<4;break j}e=e+1|0;if((e|0)!=16){continue}break}}u[f+484412>>1]=64;v[g>>2]=w[d+61|0]|w[d+62|0]<<8|(w[d+63|0]<<16|w[d+64|0]<<24);if(w[d+73|0]&2){e=f+484414|0;u[e>>1]=x[e>>1]|1;v[g>>2]=v[g>>2]>>>1}v[f+484384>>2]=w[d+65|0]|w[d+66|0]<<8|(w[d+67|0]<<16|w[d+68|0]<<24);v[f+484388>>2]=(w[d+69|0]|w[d+70|0]<<8|(w[d+71|0]<<16|w[d+72|0]<<24))-1;if(t[d+73|0]&1){e=f+484414|0;u[e>>1]=x[e>>1]|2}k:{if(!(!(w[d+73|0]&4)|w[d+76|0]==255)){t[d+80|0]=w[d+76|0];t[d|0]=64;q=f+484410|0,r=w[ac(d+80|0,d)|0]<<2,u[q>>1]=r;break k}e=f+484414|0;u[e>>1]=x[e>>1]|32768}l:{if(!(w[d+73|0]&8)){u[f+484408>>1]=128;break l}e=f+484414|0;u[e>>1]=x[e>>1]|32;g=f+484408|0;if(w[d+77|0]>=16){f=128}else{f=w[d+77|0];v[d>>2]=256;v[d+80>>2]=f<<4|8;f=v[ld(d+80|0,d)>>2]}u[g>>1]=f;u[e>>1]=x[e>>1]&65279|(w[d+77|0]==16)<<8}j=j+1|0;e=j&65535;if(e>>>0<=x[a+480190>>1]){continue}}break}m:{if(!(c&2)){break m}if(!Xc(b,w[d+228|0]|w[d+229|0]<<8|(w[d+230|0]<<16|w[d+231|0]<<24))|!x[a+480190>>1]){break m}e=1;while(1){f=B(e&65535,104)+a|0;zg(Pc(d+16|0,u[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);e=e+1|0;if(x[a+480190>>1]>=(e&65535)>>>0){continue}break}}m=a+484344|0;vg(m,w[d+223|0]+1|0);f=Fq(a);e=gb-16|0;gb=e;v[e+12>>2]=0;$t(e+12|0,f);i=v[e+12>>2];gb=e+16|0;Xc(b,w[d+219|0]|w[d+220|0]<<8|(w[d+221|0]<<16|w[d+222|0]<<24));o=c&1;k=0;j=1;n:{while(1){o:{c=Kg(b);if(c>>>0>=3){rd(d+16|0,b,c-2|0);p:{if(!o){break p}v[22640]=0;c=T(307,d+16|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break o}if(!c){break p}v[22640]=0;c=W(365,m|0,k&65535,64)|0;e=v[22640];v[22640]=0;if((e|0)==1){break o}l=0;if(!c){break p}while(1){c=_b(m,k);v[22640]=0;p=Pf(c,l);c=v[22640];v[22640]=0;if((c|0)==1){break f}q:while(1){v[22640]=0;c=T(353,d+16|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break n}r:{if(!c){break r}e=c&31;if(e>>>0>=x[a+480188>>1]){break r}f=B(e,6)+p|0;if(c&32){v[22640]=0;R(431,d+80|0,d+16|0);e=v[22640];v[22640]=0;if((e|0)==1){break f}g=md(d+80|0);e=w[d+80|0];if(e){e=(e&127)-1|0;t[d+80|0]=e;t[f|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+13;v[22640]=0;e=rv(f);h=v[22640];v[22640]=0;if((h|0)==1){break f}j=e&j}t[f+1|0]=w[g|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;g=f+5|0;while(1){v[22640]=0;c=Q(228,d+16|0,2)|0;e=v[22640];v[22640]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((e|0)!=1){if(!c){continue q}n=w[g|0];c=w[f+3|0];v[22640]=0;R(431,d+80|0,d+16|0);e=v[22640];v[22640]=0;if((e|0)==1){break f}h=w[md(d+80|0)|0];t[g|0]=h;e=w[(w[d+80|0]&31)+29168|0];t[f+3|0]=e;switch(e-2|0){case 4:case 5:break w;case 18:break x;case 13:break y;case 17:break z;case 11:break A;case 0:case 1:break B;default:break t}}break f}if(h>>>0<224){break u}e=223;if(v[a+480180>>2]!=1){break v}break u}v[22640]=0;t[d|0]=64;e=ac(g,d);h=v[22640];v[22640]=0;if((h|0)!=1){t[g|0]=w[e|0];v[22640]=0;e=iz(i,1);h=v[22640];v[22640]=0;if((h|0)==1){break f}if(!e){break u}t[f+2|0]=1;t[f+4|0]=w[g|0];t[f+3|0]=c;t[g|0]=n;e=c;break t}break f}v[22640]=0;e=uq(i,19);h=v[22640];v[22640]=0;if((h|0)==1){break f}if(e){break u}v[22640]=0;Ut(f);e=v[22640];v[22640]=0;if((e|0)!=1){break u}break f}v[22640]=0;e=uq(i,15);h=v[22640];v[22640]=0;if((h|0)==1){break f}if(e){break u}v[22640]=0;e=uq(i,19);h=v[22640];v[22640]=0;if((h|0)==1){break f}if(!e){break u}t[f+3|0]=19;t[g|0]=w[g|0]&15|144;break s}C:{e=h>>>4|0;if((e|0)!=8){if(e){break C}D:{switch(h&15){case 0:case 1:e=h-112|0;break v;case 4:t[f+3|0]=20;t[g|0]=158;break s;case 5:break D;default:break C}}t[f+3|0]=20;t[g|0]=159;break s}v[22640]=0;e=uq(i,20);h=v[22640];v[22640]=0;if((h|0)==1){break f}if(e){break u}t[f+3|0]=19;break s}t[f+3|0]=0;break s}e=h&240;if(!e){break u}}t[g|0]=e}e=w[f+3|0]}if((e&255)!=20){break s}e=w[g|0];if(w[f+2|0]|(e&240)!=128){break s}t[f+2|0]=2;t[f+4|0]=(((e&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[g|0]=n}if(w[d+80|0]&32){continue}break}continue}break}l=l+1|0;if((l|0)!=64){continue}break}}yb(d+16|0)}c=w[d+223|0]>k>>>0;k=k+1|0;if(c){continue}break e}break}break f}break f}e=P()|0;O()|0;vb(d+16|0);break a}e=P()|0;O()|0;Hb(d+80|0);break a}e=P()|0;O()|0;yb(d+16|0);break a}c=a;if(v[a+480180>>2]!=1){e=v[a+480208>>2]&-8454145}else{e=v[a+480208>>2]&-8454145|(x[a+480188>>1]==4?j&1?8454144:0:0)}v[c+480208>>2]=e;g=1;if(!(w[d+237|0]|w[d+238|0]<<8|(w[d+239|0]<<16|w[d+240|0]<<24))){break d}if(!Xc(b,w[d+233|0]|w[d+234|0]<<8|(w[d+235|0]<<16|w[d+236|0]<<24))){break d}dB(a+1298292|0,b,w[d+237|0]|w[d+238|0]<<8|(w[d+239|0]<<16|w[d+240|0]<<24),4)}gb=d+256|0;return g|0}e=P()|0;O()|0;vb(d+80|0);break a}e=P()|0;O()|0;vb(d+80|0)}S(e|0);L()}function Mpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-240|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!uY(b,d+168|0)){break j}if(!vY(d+168|0)){break j}if(!c){e=1;break j}Gd(a,131072);e=gb-16|0;gb=e;k=Tb(e,1061);Dc(d+80|0,k);vb(k);gb=e+16|0;v[22640]=0;U(488,d+120|0,d+80|0,d+168|4);e=v[22640];v[22640]=0;if((e|0)==1){break i}Eb(a+1298304|0,d+120|0);vb(d+120|0);Hb(d+80|0);e=Tb(d+120|0,8401);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;Kv(d+80|0,3,d+181|0);Bc(d+120|0,d+80|0);Eb(a+1298268|0,d+120|0);vb(d+120|0);Vj(d+56|0,3,d+211|0);Bc(d+80|0,d+56|0);v[22640]=0;U(13,d+120|0,5,d+80|0);e=v[22640];v[22640]=0;k:{l:{m:{n:{o:{if((e|0)!=1){Eb(a+1298280|0,d+120|0);vb(d+120|0);vb(d+80|0);e=Er(d+120|0);m=e,n=Jd(w[d+231|0],1,31),v[m+12>>2]=n;m=e,n=Jd(w[d+232|0],1,12)-1|0,v[m+16>>2]=n;v[e+20>>2]=w[d+233|0];k=a+1298368|0;cD(k);sY(k,e);i=d+56|4;k=eh(d+104|0);while(1){v[22640]=0;e=Q(228,b|0,8)|0;f=v[22640];v[22640]=0;if((f|0)==1){break o}if(!e){break k}v[22640]=0;R(489,b|0,d+56|0);e=v[22640];v[22640]=0;if((e|0)==1){break n}f=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);e=w[d+172|0];p:{if((e|0)==3){g=2;if((w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))==1431389523){break p}e=w[d+172|0]}if((e&255)==4){g=4;if((w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))==1431389523){break p}e=w[d+172|0]}g=0;if((e&255)>>>0>7){break p}f=(w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))==1146113363?-1:f}v[22640]=0;U(320,d+80|0,b|0,f|0);e=v[22640];v[22640]=0;if((e|0)==1){break m}v[22640]=0;U(490,k|0,d+56|0,d+80|0);e=v[22640];v[22640]=0;if((e|0)==1){break l}yb(d+80|0);v[22640]=0;Q(350,b|0,g|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+80|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+80|0);break b}v[22640]=0;b=T(251,d+80|0)|0;e=v[22640];v[22640]=0;q:{r:{s:{if((e|0)!=1){v[22640]=0;U(491,d+56|0,k|0,1431389523);e=v[22640];v[22640]=0;if((e|0)==1){break s}od(b,d+56|0);yb(d+56|0);u[d+54>>1]=0;u[d+52>>1]=65534;if(w[d+172|0]<3){break q}v[22640]=0;e=T(319,b|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){break r}break d}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}u[d+54>>1]=e;if(w[d+172|0]<4){break q}v[22640]=0;e=T(319,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break d}u[d+52>>1]=w[d+172|0]==4?e?e:-2:e}e=a+484360|0;f=Rb(e);v[22640]=0;g=T(492,b|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}v[22640]=0;ga(402,f|0,b|0,g>>>1|0,65535,65535)|0;f=v[22640];v[22640]=0;if((f|0)==1){break d}f=Rb(e);v[22640]=0;f=T(493,f|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break d}sg(d+54|0,f);f=Rb(e);v[22640]=0;f=T(493,f|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break d}sg(d+52|0,f);v[22640]=0;U(491,d+56|0,k|0,1414807888);f=v[22640];v[22640]=0;t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){od(b,d+56|0);yb(d+56|0);v[22640]=0;f=T(307,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break d}if(!f|!(c&1)){break t}v[22640]=0;R(494,b|0,d+48|0);f=v[22640];v[22640]=0;if((f|0)==1){break A}m=a,n=Jd(w[d+48|2],1,32)+1|0,u[m+480188>>1]=n;f=w[d+48|0]|w[d+49|0]<<8;v[22640]=0;f=Q(359,d|0,f|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break z}m=d,n=Sb(f),v[m+16>>2]=n;m=d,n=Wb(f),v[m+40>>2]=n;if(Gb(d+16|0,d+40|0)){while(1){i=v[d+16>>2];v[22640]=0;g=w[d+172|0]<3?9:8;Q(350,b|0,g-4|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break y}v[22640]=0;h=T(229,b|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break x}lg(b,g);v[22640]=0;U(320,d+56|0,b|0,g+h|0);g=v[22640];v[22640]=0;if((g|0)==1){break w}od(i,d+56|0);yb(d+56|0);Ah(d+16|0);if(Gb(d+16|0,d+40|0)){continue}break}}g=x[a+480188>>1];v[22640]=0;g=Q(495,d+56|0,g|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break v}h=Yl(Rb(e));v[22640]=0;i=a+484344|0;R(364,i|0,h|0);h=v[22640];v[22640]=0;if((h|0)==1){break f}h=Rb(e);m=d,n=Sb(h),v[m+16>>2]=n;m=d,n=Wb(h),v[m+40>>2]=n;if(Gb(d+16|0,d+40|0)){while(1){h=v[d+16>>2];j=x[h>>1];if(Ze(f)>>>0>j>>>0){j=Hg(f,x[h>>1]);v[22640]=0;j=ca(496,j|0,w[d+172|0],g|0,a|0)|0;l=v[22640];v[22640]=0;if((l|0)==1){break f}u[h>>1]=j}mf(d+16|0);if(Gb(d+16|0,d+40|0)){continue}break}}h=Rb(e);v[22640]=0;h=Q(497,h|0,x[d+52>>1])|0;j=v[22640];v[22640]=0;if((j|0)==1){break f}if(!h){break u}if(!x[d+54>>1]){h=x[d+52>>1];j=Rb(e);v[22640]=0;j=T(493,j|0)|0;l=v[22640];v[22640]=0;if((l|0)==1){break f}if(h>>>0>=j>>>0){break u}}e=x[rc(Rb(e),x[d+52>>1])>>1];h=_b(i,e);v[22640]=0;j=Be(d+16|0,12,w[d+54|0]);l=v[22640];v[22640]=0;if((l|0)!=1){e=op(Qe(j,v[_b(i,e)+12>>2]-1|0));v[22640]=0;Q(458,h|0,e|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){break u}}break f}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}_C(g);fd(f)}v[22640]=0;U(491,d+56|0,k|0,1196641603);e=v[22640];v[22640]=0;if((e|0)==1){break h}od(b,d+56|0);yb(d+56|0);v[22640]=0;e=T(307,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break d}if(e){v[22640]=0;Q(350,b|0,1)|0;e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;e=T(492,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break d}v[22640]=0;ga(498,a+1298292|0,b|0,e|0,40,0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break d}}v[22640]=0;U(491,d+56|0,k|0,1146113363);e=v[22640];v[22640]=0;if((e|0)==1){break g}v[22640]=0;U(491,d+16|0,k|0,1229999443);e=v[22640];v[22640]=0;B:{C:{if((e|0)!=1){od(b,d+16|0);yb(d+16|0);v[22640]=0;f=T(353,b|0)|0;g=v[22640];v[22640]=0;e=1;D:{if((g|0)!=1){u[a+480190>>1]=f;if(x[a+480190>>1]){i=c&2;g=1;while(1){f=30;E:{F:{G:{if(w[d+172|0]>=2){v[22640]=0;f=T(353,b|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break G}}v[22640]=0;W(499,b|0,((e<<5)+a|0)+946304|0,f|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break G}v[22640]=0;R(500,b|0,d|0);c=v[22640];v[22640]=0;if((c|0)==1){break F}v[22640]=0;c=B(e,104)+a|0;f=c+484380|0;R(501,d|0,f|0);e=v[22640];v[22640]=0;if((e|0)==1){break F}e=w[d+172|0];if(e>>>0>=8){v[22640]=0;W(502,b|0,c+484423|0,8)|0;e=v[22640];v[22640]=0;if((e|0)==1){break F}e=w[d+172|0]}v[22640]=0;Q(350,b|0,((e&255)>>>0>1?6:2)|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break F}v[22640]=0;e=T(229,d+56|0)|0;h=v[22640];v[22640]=0;if((h|0)!=1){v[22640]=0;U(320,d+16|0,d+56|0,e|0);e=v[22640];v[22640]=0;if((e|0)!=1){break E}}a=P()|0;O()|0;break C}a=P()|0;O()|0;break C}a=P()|0;O()|0;break C}v[22640]=0;e=T(307,d+16|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break D}H:{if(!e|!i){break H}c=Pc(d+40|0,u[c+484414>>1]&1?16:8,1,0,(w[d+15|0]&12)==4?7:0);v[22640]=0;W(363,c|0,f|0,d+16|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break H}break D}yb(d+16|0);g=g+1|0;e=g&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}v[22640]=0;wg(a);c=v[22640];v[22640]=0;e=1;if((c|0)!=1){break B}}a=P()|0;O()|0;break C}a=P()|0;O()|0;yb(d+16|0);break C}a=P()|0;O()|0}yb(d+56|0);break c}v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;yb(d+56|0);yb(b);Cd(k)}gb=d+240|0;return e|0}a=P()|0;O()|0;Hb(d+80|0);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;_C(g)}fd(f);break c}a=P()|0;O()|0}yb(b)}Cd(k)}S(a|0);L()}function G2(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=gb-560|0;gb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+96>>2]=2485;r=ge(l+136|0,l+144|0,l+96|0);b=v[r>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;u=Kb(l+96|0);m=Kb(l+80|0);n=Kb(l- -64|0);o=Kb(l+48|0);s=Kb(l+32|0);v[22640]=0;na(2494,c|0,d|0,l+120|0,l+116|0,l+112|0,u|0,m|0,n|0,o|0,l+28|0);c=v[22640];v[22640]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;e=v[l+28>>2];k=0;f:{while(1){v[22640]=0;c=Q(2463,a|0,l+552|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}g:{if(!c){break g}h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{switch(t[(l+120|0)+p|0]){case 1:if((p|0)==3){break g}v[22640]=0;c=T(2465,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}v[22640]=0;c=W(2495,h|0,8192,c|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}if(c){v[22640]=0;R(2496,l+16|0,a|0);c=v[22640];v[22640]=0;if((c|0)!=1){c=v[l+16>>2];v[22640]=0;R(105,s|0,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){break p}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break m;case 2:break n;case 3:break o;case 0:break q;default:break h}}if((p|0)==3){break g}}while(1){v[22640]=0;c=Q(2463,a|0,l+552|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}if(!c){break h}v[22640]=0;c=T(2465,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}v[22640]=0;c=W(2495,h|0,8192,c|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}if(!c){break h}v[22640]=0;R(2496,l+16|0,a|0);c=v[22640];v[22640]=0;if((c|0)!=1){c=v[l+16>>2];v[22640]=0;R(105,s|0,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if((Ab(n)|0)==(0-Ab(o)|0)){break h}r:{if(Ab(n)){if(Ab(o)){break r}}if(Ab(n)){v[22640]=0;c=T(2465,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}if((c|0)!=v[Jb(n)>>2]){break l}v[22640]=0;T(2467,a|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}k=Ab(n)>>>0>1?n:k;break h}v[22640]=0;c=T(2465,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}if((c|0)!=v[Jb(o)>>2]){break h}v[22640]=0;T(2467,a|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}t[g|0]=1;k=Ab(o)>>>0>1?o:k;break h}v[22640]=0;c=T(2465,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}if((c|0)==v[Jb(n)>>2]){v[22640]=0;T(2467,a|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}k=Ab(n)>>>0>1?n:k;break h}v[22640]=0;c=T(2465,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}if((c|0)==v[Jb(o)>>2]){v[22640]=0;T(2467,a|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}t[g|0]=1;k=Ab(o)>>>0>1?o:k;break h}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(p>>>0<2|k|((p|0)==2&w[l+123|0]!=0|z))){k=0;break h}B=l,C=wd(m),v[B+8>>2]=C;c=Fd(l+16|0,l+8|0);s:{if(!p|w[(l+p|0)+119|0]>1){break s}B=l,C=ui(m),v[B+8>>2]=C;t:{if(!Gb(c,l+8|0)){break t}while(1){d=v[v[c>>2]>>2];v[22640]=0;d=W(2495,h|0,8192,d|0)|0;q=v[22640];v[22640]=0;if((q|0)==1){break k}if(!d){break t}Fg(c);B=l,C=ui(m),v[B+8>>2]=C;if(Gb(c,l+8|0)){continue}break}}B=l,C=wd(m),v[B+8>>2]=C;d=gv(c,l+8|0);if(Ab(s)>>>0>=d>>>0){B=l,C=ui(s),v[B+8>>2]=C;c=gb-16|0;gb=c;v[c+8>>2]=v[l+8>>2];v[c+8>>2]=v[c+8>>2]+(0-d<<2);d=v[c+8>>2];gb=c+16|0;q=ui(s);x=wd(m);c=gb-32|0;gb=c;v[c+16>>2]=q;v[c+24>>2]=d;v[c+8>>2]=x;d=1;u:{if(!Gb(c+24|0,c+16|0)){break u}while(1){d=Jk(v[c+24>>2],v[c+8>>2]);if(!d){break u}Fg(c+24|0);Fg(c+8|0);if(Gb(c+24|0,c+16|0)){continue}break}}gb=c+32|0;if(d){break s}}B=l,C=wd(m),v[B>>2]=C;Fd(l+8|0,l);v[l+16>>2]=v[l+8>>2]}v[l+8>>2]=v[l+16>>2];B=l,C=ui(m),v[B>>2]=C;v:{w:{x:{if(!Gb(l+8|0,l)){break x}while(1){v[22640]=0;c=Q(2463,a|0,l+552|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break w}if(!c){break x}v[22640]=0;c=T(2465,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break w}if((c|0)!=v[v[l+8>>2]>>2]){break x}v[22640]=0;T(2467,a|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break v}Fg(l+8|0);B=l,C=ui(m),v[B>>2]=C;if(Gb(l+8|0,l)){continue}break}}if(!y){break h}B=l,C=ui(m),v[B>>2]=C;if(!Gb(l+8|0,l)){break h}v[f>>2]=v[f>>2]|4;a=0;break f}a=P()|0;O()|0;v[l+28>>2]=e;break a}a=P()|0;O()|0;v[l+28>>2]=e;break a}c=0;x=v[l+112>>2];d=b;y:{while(1){z:{v[22640]=0;b=Q(2463,a|0,l+552|0)|0;q=v[22640];v[22640]=0;if((q|0)==1){break z}if(!b){break y}v[22640]=0;q=T(2465,a|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;b=W(2495,h|0,2048,q|0)|0;A=v[22640];v[22640]=0;if((A|0)==1){break e}A:{if(b){b=v[j>>2];if((b|0)==v[l+548>>2]){v[22640]=0;U(2497,i|0,j|0,l+548|0);b=v[22640];v[22640]=0;if((b|0)==1){break e}b=v[j>>2]}v[j>>2]=b+4;v[b>>2]=q;c=c+1|0;break A}if(!Ab(u)|!c|(q|0)!=(x|0)){break y}if(v[l+128>>2]==(d|0)){v[22640]=0;U(2491,r|0,l+132|0,l+128|0);b=v[22640];v[22640]=0;if((b|0)==1){break e}d=v[l+132>>2]}b=d+4|0;v[l+132>>2]=b;v[d>>2]=c;d=b;c=0}v[22640]=0;T(2467,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!c|v[r>>2]==(d|0)){break j}if(v[l+128>>2]==(d|0)){v[22640]=0;U(2491,r|0,l+132|0,l+128|0);b=v[22640];v[22640]=0;if((b|0)==1){break d}d=v[l+132>>2]}b=d+4|0;v[l+132>>2]=b;v[d>>2]=c;break i}t[g|0]=1;break h}a=P()|0;O()|0;v[l+28>>2]=e;break a}b=d}B:{if((e|0)<1){break B}v[22640]=0;c=Q(2464,a|0,l+552|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}C:{if(!c){v[22640]=0;c=T(2465,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}if((c|0)==v[l+116>>2]){break C}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22640]=0;T(2467,a|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break d}while(1){if((e|0)<1){e=0;break B}v[22640]=0;c=Q(2464,a|0,l+552|0)|0;d=v[22640];v[22640]=0;D:{if((d|0)==1){break D}E:{if(!c){v[22640]=0;c=T(2465,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break D}v[22640]=0;c=W(2495,h|0,2048,c|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break D}if(c){break E}}v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[22640]=0;U(2497,i|0,j|0,l+548|0);c=v[22640];v[22640]=0;if((c|0)==1){break D}}v[22640]=0;c=T(2465,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break D}d=v[j>>2];v[j>>2]=d+4;v[d>>2]=c;v[22640]=0;T(2467,a|0)|0;c=v[22640];v[22640]=0;e=e-1|0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(v[i>>2]!=v[j>>2]){break h}v[f>>2]=v[f>>2]|4;a=0;break f}p=p+1|0;if((p|0)!=4){continue}}break}v[l+28>>2]=e;F:{if(!k){break F}e=1;while(1){if(Ab(k)>>>0<=e>>>0){break F}v[22640]=0;c=Q(2464,a|0,l+552|0)|0;d=v[22640];v[22640]=0;G:{if((d|0)==1){break G}H:{if(!c){v[22640]=0;c=T(2465,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break G}if((c|0)==v[kk(k,e)>>2]){break H}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22640]=0;T(2467,a|0)|0;c=v[22640];v[22640]=0;e=e+1|0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;if(v[r>>2]==(b|0)){break f}a=0;v[l+16>>2]=0;gf(u,v[r>>2],b,l+16|0);if(v[l+16>>2]){v[f>>2]=v[f>>2]|4;break f}a=1}Hc(s);Hc(o);Hc(n);Hc(m);vb(u);Gc(r);gb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Hc(s);Hc(o);Hc(n);Hc(m);vb(u);Gc(r);S(a|0);L()}function wma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,T=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;d=gb-320|0;gb=d;a:{if(!Xc(b,1080)){break a}if(!ep(b,d+316|0)){break a}Gd(a,1);p=DV(d+296|0);if(!CV(d+316|0,p)){break a}f=x[p+8>>1];if((f-1&65535)>>>0>126){break a}if(!c){g=1;break a}u[a+480188>>1]=f;l=w[p+12|0];J=w[p+11|0];e=w[p+10|0];E=1;if(!je(d+316|0,33560)){E=je(d+316|0,33565)}if(w[p+13|0]){Ob(a+1074312|0,5,1);f=x[a+480188>>1]}n=je(d+316|0,13854);i=1;if(!je(d+316|0,14563)){i=je(d+316|0,10928)}C=a+480188|0;y=(f&65535)==8&(J|0)!=0;Xc(b,0);IC(b,a+1298268|0,20);u[a+480190>>1]=31;k=(e|0)!=0;g=1;e=n;while(1){o=B(g,104)+a|0;f=o+484380|0;q=SB(b,d+160|0,f,((g<<5)+a|0)+946304|0,x[a+480188>>1]==4);f=v[f>>2];b:{if(i){t[o+484417|0]=0-(w[d+184|0]<<3);break b}k=f>>>0<65536&k}if(Ib(w[d+182|0]|w[d+183|0]<<8)){K=!Ib(w[d+188|0]|w[d+189|0]<<8)|K}o=e&1;e=0;c:{if(!o){break c}h=(Ib(w[d+182|0]|w[d+183|0]<<8)<<1)+h|0;if(w[d+184|0]){break c}if(!Ib(w[d+182|0]|w[d+183|0]<<8)){e=1;break c}e=w[d+185|0]==64}F=q+F|0;j=f+j|0;g=g+1|0;if((g|0)!=32){continue}break}d:{e:{f:{g:{h:{i:{M=v[p+4>>2];if(M>>>0>=F>>>0){AV(b,d+160|0);Yb(b,4);o=d+160|1;i=w[o|0];g=128;f=a+484360|0;Fr(Rb(f),d+160|2,128);G=h;h=!i&e;q=h?G:0;e=w[d+160|0];j:{if(e>>>0>128){break j}g=e;if(e){break j}e=128;while(1){i=e-1|0;if(!x[rc(Rb(f),i)>>1]){g=1;e=i;if(e>>>0>1){continue}break j}break}g=e}H=(l|0)!=0;l=zV(b,Rb(f),g&65535,j,C,q,0);if(!(!h|x[a+480188>>1]!=8)){v[p>>2]=8603;H=1}k:{if(!y){break k}e=Rb(f);ca=d,da=Sb(e),v[ca+144>>2]=da;ca=d,da=Wb(e),v[ca+128>>2]=da;if(!Gb(d+144|0,d+128|0)){break k}while(1){e=v[d+144>>2];u[e>>1]=x[e>>1]>>>1;mf(d+144|0);if(Gb(d+144|0,d+128|0)){continue}break}}af(Rb(f),w[o|0]);N=g-1&65535;l:{if(N>>>0>=w[o|0]){g=x[C>>1];if(w[o|0]!=120|(g|0)!=4){break l}}af(Rb(f),0);g=x[C>>1]}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;h=0;e=Lb(256/((g&65535)>>>0)|0,32,128);v[a+480208>>2]=0;v[a+480228>>2]=e;rh(a,0);t[d+159|0]=0;q=1;m:{if(k){Q=1;j=1;break m}n:{if(!l){j=n;break n}s=d+144|5;j=n;k=0;i=0;while(1){e=0;g=0;while(1){f=Zi(d+144|0);_u(b,f);r=rv(f);o:{p:{q:{f=w[d+147|0];if((f-7&255)>>>0<3){j=0;break q}j=r?j:0;r:{s:{t:{switch(f-13|0){case 2:if(w[d+149|0]>31){break s}break o;case 1:break r;case 0:break t;default:break q}}g=g+1|0;if((g&65535)>>>0<2){break o}}j=0;break o}f=w[d+149|0];j=f>>>0>1?0:j;break p}if((f|0)!=8){if((f|0)!=14){break o}f=w[d+149|0];break p}ca=d,da=w[Bf(d+159|0,s)|0],t[ca+159|0]=da;f=t[d+149|0];if((f|0)>-1){i=1;break o}k=(f|0)!=-92&(f&255)>>>0>143|k;break o}if((f&240)!=128){break o}t[d+128|0]=f<<4;ca=d,da=w[Bf(d+159|0,d+128|0)|0],t[ca+159|0]=da}q=q&r;e=e+1|0;if((e|0)!=256){continue}break}h=h+1|0;if(l>>>0>(h&65535)>>>0){continue}break}h=0;if((i^-1|k)&1){break n}h=w[d+159|0]>47}Q=j&1;j=h^1}Xc(b,1084);e=x[a+480188>>1];s=a+484344|0;z=l+y&65535;vg(s,z);T=y?4:e;l=a+1074312|0;u:{if(!z){z=0;break u}aa=c&1;V=T&65535;k=0;v:{w:{while(1){x:{if(y){e=(k&65534)>>>1|0;g=k&1;if(!g){if(!qh(s,e,64)){break u}}i=Tc(_b(s,e),0,g<<2);break x}if(!qh(s,k&65535,64)){break u}i=Tc(_b(s,k),0,0)}if(!i|!aa){break u}e=x[a+480188>>1];t[d+128|0]=0;r=Dv(d+144|0,e,d+128|0);e=x[a+480188>>1];v[22640]=0;t[d+64|0]=0;D=W(796,d+128|0,e|0,d- -64|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){I=0;while(1){G=m;y:{if(V){f=0;X=0;g=0;while(1){v[22640]=0;h=B(f,6)+i|0;R(797,b|0,h|0);e=v[22640];v[22640]=0;if((e|0)==1){break w}e=w[h+3|0];z:{A:{B:{if(!e){if(w[h+5|0]){break B}break A}if(!J){break B}C:{switch(e-14|0){case 0:t[h+3|0]=0;t[h+5|0]=0;break B;case 1:break C;default:break B}}if(w[h+5|0]<32){break B}t[h+5|0]=31}Mf(h);e=1;D:{E:{F:{m=w[h+3|0];switch(m-14|0){case 2:break z;case 0:break E;case 3:break F;default:break D}}Y=w[h+5|0]<100|Y;X=1;break A}if(!Q){break A}t[h+5|0]=0;break A}if(!((m|0)!=9|j)){e=w[h+5|0];if((e|0)==164){t[h+3|0]=20;t[h+5|0]=145;break A}ca=h,da=di(e<<1),t[ca+5|0]=da;break A}if((m|0)!=19){break A}e=w[h+5|0];if(e>>>0>15){break A}m=e&1;e=!m;ba=!m;m=Z&1;Z=(m|0)==(e|0)?Z:ba;_=((e|0)!=(m|0))+_|0}e=g}G:{if(!w[h|0]){if(!w[h+1|0]|y){break G}if(!w[kc(r,f)|0]){break G}if(w[kc(r,f)|0]==w[h+1|0]){break G}m=kc(D,f);g=w[m|0]+1|0;t[m|0]=g;if((g&255)>>>0<4){break G}v[22640]=0;W(437,l|0,85,1)|0;g=v[22640];v[22640]=0;if((g|0)==1){break w}break G}ca=kc(D,f),da=0,t[ca|0]=da}g=w[h+1|0];if(g){ca=kc(r,f),da=g,t[ca|0]=da}g=e;f=f+1|0;if((V|0)!=(f|0)){continue}break}e=e&X;break y}e=0}m=G|e;i=B(x[C>>1],6)+i|0;I=I+1|0;if((I|0)!=64){continue}break}gc(D);gc(r);k=k+1|0;if((z|0)==(k|0)){break u}continue}break}f=P()|0;O()|0;break v}f=P()|0;O()|0;gc(D)}gc(r);break d}H:{I:{J:{e=q^1;if((e|K)&1){break J}K:{if(je(d+316|0,13854)){break K}if(je(d+316|0,14568)){break K}if(!je(d+316|0,10923)){break J}}v[a+480208>>2]=v[a+480208>>2]|2162688;Ob(l,85,1);Ob(l,91,1);Ob(l,92,1);L:{if(w[d+159|0]>47){break L}Ob(l,84,1);if(w[o|0]==127){break L}Ob(l,83,1)}if(!q){break H}break I}if(q){break I}if(n^1|w[o|0]!=127|w[o|0]+1>>>0<N>>>0){break H}v[p>>2]=5565;break H}if((_|0)>6|H){break H}v[a+480208>>2]=v[a+480208>>2]|8388608}if((n|H)==1){Ob(l,89,1)}if(E){Ob(l,84,1)}M:{if(!(c&2)){k=n^1;break M}Xc(b,(B(T&65535,z)<<8)+1084|0);k=n^1;n=e|k;g=1;while(1){j=B(g,104)+a|0;c=j+484380|0;if(v[c>>2]){i=d+144|0;if(E){e=2}else{e=yV(b,11209)?11:0}e=Pc(i,8,1,0,e);i=v[b+8>>2]+pv(e,v[c>>2])|0;if(!n){ca=c,da=v[Jc(c,j+484388|0)>>2],v[ca>>2]=da}zg(e,c,b);Xc(b,i)}g=g+1|0;if((g|0)!=32){continue}break}}N:{if((Y^-1|k|m)&1){break N}b=xV(d+104|0,0);c=v[b+20>>2];v[d+40>>2]=v[b+16>>2];v[d+44>>2]=c;c=v[b+12>>2];v[d+32>>2]=v[b+8>>2];v[d+36>>2]=c;c=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=c;mu(d+144|0,a,0,d+24|0);$=A[v[d+144>>2]>>3];en(d+144|0);if($<600){break N}Ob(l,5,1);b=wV(d+80|0,$);c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;mu(d+144|0,a,0,d);b=w[v[d+144>>2]+26|0];en(d+144|0);if(b){Yf(l,5);break N}v[p>>2]=14171}c=ec(d+316|0);g=c;n=d+316|0;e=n;b=e;if((g|0)!=(e|0)){while(1){j=w[e|0];t[b|0]=j>>>0>32?j:32;b=b+1|0;e=e+1|0;if((g|0)!=(e|0)){continue}break}}Df(d+128|0,13941);v[22640]=0;b=W(798,d+48|0,n|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break i}v[22640]=0;U(13,d- -64|0,1,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break h}v[22640]=0;U(204,d+144|0,d+128|0,d- -64|0);c=v[22640];v[22640]=0;if((c|0)==1){break g}Eb(a+1298304|0,d+144|0);vb(d+144|0);vb(d- -64|0);vb(b);Hb(d+128|0);b=Tb(d+144|0,9606);Eb(a+1298316|0,b);vb(b);b=v[p>>2];if(b){Vc(a+1298328|0,b)}v[a+1298364>>2]=2}g=F>>>0<=M>>>0;break a}f=P()|0;O()|0;break e}f=P()|0;O()|0;break f}f=P()|0;O()|0;vb(d- -64|0)}vb(b)}Hb(d+128|0)}S(f|0);L()}gb=d+320|0;return g|0}function hla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-272|0;gb=d;vc(b);f=gb-32|0;gb=f;h=d+120|0;xU(f+24|0,h);i=xb(f+24|0);e=v[f+28>>2];g=v[f+24>>2];v[f+8>>2]=g;v[f+12>>2]=e;v[f>>2]=g;v[f+4>>2]=e;e=b;fc(f+16|0,e,f);g=xb(f+16|0);if((g|0)==(i|0)){Yb(e,xb(f+24|0))}gb=f+32|0;e=(g|0)==(i|0);if(!e){wU(h)}a:{b:{c:{d:{e:{if(!e){break e}if(!EU(d+120|0)){break e}if(!c){k=1;break e}Gd(a,4194304);e=Tb(d+32|0,14130);Eb(a+1298304|0,e);vb(e);e=Tb(d+32|0,7463);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;m=a,n=Jd(w[d+198|0]|w[d+199|0]<<8,w[d+200|0]|w[d+201|0]<<8,127),u[m+480188>>1]=n;e=w[d+189|0];v[a+480228>>2]=(e|0)==255?48:e;v[a+480196>>2]=w[d+187|0];v[a+480204>>2]=B(w[d+188|0],1e4);nf(d+96|0,d+120|4,59,3);Bc(d+32|0,d+96|0);Eb(a+1298268|0,d+32|0);vb(d+32|0);f:{if((w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))>>>0<5){break f}if(!Xc(b,(w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))-4|0)){break f}if(!Fh(b,11512)){break f}hp(Rb(a+484360|0),b,w[d+192|0]|w[d+193|0]<<8,65535,65535)}g:{if((w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))>>>0<5){break g}if(!Xc(b,(w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))-4|0)){break g}if(!Fh(b,11168)){break g}while(1){e=(k<<5)+a|0;Se(e+480280|0);m=e+480284|0,n=((((de(b)^-1)&15)<<8|8)>>>0)/15|0,u[m>>1]=n;k=k+1|0;if((k|0)!=32){continue}break}}h:{if((w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))>>>0<5){break h}if(!Xc(b,(w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))-4|0)){break h}if(!Fh(b,11444)){break h}rd(d+96|0,b,(w[d+196|0]|w[d+197|0]<<8)<<6);i:{if(!(w[d+196|0]|w[d+197|0]<<8)){break i}k=c&2;i=a+480190|0;h=d+45|0;while(1){v[22640]=0;e=Q(886,d+96|0,d+32|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break d}if(!e){break i}e=w[d+77|0]|w[d+78|0]<<8;u[d+30>>1]=e;j:{if((e-1&65535)>>>0>3998){break j}if(Ld((B(e,104)+a|0)+484380|0)){break j}v[22640]=0;e=Ie(i,d+30|0);f=v[22640];v[22640]=0;if((f|0)==1){break c}u[a+480190>>1]=x[e>>1];v[22640]=0;R(887,d+32|0,(B(x[d+30>>1],104)+a|0)+484380|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}nf(d,h,24,1);v[22640]=0;R(377,d+16|0,d|0);e=v[22640];v[22640]=0;k:{if((e|0)!=1){v[22640]=0;Q(333,((x[d+30>>1]<<5)+a|0)+946304|0,d+16|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break k}vb(d+16|0);if(!k){break j}e=w[d+69|0]|w[d+70|0]<<8|(w[d+71|0]<<16|w[d+72|0]<<24);v[22640]=0;Q(227,b|0,e|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break c}f=1;e=d+79|0;g=Pc(d+16|0,w[e|0]&4?16:8,1,0,0);l:{m:{if(w[e|0]&8){break m}f=2;if(w[e|0]&16){break m}if(w[e|0]&127){break l}}zf(g,f)}v[22640]=0;W(363,d+16|0,(B(x[d+30>>1],104)+a|0)+484380|0,b|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){break j}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(d+16|0);break b}j=j+1|0;if((j&65535)>>>0<(w[d+196|0]|w[d+197|0]<<8)>>>0){continue}break}}yb(d+96|0)}k=1;if(!(c&1)){break e}n:{if((w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))>>>0<5){break n}if(!Xc(b,(w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))-4|0)){break n}if(!Fh(b,11034)){break n}h=a+484344|0;vg(h,w[d+194|0]|w[d+195|0]<<8);if(!(w[d+194|0]|w[d+195|0]<<8)){break n}i=d+16|2;f=0;while(1){if(!iC(b,d+16|0)){break n}if((w[d+16|0]|w[d+17|0]<<8)>>>0>3){rd(d+32|0,b,((w[d+16|0]|w[d+17|0]<<8)+15&131056)-4|0);c=w[i|0];v[22640]=0;c=W(365,h|0,f&65535,c|0)|0;e=v[22640];v[22640]=0;o:{if((e|0)!=1){p:{j=0;if(!c){break o}while(1){v[22640]=0;c=Q(228,d+32|0,1)|0;e=v[22640];v[22640]=0;q:{r:{s:{if((e|0)!=1){if(!c|w[i|0]<=j>>>0){break r}v[22640]=0;e=T(353,d+32|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break p}if(e){break s}j=j+1|0;continue}break p}c=_b(h,f);u[d+96>>1]=e&31;g=x[a+480188>>1];v[22640]=0;u[d>>1]=g-1;g=Oc(d+96|0,d);l=v[22640];v[22640]=0;if((l|0)==1){break p}g=x[g>>1];v[22640]=0;c=Tc(c,j,g);g=v[22640];v[22640]=0;if((g|0)==1){break p}if(e&128){v[22640]=0;R(431,d+96|0,d+32|0);g=v[22640];v[22640]=0;if((g|0)==1){break p}g=md(d+96|0);t[c|0]=w[d+96|0]+36;t[c+1|0]=w[g|0]}if(!(e&64)){break q}t[c+2|0]=1;v[22640]=0;g=T(353,d+32|0)|0;l=v[22640];v[22640]=0;t:{if((l|0)!=1){t[d+96|0]=g;v[22640]=0;t[d|0]=64;g=ac(d+96|0,d);l=v[22640];v[22640]=0;if((l|0)==1){break t}t[c+4|0]=w[g|0];break q}break p}break p}if(w[i|0]==64){break o}c=_b(h,f);v[22640]=0;e=Be(d+96|0,14,0);j=v[22640];v[22640]=0;if((j|0)!=1){e=Eh(Qe(e,w[i|0]-1|0));v[22640]=0;Q(458,c|0,e|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break o}}break p}if(!(e&32)){continue}v[22640]=0;R(431,d+96|0,d+32|0);e=v[22640];v[22640]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((e|0)!=1){e=w[md(d+96|0)|0];t[c+5|0]=e;switch(w[d+96|0]-1|0){case 71:break v;case 70:break w;case 69:break x;case 60:break y;case 59:break z;case 52:break A;case 51:break B;case 50:break C;case 49:break D;case 42:break E;case 41:break F;case 40:break G;case 39:break H;case 30:break I;case 29:break J;case 22:break K;case 21:break L;case 20:break M;case 19:break N;case 16:break O;case 15:break P;case 14:break Q;case 13:break R;case 12:break S;case 11:break T;case 10:break U;case 9:break V;case 3:break W;case 2:break X;case 1:break Y;case 0:break Z;default:break u}}break p}t[c+3|0]=11;t[c+5|0]=e<<4|15;continue}t[c+3|0]=11;t[c+5|0]=e<<4;continue}t[c+3|0]=11;t[c+5|0]=e|240;continue}t[c+3|0]=11;t[c+5|0]=e&15;continue}t[c+3|0]=2;t[c+5|0]=e|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=e|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=e|16;continue}t[c+3|0]=6;t[c+5|0]=e<<4;continue}t[c+3|0]=6;t[c+5|0]=e&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=e|48;continue}t[c+3|0]=7;t[c+5|0]=e<<4;continue}t[c+3|0]=7;t[c+5|0]=e&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=e|64;continue}t[c+3|0]=10;v[22640]=0;e=T(353,d+32|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){t[c+5|0]=e;v[22640]=0;Q(350,d+32|0,1)|0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}}break p}t[c+3|0]=15;t[c+5|0]=e&15;continue}t[c+3|0]=20;t[c+5|0]=e|192;continue}t[c+3|0]=20;t[c+5|0]=e|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=e|176;continue}t[c+3|0]=20;t[c+5|0]=e|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=e&15|32;continue}t[c+3|0]=20;t[c+5|0]=e&15|128;continue}t[c+3|0]=0;continue}}}b=P()|0;O()|0;yb(d+32|0);break a}yb(d+32|0)}f=f+1|0;if(f>>>0<(w[d+194|0]|w[d+195|0]<<8)>>>0){continue}break}}if(!(w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24))){break e}Xc(b,w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24));dB(a+1298292|0,b,Kg(b),4)}gb=d+272|0;return k|0}b=P()|0;O()|0;break b}b=P()|0;O()|0}yb(d+96|0)}S(b|0);L()}function ku(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-32|0;gb=h;v[h+28>>2]=c;a:{if((c|0)<1){break a}l=v[b+104>>2];i=v[b+656>>2];if(!(!i|v[a+480180>>2]!=16777216)){n=v[i+44>>2]!=0}b:{if(!(!i|(c|0)>128)){k=x[sd(i+236|0,c-1|0)>>1];c:{if((k-1&65535)>>>0<=3998){l=(B(k,104)+a|0)+484380|0;break c}Db(h+16|0,a+1074312|0,43);if(!Cb(h+16|0)){break c}if(!rk(b)){break a}}k=w[lc(i+108|0,v[h+28>>2]-1|0)|0];v[h+28>>2]=k;break b}k=c}if((k|0)>=121){d:{if(!(v[a+480180>>2]&16777248?(k|0)!=255:0)){Bo(a,b);if(d){break d}Db(h+16|0,a+1074312|0,100);if(!Cb(h+16|0)|!(w[a+480208|0]&4)|!w[b+789|0]){break d}v[b+88>>2]=v[b+88>>2]&-6145;break d}if(!x[a+480192>>1]){break d}v[b+88>>2]=v[b+88>>2]|4096}e:{if(v[h+28>>2]!=254){break e}f:{c=v[b+88>>2];if(!(c&512)){break f}c=v[b+88>>2];if(v[a+480180>>2]!=2){break f}v[b+88>>2]=c|2048;break e}v[b+88>>2]=c|2101248;g:{if(v[a+480180>>2]&16777248){if(!x[a+480192>>1]){break g}Db(h+16|0,a+1074312|0,50);if(Cb(h+16|0)){break g}}v[b+688>>2]=0}Db(h+16|0,a+1074312|0,50);if(Cb(h+16|0)){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}Db(h+16|0,a+1074312|0,20);if(!Cb(h+16|0)){break a}t[b+797|0]=0;t[b+802|0]=0;break a}h:{i:{j:{if(n){if(d){j=w[b+797|0];if(j){break j}}v[b+708>>2]=0}if(d){break i}if(!(!(v[a+480180>>2]&1048588)|!l)){u[b+770>>1]=t[l+36|0];u[b+772>>1]=t[l+37|0]}if(l){Db(h+16|0,a+1074312|0,24);k=0;m=1;if(!Cb(h+16|0)){break h}v[b+704>>2]=v[l+24>>2];break h}k=0;break h}m=v[i+44>>2];u[h>>1]=j;u[h+14>>1]=k;v[h+16>>2]=0;k=(v[h+16>>2]+B(u[m+36>>1]+1|0,u[h+14>>1]-u[h>>1]|0)|0)-v[b+852>>2]|0;v[b+708>>2]=k;v[b+852>>2]=0-k}m=(l|0)!=0;k=1;if(Ki(b)){break h}k=a+1074312|0;Db(h+16|0,k,54);if(Cb(h+16|0)){v[b+700>>2]=0;break a}Db(h+16|0,k,39);k=(Cb(h+16|0)^-1)&d}k:{if(fp(a)){v[h+28>>2]=v[h+28>>2]+u[b+770>>1];Qd(h+28|0,12,131);break k}dV(h+28|0)}j=a+1074312|0;Db(h+16|0,j,34);d=b;l:{if(Cb(h+16|0)){c=pn(c);break l}c=v[h+28>>2]}t[d+797|0]=c;t[b+851|0]=w[b+851|0]&219|32;if(!(v[a+480180>>2]&16777250?0:k)){t[b+803|0]=0}d=Yg(a,v[h+28>>2],u[b+772>>1],v[b+704>>2]);t[b+831|0]=0;Db(h+16|0,j,48);if(Cb(h+16|0)){QP(a,b,i,l)}m:{if(e^1|k){break m}v[b+776>>2]=0;v[b+780>>2]=0;if(!i){break m}Db(h+16|0,j,29);if(Cb(h+16|0)){t[b+798|0]=w[i+16|0]}if(!(w[i+60|0]&8)){Dj(b+724|0)}if(!(w[i+80|0]&8)){Dj(b+732|0)}if(!(w[i+100|0]&8)){Dj(b+740|0)}if(w[i+20|0]){c=iu(Ao(a));o=w[i+20|0];Db(h+16|0,j,28);p=((B(c,o)<<16>>16)/64<<16)+65536>>16;c=b;n:{if(Cb(h+16|0)){o=v[b+752>>2];break n}o=(v[b+688>>2]+1|0)/2|0}u[c+776>>1]=(B(o,p)|0)/199}o:{if(!w[i+19|0]){break o}q=b,r=(B(iu(Ao(a)),w[i+19|0])<<16>>16)/32|0,u[q+778>>1]=r;Db(h+16|0,j,28);if(Cb(h+16|0)|x[b+784>>1]){break o}u[b+784>>1]=x[b+692>>1]+1}c=w[i+23|0];if(c){o=iu(Ao(a));p=w[b+837|0];t[b+796|0]=p+1;u[b+780>>1]=(B(p,(B(c,o+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=w[i+24|0];if(!c){break m}o=iu(Ao(a));p=w[b+838|0];t[b+795|0]=p+1;u[b+782>>1]=(B(p,(B(c,o+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!m){break a}m=0;p:{q:{if(!d){break q}r:{s:{t:{if(k){u:{if(!v[b+700>>2]){v[b+700>>2]=d;if(!n){break u}break t}if(n){break t}}v[b+708>>2]=d;t[b+851|0]=w[b+851|0]&247;break t}v[b+700>>2]=d;if(n){break s}Db(h+16|0,j,69);if(Cb(h+16|0)){break s}Db(h,j,46);if(Cb(h)|v[a+480180>>2]==1){break s}v[b+708>>2]=d;t[b+851|0]=w[b+851|0]&247;break s}if(v[b+76>>2]|v[a+480180>>2]&2){break r}}v[b+104>>2]=l;c=v[l>>2];v[b+84>>2]=c;v[b+76>>2]=c;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;v:{w:{if(!(v[a+480208>>2]&2097152)){Db(h+16|0,j,96);if(!Cb(h+16|0)){break w}}if(w[b+789|0]){break w}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Fb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break v}v[b+660>>2]=0}c=x[l+34>>1];d=c&1023;n=d|v[b+88>>2]&-525056;v[b+88>>2]=n;x:{y:{if(c&8){v[b+80>>2]=v[l+12>>2];c=v[l+16>>2];v[b+88>>2]=(d&16?n|4:n&-524295)|2;v[b+84>>2]=c;if(y[b+76>>2]>c>>>0){break y}break x}if(!(d&2)){break x}v[b+80>>2]=v[l+4>>2];c=v[l+8>>2];v[b+84>>2]=c;if(y[b+76>>2]<=c>>>0){break x}}v[b+76>>2]=c}Db(h+16|0,j,83);if(!(!Cb(h+16|0)|v[b+80>>2])){c=v[l>>2];v[b+84>>2]=c;v[b+76>>2]=c}c=v[b+88>>2];if(c&128){v[b+88>>2]=c|128;v[b+4>>2]=v[b+76>>2]-1}z:{if(w[b+822|0]>3){break z}Db(h+16|0,j,21);c=b;A:{if(!(Cb(h+16|0)|!(v[a+480180>>2]&16777248))){d=16;if(!(v[a+480208>>2]&4)){break A}}d=32;if(v[a+480180>>2]==16){break A}if(v[a+480180>>2]&67633152){break z}d=0}t[c+819|0]=d}Db(h+16|0,j,21);if(Cb(h+16|0)|w[b+825|0]>3){break r}t[b+820|0]=0}d=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){c=d;d=v[b+80>>2];v[b>>2]=c;v[b+4>>2]=d}if(!k){break q}m=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break q}if(!(w[a+480208|0]&8)|!w[b+789|0]){break p}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){Km(b);Db(h+16|0,j,21);if(!Cb(h+16|0)){t[b+818|0]=0;v[b+756>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}if(!(w[b+789|0]|(!m|!(w[a+480208|0]&8)))){m=1;break p}if(w[b+789|0]?0:v[a+480180>>2]&1048580){break p}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}Db(h+16|0,j,40);B:{C:{D:{E:{if(Cb(h+16|0)){if(m){if(w[b+789|0]?w[a+480208|0]&8:0){break D}v[b+88>>2]=v[b+88>>2]&-4194305;break C}c=v[b+88>>2]&-4196353;break E}c=v[b+88>>2]&-4196353;v[b+88>>2]=c;l=1;if(m){break B}}u[b+842>>1]=65535;v[b+88>>2]=c&-6326273|2097152;Db(h+16|0,j,23);F:{if(Cb(h+16|0)){break F}Db(h,j,22);if(Cb(h)){break F}Db(h+16|0,j,52);if(Cb(h+16|0)){break F}Db(h,j,71);if(Cb(h)){break F}t[b+839|0]=0;t[b+808|0]=0}if(e){t[b+818|0]=0;v[b+756>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;G:{if(i){H:{I:{if(!OE(i)){if(lw(i)){break I}c=!(c>>>13|0);if(c){break H}break G}q=b,r=PE(i),t[q+838|0]=r;if(!lw(i)){break H}}q=b,r=QE(i),t[q+837|0]=r}c=1;d=w[i+25|0];if((d|0)==255){break G}t[b+845|0]=d;break G}v[b+776>>2]=0;v[b+780>>2]=0;c=!c}J:{if(w[b+837|0]>=127){Db(h+16|0,j,36);if(!Cb(h+16|0)){break J}}if(!c){break J}if((Oq(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break J}c=a+1298260|0;if(!Bd(c)|(g|0)==65535){break J}Vq(v[c>>2],g,w[b+837|0]>>>1|0,1)}l=0;if(!(w[b+89|0]&2)){break B}c=a+1298260|0;if(!Bd(c)|(g|0)==65535){break B}Db(h+16|0,j,111);if(Cb(h+16|0)){uk(v[c>>2],g);break B}Db(h+16|0,j,110);if(!Cb(h+16|0)){break B}JA(v[c>>2],g,0,1,0);break B}v[b+88>>2]=v[b+88>>2]&-4196353}l=1}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}K:{L:{if(w[a+24618|0]&16?c&1024:0){break L}a=v[b+104>>2];if(!(f?1:!a|!(w[a+35|0]&4))){break L}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break K}}if(f){break K}v[b+700>>2]=0}if(l){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}gb=h+32|0}function Poa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;d=gb-1328|0;gb=d;vc(b);f=gb-32|0;gb=f;j=d+752|0;pX(f+24|0,j);k=xb(f+24|0);h=v[f+28>>2];l=v[f+24>>2];v[f+8>>2]=l;v[f+12>>2]=h;v[f>>2]=l;v[f+4>>2]=h;h=b;fc(f+16|0,h,f);l=xb(f+16|0);if((l|0)==(k|0)){Yb(h,xb(f+24|0))}gb=f+32|0;h=(k|0)==(l|0);if(!h){oX(j)}a:{b:{c:{d:{if(!h){break d}if(!sX(d+752|0)){break d}if(!Pb(b,Uc(rX(d+752|0),jb))){break d}if(!c){e=1;break d}o=wr(d+744|0);q=1;e:{while(1){h=(e<<5)+a|0;f=h+480280|0;Se(f);k=(d+752|0)+(e<<4)|0;u[h+480284>>1]=((w[k+78|0]<<8&65280)>>>0)/255;Gk(d+480|0,1,k- -64|0);Bc(d+96|0,d+480|0);v[22640]=0;Q(427,h+480289|0,d+96|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break c}vb(d+96|0);f:{g:{switch(w[k+79|0]){case 0:i=e+1|0;break f;case 1:v[f>>2]=1024;i=g+1|0;break f;case 2:break g;default:break e}}v[f>>2]=1024;nl(d+96|0,o,e);Af(d+96|0,1)}q=e>>>0<31;g=g+1|0;e=e+1|0;if((e|0)!=32){continue}break}Gd(a,33554432);u[a+480188>>1]=i&255;e=Tb(d+96|0,3836);Eb(a+1298304|0,e);vb(e);e=Tb(d+96|0,8397);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;h:{if(w[d+831|0]){break h}g=1;while(1){if(w[((g<<4)+d|0)+831|0]!=1){break h}e=1;g=g+1|0;if((g|0)!=16){continue}break}while(1){i=((e<<5)+a|0)+480280|0;v[i>>2]=v[i>>2]&-1025;e=e+1|0;if((e|0)!=16){continue}break}}_e(d+480|0,1,d+752|0);Bc(d+96|0,d+480|0);Eb(a+1298268|0,d+96|0);vb(d+96|0);v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+790|0]|w[d+791|0]<<8)<<4&16;v[a+480196>>2]=w[d+800|0];v[a+480204>>2]=B(w[d+801|0],1e4);A=a,C=Jd(w[d+802|0],0,64)<<2,v[A+480200>>2]=C;A=a,C=Jd(w[d+803|0],4,127),v[A+480228>>2]=C;e=w[d+788|0]|w[d+789|0]<<8;u[a+480190>>1]=0;u[a+480192>>1]=e;cw(b,d+480|0);Or(Rb(a+484360|0),d+480|0,w[d+784|0]|w[d+785|0]<<8,65535,255);r=c&1;if(r){vg(a+484344|0,w[d+786|0]|w[d+787|0]<<8)}if(w[d+786|0]|w[d+787|0]<<8){s=a+484344|0;while(1){e=Kg(b);n=Kg(b);rd(d+96|0,b,e-4|0);i:{if(!r){break i}v[22640]=0;e=W(365,s|0,m&65535,n|0)|0;i=v[22640];v[22640]=0;if((i|0)!=1){j:{if(!e){break i}l=0;k=Zi(d+8|0);if(!n){break i}while(1){k:{v[22640]=0;h=T(353,d+96|0)|0;e=v[22640];v[22640]=0;l:{m:{if((e|0)!=1){if(h){break m}l=l+1|0;break l}break j}e=k;p=h&31;if(p>>>0<x[a+480188>>1]){e=_b(s,m);v[22640]=0;e=Tc(e,l,p);i=v[22640];v[22640]=0;if((i|0)==1){break j}}n:{if(!(h&32)){break n}v[22640]=0;R(431,d+32|0,d+96|0);g=v[22640];v[22640]=0;j=e;o:{p:{if((g|0)!=1){f=md(d+32|0);g=w[d+32|0];t[e|0]=g;t[e+1|0]=w[f|0];if((g|0)!=160){break p}i=255;break o}break j}if((g|0)!=255){t[e|0]=(B(g>>>4|0,12)+(g&15)|0)+13;v[22640]=0;f=LC(e);g=v[22640];v[22640]=0;if((g|0)!=1){i=0;if(!f){break o}break n}break j}i=0}t[j|0]=i}i=h&192;q:{if(!i){break q}if((i|0)==192){v[22640]=0;R(550,d+32|0,d+96|0);i=v[22640];v[22640]=0;r:{s:{t:{if((i|0)!=1){f=md(d+32|0);g=Re(d+32|0);i=aj(d+32|0);j=d+32|0;z=w[j|0];if((z|0)!=12){break t}v[22640]=0;t[d|0]=64;h=ac(f,d);f=v[22640];v[22640]=0;if((f|0)==1){break j}t[e+4|0]=w[h|0];h=1;break s}break j}h=w[g|0];u:{if((h|0)==12){v[22640]=0;t[d|0]=64;i=ac(i,d);h=v[22640];v[22640]=0;if((h|0)!=1){t[e+4|0]=w[i|0];h=1;break u}break j}if((z|0)==10){t[e+4|0]=(w[f|0]<<6>>>0)/255;h=2;break s}if((h|0)!=10){break r}t[e+4|0]=(w[i|0]<<6>>>0)/255;h=2}g=j;i=f}t[e+2|0]=h;h=w[g|0]}t[e+3|0]=h;t[e+5|0]=w[i|0];break q}v[22640]=0;R(431,d+32|0,d+96|0);i=v[22640];v[22640]=0;if((i|0)==1){break j}i=md(d+32|0);t[e+3|0]=w[d+32|0];t[e+5|0]=w[i|0]}if(w[e+3|0]){v[22640]=0;_(573,e|0);i=v[22640];v[22640]=0;if((i|0)==1){break j}}nl(d+32|0,o,p);if(!Cb(d+32|0)){break l}v[22640]=0;i=qX(e);h=v[22640];v[22640]=0;if((h|0)==1){break k}if(!i){break l}t[e+3|0]=0}if(l>>>0<n>>>0){continue}break i}break}}}e=P()|0;O()|0;yb(d+96|0);break b}yb(d+96|0);m=m+1|0;if(m>>>0<(w[d+786|0]|w[d+787|0]<<8)>>>0){continue}break}}if(!x[a+480192>>1]){break e}n=c&2;h=1;i=1;while(1){m=h&65535;g=RO(a,m,0);e=gb-32|0;gb=e;k=d+96|0;bc(e+24|0,k,384);f=xb(e+24|0);c=v[e+28>>2];j=v[e+24>>2];v[e+8>>2]=j;v[e+12>>2]=c;v[e>>2]=j;v[e+4>>2]=c;c=b;fc(e+16|0,c,e);j=xb(e+16|0);if((j|0)==(f|0)){Yb(c,xb(e+24|0))}gb=e+32|0;c=(f|0)==(j|0);if(!c){Qb(k,0,384)}if(!(!c|!g)){k=i&65535;c=gb-32|0;gb=c;f=d+96|0;_e(c,1,f);Bc(c+16|0,c);v[22640]=0;Q(333,g+492|0,c+16|0)|0;e=v[22640];v[22640]=0;v:{if((e|0)!=1){vb(c+16|0);w:{if(!(w[f+378|0]|w[f+379|0]<<8)){break w}v[c+16>>2]=120;v[c>>2]=116;if(!v[Fb(c+16|0,c)>>2]){break w}j=g+236|0;e=0;while(1){l=w[(e+f|0)+32|0];A=sd(j,e+12|0),C=k+l|0,u[A>>1]=C;v[c+16>>2]=120;v[c>>2]=116;e=e+1|0;if(e>>>0<y[Fb(c+16|0,c)>>2]){continue}break}}e=w[f+376|0]|w[f+377|0]<<8;t[g+33|0]=1;v[g>>2]=e;KC(f,g+48|0,0);KC(f,g+68|0,1);KC(f,g+88|0,2);e=w[g+100|0];if(e&1){t[g+100|0]=e|16}if(!(v[g>>2]|t[g+60|0]&1)){v[g>>2]=32767}gb=c+32|0;break v}break a}e=0;x:{if(!(w[d+474|0]|w[d+475|0]<<8)){break x}while(1){y:{YX(b,d+32|0);z:{if((w[d+92|0]|w[d+93|0]<<8|(w[d+94|0]<<16|w[d+95|0]<<24))!=808538953){break z}c=e+i|0;j=c&65535;if(j>>>0>3999){break z}u[a+480190>>1]=c;c=gb-32|0;gb=c;l=B(j,104)+a|0;k=l+484380|0;f=k;td(f,0);g=d+32|0;Yj(c,1,g);Bc(c+16|0,c);v[22640]=0;Q(335,f+43|0,c+16|0)|0;o=v[22640];v[22640]=0;A:{if((o|0)!=1){vb(c+16|0);v[f>>2]=w[g+16|0]|w[g+17|0]<<8|(w[g+18|0]<<16|w[g+19|0]<<24);v[f+4>>2]=w[g+20|0]|w[g+21|0]<<8|(w[g+22|0]<<16|w[g+23|0]<<24);v[f+8>>2]=w[g+24|0]|w[g+25|0]<<8|(w[g+26|0]<<16|w[g+27|0]<<24);v[f+24>>2]=w[g+28|0]|w[g+29|0]<<8|(w[g+30|0]<<16|w[g+31|0]<<24);u[f+30>>1]=w[g+32|0]<<2;u[f+28>>1]=w[g+33|0];if(t[g+48|0]&1){u[f+34>>1]=x[f+34>>1]|2}if(w[g+48|0]&2){u[f+34>>1]=x[f+34>>1]|4}if(w[g+48|0]&4){u[f+34>>1]=x[f+34>>1]|1;v[f>>2]=v[f>>2]>>>1;v[f+4>>2]=v[f+4>>2]>>>1;v[f+8>>2]=v[f+8>>2]>>>1}if(w[g+48|0]&8){u[f+34>>1]=x[f+34>>1]|32}gb=c+32|0;break A}break a}c=gb-16|0;gb=c;ME(c+8|0,l+484423|0);Ur(d+8|0,c+8|0);gb=c+16|0;v[22640]=0;Q(333,((j<<5)+a|0)+946304|0,d+8|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break y}vb(d+8|0);if(!(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))){break z}rd(d+8|0,b,w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24));B:{if(!n){break B}c=Pc(d,u[l+484414>>1]&1?16:8,1,0,0);v[22640]=0;W(363,c|0,k|0,d+8|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break B}e=P()|0;O()|0;yb(d+8|0);break b}yb(d+8|0)}e=e+1|0;if(e>>>0<(w[d+474|0]|w[d+475|0]<<8)>>>0){continue}break x}break}e=P()|0;O()|0;vb(d+8|0);break b}i=(w[d+474|0]|w[d+475|0]<<8)+i|0}if(m>>>0>=x[a+480192>>1]){break e}h=h+1|0;continue}}e=!q}gb=d+1328|0;return e&1}e=P()|0;O()|0;vb(d+96|0)}S(e|0);L()}a=P()|0;O()|0;vb(c+16|0);S(a|0);L()}function O2(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0;l=gb-560|0;gb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+104>>2]=2485;p=ge(l+136|0,l+144|0,l+104|0);b=v[p>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;u=Kb(l+104|0);m=Kb(l+88|0);n=Kb(l+72|0);o=Kb(l+56|0);r=Kb(l+40|0);v[22640]=0;na(2488,c|0,d|0,l+120|0,l+119|0,l+118|0,u|0,m|0,n|0,o|0,l+36|0);c=v[22640];v[22640]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;q=v[l+36>>2];k=0;e=0;f:{while(1){v[22640]=0;c=Q(2436,a|0,l+552|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}g:{if(!c){break g}h:{i:{j:{k:{l:{m:{n:{o:{p:{switch(t[(l+120|0)+e|0]){case 1:if((e|0)==3){break g}v[22640]=0;c=T(2438,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}if(jh(h,8192,c)){v[22640]=0;R(2489,l+24|0,a|0);c=v[22640];v[22640]=0;if((c|0)!=1){c=t[l+24|0];v[22640]=0;R(103,r|0,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){break o}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break f;case 4:break l;case 2:break m;case 3:break n;case 0:break p;default:break h}}if((e|0)==3){break g}}while(1){v[22640]=0;c=Q(2436,a|0,l+552|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}if(!c){break h}v[22640]=0;c=T(2438,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}if(!jh(h,8192,c)){break h}v[22640]=0;R(2489,l+24|0,a|0);c=v[22640];v[22640]=0;if((c|0)!=1){c=t[l+24|0];v[22640]=0;R(103,r|0,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if((Ab(n)|0)==(0-Ab(o)|0)){break h}q:{if(Ab(n)){if(Ab(o)){break q}}if(Ab(n)){v[22640]=0;c=T(2438,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}if(w[mc(n,0)|0]!=(c&255)){break k}v[22640]=0;T(2440,a|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}k=Ab(n)>>>0>1?n:k;break h}v[22640]=0;c=T(2438,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}if(w[mc(o,0)|0]!=(c&255)){break h}v[22640]=0;T(2440,a|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}t[g|0]=1;k=Ab(o)>>>0>1?o:k;break h}v[22640]=0;c=T(2438,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}if(w[mc(n,0)|0]==(c&255)){v[22640]=0;T(2440,a|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}k=Ab(n)>>>0>1?n:k;break h}v[22640]=0;c=T(2438,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}if(w[mc(o,0)|0]==(c&255)){v[22640]=0;T(2440,a|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}t[g|0]=1;k=Ab(o)>>>0>1?o:k;break h}v[f>>2]=v[f>>2]|4;a=0;break f}if(!(e>>>0<2|k|((e|0)==2&w[l+123|0]!=0|z))){k=0;break h}A=l,B=wd(m),v[A+16>>2]=B;c=Fd(l+24|0,l+16|0);r:{if(!e|w[(e+l|0)+119|0]>1){break r}A=l,B=df(m),v[A+16>>2]=B;s:{if(!Gb(c,l+16|0)){break s}while(1){if(!jh(h,8192,t[v[c>>2]])){break s}Me(c);A=l,B=df(m),v[A+16>>2]=B;if(Gb(c,l+16|0)){continue}break}}A=l,B=wd(m),v[A+16>>2]=B;c=Xj(c,l+16|0);if(Ab(r)>>>0>=c>>>0){A=l,B=df(r),v[A+16>>2]=B;d=we(l+16|0,0-c|0);s=df(r);x=wd(m);c=gb-32|0;gb=c;v[c+16>>2]=s;v[c+24>>2]=d;v[c+8>>2]=x;d=1;t:{if(!Gb(c+24|0,c+16|0)){break t}while(1){d=w[v[c+24>>2]]==w[v[c+8>>2]];if(!d){break t}Me(c+24|0);Me(c+8|0);if(Gb(c+24|0,c+16|0)){continue}break}}gb=c+32|0;if(d){break r}}A=l,B=wd(m),v[A+8>>2]=B;Fd(l+16|0,l+8|0);v[l+24>>2]=v[l+16>>2]}v[l+16>>2]=v[l+24>>2];A=l,B=df(m),v[A+8>>2]=B;u:{v:{w:{if(!Gb(l+16|0,l+8|0)){break w}while(1){v[22640]=0;c=Q(2436,a|0,l+552|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break v}if(!c){break w}v[22640]=0;c=T(2438,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break v}if(w[v[l+16>>2]]!=(c&255)){break w}v[22640]=0;T(2440,a|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break u}Me(l+16|0);A=l,B=df(m),v[A+8>>2]=B;if(Gb(l+16|0,l+8|0)){continue}break}}if(!y){break h}A=l,B=df(m),v[A+8>>2]=B;if(!Gb(l+16|0,l+8|0)){break h}v[f>>2]=v[f>>2]|4;a=0;break f}a=P()|0;O()|0;v[l+36>>2]=q;break a}a=P()|0;O()|0;v[l+36>>2]=q;break a}c=0;x=w[l+118|0];d=b;x:{while(1){y:{v[22640]=0;b=Q(2436,a|0,l+552|0)|0;s=v[22640];v[22640]=0;if((s|0)==1){break y}if(!b){break x}v[22640]=0;s=T(2438,a|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}z:{if(jh(h,2048,s)){b=v[j>>2];if((b|0)==v[l+548>>2]){v[22640]=0;U(2490,i|0,j|0,l+548|0);b=v[22640];v[22640]=0;if((b|0)==1){break e}b=v[j>>2]}v[j>>2]=b+1;t[b|0]=s;c=c+1|0;break z}if(!Ab(u)|!c|(x|0)!=(s&255)){break x}if(v[l+128>>2]==(d|0)){v[22640]=0;U(2491,p|0,l+132|0,l+128|0);b=v[22640];v[22640]=0;if((b|0)==1){break e}d=v[l+132>>2]}b=d+4|0;v[l+132>>2]=b;v[d>>2]=c;d=b;c=0}v[22640]=0;T(2440,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!c|v[p>>2]==(d|0)){break j}if(v[l+128>>2]==(d|0)){v[22640]=0;U(2491,p|0,l+132|0,l+128|0);b=v[22640];v[22640]=0;if((b|0)==1){break d}d=v[l+132>>2]}b=d+4|0;v[l+132>>2]=b;v[d>>2]=c;break i}t[g|0]=1;break h}b=d}A:{if((q|0)<1){break A}v[22640]=0;c=Q(2437,a|0,l+552|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}B:{if(!c){v[22640]=0;c=T(2438,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}if(w[l+119|0]==(c&255)){break B}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22640]=0;T(2440,a|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break d}while(1){if((q|0)<1){q=0;break A}v[22640]=0;c=Q(2437,a|0,l+552|0)|0;d=v[22640];v[22640]=0;C:{if((d|0)==1){break C}D:{if(!c){v[22640]=0;c=T(2438,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break C}if(jh(h,2048,c)){break D}}v[f>>2]=v[f>>2]|4;a=0;break f}if(v[j>>2]==v[l+548>>2]){v[22640]=0;U(2490,i|0,j|0,l+548|0);c=v[22640];v[22640]=0;if((c|0)==1){break C}}v[22640]=0;c=T(2438,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break C}d=v[j>>2];v[j>>2]=d+1;t[d|0]=c;v[22640]=0;T(2440,a|0)|0;c=v[22640];v[22640]=0;q=q-1|0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(v[i>>2]!=v[j>>2]){break h}v[f>>2]=v[f>>2]|4;a=0;break f}e=e+1|0;if((e|0)!=4){continue}}break}v[l+36>>2]=q;E:{if(!k){break E}e=1;while(1){if(Ab(k)>>>0<=e>>>0){break E}v[22640]=0;c=Q(2437,a|0,l+552|0)|0;d=v[22640];v[22640]=0;F:{if((d|0)==1){break F}G:{if(!c){v[22640]=0;c=T(2438,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break F}if(w[mc(k,e)|0]==(c&255)){break G}}v[f>>2]=v[f>>2]|4;a=0;break f}v[22640]=0;T(2440,a|0)|0;c=v[22640];v[22640]=0;e=e+1|0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;if(v[p>>2]==(b|0)){break f}a=0;v[l+24>>2]=0;gf(u,v[p>>2],b,l+24|0);if(v[l+24>>2]){v[f>>2]=v[f>>2]|4;break f}a=1}vb(r);vb(o);vb(n);vb(m);vb(u);Gc(p);gb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}vb(r);vb(o);vb(n);vb(m);vb(u);Gc(p);S(a|0);L()}function Lga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-240|0;gb=e;vc(c);k=Xi(e+216|0,c);v[22640]=0;c=Q(1158,k|0,e+200|0)|0;f=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((f|0)!=1){if(!c|v[e+200>>2]!=1297239878|((w[e+208|0]|w[e+209|0]<<8|(w[e+210|0]<<16|w[e+211|0]<<24))!=1128679745?v[e+208>>2]!=1179011393:0)){break a}v[22640]=0;R(1159,e+184|0,k|0);c=v[22640];v[22640]=0;l:{m:{n:{o:{p:{if((c|0)!=1){v[22640]=0;U(1160,e+160|0,e+184|0,1129270605);c=v[22640];v[22640]=0;if((c|0)==1){break p}v[22640]=0;c=Q(1161,e+160|0,e+136|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break l}if(!c){break b}h=e+136|2;if(!Xb(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))){break b}if(!Ib(w[e+136|0]|w[e+137|0]<<8)){break b}if(Ib(w[e+136|0]|w[e+137|0]<<8)>>>0>2){break b}c=e+136|6;if(!Ib(w[c|0]|w[c+1|0]<<8)){break b}if(Ib(w[c|0]|w[c+1|0]<<8)>>>0>64){break b}v[e+132>>2]=1162760014;f=1;if((w[e+208|0]|w[e+209|0]<<8|(w[e+210|0]<<16|w[e+211|0]<<24))==1128679745){v[22640]=0;f=Q(814,e+160|0,e+132|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break k}if(!f){break b}f=v[e+132>>2]!=1936684916}v[22640]=0;U(1160,e+112|0,e+184|0,1397968452);i=v[22640];v[22640]=0;if((i|0)==1){break o}v[22640]=0;g=Q(1162,e+112|0,e+104|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break m}i=0;if(!g){break c}g=Xb(w[e+104|0]|w[e+105|0]<<8|(w[e+106|0]<<16|w[e+107|0]<<24));v[22640]=0;g=Q(228,e+112|0,g|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break m}if(g){break n}break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}i=((Ib(w[c|0]|w[c+1|0]<<8)-1|0)/8|0)-1|0;g=i<<3;c=g&31;f=Pc(e+96|0,(i>>>0<7?(g&63)>>>0>=32?4196360>>>c|0:((1<<c)-1&4196360)<<32-c|136321040>>>c:8)&255,(Ib(w[e+136|0]|w[e+137|0]<<8)|0)==2?2:1,f,0);q:{c=v[e+132>>2];if((c|0)<=875981925){if((c|0)<=842230885){if((c|0)==544694642){break q}if((c|0)==842222662){break i}break h}if((c|0)==842230886){break i}if((c|0)!=875973702){break h}break i}if((c|0)<=1463897172){if((c|0)==875981926){break i}if((c|0)!=1463897153){break h}break j}if((c|0)!=1463897173){if((c|0)==2002873441){break j}if((c|0)!=2002873461){break h}}zf(f,17);Vi(f,16);break h}zf(f,1);break h}a=P()|0;O()|0;break g}a=P()|0;O()|0;break f}a=P()|0;O()|0;break d}a=P()|0;O()|0;break f}zf(f,18);Vi(f,16);break h}zf(f,3)}if(d){eR(f)}c=Xb(w[e+104|0]|w[e+105|0]<<8|(w[e+106|0]<<16|w[e+107|0]<<24));v[22640]=0;Q(350,e+112|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;Q(1149,a|0,b|0)|0;c=v[22640];v[22640]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((c|0)==1){break A}v[22640]=0;i=(B(b,104)+a|0)+484380|0;R(352,i|0,0);c=v[22640];v[22640]=0;if((c|0)==1){break A}m=i,n=Xb(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24)),v[m>>2]=n;d=e+136|0;c=w[d+13|0]|(w[d+11|0]<<16|w[d+10|0]<<24|w[d+12|0]<<8);g=(B(b,104)+a|0)+484404|0;h=30-w[d+9|0]|0;B:{if(h&255){while(1){d=c;c=c>>>1|0;h=h-1|0;if(h&255){continue}break}d=d&1;break B}d=0}v[g>>2]=c+d;v[22640]=0;W(363,f|0,i|0,e+112|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break A}v[22640]=0;U(1160,e+72|0,e+184|0,1296126539);c=v[22640];v[22640]=0;if((c|0)==1){break z}v[22640]=0;c=T(307,e+72|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break y}if(!c){break s}v[22640]=0;U(1160,e+24|0,e+184|0,1229869908);c=v[22640];v[22640]=0;if((c|0)==1){break x}v[22640]=0;c=Q(1163,e+24|0,e+48|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break w}yb(e+24|0);if(!c){break s}v[22640]=0;c=T(444,e+72|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break v}d=ad(e+24|0);v[22640]=0;R(1164,d|0,c|0);f=v[22640];v[22640]=0;if((f|0)!=1){C:{if(!c){break C}f=e|6;h=0;while(1){v[22640]=0;g=Q(1165,e+72|0,e|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break u}if(!g){break C}v[22640]=0;R(1166,d|0,e|0);g=v[22640];v[22640]=0;if((g|0)==1){break u}g=w[f|0];j=w[f|0];v[22640]=0;Q(350,e+72|0,g+((j^-1)&1)|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break u}h=h+1|0;if((c|0)!=(h|0)){continue}break}}if(Ib(w[e+56|0]|w[e+57|0]<<8)){c=(B(b,104)+a|0)+484414|0;u[c>>1]=x[c>>1]|8;f=Ib(w[e+56|0]|w[e+57|0]<<8);u[c>>1]=x[c>>1]&65519|((f|0)==2)<<4}if(Ib(w[e+62|0]|w[e+63|0]<<8)){c=(B(b,104)+a|0)+484414|0;u[c>>1]=x[c>>1]|2;f=Ib(w[e+62|0]|w[e+63|0]<<8);u[c>>1]=x[c>>1]&65531|((f|0)==2)<<2}m=e,n=Sb(d),v[m>>2]=n;m=e,n=Wb(d),v[m+16>>2]=n;if(Gb(e,e+16|0)){c=B(b,104)+a|0;h=c+484388|0;g=c+484384|0;j=c+484396|0;l=c+484392|0;f=e- -64|0;while(1){c=v[e>>2];if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+58|0]|w[e+59|0]<<8)|0)){m=l,n=Xb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[m>>2]=n}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+60|0]|w[e+61|0]<<8)|0)){m=j,n=Xb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[m>>2]=n}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[f|0]|w[f+1|0]<<8)|0)){m=g,n=Xb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[m>>2]=n}if((Ib(w[c|0]|w[c+1|0]<<8)|0)==(Ib(w[e+66|0]|w[e+67|0]<<8)|0)){m=h,n=Xb(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[m>>2]=n}v[e>>2]=v[e>>2]+7;if(Gb(e,e+16|0)){continue}break}}v[22640]=0;wk(i);c=v[22640];v[22640]=0;if((c|0)!=1){break t}}break u}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(e+24|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;aR(d);break r}aR(d)}v[22640]=0;U(1160,e+24|0,e+184|0,1312902469);c=v[22640];v[22640]=0;D:{E:{if((c|0)!=1){v[22640]=0;c=T(307,e+24|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break E}F:{G:{H:{I:{if(c){v[22640]=0;c=T(232,e+24|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break E}v[22640]=0;W(499,e+24|0,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break I}break E}v[22640]=0;c=Q(112,e|0,18693)|0;d=v[22640];v[22640]=0;if((d|0)==1){break H}v[22640]=0;Q(333,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break G}vb(c)}b=v[a+480180>>2];v[22640]=0;U(1151,i|0,32,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break F}v[22640]=0;Zh(i,a,0);a=v[22640];v[22640]=0;if((a|0)==1){break E}yb(e+24|0);yb(e+72|0);i=1;break c}a=P()|0;O()|0;break D}a=P()|0;O()|0;vb(c);break D}a=P()|0;O()|0;break D}a=P()|0;O()|0;break r}a=P()|0;O()|0}yb(e+24|0)}yb(e+72|0);break g}a=P()|0;O()|0}yb(e+112|0)}yb(e+160|0)}Cd(e+184|0)}yb(k);S(a|0);L()}yb(e+112|0)}yb(e+160|0);Cd(e+184|0)}yb(k);gb=e+240|0;return i|0}function Jba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=C(0),A=C(0),B=0,D=0,E=0,F=C(0),G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=C(0),S=C(0),T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=C(0);a:{if(!w[a+5046|0]){break a}h=z[a+4268>>2];cM(a);if(h==z[a+4268>>2]){break a}Ly(a)}b:{if(!w[a+5045|0]){break b}p=a+44|0;if(!ki(p)){break b}q=Md(p,0);x=Md(p,1);m=kd(p,0);n=kd(p,1);c:{if(!(w[a+4264|0]&2|(!w[a+5044|0]|!d))){z[m>>2]=z[a+5036>>2];z[n>>2]=z[a+5040>>2];t[a+5044|0]=0;x=x+4|0;q=q+4|0;n=n+4|0;m=m+4|0;k=d-1|0;break c}k=d}r=k;d:{if(!r){break d}X=a+4960|0;G=a+4648|0;H=a+4672|0;T=a+4936|0;I=a+4696|0;J=a+4720|0;K=a+4744|0;L=a+4768|0;U=a+4840|0;E=a+4504|0;M=a+4528|0;V=a+4912|0;N=a+4552|0;O=a+4576|0;P=a+4600|0;Q=a+4624|0;W=a+4816|0;s=a+4888|0;u=a+4864|0;while(1){h=z[q>>2];h=C(C(C(z[a+5008>>2]-h)*z[a+4276>>2])+h);z[a+5008>>2]=h;_=Ac(u,v[a+4880>>2]),$=h,z[_>>2]=$;h=z[x>>2];h=C(C(C(z[a+5012>>2]-h)*z[a+4276>>2])+h);z[a+5012>>2]=h;_=Ac(s,v[a+4904>>2]),$=h,z[_>>2]=$;h=Uh(u,v[a+4356>>2]);f=Uh(u,v[a+4360>>2]);e=Uh(u,v[a+4364>>2]);g=Uh(u,v[a+4368>>2]);h=C(C(C(h*C(.6800000071525574))+C(C(e+Uh(u,v[a+4372>>2]))*C(-.6200000047683716)))+C(C(g+f)*C(-.5)));if(t[a+4264|0]&1){f=h;h=C(z[Ac(W,v[a+4836>>2])>>2]+C(f*C(.6180340051651001)));_=Ac(W,v[a+4832>>2]),$=C(f-C(h*C(.6180340051651001))),z[_>>2]=$}R=z[a+4280>>2];_=a,$=C(Uh(u,v[a+4352>>2])+z[a+5020>>2]),z[_+5020>>2]=$;f=C(Uh(s,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=f;e=z[a+5020>>2];g=z[a+4980>>2];i=z[Ac(Q,v[a+4644>>2])>>2];y=z[a+4444>>2];g=C(z[Ac(Q,v[a+4644>>2])>>2]+C(y*C(g-i)));z[a+4980>>2]=g;i=z[a+4272>>2];j=C(e*C(-.7070000171661377));l=C(f*C(.7070000171661377));e=C(j+l);f=C(C(i*e)+C(z[a+4440>>2]*g));_=Ac(Q,v[a+4640>>2]),$=C(e-C(i*f)),z[_>>2]=$;e=z[a+4976>>2];g=z[Ac(P,v[a+4620>>2])>>2];i=z[a+4436>>2];e=C(z[Ac(P,v[a+4620>>2])>>2]+C(i*C(e-g)));z[a+4976>>2]=e;g=z[a+4272>>2];e=C(C(g*f)+C(z[a+4432>>2]*e));_=Ac(P,v[a+4616>>2]),$=C(f-C(g*e)),z[_>>2]=$;y=C(C(f*C(-.15000000596046448))+C(e*C(-.20000000298023224)));if(t[a+4264|0]&1){f=z[a+4972>>2];g=z[Ac(O,v[a+4596>>2])>>2];i=z[a+4428>>2];f=C(z[Ac(O,v[a+4596>>2])>>2]+C(i*C(f-g)));z[a+4972>>2]=f;g=z[a+4272>>2];f=C(C(g*e)+C(z[a+4424>>2]*f));_=Ac(O,v[a+4592>>2]),$=C(e-C(g*f)),z[_>>2]=$;e=z[a+4968>>2];g=z[Ac(N,v[a+4572>>2])>>2];i=z[a+4420>>2];e=C(z[Ac(N,v[a+4572>>2])>>2]+C(i*C(e-g)));z[a+4968>>2]=e;g=z[a+4272>>2];e=C(C(g*f)+C(z[a+4416>>2]*e));_=Ac(N,v[a+4568>>2]),$=C(f-C(g*e)),z[_>>2]=$;y=C(C(C(f*C(.3499999940395355))+y)+C(e*C(-.3799999952316284)))}_=Ac(V,v[a+4928>>2]),$=e,z[_>>2]=$;k=Ac(V,v[a+4932>>2]);f=C(z[a+4496>>2]*z[k>>2]);z[a+5028>>2]=C(C(z[a+5028>>2]-f)*z[a+4500>>2])+f;f=z[a+4964>>2];e=z[Ac(M,v[a+4548>>2])>>2];g=z[a+4412>>2];f=C(z[Ac(M,v[a+4548>>2])>>2]+C(g*C(f-e)));z[a+4964>>2]=f;g=C(z[a+4408>>2]*f);f=z[a+4272>>2];e=z[a+5028>>2];g=C(g+C(f*e));_=Ac(M,v[a+4544>>2]),$=C(e-C(f*g)),z[_>>2]=$;f=z[a+4960>>2];e=z[Ac(E,v[a+4524>>2])>>2];i=z[a+4404>>2];f=C(z[Ac(E,v[a+4524>>2])>>2]+C(i*C(f-e)));z[a+4960>>2]=f;e=z[a+4272>>2];A=C(C(e*g)+C(z[a+4400>>2]*f));_=Ac(E,v[a+4520>>2]),$=C(g-C(e*A)),z[_>>2]=$;z[a+5020>>2]=A;f=Uh(s,v[a+4380>>2]);e=Uh(s,v[a+4384>>2]);i=Uh(s,v[a+4388>>2]);S=Uh(s,v[a+4392>>2]);f=C(C(C(f*C(.7070000171661377))+C(C(i+Uh(s,v[a+4396>>2]))*C(-.5)))+C(C(S+e)*C(-.6000000238418579)));if(t[a+4264|0]&1){e=f;f=C(z[Ac(U,v[a+4860>>2])>>2]+C(e*C(.6180340051651001)));_=Ac(U,v[a+4856>>2]),$=C(e-C(f*C(.6180340051651001))),z[_>>2]=$}S=z[a+4280>>2];e=z[a+5004>>2];i=z[Ac(L,v[a+4788>>2])>>2];F=z[a+4492>>2];e=C(z[Ac(L,v[a+4788>>2])>>2]+C(F*C(e-i)));z[a+5004>>2]=e;F=z[a+4272>>2];j=C(j-l);i=C(C(F*j)+C(z[a+4488>>2]*e));_=Ac(L,v[a+4784>>2]),$=C(j-C(F*i)),z[_>>2]=$;e=z[a+5e3>>2];j=z[Ac(K,v[a+4764>>2])>>2];l=z[a+4484>>2];e=C(z[Ac(K,v[a+4764>>2])>>2]+C(l*C(e-j)));z[a+5e3>>2]=e;j=z[a+4272>>2];e=C(C(j*i)+C(z[a+4480>>2]*e));_=Ac(K,v[a+4760>>2]),$=C(i-C(j*e)),z[_>>2]=$;i=C(C(e*C(-.20000000298023224))+C(C(g*C(.3799999952316284))+C(i*C(-.15000000596046448))));if(t[a+4264|0]&1){g=z[a+4996>>2];j=z[Ac(J,v[a+4740>>2])>>2];l=z[a+4476>>2];g=C(z[Ac(J,v[a+4740>>2])>>2]+C(l*C(g-j)));z[a+4996>>2]=g;j=z[a+4272>>2];g=C(C(j*e)+C(z[a+4472>>2]*g));_=Ac(J,v[a+4736>>2]),$=C(e-C(j*g)),z[_>>2]=$;e=z[a+4992>>2];j=z[Ac(I,v[a+4716>>2])>>2];l=z[a+4468>>2];e=C(z[Ac(I,v[a+4716>>2])>>2]+C(l*C(e-j)));z[a+4992>>2]=e;j=z[a+4272>>2];e=C(C(j*g)+C(z[a+4464>>2]*e));_=Ac(I,v[a+4712>>2]),$=C(g-C(j*e)),z[_>>2]=$;i=C(C(C(g*C(.3499999940395355))+i)+C(e*C(-.3799999952316284)))}Y=x+4|0;Z=q+4|0;g=C(R*h);R=C(S*f);_=Ac(T,v[a+4952>>2]),$=e,z[_>>2]=$;k=Ac(T,v[a+4956>>2]);h=C(z[a+4496>>2]*z[k>>2]);z[a+5032>>2]=C(C(z[a+5032>>2]-h)*z[a+4500>>2])+h;h=z[a+4988>>2];f=z[Ac(H,v[a+4692>>2])>>2];e=z[a+4460>>2];h=C(z[Ac(H,v[a+4692>>2])>>2]+C(e*C(h-f)));z[a+4988>>2]=h;f=z[a+4272>>2];e=z[a+5032>>2];h=C(C(z[a+4456>>2]*h)+C(f*e));_=Ac(H,v[a+4688>>2]),$=C(e-C(f*h)),z[_>>2]=$;e=z[a+4284>>2];f=z[a+4984>>2];j=z[Ac(G,v[a+4668>>2])>>2];l=z[a+4452>>2];f=C(z[Ac(G,v[a+4668>>2])>>2]+C(l*C(f-j)));z[a+4984>>2]=f;j=z[a+4272>>2];f=C(C(j*h)+C(z[a+4448>>2]*f));_=Ac(G,v[a+4664>>2]),$=C(h-C(j*f)),z[_>>2]=$;z[a+5024>>2]=f;h=C(C(h-A)*C(.3799999952316284));A=z[a+4288>>2];k=E;while(1){o=k;B=v[o+16>>2];D=B-1|0;v[o+16>>2]=D;if((B|0)<=0){v[o+16>>2]=D+v[o+12>>2]}D=v[o+20>>2];B=D-1|0;v[o+20>>2]=B;if((D|0)<=0){v[o+20>>2]=B+v[o+12>>2]}k=k+24|0;if((X|0)!=(k|0)){continue}break}h=C(C(C(h+y)*e)+g);f=C(C(A*C(i+C(f*C(-.3799999952316284))))+R);e:{f:{if(w[a+4264|0]&2){q=Z;k=Y;break f}z[m>>2]=C(z[a+5036>>2]+h)*C(.5);z[n>>2]=C(z[a+5040>>2]+f)*C(.5);z[a+5040>>2]=f;z[a+5036>>2]=h;if((r|0)==1){break e}r=r-1|0;q=q+8|0;n=n+4|0;m=m+4|0;k=x+8|0}x=k;z[m>>2]=h;z[n>>2]=f;n=n+4|0;m=m+4|0;r=r-1|0;if(r){continue}break d}break}t[a+5044|0]=1}Ci(a,b,c,kd(p,0),kd(p,1),d)}}function uoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0;f=gb-208|0;gb=f;a:{b:{c:{d:{e:{f:{g:{h:{if(!Fh(b,11199)){break h}if(d){t[d|0]=1}i=a+1074312|0;ov(i);m=a+480216|0;n=a+480224|0;j=a+1074368|0;o=a+480200|0;k=a+480248|0;i:{if(!Pb(b,7)){break i}r=a+480220|0;s=a+480228|0;z=a+480232|0;A=a+484360|0;l=a+480268|0;C=a+1298280|0;while(1){d=og(b);e=Kg(b);if((d|0)==(w[18669]|w[18670]<<8|(w[18671]<<16|w[18672]<<24))){lg(b,6);break i}if(!(d&1616928864)|d&-2139062144){break i}if(!Pb(b,e)){break i}rd(f+184|0,b,e);j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if((d|0)<=1347243309){if((d|0)<=1146367533){if((d|0)<=1130917458){if((d|0)==1127099950){break A}if((d|0)!=1129797166){break j}v[22640]=0;v[f+24>>2]=0;U(628,f+184|0,e|0,f+24|0);d=v[22640];v[22640]=0;if((d|0)==1){break x}v[a+1074304>>2]=v[f+24>>2];break j}if((d|0)==1130917459){break s}if((d|0)!=1145525806){break j}v[22640]=0;U(628,f+184|0,e|0,o|0);d=v[22640];v[22640]=0;if((d|0)==1){break b}break j}if((d|0)<=1213486400){if((d|0)==1146367534){break C}if((d|0)!=1196316499|e>>>0<3){break j}v[22640]=0;R(629,f+8|0,f+184|0);d=v[22640];v[22640]=0;if((d|0)==1){break q}v[22640]=0;R(630,f+168|0,f+8|0);d=v[22640];v[22640]=0;if((d|0)==1){break p}v[22640]=0;d=W(142,f+24|0,f+168|0,8)|0;e=v[22640];v[22640]=0;if((e|0)==1){break o}vb(f+168|0);gc(f+8|0);v[22640]=0;e=T(232,f+184|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break m}v[22640]=0;U(631,f+24|0,k|0,e|0);e=v[22640];v[22640]=0;if((e|0)==1){break m}tf(d);break j}if((d|0)==1213486401){break t}if((d|0)==1280530262){break w}if((d|0)!=1297303086){break j}ov(i);d=0;break l}if((d|0)<=1380994349){if((d|0)<=1380340803){if((d|0)==1347243310){break y}if((d|0)!=1347244882){break j}v[22640]=0;U(632,f+184|0,e|0,l|0);d=v[22640];v[22640]=0;if((d|0)==1){break b}if(wp(w[l|0])){break j}t[l|0]=5;break j}if((d|0)==1380340804){break B}if((d|0)==1380986414){break u}if((d|0)!=1380991534){break j}v[22640]=0;U(628,f+184|0,e|0,m|0);d=v[22640];v[22640]=0;if((d|0)==1){break b}break j}if((d|0)<=1397768493){if((d|0)==1380994350){break k}if((d|0)!=1397052739|e>>>0<3){break j}v[22640]=0;d=T(319,f+184|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break c}if(!d|d>>>0>x[a+480190>>1]){break j}e=B(d,104)+a|0;d=e+484448|0;e=e+484484|0;while(1){v[22640]=0;g=T(229,f+184|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break r}v[d>>2]=g;d=d+4|0;if((e|0)!=(d|0)){continue}break}break j}if((d|0)==1397768494){break v}if((d|0)==1414344238){break z}if((d|0)!=1448301654){break j}v[22640]=0;U(628,f+184|0,e|0,z|0);d=v[22640];v[22640]=0;if((d|0)==1){break b}break j}v[22640]=0;U(628,f+184|0,e|0,f+24|0);d=v[22640];v[22640]=0;if((d|0)==1){break g}v[a+480204>>2]=B(v[f+24>>2],1e4)+(y[a+480204>>2]%1e4|0);break j}v[22640]=0;U(628,f+184|0,e|0,f+24|0);d=v[22640];v[22640]=0;if((d|0)!=1){d=v[a+480204>>2];v[a+480204>>2]=d-((d>>>0)%1e4|0)+y[f+24>>2]%1e4;break j}e=P()|0;O()|0;break a}if(c){break j}v[22640]=0;u[f+24>>1]=0;U(633,f+184|0,e|0,f+24|0);d=v[22640];v[22640]=0;if((d|0)!=1){D=a,E=Jd(x[f+24>>1],x[a+480188>>1],127),u[D+480188>>1]=E;break j}e=P()|0;O()|0;break a}v[22640]=0;U(634,f+184|0,e|0,n|0);d=v[22640];v[22640]=0;if((d|0)==1){break b}break j}v[22640]=0;U(635,f+184|0,e|0,j|0);d=v[22640];v[22640]=0;if((d|0)==1){break b}break j}e=P()|0;O()|0;break a}v[22640]=0;v[f+24>>2]=0;U(628,f+184|0,e|0,f+24|0);d=v[22640];v[22640]=0;if((d|0)==1){break f}d=v[f+24>>2];if(!d){break j}v[a+1074308>>2]=d;break j}v[22640]=0;U(628,f+184|0,e|0,s|0);d=v[22640];v[22640]=0;if((d|0)!=1){break j}break b}if(v[a+480180>>2]==4){break j}v[22640]=0;U(633,f+184|0,e|0,f+24|0);d=v[22640];v[22640]=0;if((d|0)!=1){af(Rb(A),x[f+24>>1]);break j}e=P()|0;O()|0;break a}d=Kb(f+24|0);v[22640]=0;e=T(232,f+184|0)|0;g=v[22640];v[22640]=0;D:{if((g|0)==1){break D}v[22640]=0;W(636,f+184|0,d|0,e|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break D}v[22640]=0;U(13,f+168|0,0,d|0);e=v[22640];v[22640]=0;if((e|0)==1){break D}Eb(C,f+168|0);vb(f+168|0);vb(d);break j}e=P()|0;O()|0;vb(d);break a}if(e&1|e>>>0>126){break j}u[f+24>>1]=(e>>>1|0)- -64;v[22640]=0;u[f+168>>1]=127;d=Oc(f+24|0,f+168|0);e=v[22640];v[22640]=0;if((e|0)==1){break e}p=x[d>>1];if(p>>>0<65){break j}e=64;while(1){v[22640]=0;R(431,f+24|0,f+184|0);d=v[22640];v[22640]=0;if((d|0)==1){break d}d=md(f+24|0);g=f+24|0;E:{if(w[g|0]==255){break E}h=w[d|0];d=(e<<5)+a|0;q=d+480284|0;u[q>>1]=128;u[d+480286>>1]=h;h=d+480280|0;v[h>>2]=0;v[h>>2]=(w[g|0]&128)<<3;d=w[g|0]&127;t[g|0]=d;if(d>>>0<65){u[q>>1]=d<<2;d=w[g|0]}if((d|0)!=100){break E}v[h>>2]=v[h>>2]|256}e=e+1|0;if((p|0)!=(e|0)){continue}break}break j}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break n}e=P()|0;O()|0;vb(f+168|0)}gc(f+8|0);break a}e=P()|0;O()|0;tf(d);break a}F:{G:{H:while(1){v[22640]=0;e=Q(228,f+184|0,1)|0;g=v[22640];v[22640]=0;if((g|0)==1){break G}if(!(e&d>>>0<113)){break j}v[22640]=0;g=T(353,f+184|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break F}e=0;while(1){I:{if(!(!(g>>>e&1)|d>>>0>112)){v[22640]=0;W(437,i|0,d|0,1)|0;h=v[22640];v[22640]=0;if((h|0)==1){break I}}d=d+1|0;e=e+1|0;if((e|0)!=8){continue}continue H}break}break}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}v[22640]=0;U(628,f+184|0,e|0,r|0);d=v[22640];v[22640]=0;if((d|0)==1){break b}}yb(f+184|0);if(Pb(b,7)){continue}break}}Gp(a+480204|0,B(v[v[a+8>>2]+20>>2],1e4),B(v[v[a+8>>2]+24>>2],1e4));if(w[a+480224|0]>=3){t[n|0]=0}if(w[j|0]>=6){t[j|0]=0}tc(o,256);if($c(k)){break h}HC(k,v[m>>2],16777216)}gb=f+208|0;return}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0}yb(f+184|0);S(e|0);L()}function Do(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;h=gb-16|0;gb=h;g=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:g;s=v[b+752>>2];i=w[b+802|0];a:{if(!i){Db(h+8|0,a+1074312|0,11);if(Cb(h+8|0)){break a}}b:{c:{if(!g){break c}if(!ve(i)){break c}d:{k=g+236|0;i=i-1|0;if(x[sd(k,i)>>1]){break d}Db(h+8|0,a+1074312|0,43);if(!Cb(h+8|0)){break d}if(Fj(g)){break d}v[b+656>>2]=g;break a}if(w[lc(g+108|0,i)|0]>120){break a}k=x[sd(k,i)>>1];k=(k-1&65535)>>>0<3999?(B(k,104)+a|0)+484380|0:0;break b}k=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(i>>>0>250){break a}Db(h+8|0,a+1074312|0,43);if(Cb(h+8|0)){if(g){k=0;if(Fj(g)){break b}}t[b+803|0]=0;v[b+656>>2]=0;break a}k=0}i=v[b+104>>2];o=(i|0)!=0&(i|0)!=(k|0);j=v[b+656>>2];q=!g|v[a+480180>>2]!=16777216?q:v[g+44>>2]!=0;p=d^1;l=(g|0)!=(j|0);if((p|l|o)==1){u[b+774>>1]=0}r=!o;if(!(r?1:!(d&q)|v[b+656>>2]!=(g|0))){break a}e:{if(p|r){break e}i=a+1074312|0;Db(h+8|0,i,32);if(!(!Cb(h+8|0)|!(w[a+480208|0]&8))){k=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:k}f:{if(!(g?!(v[a+480180>>2]&1048580)|l:1)|v[a+480180>>2]==268435456){break f}if(v[a+480180>>2]==1){if(Ki(b)){break f}}Db(h+8|0,i,79);if(!Cb(h+8|0)){break e}if(!Ki(b)){break e}}n=1}g:{if(!v[b+16>>2]|(!o|(l|!x[a+480192>>1]))){break g}Db(h+8|0,a+1074312|0,87);if(!Cb(h+8|0)){break g}n=ce(b+788|0)^1|n}h:{i:{j:{k:{if(Ki(b)|!(v[a+480180>>2]&16777248)){break k}if(g){if(Fj(g)){break k}}m=1;break j}if(!(l|o)){break i}m=(g|0)!=(j|0)}if(!d){break i}Db(h+8|0,a+1074312|0,61);if(!Cb(h+8|0)){break i}i=v[b+656>>2];if(!i){l=0;i=0;j=v[b+104>>2];if(!j){break i}break h}j=v[b+104>>2];l=0;break h}v[b+656>>2]=g;l=m;j=k;i=g}l:{if(!e){break l}k=b;m:{n:{o:{if(v[a+480180>>2]&3){if(j){if(Ld(j)){break o}}if(!rk(b)){break l}}if(!j){break n}}if(u[j+34>>1]<0){break l}g=x[j+30>>1];break m}g=0;if(!i|!w[i+34|0]){break m}g=b;m=v[b+656>>2];p:{if(m){g=v[m+4>>2]<<2;break p}g=v[g+688>>2]}}v[k+688>>2]=g}if(n){if(!((j|0)!=0&o)){break a}Db(h+8|0,a+1074312|0,85);if(Cb(h+8|0)){u[b+772>>1]=t[j+37|0]}if(v[a+480180>>2]!=2){break a}if(!Ld(j)){break a}v[b+704>>2]=v[j+24>>2];break a}t[b+803|0]=0;q:{if(!i){break q}Db(h+8|0,a+1074312|0,29);if(z=0,A=(D=Cb(h+8|0),E=1,F=j,F?D:E),C=w[i+34|0]!=0|l,C?z:A){break q}t[b+798|0]=w[i+16|0]}k=i;n=64;m=b;v[b+752>>2]=64;g=j;if(g){n=x[g+32>>1];v[m+752>>2]=n}if(k){v[m+752>>2]=B(v[k+4>>2],n)>>>6}r:{if(!(v[a+480180>>2]&1048580?e:1)){break r}Db(h+8|0,a+1074312|0,48);if(Cb(h+8|0)){break r}QP(a,b,i,j)}s:{t:{u:{if(!f){break u}e=a+1074312|0;Db(h+8|0,e,19);v:{w:{x:{y:{z:{A:{B:{C:{if(Cb(h+8|0)){if(!v[b+76>>2]){g=1;break B}if(!(!c|p)){g=(w[a+480208|0]&8)>>>3|0;if(g){break B}break C}g=0;if(c){break C}break B}g=1;D:{if(!d|!(v[a+480180>>2]&17301536)|(!v[b+76>>2]|w[a+480208|0]&8)){break D}g=0;if(!(w[b+89|0]&16)){break D}g=!v[b+696>>2]}if(!(v[a+480180>>2]&17301536)|(!i|l)){break z}if(!g){break y}g=v[b+88>>2];c=g&6144;break A}if(d){break B}if(!(w[b+89|0]&24)){g=0;break B}g=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|l){break z}if(!g){break y}g=v[b+88>>2];c=g&2048}v[b+88>>2]=g|2097152;if(!i){break v}if(c){break w}if(!(w[i+60|0]&8)){Dj(b+724|0)}if(!(w[i+80|0]&8)){Dj(b+732|0)}if(w[i+100|0]&8){break v}Dj(b+740|0);break v}if(g){break x}}if(i){if(t[i+60|0]&1){break u}Db(h+8|0,e,32);if(Cb(h+8|0)){Dj(b+724|0);break u}Km(b);break u}g=0;if(!j){break t}break s}v[b+88>>2]=v[b+88>>2]|2097152;if(!i){break v}}Km(b)}Db(h+8|0,e,21);if(Cb(h+8|0)){break u}t[b+818|0]=0;v[b+756>>2]=0}g=0;if(j){break s}if(!i){break t}g=1;if(Fj(i)){break s}}v[b+752>>2]=0;v[b+104>>2]=0;break a}c=b;E:{F:{G:{H:{I:{if(!(!d|!j|v[b+104>>2]!=(j|0))){if(v[b+76>>2]?v[a+480180>>2]&16777250:0){break a}if(v[a+480180>>2]!=4){break I}Db(h+8|0,a+1074312|0,40);if(!Cb(h+8|0)|w[b+789|0]){break I}d=v[b+88>>2];break H}v[b+88>>2]=v[b+88>>2]&-6145;e=a+1074312|0;Db(h+8|0,e,18);c=b;J:{if(z=Cb(h+8|0),A=1,C=v[a+480180>>2]&16777248,C?z:A){f=-640;if(!(v[b+104>>2]!=(j|0)|l)){break J}}f=-768}v[c+88>>2]=f&v[b+88>>2];K:{if(!i){break K}t[b+730|0]=w[i+60|0];t[b+738|0]=w[i+80|0];t[b+746|0]=w[i+100|0];L:{if((w[i+100|0]&17)!=17){break L}Db(h+8|0,e,36);if(Cb(h+8|0)|w[b+837|0]){break L}t[b+837|0]=127}if(lw(i)){z=b,A=QE(i),t[z+837|0]=A}if(!OE(i)){break K}z=b,A=PE(i),t[z+838|0]=A}if(g){break G}if(!d){break E}break F}d=v[b+88>>2]&-6145}v[c+88>>2]=d&-640;if(!g){break F}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break E}c=a+1074312|0;Db(h+8|0,c,54);if(!Cb(h+8|0)){Db(h,c,39);if(!Cb(h)){break E}}v[b+8>>2]=0;v[b+12>>2]=0}M:{if(w[b+788|0]!=255){break M}Db(h+8|0,a+1074312|0,100);if(!Cb(h+8|0)|(!(v[a+480208>>2]&4)|r)){break M}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+752>>2]=s;v[b+688>>2]=x[j+30>>1];if(!(w[j+34|0]&32)){break a}Ro(b,x[j+28>>1],a);break a}v[b+104>>2]=j;v[b+76>>2]=v[j>>2];v[b+80>>2]=v[j+4>>2];v[b+84>>2]=v[j+8>>2];e=a+1074312|0;Db(h+8|0,e,83);if(!(!Cb(h+8|0)|v[b+80>>2])){v[b+84>>2]=v[j>>2]}v[b+88>>2]=v[b+88>>2]|x[j+34>>1]&1023;Db(h+8|0,e,21);if(Cb(h+8|0)){t[b+818|0]=0;v[b+756>>2]=0}c=b;N:{O:{if(q){v[b+704>>2]=v[j+24>>2];t[b+851|0]=w[b+851|0]|32;d=0;break O}if(!(v[a+480180>>2]&5?o|p:1)){break N}v[b+704>>2]=v[j+24>>2];d=t[j+37|0]}u[c+772>>1]=d}c=b;if(fp(a)){d=t[j+36|0]}else{d=0}u[c+770>>1]=d;Db(h+8|0,e,69);if(!(Cb(h+8|0)|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+852>>2]=0;g=v[b+88>>2];if(g&8){v[b+80>>2]=v[j+12>>2];v[b+84>>2]=v[j+16>>2];g=g>>>2&4|g|2;v[b+88>>2]=g}P:{if(!(g&2)){g=v[b+76>>2];break P}g=v[b+76>>2];c=v[b+84>>2];if(g>>>0<=c>>>0){break P}v[b+76>>2]=c;g=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<g>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}gb=h+16|0}function Lfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-208|0;gb=g;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;jP(a+900380|0);v[22640]=0;$z(a+946304|0);d=v[22640];v[22640]=0;a:{b:{c:{d:{e:{if((d|0)==1){break e}Qb(g+48|0,0,160);d=nP(g+48|0);v[22640]=0;e=a+906300|0;U(1305,e|0,e+4e4|0,d|0);e=v[22640];v[22640]=0;f:{g:{h:{i:{if((e|0)!=1){Hq(d);v[22640]=0;d=T(307,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break e}if(!d){break f}i=ad(g+48|0);e=0;if(c&16){break h}v[22640]=0;h=(c|0)!=0;e=W(1306,i|0,b|0,h|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break g}d=4;j:{if(e){break j}v[22640]=0;e=W(1307,i|0,b|0,h|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break g}d=5;if(e){break j}v[22640]=0;e=W(1308,i|0,b|0,h|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break g}d=6;if(e){break j}e=0;v[22640]=0;h=W(1309,i|0,b|0,h|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break g}d=3;if(!h){break h}}if(c){break i}f=1;break b}a=P()|0;O()|0;Hq(d);break c}if(!$c(i)){uw(b,v[i>>2]+12|0)}e=d}if(c&32){break b}d=38192;k:{l:{while(1){j=v[d+8>>2];h=(j>>1)+a|0;f=v[d+4>>2];f=j&1?v[v[h>>2]+f>>2]:f;v[22640]=0;f=W(f|0,h|0,b|0,c|0)|0;h=v[22640];v[22640]=0;if((h|0)!=1){if(f){break k}d=d+12|0;if((d|0)==38696){break l}continue}break}break g}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){break b}if(!(v[a+480184>>2]|!e)){v[a+480184>>2]=e}v[22640]=0;R(1133,a+1298224|0,1);d=v[22640];v[22640]=0;if((d|0)!=1){Uz(i);break d}}a=P()|0;O()|0;Uz(i);break c}v[22640]=0;R(407,a|0,0);d=v[22640];v[22640]=0;if((d|0)==1){break e}v[22640]=0;R(1133,a+1298224|0,1);d=v[22640];v[22640]=0;if((d|0)==1){break e}v[a+1074304>>2]=19923012;break d}a=P()|0;O()|0;break c}d=0;m:{n:{while(1){e=(d<<5)+a|0;sg(e+480286|0,64);e=e+480284|0;if(x[e>>1]>=257){u[e>>1]=128}v[22640]=0;$m((B(d,872)+a|0)+1074992|0,7,a,d&65535,134217728);e=v[22640];v[22640]=0;if((e|0)==1){break n}d=d+1|0;if((d|0)!=127){continue}break}if(x[a+480190>>1]){i=a+1298260|0;f=1;while(1){e=B(f&65535,104)+a|0;d=e+484380|0;o:{if(Ld(d)){v[22640]=0;Zh(d,a,0);d=v[22640];v[22640]=0;if((d|0)!=1){break o}break m}h=e+484414|0;j=x[h>>1];if(j&16384){break o}v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0;v[d+8>>2]=0;v[d+12>>2]=0;u[h>>1]=j&65505}d=e+484412|0;if(x[d>>1]>=65){u[d>>1]=64}p:{if(!(w[e+484415|0]&2)){break p}if(!vk(i)){break p}v[22640]=0;_(1311,a|0);d=v[22640];v[22640]=0;if((d|0)==1){break m}}f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}d=0;e=0;while(1){q:{f=v[(((d&65535)<<2)+a|0)+900380>>2];if(!f){break q}e=v[a+480180>>2];v[22640]=0;JS(f,e);f=v[22640];v[22640]=0;e=d;if((f|0)!=1){break q}a=P()|0;O()|0;break c}d=d+1|0;if(x[a+480192>>1]>=(d&65535)>>>0){continue}break}u[a+480192>>1]=e;d=a+480204|0;r:{if(y[a+480204>>2]<1e4){v[d>>2]=125e4;break r}tc(d,65535e4)}e=v[a+480196>>2];if(!e){v[a+480196>>2]=6;e=6}f=v[a+480220>>2];d=v[a+480216>>2];if(f>>>0<d>>>0){v[a+480220>>2]=d;f=d}v[a+1074416>>2]=e;v[a+1074420>>2]=v[a+480204>>2];v[a+1074412>>2]=f;v[a+1074408>>2]=d;v[a+1074456>>2]=v[a+480200>>2];iA(a+1074376|0);d=a+1074446|0;u[d>>1]=0;u[d+2>>1]=0;u[d+4>>1]=0;u[d+6>>1]=65535;v[a+1074392>>2]=-2;d=a+1074384|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074380>>2]=0;d=a+1074424|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074432>>2]=0;d=a+1074396|0;v[d>>2]=0;v[d+4>>2]=0;u[a+480276>>1]=0;v[22640]=0;_(1313,a|0);d=v[22640];v[22640]=0;if((d|0)!=1){d=a+484360|0;k=g,l=Sb(d),v[k+48>>2]=l;k=g,l=Wb(d),v[k+32>>2]=l;s:{if(Gb(g+48|0,g+32|0)){while(1){d=v[g+48>>2];v[22640]=0;_(1314,d|0);e=v[22640];v[22640]=0;if((e|0)==1){break s}e=x[d+28>>1];if(sc(d)>>>0<=e>>>0){af(d,0)}vS(g+48|0);if(Gb(g+48|0,g+32|0)){continue}break}}f=ad(g+48|0);t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c&12)==12){d=0;while(1){j=B(d,160)+a|0;i=j+906300|0;e=i;c=e+16|0;h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=e+20|0;C:{if(!(h|(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)))){break C}v[22640]=0;Q(1315,i|0,a|0)|0;c=v[22640];v[22640]=0;D:{if((c|0)!=1){c=v[i>>2];if(!c){break D}e=v[j+906448>>2];i=v[v[c>>2]+56>>2];v[22640]=0;R(i|0,c|0,e|0);c=v[22640];v[22640]=0;if((c|0)!=1){break C}}a=P()|0;O()|0;break t}e=Sb(f);h=Wb(f);c=gb-32|0;gb=c;v[c+16>>2]=h;v[c+24>>2]=e;v[c+8>>2]=i;if(Gb(c+24|0,c+16|0)){while(1){e=v[v[c+24>>2]>>2];h=v[c+8>>2];if((w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24))==(w[h+20|0]|w[h+21|0]<<8|(w[h+22|0]<<16|w[h+23|0]<<24))){h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=v[c+8>>2];e=(h|0)==(w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24))}else{e=0}if(!e){Fg(c+24|0);if(Gb(c+24|0,c+16|0)){continue}}break}e=v[c+24>>2]}gb=c+32|0;v[g+32>>2]=e;k=g,l=Wb(f),v[k+16>>2]=l;if(Gb(g+32|0,g+16|0)){break C}v[22640]=0;v[g+32>>2]=j+906316;R(1316,f|0,g+32|0);c=v[22640];v[22640]=0;if((c|0)==1){break u}v[22640]=0;c=Q(2,g+16|0,14763)|0;e=v[22640];v[22640]=0;if((e|0)==1){break B}v[22640]=0;R(1317,g|0,i|0);e=v[22640];v[22640]=0;if((e|0)==1){break A}v[22640]=0;U(3,g+32|0,c|0,g|0);e=v[22640];v[22640]=0;if((e|0)==1){break z}v[22640]=0;U(580,a|0,2,g+32|0);e=v[22640];v[22640]=0;if((e|0)==1){break y}vb(g+32|0);vb(g);vb(c)}d=d+1|0;if((d|0)!=250){continue}break}}c=w[a+1074368|0];v[22640]=0;R(1318,a|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break v}c=v[a+480180>>2];E:{if(!c){break E}$t(a+8|0,Fq(a));if(!v[a+1074308>>2]){break E}v[22640]=0;_(1319,a|0);a=v[22640];v[22640]=0;if((a|0)==1){break v}}Gl(f);f=(c|0)!=0;break a}a=P()|0;O()|0;break t}a=P()|0;O()|0;break w}a=P()|0;O()|0;break x}a=P()|0;O()|0;vb(g+32|0)}vb(g)}vb(c);break t}a=P()|0;O()|0;break t}a=P()|0;O()|0}Gl(f);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0}yb(b);S(a|0);L()}Uz(i)}yb(b);gb=g+208|0;return f|0}function b6(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0,G=0,H=0;k=gb-560|0;gb=k;v[k+44>>2]=0;o(+b);l=j(1)|0;j(0)|0;a:{if((l|0)<-1?1:(l|0)<=-1){z=1;A=2388;b=-b;o(+b);l=j(1)|0;j(0)|0;break a}if(e&2048){z=1;A=2391;break a}z=e&1;A=z?2394:2389;H=!z}b:{if((l&2146435072)==2146435072){p=z+3|0;$f(a,32,c,p,e&-65537);sf(a,A,z);d=f&32;sf(a,b!=b?d?7304:11173:d?8393:11482,3);break b}x=k+16|0;c:{d:{e:{b=UI(b,k+44|0);b=b+b;if(b!=0){g=v[k+44>>2];v[k+44>>2]=g-1;C=f|32;if((C|0)!=97){break e}break c}C=f|32;if((C|0)==97){break c}q=v[k+44>>2];n=(d|0)<0?6:d;break d}q=g-29|0;v[k+44>>2]=q;b=b*268435456;n=(d|0)<0?6:d}s=(q|0)<0?k+48|0:k+336|0;h=s;while(1){d=h;if(b<4294967296&b>=0){g=~~b>>>0}else{g=0}v[d>>2]=g;h=h+4|0;b=(b-+(g>>>0))*1e9;if(b!=0){continue}break}f:{if((q|0)<1){d=q;g=h;i=s;break f}i=s;d=q;while(1){p=(d|0)<29?d:29;g=h-4|0;g:{if(i>>>0>g>>>0){break g}m=p;d=0;l=0;while(1){u=g;G=v[g>>2];r=m&31;if((m&63)>>>0>=32){F=G<<r;r=0}else{F=(1<<r)-1&G>>>32-r;r=G<<r}r=r+d|0;F=l+F|0;l=r;d=pqa(l,d>>>0>l>>>0?F+1|0:F,1e9,0);r=mqa(d,jb,1e9,0);v[u>>2]=l-r;g=g-4|0;if(i>>>0<=g>>>0){l=0;continue}break}if(!d){break g}i=i-4|0;v[i>>2]=d}while(1){g=h;if(i>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[k+44>>2]-p|0;v[k+44>>2]=d;h=g;if((d|0)>0){continue}break}}h=(n+25|0)/9|0;if((d|0)<=-1){r=h+1|0;E=(C|0)==102;while(1){u=(d|0)<-9?9:0-d|0;h:{if(g>>>0>i>>>0){l=1e9>>>u|0;m=-1<<u^-1;d=0;h=i;while(1){p=d;d=v[h>>2];v[h>>2]=p+(d>>>u|0);d=B(l,d&m);h=h+4|0;if(h>>>0<g>>>0){continue}break}i=v[i>>2]?i:i+4|0;if(!d){break h}v[g>>2]=d;g=g+4|0;break h}i=v[i>>2]?i:i+4|0}d=v[k+44>>2]+u|0;v[k+44>>2]=d;h=E?s:i;g=(r|0)<g-h>>2?h+(r<<2)|0:g;if((d|0)<0){continue}break}}h=0;i:{if(g>>>0<=i>>>0){break i}h=B(s-i>>2,9);m=v[i>>2];if(m>>>0<10){break i}d=100;while(1){h=h+1|0;if(d>>>0>m>>>0){break i}d=B(d,10);continue}}d=(n-((C|0)==102?0:h)|0)-((C|0)==103&(n|0)!=0)|0;if((d|0)<(B(g-s>>2,9)-9|0)){l=d+9216|0;m=(l|0)/9|0;p=((m<<2)+((q|0)<0?k+48|4:k+340|0)|0)-4096|0;d=10;j:{l=l-B(m,9)|0;if((l|0)>7){break j}d=100;while(1){l=l+1|0;if((l|0)==8){break j}d=B(d,10);continue}}l=v[p>>2];q=(l>>>0)/(d>>>0)|0;k:{r=l-B(d,q)|0;m=p+4|0;if(!((m|0)==(g|0)?r:1)){break k}b=(g|0)==(m|0)?1:1.5;m=d>>>1|0;y=m>>>0>r>>>0?.5:(m|0)==(r|0)?b:1.5;b=q&1?9007199254740994:9007199254740992;if(!(w[A|0]!=45|H)){y=-y;b=-b}m=l-r|0;v[p>>2]=m;if(b+y==b){break k}d=d+m|0;v[p>>2]=d;if(d>>>0>=1e9){while(1){v[p>>2]=0;p=p-4|0;if(p>>>0<i>>>0){i=i-4|0;v[i>>2]=0}d=v[p>>2]+1|0;v[p>>2]=d;if(d>>>0>999999999){continue}break}}h=B(s-i>>2,9);m=v[i>>2];if(m>>>0<10){break k}d=100;while(1){h=h+1|0;if(d>>>0>m>>>0){break k}d=B(d,10);continue}}d=p+4|0;g=d>>>0<g>>>0?d:g}while(1){q=g;m=g>>>0<=i>>>0;if(!m){g=q-4|0;if(!v[g>>2]){continue}}break}l:{if((C|0)!=103){u=e&8;break l}g=n?n:1;d=(g|0)>(h|0)&(h|0)>-5;n=(d?h^-1:-1)+g|0;f=(d?-1:-2)+f|0;u=e&8;if(u){break l}d=-9;m:{if(m){break m}m=v[q-4>>2];d=-9;if(!m){break m}d=0;if((m>>>0)%10|0){break m}l=0;g=100;while(1){if(!((m>>>0)%(g>>>0)|0)){l=l+1|0;g=B(g,10);continue}break}d=l^-1}g=B(q-s>>2,9)-9|0;if((f&-33)==70){u=0;d=d+g|0;d=(d|0)>0?d:0;n=(d|0)>(n|0)?n:d;break l}u=0;d=d+(g+h|0)|0;d=(d|0)>0?d:0;n=(d|0)>(n|0)?n:d}r=(n|u)!=0;d=a;m=c;l=f&-33;if((l|0)==70){f=(h|0)>0?h:0}else{g=h>>31;g=co(g+h^g,0,x);if((x-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((x-g|0)<2){continue}break}}E=g-2|0;t[E|0]=f;t[g-1|0]=(h|0)<0?45:43;f=x-E|0}p=(f+(r+(n+z|0)|0)|0)+1|0;$f(d,32,m,p,e);sf(a,A,z);$f(a,48,c,p,e^65536);n:{o:{p:{if((l|0)==70){d=k+16|8;h=k+16|9;f=i>>>0>s>>>0?s:i;i=f;while(1){g=co(v[i>>2],0,h);q:{if((f|0)!=(i|0)){if(k+16>>>0>=g>>>0){break q}while(1){g=g-1|0;t[g|0]=48;if(k+16>>>0<g>>>0){continue}break}break q}if((g|0)!=(h|0)){break q}t[k+24|0]=48;g=d}sf(a,g,h-g|0);i=i+4|0;if(s>>>0>=i>>>0){continue}break}g=0;if(!r){break o}sf(a,13880,1);if((n|0)<1|i>>>0>=q>>>0){break p}while(1){g=co(v[i>>2],0,h);if(g>>>0>k+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(k+16>>>0<g>>>0){continue}break}}sf(a,g,(n|0)<9?n:9);g=n-9|0;i=i+4|0;if(q>>>0<=i>>>0){break o}d=(n|0)>9;n=g;if(d){continue}break}break o}r:{if((n|0)<0){break r}f=i>>>0<q>>>0?q:i+4|0;m=k+16|9;d=k+16|8;h=i;while(1){g=co(v[h>>2],0,m);if((m|0)==(g|0)){t[k+24|0]=48;g=d}s:{if((h|0)!=(i|0)){if(k+16>>>0>=g>>>0){break s}while(1){g=g-1|0;t[g|0]=48;if(k+16>>>0<g>>>0){continue}break}break s}sf(a,g,1);g=g+1|0;if(u?0:(n|0)<=0){break s}sf(a,13880,1)}q=g;g=m-g|0;sf(a,q,(g|0)<(n|0)?g:n);n=n-g|0;h=h+4|0;if(f>>>0<=h>>>0){break r}if((n|0)>-1){continue}break}}$f(a,48,n+18|0,18,0);sf(a,E,x-E|0);break n}g=n}$f(a,48,g+9|0,9,0)}break b}n=f&32;q=n?A+9|0:A;t:{if(d>>>0>11){break t}g=12-d|0;if(!g){break t}y=8;while(1){y=y*16;g=g-1|0;if(g){continue}break}if(w[q|0]==45){b=-(y+(-b-y));break t}b=b+y-y}g=v[k+44>>2];h=g>>31;g=co(h^g+h,0,x);if((x|0)==(g|0)){t[k+15|0]=48;g=k+15|0}m=z|2;h=v[k+44>>2];l=g-2|0;t[l|0]=f+15;t[g-1|0]=(h|0)<0?45:43;g=e&8;i=k+16|0;while(1){f=i;s=n;if(D(b)<2147483648){h=~~b}else{h=-2147483648}t[i|0]=s|w[h+70992|0];b=(b-+(h|0))*16;i=f+1|0;if(!(!(g?1:(d|0)>0|b!=0)|(i-(k+16|0)|0)!=1)){t[f+1|0]=46;i=f+2|0}if(b!=0){continue}break}f=!d|((i-k|0)-18|0)>=(d|0)?(x-(l+(k+16|0)|0)|0)+i|0:((d+x|0)-l|0)+2|0;p=f+m|0;$f(a,32,c,p,e);sf(a,q,m);$f(a,48,c,p,e^65536);d=i-(k+16|0)|0;sf(a,k+16|0,d);g=d;d=x-l|0;$f(a,48,f-(g+d|0)|0,0,0);sf(a,l,d)}$f(a,32,c,p,e^8192);gb=k+560|0;return((c|0)>(p|0)?c:p)|0}function xP(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,y=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=C(0),L=C(0),M=0,N=0,O=C(0),P=0;j=gb-48|0;gb=j;m=x[a+480192>>1]?v[(B(b,872)+a|0)+1075648>>2]:m;n=a+1074312|0;f=B(b,872)+a|0;q=f+1075791|0;A=f+1075680|0;D=f+1075768|0;r=f+1075744|0;y=f+1075740|0;E=f+1075712|0;F=f+1075684|0;G=f+1075676|0;H=f+1075656|0;I=f+1075778|0;J=f+1075080|0;g=e&127;K=C(g>>>0);s=f+1075842|0;L=C(w[s|0]);f=1;while(1){e=w[d+o|0];if(e){h=e-48|0;a:{b:{if((h&255)>>>0<10){break b}if((e-65&255)>>>0<=5){h=e-55|0;break b}c:{d:{e:{switch(e-97|0){case 2:f:{e=Im(a,b,3,0);if(!e|e-251>>>0<5){break f}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break f}e=Vw(e,50704,50736);if(!e){break f}h=kb[v[v[e>>2]+188>>2]](e,b)|0;e=(h|0)!=255;h=e?h:0;if(e|!m){break b}break c}if(m){break c}h=0;break b;case 13:e=0;if(!ve(w[q|0])){break d}e=w[q|0]-1|0;break d;case 21:Db(j+8|0,n,28);g:{if(!Cb(j+8|0)){Db(j,n,1);e=0;if(!Cb(j)){break g}}e=u[D>>1]}h=B(v[r>>2],v[y>>2]);e=B(v[a+1074456>>2],e+v[A>>2]|0);e=Lb((zc(nqa(mqa(h,h>>31,e,e>>31),jb,1048576,0),jb)|0)/2|0,1,127);break d;case 23:v[j+8>>2]=v[F>>2]/2;v[j>>2]=127;e=v[ld(j+8|0,j)>>2];break d;case 24:v[j+8>>2]=v[G>>2]/2;v[j>>2]=127;e=v[ld(j+8|0,j)>>2];break d;case 0:e=0;if(!m){break d}h=x[m+28>>1];if(!h){break d}e=h-1>>>7&127;break d;case 1:e=0;if(!m){break d}h=x[m+28>>1];if(!h){break d}e=h-1&127;break d;case 14:e=v[H>>2]>>>8|0;break d;case 7:e=b;if(e>>>0>=x[a+480188>>1]){e=w[I|0]-1|0}e=e&127;break d;case 12:e=v[J>>2]>>>7&1;break d;case 15:e=0;if(!m){break d}h=w[m+30|0];if(!h){break d}e=h-1&127;break d;case 25:l=s;e=g;h:{if(!c){break h}e=g;if(t[s|0]<0){break h}i:{if(i>>>0<3){break i}k=(j+16|0)+i|0;if(w[k-3|0]!=240){break i}e=g;if(w[k-2|0]>239){break h}}p=Iq(a,L,K);if(p<C(4294967296)&p>=C(0)){e=~~p>>>0;break h}e=0}t[l|0]=e;break d;case 18:e=i;j:{if(!e){e=0;break j}while(1){e=e-1|0;if(w[e+(j+16|0)|0]==240){break j}if(e){continue}break}}if(w[(j+16|0)+e|0]!=240|i-e>>>0<5){break a}h=0;e=e+5|0;if((i|0)==(e|0)){e=0}else{while(1){h=w[(j+16|0)+e|0]+h|0;e=e+1|0;if((i|0)!=(e|0)){continue}break}e=0-h|0}e=e&127;break d;case 20:break e;default:break a}}e=B(v[r>>2],v[y>>2]);k=e;l=e>>31;e=B(v[a+1074456>>2],v[E>>2]);e=Lb((zc(nqa(mqa(k,l,e,e>>31),jb,67108864,0),jb)|0)/2|0,1,127)}h=f^-1;f=1;i=(h&1)+i|0;t[i+(j+16|0)|0]=e;i=i+1|0;break a}e=m;l=a;h=0;k=b;k:{if(k>>>0>=256){break k}if(w[e+31|0]==17){e=x[(l+B(k,872)|0)+1075778>>1];h=(e?e-1|0:k)&15;break k}if(!Fj(e)){break k}h=w[e+31|0]-1&15}}e=(j+16|0)+i|0;l:{if(f&1){t[e|0]=h;break l}t[e|0]=w[e|0]<<4|h;i=i+1|0}f=(f^-1)&1}o=o+1|0;if((o|0)!=31){continue}}break}e=((f^-1)&1)+i|0;m:{if(!e){break m}h=0;f=0;while(1){l=(j+16|0)+f|0;d=t[l|0];n:{o:{p:{if((d|0)==-16){if(e-f>>>0>=4){o=4;if((w[(f+j|0)+17|0]&254)==240){break o}}o=f;q:{while(1){o=o+1|0;if(o>>>0>=e>>>0){break q}if(w[(j+16|0)+o|0]!=247){continue}break}d=o-f|0;o=d+1|0;if(o>>>0>=d>>>0){break o}}t[(j+16|0)+e|0]=247;e=e+1|0;o=e-f|0;break p}if((d|0)>=0){if(h&255){f=f-1|0;t[f+(j+16|0)|0]=h;break n}f=f+1|0;h=0;break n}M=j,N=_S(d&255),v[M+8>>2]=N;v[j>>2]=e-f;o=v[Fb(j+8|0,j)>>2]}if(!o){break m}d=w[l|0];h=d>>>0<240?d:h}s=f;d=a;f=b;m=c;k=gb-32|0;gb=k;i=o;v[k+28>>2]=i;g=w[l|0];n=g-250|0;if(!(n>>>0>5|!(1<<n&37))){if(x[d+480188>>1]){g=0;while(1){n=(d+B(g,872)|0)+1075829|0;t[n|0]=127;t[n+1|0]=0;g=g+1|0;if(g>>>0<x[d+480188>>1]){continue}break}}g=w[l|0]}r:{s:{if((g&255)!=240){break s}n=w[l+1|0];if((n&254)!=240){break s}g=i>>>0<4;i=0;if(g){break r}r=(d+B(f,872)|0)+1074992|0;q=w[l+2|0];g=t[l+3|0];if(!(q|(n|0)==241|(g|0)<0)){l=d+B(f,872)|0;i=l+1075829|0;n=i;if(m){g=cA(Iq(d,C(w[i|0]),C((g&255)>>>0)))}t[n|0]=g;t[l+1075788|0]=0;i=4;g=l+1075080|0;m=Oq(d,r,!(v[g>>2]&32768),256);if((m|0)<0|!(w[g+1|0]&2)){break r}d=d+1298260|0;if(!Bd(d)){break r}Vq(v[d>>2],f,m>>>2&255,1);break r}if(!((n|0)==241|(q|0)!=1|(g|0)<0)){i=d+B(f,872)|0;f=i+1075830|0;t:{if(!m){break t}p=Iq(d,C(w[f|0]),C((g&255)>>>0));if(p<C(4294967296)&p>=C(0)){g=~~p>>>0;break t}g=0}t[f|0]=g;t[i+1075787|0]=0;Oq(d,r,!(v[i+1075080>>2]&32768),256);i=4;break r}if(!((n|0)==241|(q|0)!=2)){i=4;if((g&255)>>>0>31){break r}f=d+B(f,872)|0;t[f+1075837|0]=(g&240)>>>4;Oq(d,r,!(v[f+1075080>>2]&32768),256);break r}if(!((n|0)==241|(q|0)!=3)){i=4;f=Im(d,f,3,0);if((g|0)<0|(f+5&255)>>>0<6){break r}f=(d+B(f,160)|0)+906284|0;p=C(C(((g^127)&255)>>>0)*C(.007874015718698502));if(!m){z[f>>2]=p;break r}M=f,O=Iq(d,z[f>>2],p),z[M>>2]=O;break r}if(!((n|0)!=241?q&128:1)){break r}i=4;f=Im(d,f,3,0);if((f+5&255)>>>0<6){break r}f=v[(d+B(f,160)|0)+906140>>2];if(!f|(g|0)<0){break r}l=(n|0)==241?q+128|0:q&127;p=C(C((g&255)>>>0)*C(.007874015718698502));if(!m){kb[v[v[f>>2]+44>>2]](f,l,p);break r}N=f,P=l,O=Iq(d,C(kb[v[v[f>>2]+48>>2]](f,l)),p),M=v[v[f>>2]+44>>2],kb[M](N|0,P|0,C(O));break r}u:{if(f>>>0<x[d+480188>>1]){g=f+1|0;break u}g=x[(d+B(f,872)|0)+1075778>>1];if(!g){break r}}if(w[(d+B(f,872)|0)+1075083|0]&4|x[d+480188>>1]<(g&65535)>>>0){break r}g=Im(d,f,3,0);if(!g|g-251>>>0<5){break r}d=v[(d+B(g,160)|0)+906140>>2];if(!d){break r}g=w[l|0];if((g|0)==240){bc(k+16|0,zb(l),i);g=v[v[d>>2]+72>>2];f=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=f;kb[g|0](d,k)|0;break r}M=k,P=_S(g),v[M+12>>2]=P;g=v[Fb(k+12|0,k+28|0)>>2];v[k+12>>2]=0;hc(k+12|0,l,g);kb[v[v[d>>2]+68>>2]](d,v[k+12>>2])|0;i=v[k+28>>2]}gb=k+32|0;f=(i?i:o)+s|0}if(e>>>0>f>>>0){continue}break}}gb=j+48|0}function Tka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-336|0;gb=e;Xc(b,60);j=15;a:{if(!Fh(b,11467)){Xc(b,124);j=31;if(!Fh(b,12540)){break a}}Gd(a,536870912);u[a+480190>>1]=j;vc(b);b:{if(x[a+480190>>1]){while(1){d=Jv(b);v[(e+208|0)+(f<<2)>>2]=d;if(d>>>0>131072){break b}f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break}}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;f=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;rh(a,1);Yb(b,4);d=Lv(b);if(d>>>0<178){break a}f=a;o=177693e5/+(d>>>0);c:{if(o<4294967296&o>=0){d=~~o>>>0;break c}d=0}v[f+480204>>2]=d;Yb(b,14);d:{e:{f:{if(x[a+480190>>1]){p=e+62|0;k=1;j=0;m=1;while(1){vV(b,e+40|0);d=v[((k<<2)+e|0)+204>>2];l=gb-16|0;gb=l;h=(B(k,104)+a|0)+484380|0;td(h,1);v[h>>2]=d;d=e+40|0;t[h+37|0]=w[d+24|0]<<4;t[l+15|0]=w[d+25|0];t[l+14|0]=64;q=h,r=w[ac(l+15|0,l+14|0)|0]<<2,u[q+30>>1]=r;f=d+26|0;g=Ib(w[f|0]|w[f+1|0]<<8);d=d+28|0;d=Ib(w[d|0]|w[d+1|0]<<8);f=v[h>>2];g:{if(!f){break g}v[h+4>>2]=g;d=(d<<1)+g|0;v[h+8>>2]=d;if(f>>>0<=g>>>0){g=f-1|0;v[h+4>>2]=g}if(d>>>0>f>>>0){v[h+8>>2]=f;d=f}if(!(d-g>>>0>3?!(d>>>0<g>>>0|d>>>0<4):0)){v[h+4>>2]=0;v[h+8>>2]=0;break g}if(d>>>0<=g>>>0){break g}u[h+34>>1]=x[h+34>>1]|2}gb=l+16|0;f=e+40|0;while(1){if((w[f|0]-1&255)>>>0<=30){t[f|0]=32;j=j+1|0}f=f+1|0;if((p|0)!=(f|0)){continue}break}if(j>>>0>127){break b}Mk(e+176|0,3,e+40|0);Bc(e+192|0,e+176|0);v[22640]=0;Q(333,((k<<5)+a|0)+946304|0,e+192|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break f}vb(e+192|0);m=m+1|0;k=m&65535;if(k>>>0<=x[a+480190>>1]){continue}break}}d=Tb(e+40|0,11352);v[22640]=0;h=a+946336|0;f=Q(901,h|0,d|0)|0;k=v[22640];v[22640]=0;j=1;h:{i:{j:{k:{if((k|0)!=1){if(!f){v[22640]=0;f=Q(112,e+192|0,11363)|0;j=v[22640];v[22640]=0;if((j|0)==1){break k}v[22640]=0;j=Q(901,h|0,f|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break j}vb(f)}vb(d);f=0;d=e+40|0;h=oV(b,d);if(!h){mV(d)}if(!h){break a}if(!oU(e+40|0)){break a}if(c){break h}break d}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(f)}vb(d);break e}u[e+38>>1]=0;if(w[e+40|0]){while(1){u[e+192>>1]=w[(e+f|0)+42|0]+1;q=e,r=x[Ie(e+38|0,e+192|0)>>1],u[q+38>>1]=r;f=f+1|0;if(f>>>0<w[e+40|0]){continue}break}}d=e+40|1;f=w[d|0];h=w[e+40|0];k=a+484360|0;af(Rb(k),f>>>0<h>>>0?w[d|0]:0);Fr(Rb(k),e+40|2,w[e+40|0]);if(x[a+480190>>1]==31){Yb(b,4)}k=0;v[e+32>>2]=0;v[e+28>>2]=0;v[e+24>>2]=0;t[e+23|0]=0;l=c&1;if(l){vg(a+484344|0,x[e+38>>1])}if(x[e+38>>1]){h=a+484344|0;while(1){l:{m:{if(l){m=0;if(qh(h,k&65535,64)){break m}}Yb(b,1024);break l}while(1){p=Tc(_b(h,k),m,0);f=0;while(1){xn(e+192|0,b);d=p+B(f,6)|0;n:{o:{p:{q:{if(w[lc(e+192|0,0)|0]!=255){break q}t[(e+32|0)+f|0]=0;t[(e+24|0)+f|0]=0;g=lc(e+192|0,1);i=w[g|0];if((i|0)==252&j){t[g|0]=254;break o}switch(i-252|0){case 1:break n;case 2:break o;case 0:break p;default:break q}}g=v[e+192>>2];v[e+16>>2]=g;v[e+8>>2]=g;gr(e+8|0,d);g=w[d|0];r:{if(!g){break r}t[(e+24|0)+f|0]=0;t[(e+32|0)+f|0]=g;if(g>>>0>48){break r}t[e+176|0]=8;q=e,r=w[Bf(e+23|0,e+176|0)|0],t[q+23|0]=r}s:{t:{u:{v:{w:{x:{switch(w[d+3|0]){case 1:t[d+3|0]=1;break n;case 2:g=w[d+5|0];if(g&240){t[d+3|0]=3;t[d+5|0]=g>>>4;break n}g=g&15;if(g){t[d+3|0]=2;t[d+5|0]=g;break n}t[d+5|0]=0;break t;case 3:if(w[(e+24|0)+f|0]){break u}t[d+3|0]=19;t[d+5|0]=0;break n;case 4:if(w[(e+24|0)+f|0]){break u}t[d+3|0]=19;t[d+5|0]=1;break n;case 5:if(!w[d+1|0]){break u}t[d+3|0]=13;t[e+176|0]=63;t[e+15|0]=w[d+5|0]+(x[(B(w[d+1|0],104)+a|0)+484410>>1]>>>2|0);q=d,r=w[ac(e+176|0,e+15|0)|0],t[q+5|0]=r;if(!w[(e+24|0)+f|0]){break w}t[d+2|0]=1;t[d+4|0]=w[d+5|0];t[d+5|0]=0;break t;case 6:g=w[d+1|0];if(!g){break u}t[d+3|0]=13;g=x[(B(g,104)+a|0)+484410>>1]>>>2|0;i=w[d+5|0];g=g>>>0<i>>>0?0:g-i|0;t[d+5|0]=g;if(!w[(e+24|0)+f|0]){break w}t[d+4|0]=g;t[d+2|0]=1;t[d+5|0]=0;break t;case 8:g=w[(e+32|0)+f|0];i=w[d+5|0];n=g+(i>>>4|0)|0;t[(e+28|0)+f|0]=n;t[d+3|0]=2;i=i&15;t[(e+24|0)+f|0]=i;q=d,r=nU(i,g,n&255),t[q+5|0]=r;break w;case 9:t[e+176|0]=8;q=e,r=w[Bf(e+23|0,e+176|0)|0],t[q+23|0]=r;break t;case 0:break v;case 7:break x;default:break t}}g=w[(e+32|0)+f|0];i=w[d+5|0];n=g-(i>>>4|0)|0;t[(e+28|0)+f|0]=n;t[d+3|0]=3;i=i&15;t[(e+24|0)+f|0]=i;q=d,r=nU(i,n&255,g),t[q+5|0]=r}if(!w[d+3|0]){break s}break n}if(!w[d+5|0]){break s}break t}t[d+5|0]=0}t[d+3|0]=0}i=w[(e+24|0)+f|0];if(!i){break n}n=(e+28|0)+f|0;g=w[n|0];if(g){t[(e+32|0)+f|0]=g;t[d|0]=g;t[d+5|0]=i;t[n|0]=0}t[d+3|0]=4;break n}t[d+3|0]=14;t[e+23|0]=9;break n}t[d+3|0]=13}f=f+1|0;if((f|0)!=4){continue}break}m=m+1|0;if((m|0)!=64){continue}break}}k=k+1|0;if(k>>>0<x[e+38>>1]){continue}break}}y:{z:{A:{B:{if(c&2){j=x[a+480190>>1];if(!j){break A}f=1;while(1){c=(B(f&65535,104)+a|0)+484380|0;if(v[c>>2]){zg(Pc(e+192|0,8,1,0,0),c,b);j=x[a+480190>>1]}f=f+1|0;if((f&65535)>>>0<=(j&65535)>>>0){continue}break}break B}j=x[a+480190>>1]}if((j&65535)!=15){break A}b=gb-16|0;gb=b;c=Tb(b,1514);Dc(e+176|0,c);vb(c);gb=b+16|0;v[22640]=0;U(488,e+192|0,e+176|0,e+23|0);b=v[22640];v[22640]=0;f=1;if((b|0)!=1){break z}a=P()|0;O()|0;Hb(e+176|0);break e}f=0;v[22640]=0;Q(2,e+192|0,9610)|0;b=v[22640];v[22640]=0;if((b|0)==1){break y}}Eb(a+1298304|0,e+192|0);vb(e+192|0);if(f){Hb(e+176|0)}Vc(a+1298316|0,x[a+480190>>1]==15?2374:12329);v[a+1298364>>2]=2;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(e+192|0)}S(a|0);L()}f=1;break a}f=0}gb=e+336|0;return f|0}function DK(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=gb-48|0;gb=g;v[g+44>>2]=c;u[g+32>>1]=0;u[g+16>>1]=65535;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(At(g+44|0,g+32|0,g+16|0)){if(ke(v[b+24>>2]+484344|0,c&65535)){break j}}c=a;a=Kb(g+32|0);b=Kb(g+16|0);zi(c,a,b);vb(b);vb(a);break i}c=_b(v[b+24>>2]+484344|0,c);if(!(v[c+12>>2]>(d|0)?(d|0)>=0:0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);zi(c,a,b);vb(b);vb(a);break i}if(!(x[v[b+24>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);zi(c,a,b);vb(b);vb(a);break i}if(f>>>0>=6){c=a;a=Kb(g+32|0);b=Kb(g+16|0);zi(c,a,b);vb(b);vb(a);break i}e=Tc(c,d,e&65535);k:{switch(f|0){case 0:l:{m:{n:{if(!ce(e)){if(!Tt(e)){break n}}XO(g+16|0,v[b+24>>2],w[e|0],w[e+1|0]);v[22640]=0;R(2039,g+32|0,g+16|0);c=v[22640];v[22640]=0;b=1;if((c|0)!=1){break m}c=P()|0;O()|0;break b}b=0;v[22640]=0;Q(112,g+32|0,13874)|0;c=v[22640];v[22640]=0;if((c|0)==1){break l}}v[22640]=0;c=ce(e);d=v[22640];v[22640]=0;if((d|0)==1){break c}o:{if(c){v[22640]=0;Q(112,g|0,7294)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}break o}if(Tt(e)){v[22640]=0;Q(112,g|0,7604)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break o}break c}v[22640]=0;Q(112,g|0,13874)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}}zi(a,g+32|0,g);vb(g);vb(g+32|0);if(!b){break i}vb(g+16|0);break i}c=P()|0;O()|0;break a;case 1:b=e+1|0;p:{if(w[e+1|0]){bv(g+32|0,b);break p}Tb(g+32|0,13879)}q:{if(w[b|0]){v[22640]=0;Q(112,g+16|0,8111)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break q}break d}v[22640]=0;Q(112,g+16|0,13879)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}}zi(a,g+32|0,g+16|0);vb(g+16|0);vb(g+32|0);break i;case 2:r:{if(xg(e)){Tb(g+32|0,14878);break r}if(w[e+2|0]){Ge(g+32|0,1,hz(v[v[b+24>>2]+8>>2],w[e+2|0]));break r}Tb(g+32|0,14878)}v[22640]=0;b=xg(e);c=v[22640];v[22640]=0;if((c|0)==1){break e}s:{if(b){v[22640]=0;Q(112,g+16|0,14878)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}break s}if(w[e+2|0]){v[22640]=0;Q(112,g+16|0,2597)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break s}break e}v[22640]=0;Q(112,g+16|0,14878)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}}zi(a,g+32|0,g+16|0);vb(g+16|0);vb(g+32|0);break i;case 4:t:{if(xg(e)){q=g,r=Mq(e)&255,v[q>>2]=r;XB(g+32|0,g);break t}if(w[e+2|0]){bv(g+32|0,e+4|0);break t}Tb(g+32|0,13879)}v[22640]=0;b=xg(e);c=v[22640];v[22640]=0;if((c|0)==1){break f}u:{if(b){v[22640]=0;Q(112,g+16|0,2581)|0;b=v[22640];v[22640]=0;if((b|0)==1){break f}break u}if(w[e+2|0]){v[22640]=0;Q(112,g+16|0,2581)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break u}break f}v[22640]=0;Q(112,g+16|0,13879)|0;b=v[22640];v[22640]=0;if((b|0)==1){break f}}zi(a,g+32|0,g+16|0);vb(g+16|0);vb(g+32|0);break i;case 3:v:{if(xg(e)){q=g,r=(Eo(e)&3840)!=0,t[q|0]=r;i=gb-32|0;gb=i;t[i+24|0]=44;v[i+16>>2]=-1;v[i+20>>2]=0;v[i+8>>2]=1058;v[i+12>>2]=1;n=g+32|0;c=g;b=gb+-64|0;gb=b;d=b;k=i+8|0;l=v[k>>2]&2?16:10;j=gb-32|0;gb=j;f=Ge(j+16|0,1,0);w:{x:{y:{while(1){h=Jb(f);m=Jb(f);o=Ab(f);p=w[c|0];v[22640]=0;ha(133,j+8|0,h|0,m+o|0,p|0,l|0);h=v[22640];v[22640]=0;if((h|0)==1){break x}if(!v[j+12>>2]){break y}h=Ab(f);v[22640]=0;v[j+4>>2]=h;h=wf(j+4|0);m=v[22640];v[22640]=0;if((m|0)!=1){v[22640]=0;U(117,f|0,h|0,0);h=v[22640];v[22640]=0;if((h|0)!=1){continue}}break}break x}c=v[j+8>>2];l=Jb(f);v[22640]=0;R(118,f|0,c-l|0);c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;R(119,d|0,f|0);c=v[22640];v[22640]=0;if((c|0)==1){break x}vb(f);gb=j+32|0;break w}}a=P()|0;O()|0;vb(f);S(a|0);L()}Al(b+16|0,b,k);v[22640]=0;U(131,b+32|0,b+16|0,k|0);c=v[22640];v[22640]=0;z:{A:{B:{C:{D:{if((c|0)!=1){v[22640]=0;U(132,b+48|0,b+32|0,k|0);c=v[22640];v[22640]=0;if((c|0)==1){break D}v[22640]=0;R(114,n|0,b+48|0);c=v[22640];v[22640]=0;if((c|0)==1){break C}vb(b+48|0);vb(b+32|0);vb(b+16|0);vb(b);gb=b- -64|0;break z}a=P()|0;O()|0;break A}a=P()|0;O()|0;break B}a=P()|0;O()|0;vb(b+48|0)}vb(b+32|0)}vb(b+16|0);vb(b);S(a|0);L()}gb=i+32|0;break v}if(w[e+3|0]){Ge(g+32|0,1,gz(v[v[b+24>>2]+8>>2],w[e+3|0]));break v}Tb(g+32|0,13880)}v[22640]=0;b=xg(e);c=v[22640];v[22640]=0;if((c|0)==1){break g}E:{if(b){v[22640]=0;Q(112,g+16|0,9601)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}break E}if(w[e+3|0]){v[22640]=0;Q(112,g+16|0,9601)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break E}break g}v[22640]=0;Q(112,g+16|0,13880)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}}zi(a,g+32|0,g+16|0);vb(g+16|0);vb(g+32|0);break i;case 5:F:{if(xg(e)){q=g,r=Eo(e)&255,v[q>>2]=r;XB(g+32|0,g);break F}if(w[e+3|0]){bv(g+32|0,e+5|0);break F}Tb(g+32|0,13879)}v[22640]=0;b=xg(e);c=v[22640];v[22640]=0;if((c|0)==1){break h}G:{if(b){v[22640]=0;Q(112,g+16|0,8410)|0;b=v[22640];v[22640]=0;if((b|0)==1){break h}break G}if(w[e+3|0]){v[22640]=0;Q(112,g+16|0,8410)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break G}break h}v[22640]=0;Q(112,g+16|0,13879)|0;b=v[22640];v[22640]=0;if((b|0)==1){break h}}zi(a,g+32|0,g+16|0);vb(g+16|0);vb(g+32|0);break i;default:break k}}c=a;a=Kb(g+32|0);b=Kb(g+16|0);zi(c,a,b);vb(b);vb(a)}gb=g+48|0;return}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);break a}c=P()|0;O()|0;vb(g+32|0);if(!b){break a}}vb(g+16|0)}S(c|0);L()}function tma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;d=gb-1824|0;gb=d;vc(b);g=gb-32|0;gb=g;j=d+1224|0;kV(g+24|0,j);i=xb(g+24|0);e=v[g+28>>2];k=v[g+24>>2];v[g+8>>2]=k;v[g+12>>2]=e;v[g>>2]=k;v[g+4>>2]=e;e=b;fc(g+16|0,e,g);k=xb(g+16|0);if((k|0)==(i|0)){Yb(e,xb(g+24|0))}gb=g+32|0;e=(i|0)==(k|0);if(!e){iV(j)}a:{if(!e){break a}if(!uV(d+1224|0)){break a}if(!RB(b,16,0)){break a}v[d+1216>>2]=v[d+1240>>2];e=v[d+1228>>2];v[d+1200>>2]=v[d+1224>>2];v[d+1204>>2]=e;e=d+1232|0;h=v[e+4>>2];v[d+1208>>2]=v[e>>2];v[d+1212>>2]=h;Gd(a,1);e=a+1074312|0;Yf(e,83);Ob(e,84,1);Ob(e,85,1);u[a+480188>>1]=4;v[d+1196>>2]=0;u[a+480190>>1]=15;Xc(b,20);k=a+480188|0;h=1;g=1;while(1){i=B(h,104)+a|0;j=i+484380|0;e=((h<<5)+a|0)+946304|0;SB(b,d+16|0,j,e,1);m=v[j>>2];b:{if(!w[lc(e,0)|0]){break b}c:{if(yd(e,13882,3)){if(yd(e,13886,3)){break c}}if(w[lc(e,5)|0]==58){break b}}g=0}if(Ib(w[d+44|0]|w[d+45|0]<<8)>>>0>=2){z=i+484384|0,A=Ib(w[d+42|0]|w[d+43|0]<<8),v[z>>2]=A;z=i+484388|0,A=Ib(w[d+42|0]|w[d+43|0]<<8)+(Ib(w[d+44|0]|w[d+45|0]<<8)<<1)|0,v[z>>2]=A;wk(j)}d:{if(Ib(w[d+38|0]|w[d+39|0]<<8)>>>0<=4999){if(Ib(w[d+42|0]|w[d+43|0]<<8)>>>0<1e4){break d}}v[d+1064>>2]=5;z=d,A=v[_o(d+1196|0,d+1064|0)>>2],v[z+1196>>2]=A}f=f+m|0;h=h+1|0;if((h|0)!=16){continue}break}AV(b,d+1064|0);p=a+484360|0;Fr(Rb(p),d+1064|2,128);h=0;m=zV(b,Rb(p),w[d+1064|0],f,k,0,1);e=d+1064|1;if(!(m>>>0<2?w[e|0]|w[d+1064|0]:1)){break a}if(xf(b)+65536>>>0<(m<<10)+f>>>0){break a}if(!c){h=1;break a}if(!w[e|0]){t[e|0]=120}if(!yd(d+1200|0,12139,6)){t[e|0]=120}v[a+480204>>2]=125e4;e:{if(w[e|0]==120){break e}f=a;r=145364549.18032786/+(240-w[e|0]|0);f:{if(r<4294967296&r>=0){e=~~r>>>0;break f}e=0}v[f+480204>>2]=e;if(v[d+1196>>2]>=2){v[d+16>>2]=g?4:5;z=d,A=v[_o(d+1196|0,d+16|0)>>2],v[z+1196>>2]=A;break e}v[d+16>>2]=g?1:2;z=d,A=v[_o(d+1196|0,d+16|0)>>2],v[z+1196>>2]=A}v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|2097152;Vj(d+1048|0,3,d+1200|0);Bc(d+16|0,d+1048|0);Eb(a+1298268|0,d+16|0);vb(d+16|0);j=0;rh(a,0);s=v[b+8>>2];u[d+1046>>1]=0;g:{if(m){while(1){f=Rb(p);z=d,A=PB(Sb(f),Wb(f),d+1046|0),v[z+16>>2]=A;z=d,A=Wb(f),v[z+1048>>2]=A;f=Gb(d+16|0,d+1048|0);tV(b,d+16|0);if(f){j=OB(d+16|0,0)+j|0;if(j>>>0>512){break g}}k=0;f=0;o=0;while(1){y=sV(d+16|0,k);h=0;while(1){e=f;l=ci(y,h);q=w[lc(l,2)|0]&15;i=w[lc(l,3)|0];f=0;h:{if(!(e&255)|(w[l|0]|w[l+1|0]<<8|(w[l+2|0]<<16|w[l+3|0]<<24))){break h}f=e+1|0;if((f&255)>>>0<33){break h}v[d+1196>>2]=6}i:{j:{k:{switch(q-1|0){case 0:case 1:e=v[d+1196>>2];if((e|0)==1?i>>>0>=32:0){break j}l=(q|0)!=1;if(!(l|!i|i>>>0>2)){v[d+1048>>2]=2;z=d,A=v[_o(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break i}if(l){break i}if((i|0)!=55){if((i|0)!=71){break i}if((e|0)<3){break j}break i}if((e|0)<=2){break j}break i;case 10:v[d+1196>>2]=6;break i;case 11:case 12:case 13:v[d+1048>>2]=2;z=d,A=v[_o(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;if((q|0)!=13){break i}o=((i|k)!=0)+o|0;f=1;break i;case 14:break k;default:break i}}v[d+1048>>2]=3;z=d,A=v[_o(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break i}v[d+1196>>2]=g}h=h+1|0;if((h|0)!=4){continue}break}k=k+1|0;if((k|0)!=64){continue}break}if((o-1&255)>>>0<2){v[d+1196>>2]=6}n=(o&255)+n|0;f=x[d+1046>>1]+1|0;u[d+1046>>1]=f;if(m>>>0>(f&65535)>>>0){continue}break}}if(!(v[d+1196>>2]!=6|m+32>>>0>=n>>>0)){v[d+1196>>2]=5}Xc(b,s);o=c&1;if(o){vg(a+484344|0,m)}if(m){l=a+484344|0;k=0;while(1){tV(b,d+16|0);l:{if(!o){break l}if(!qh(l,k&65535,64)){break l}v[d+1048>>2]=0;n=0;while(1){q=Tc(_b(l,k),n,0);p=sV(d+16|0,n);i=0;while(1){f=ci(p,i);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[d+8>>2]=f;v[d+12>>2]=f;e=q+B(i,6)|0;gr(d+8|0,e);m:{n:{o:{p:{q:{r:{s:{t:{f=w[e+5|0];if(f){h=e+3|0;g=(d+1048|0)+i|0;j=w[e+3|0];if((j|0)!=14){break t}t[g|0]=0;break q}h=(d+1048|0)+i|0;t[h|0]=0;j=w[e+3|0];if(!j){break r}h=e+3|0;break s}g=w[g|0];if(!g){break s}u:{if(g>>>0>=16){t[e+2|0]=3;g=g>>>4|0;break u}t[e+2|0]=4}t[e+4|0]=g}v:{w:{switch(j-12|0){case 1:g=v[d+1196>>2];if((g|0)==6){break v}j=10;t[h|0]=10;break o;case 0:f=f&127;t[e+5|0]=f;j=12;break p;case 2:break q;case 3:break w;default:break p}}j=15;f=f&15;t[e+5|0]=f;break p}t[e+5|0]=0;break n}t[h|0]=0;break m}if(v[d+1196>>2]>3?f>>>0<=1:0){break n}j=10;t[h|0]=10;t[(d+1048|0)+i|0]=f}g=v[d+1196>>2]}if((g|0)>1){break n}x:{y:{z:{switch(j|0){case 0:if(f>>>0>2){break y}break;case 2:break x;case 1:break y;default:break z}}t[h|0]=0;break m}t[h|0]=1;break m}g=f&15;if(g){t[h|0]=2;t[e+5|0]=g;break m}if(f>>>0<16){break m}t[h|0]=3;t[e+5|0]=f>>>4;break m}Mf(e)}i=i+1|0;if((i|0)!=4){continue}break}n=n+1|0;if((n|0)!=64){continue}break}}k=k+1|0;if((m|0)!=(k|0)){continue}break}}h=18693;f=v[d+1196>>2];if(f>>>0<7){h=v[(f<<2)+33576>>2]}f=Tb(d+16|0,5517);Eb(a+1298304|0,f);vb(f);f=Tb(d+16|0,8099);Eb(a+1298316|0,f);vb(f);Vc(a+1298328|0,h);v[a+1298364>>2]=2;h=1;if(!(c&2)){break a}i=1;while(1){c=B(i,104)+a|0;f=c+484384|0;Yb(b,v[f>>2]);e=v[f>>2];v[f>>2]=0;f=c+484380|0;v[f>>2]=v[f>>2]-e;c=c+484388|0;v[c>>2]=v[c>>2]-e;Pc(d+16|0,8,1,1,0);zg(d+16|0,f,b);i=i+1|0;if((i|0)!=16){continue}break}break a}h=0}gb=d+1824|0;return h|0}function Xx(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0,D=0;h=gb-80|0;gb=h;v[h+76>>2]=b;z=h+55|0;x=h+56|0;b=0;a:{b:while(1){c:{if((q|0)<0){break c}if((2147483647-q|0)<(b|0)){v[115121]=61;q=-1;break c}q=b+q|0}d:{e:{f:{g:{h:{n=h;i:{j:{k:{j=v[h+76>>2];b=j;i=w[b|0];if(i){while(1){l:{i=i&255;m:{if(!i){i=b;break m}if((i|0)!=37){break l}i=b;while(1){if(w[b+1|0]!=37){break m}k=b+2|0;v[h+76>>2]=k;i=i+1|0;m=w[b+2|0];b=k;if((m|0)==37){continue}break}}b=i-j|0;if(a){sf(a,j,b)}if(b){continue b}k=!Sh(t[v[h+76>>2]+1|0]);b=v[h+76>>2];if(k|w[b+2|0]!=36){break k}r=t[b+1|0]-48|0;y=1;b=b+3|0;break j}k=b+1|0;v[h+76>>2]=k;i=w[b+1|0];b=k;continue}}o=q;if(a){break a}if(!y){break i}b=1;while(1){a=v[(b<<2)+e>>2];if(a){YI((b<<3)+d|0,a,c,g);o=1;b=b+1|0;if((b|0)!=10){continue}break a}break}o=1;if(b>>>0>9){break a}while(1){o=1;b=b+1|0;if((b|0)==10){break a}o=-1;if(!v[(b<<2)+e>>2]){continue}break}break a}r=-1;b=b+1|0}v[n+76>>2]=b;k=0;l=t[b|0];i=l-32|0;n:{if(i>>>0>31){break n}i=1<<i;if(!(i&75913)){break n}while(1){o:{k=b+1|0;v[h+76>>2]=k;l=t[b+1|0];b=l-32|0;if(b>>>0>=32){break o}b=1<<b;if(!(b&75913)){break o}i=b|i;b=k;continue}break}b=k;k=i}p:{if((l|0)==42){n=h;q:{r:{if(!Sh(t[b+1|0])){break r}b=v[h+76>>2];if(w[b+2|0]!=36){break r}v[((t[b+1|0]<<2)+e|0)-192>>2]=10;p=v[((t[b+1|0]<<3)+d|0)-384>>2];y=1;b=b+3|0;break q}if(y){break d}y=0;p=0;if(a){b=v[c>>2];v[c>>2]=b+4;p=v[b>>2]}b=v[h+76>>2]+1|0}v[n+76>>2]=b;if((p|0)>-1){break p}p=0-p|0;k=k|8192;break p}p=XI(h+76|0);if((p|0)<0){break d}b=v[h+76>>2]}m=-1;s:{if(w[b|0]!=46){break s}if(w[b+1|0]==42){t:{if(!Sh(t[b+2|0])){break t}b=v[h+76>>2];if(w[b+3|0]!=36){break t}v[((t[b+2|0]<<2)+e|0)-192>>2]=10;m=v[((t[b+2|0]<<3)+d|0)-384>>2];b=b+4|0;v[h+76>>2]=b;break s}if(y){break d}if(a){b=v[c>>2];v[c>>2]=b+4;m=v[b>>2]}else{m=0}b=v[h+76>>2]+2|0;v[h+76>>2]=b;break s}v[h+76>>2]=b+1;m=XI(h+76|0);b=v[h+76>>2]}i=0;while(1){s=i;o=-1;if(t[b|0]-65>>>0>57){break a}l=b+1|0;v[h+76>>2]=l;i=t[b|0];b=l;i=w[(i+B(s,58)|0)+70463|0];if(i-1>>>0<8){continue}break}if((i|0)==19){break g}if(!i){break a}if((r|0)>=0){v[(r<<2)+e>>2]=i;b=(r<<3)+d|0;i=v[b+4>>2];v[h+64>>2]=v[b>>2];v[h+68>>2]=i;break f}if(a){break h}}o=0;break a}YI(h- -64|0,i,c,g);l=v[h+76>>2];break e}if((r|0)>-1){break a}}b=0;if(!a){continue}}n=k&-65537;i=k&8192?n:k;o=0;r=2378;k=x;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{b=t[l-1|0];b=s?(b&15)==3?b&-33:b:b;switch(b-88|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break u;case 11:break v;case 9:case 13:case 14:case 15:break w;case 27:break B;case 12:case 17:break E;case 23:break F;case 0:case 32:break G;case 24:break H;case 22:break I;case 29:break J;default:break K}}L:{switch(b-65|0){case 1:case 3:break u;case 0:case 4:case 5:case 6:break w;case 2:break z;default:break L}}if((b|0)==83){break A}break u}l=v[h+64>>2];j=v[h+68>>2];r=2378;break D}b=0;M:{switch(s&255){case 0:v[v[h+64>>2]>>2]=q;continue;case 1:v[v[h+64>>2]>>2]=q;continue;case 2:i=v[h+64>>2];v[i>>2]=q;v[i+4>>2]=q>>31;continue;case 3:u[v[h+64>>2]>>1]=q;continue;case 4:t[v[h+64>>2]]=q;continue;case 6:v[v[h+64>>2]>>2]=q;continue;case 7:break M;default:continue}}i=v[h+64>>2];v[i>>2]=q;v[i+4>>2]=q>>31;continue}m=m>>>0>8?m:8;i=i|8;b=120}n=x;C=b&32;s=v[h+68>>2];j=s;l=v[h+64>>2];if(j|l){while(1){n=n-1|0;t[n|0]=C|w[(l&15)+70992|0];D=!j&l>>>0>15|(j|0)!=0;s=j;j=j>>>4|0;l=(s&15)<<28|l>>>4;if(D){continue}break}}j=n;if(!(i&8)|!(v[h+64>>2]|v[h+68>>2])){break C}r=(b>>>4|0)+2378|0;o=2;break C}b=x;n=v[h+68>>2];j=n;l=v[h+64>>2];if(j|l){while(1){b=b-1|0;t[b|0]=l&7|48;s=!j&l>>>0>7|(j|0)!=0;n=j;j=j>>>3|0;l=(n&7)<<29|l>>>3;if(s){continue}break}}j=b;if(!(i&8)){break C}b=x-j|0;m=(b|0)<(m|0)?m:b+1|0;break C}b=v[h+68>>2];j=b;l=v[h+64>>2];if((b|0)<-1?1:(b|0)<=-1){j=0-(j+((l|0)!=0)|0)|0;l=0-l|0;v[h+64>>2]=l;v[h+68>>2]=j;o=1;r=2378;break D}if(i&2048){o=1;r=2379;break D}o=i&1;r=o?2380:2378}j=co(l,j,x)}i=(m|0)>-1?i&-65537:i;b=v[h+68>>2];n=b;l=v[h+64>>2];if(!((l|0)!=0|(b|0)!=0|m)){m=0;j=x;break u}b=!(l|n)+(x-j|0)|0;m=(b|0)<(m|0)?m:b;break u}b=v[h+64>>2];j=b?b:14164;b=jt(j,0,m);k=b?b:j+m|0;i=n;m=b?b-j|0:m;break u}k=v[h+64>>2];if(m){break y}b=0;$f(a,32,p,0,i);break x}v[h+12>>2]=0;v[h+8>>2]=v[h+64>>2];v[h+64>>2]=h+8;m=-1;k=h+8|0}b=0;N:{while(1){j=v[k>>2];if(!j){break N}j=RI(h+4|0,j);n=(j|0)<0;if(!(n|j>>>0>m-b>>>0)){k=k+4|0;b=b+j|0;if(m>>>0>b>>>0){continue}break N}break}o=-1;if(n){break a}}$f(a,32,p,b,i);if(!b){b=0;break x}k=0;l=v[h+64>>2];while(1){j=v[l>>2];if(!j){break x}j=RI(h+4|0,j);k=j+k|0;if((k|0)>(b|0)){break x}sf(a,h+4|0,j);l=l+4|0;if(b>>>0>k>>>0){continue}break}}$f(a,32,p,b,i^8192);b=(b|0)<(p|0)?p:b;continue}b=kb[f|0](a,A[h+64>>3],p,m,i,b)|0;continue}t[h+55|0]=v[h+64>>2];m=1;j=z;i=n}n=k-j|0;m=(m|0)<(n|0)?n:m;k=m+o|0;b=(k|0)>(p|0)?k:p;$f(a,32,b,k,i);sf(a,r,o);$f(a,48,b,k,i^65536);$f(a,48,m,n,0);sf(a,j,n);$f(a,32,b,k,i^8192);continue}break}o=-1}gb=h+80|0;return o}function jL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-448|0;gb=e;a:{if(nk(b)){break a}f=w[wl(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Kl(e+184|0,b,v[b+4>>2]-1|0);f=v[e+188>>2];v[b>>2]=v[e+184>>2];v[b+4>>2]=f}Kd(e+184|0);f=v[e+184>>2];Kd(e+416|0);h=vl(f,v[e+420>>2],b);Kd(e+184|0);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{if((h|0)==v[e+188>>2]){v[e+440>>2]=f;v[e+444>>2]=g;a=uc(e+432|0,18693);f=v[e+444>>2];v[e+16>>2]=v[e+440>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Fc(e+16|0,e+8|0)){a=aa(8)|0;v[22640]=0;c=Q(2057,e+416|0,c|0)|0;b=v[22640];v[22640]=0;f:{g:{h:{if((b|0)!=1){v[22640]=0;U(2037,e+184|0,14695,c|0);b=v[22640];v[22640]=0;if((b|0)==1){break h}qc(a,e+184|0);d=0;v[22640]=0;U(223,a|0,55256,1936);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);break g}b=P()|0;O()|0;break f}b=P()|0;d=1;O()|0}vb(c);if(!d){break c}}da(a|0);break c}if(!d){break e}d=aa(8)|0;v[22640]=0;f=Q(2057,e+384|0,b|0)|0;b=v[22640];v[22640]=0;a=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[22640]=0;U(2037,e+400|0,14731,f|0);a=v[22640];v[22640]=0;if((a|0)==1){break q}v[22640]=0;R(2054,e+416|0,e+400|0);b=v[22640];v[22640]=0;a=1;if((b|0)==1){break p}v[22640]=0;c=Q(2057,e+368|0,c|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break o}v[22640]=0;U(2058,e+184|0,e+416|0,c|0);b=v[22640];v[22640]=0;a=1;if((b|0)==1){break n}qc(d,e+184|0);v[22640]=0;U(223,d|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}vb(c)}vb(e+416|0)}vb(e+400|0)}vb(f)}if(!a){break c}da(d|0);break c}v[e+360>>2]=f;v[e+364>>2]=g;d=uc(e+352|0,18693);f=v[e+364>>2];v[e+176>>2]=v[e+360>>2];v[e+180>>2]=f;f=v[d+4>>2];v[e+168>>2]=v[d>>2];v[e+172>>2]=f;if(Fc(e+176|0,e+168|0)){a=aa(8)|0;v[22640]=0;c=Q(2057,e+416|0,c|0)|0;b=v[22640];v[22640]=0;r:{s:{t:{if((b|0)!=1){v[22640]=0;U(2037,e+184|0,14695,c|0);b=v[22640];v[22640]=0;if((b|0)==1){break t}qc(a,e+184|0);d=0;v[22640]=0;U(223,a|0,55256,1936);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);break s}b=P()|0;O()|0;break r}b=P()|0;d=1;O()|0}vb(c);if(!d){break c}}da(a|0);break c}d=v[b+4>>2];v[e+344>>2]=v[b>>2];v[e+348>>2]=d;d=uc(e+336|0,9641);f=v[e+348>>2];v[e+160>>2]=v[e+344>>2];v[e+164>>2]=f;f=v[d+4>>2];v[e+152>>2]=v[d>>2];v[e+156>>2]=f;if(Fc(e+160|0,e+152|0)){b=v[c+4>>2];d=v[c>>2];v[e+328>>2]=d;v[e+332>>2]=b;f=uc(e+320|0,2693);g=v[e+332>>2];v[e+64>>2]=v[e+328>>2];v[e+68>>2]=g;g=v[f+4>>2];v[e+56>>2]=v[f>>2];v[e+60>>2]=g;if(Fc(e- -64|0,e+56|0)){v[a+52>>2]=0;break e}v[e+312>>2]=d;v[e+316>>2]=b;f=uc(e+304|0,8625);g=v[e+316>>2];v[e+48>>2]=v[e+312>>2];v[e+52>>2]=g;g=v[f+4>>2];v[e+40>>2]=v[f>>2];v[e+44>>2]=g;if(Fc(e+48|0,e+40|0)){v[a+52>>2]=1;break e}v[e+296>>2]=d;v[e+300>>2]=b;b=uc(e+288|0,6381);d=v[e+300>>2];v[e+32>>2]=v[e+296>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(Fc(e+32|0,e+24|0)){v[a+52>>2]=2;break e}a=aa(8)|0;v[22640]=0;c=Q(2057,e+416|0,c|0)|0;b=v[22640];v[22640]=0;u:{v:{w:{if((b|0)!=1){v[22640]=0;U(2037,e+184|0,11864,c|0);b=v[22640];v[22640]=0;if((b|0)==1){break w}qc(a,e+184|0);d=0;v[22640]=0;U(223,a|0,55256,1936);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+184|0);break v}b=P()|0;O()|0;break u}b=P()|0;d=1;O()|0}vb(c);if(!d){break c}}da(a|0);break c}d=v[b+4>>2];v[e+280>>2]=v[b>>2];v[e+284>>2]=d;b=uc(e+272|0,8862);d=v[e+284>>2];v[e+144>>2]=v[e+280>>2];v[e+148>>2]=d;d=v[b+4>>2];v[e+136>>2]=v[b>>2];v[e+140>>2]=d;if(!Fc(e+144|0,e+136|0)){break e}d=v[c+4>>2];c=v[c>>2];v[e+264>>2]=c;v[e+268>>2]=d;b=uc(e+256|0,12724);f=v[e+268>>2];v[e+128>>2]=v[e+264>>2];v[e+132>>2]=f;f=v[b+4>>2];v[e+120>>2]=v[b>>2];v[e+124>>2]=f;b=0;x:{if(Fc(e+128|0,e+120|0)){break x}v[e+248>>2]=c;v[e+252>>2]=d;b=uc(e+240|0,12729);f=v[e+252>>2];v[e+112>>2]=v[e+248>>2];v[e+116>>2]=f;f=v[b+4>>2];v[e+104>>2]=v[b>>2];v[e+108>>2]=f;b=1;if(Fc(e+112|0,e+104|0)){break x}v[e+232>>2]=c;v[e+236>>2]=d;b=uc(e+224|0,9946);f=v[e+236>>2];v[e+96>>2]=v[e+232>>2];v[e+100>>2]=f;f=v[b+4>>2];v[e+88>>2]=v[b>>2];v[e+92>>2]=f;b=2;if(Fc(e+96|0,e+88|0)){break x}v[e+216>>2]=c;v[e+220>>2]=d;b=uc(e+208|0,6445);c=v[e+220>>2];v[e+80>>2]=v[e+216>>2];v[e+84>>2]=c;c=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=c;b=3;if(Fc(e+80|0,e+72|0)){break x}a=aa(8)|0;v[22640]=0;c=Q(112,e+184|0,8898)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}v[a+56>>2]=b;b=a+24|0;if(!v[v[b>>2]+24668>>2]){break e}c=v[b>>2];d=c+24664|0;f=v[d+4>>2];v[e+200>>2]=v[d>>2];v[e+204>>2]=f;d=c+24656|0;f=v[d+4>>2];v[e+192>>2]=v[d>>2];v[e+196>>2]=f;d=v[c+24652>>2];v[e+184>>2]=v[c+24648>>2];v[e+188>>2]=d;i=e,j=BK(v[a+56>>2]),v[i+204>>2]=j;if(!Dy(e+184|0,v[b>>2]+24648|0)){break e}Hz(v[b>>2],e+184|0)}gb=e+448|0;return}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function sJ(a,b,c,d,e,f){var g=0,h=C(0),i=C(0),j=0,k=0,l=0,m=C(0),n=C(0),o=0,p=0,q=0,r=0,s=0,t=C(0),v=0,w=0,x=0,y=C(0),A=0,D=0,E=0,F=C(0),G=C(0),H=0,I=0,J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0),P=0,Q=0,R=0;if((d|0)>=1){while(1){A=B(v,2304)+b|0;q=c;k=0;s=gb-128|0;while(1){l=A+(k<<2)|0;j=s;o=0;while(1){i=z[B(31-o|0,72)+l>>2];w=B(o,72)+l|0;h=z[w>>2];m=C(i+h);n=z[w+1152>>2];t=z[B(15-o|0,72)+l>>2];y=C(n+t);z[j>>2]=m+y;w=B(o,12);i=C(z[w+68068>>2]*C(h-i));h=C(z[w+68064>>2]*C(t-n));z[j+64>>2]=i+h;n=z[w+68072>>2];z[j+32>>2]=n*C(m-y);z[j+96>>2]=C(i-h)*n;j=j+4|0;o=o+1|0;if((o|0)!=8){continue}break}o=1;j=s;while(1){m=z[j+28>>2];n=z[j>>2];i=C(m+n);t=z[j+16>>2];y=z[j+12>>2];h=C(t+y);F=C(i+h);G=z[j+24>>2];J=z[j+4>>2];K=C(G+J);L=z[j+20>>2];M=z[j+8>>2];N=C(L+M);O=C(K+N);z[j>>2]=F+O;z[j+16>>2]=C(F-O)*C(.7071067690849304);i=C(i-h);h=C(C(i+C(K-N))*C(.7071067690849304));z[j+24>>2]=C(i-h)*C(1.3065630197525024);z[j+8>>2]=C(h+i)*C(.5411961078643799);h=C(J-G);F=C(M-L);G=C(C(h+F)*C(.7071067690849304));i=C(n-m);m=C(G+i);h=C(i+h);n=C(C(C(y-t)+F)+C(h*C(-.1989123672246933)));h=C(C(n*C(.3826834261417389))+h);z[j+28>>2]=C(m-h)*C(2.562915563583374);z[j+4>>2]=C(h+m)*C(.509795606136322);h=C(n+C(h*C(-.1989123672246933)));i=C(i-G);z[j+20>>2]=C(h+i)*C(.8999761939048767);z[j+12>>2]=C(i-h)*C(.601344883441925);if((o|0)!=4){j=j+32|0;o=o+1|0;continue}break}o=0;i=z[s+32>>2];h=z[s+96>>2];n=z[s+64>>2];while(1){j=l;z[j>>2]=z[s+(o<<2)>>2];o=o+1|0;l=s+(o<<2)|0;m=z[l+96>>2];t=C(m+h);z[j+72>>2]=t+n;h=z[l+32>>2];z[j+144>>2]=h+i;n=z[l- -64>>2];z[j+216>>2]=n+t;l=j+288|0;i=h;h=m;if((o|0)!=7){continue}break}z[j+288>>2]=z[s+28>>2];i=z[s+124>>2];z[j+360>>2]=i+z[s+92>>2];h=z[s+60>>2];z[j+504>>2]=i;z[j+432>>2]=h;k=k+1|0;if((q|0)!=(k|0)){continue}break}v=v+1|0;if((v|0)!=(d|0)){continue}break}}I=hc(f,a,3840);P=d<<5;v=0;while(1){l=gb-32|0;gb=l;o=(v<<8)+I|0;w=(v<<2)+b|0;z[o+4080>>2]=z[w+1152>>2];j=d;f=j-1|0;A=w+B(f,2304)|0;z[o+4084>>2]=z[A+1152>>2];z[o+4088>>2]=z[w>>2];z[o+4092>>2]=z[A>>2];z[o+4336>>2]=z[w+1156>>2];z[o+4340>>2]=z[A+1156>>2];z[o+4344>>2]=z[w+4>>2];z[o+4348>>2]=z[A+4>>2];D=(B(v,P)<<1)+e|0;E=D+(f<<1)|0;nt(E,j,o+244|0);f=j<<6;nt(f+E|0,j,o+500|0);nt(D,j,o+240|0);nt(f+D|0,j,o+496|0);H=o+3840|0;q=68160;f=14;while(1){s=f;g=f<<4;k=g+H|0;p=B(31-f|0,72);m=z[p+w>>2];z[k>>2]=m;z[(g|4)+H>>2]=z[p+A>>2];p=p|4;z[(g|8)+H>>2]=z[p+w>>2];z[(g|12)+H>>2]=z[p+A>>2];p=B(f,72);r=p+76|0;z[k+256>>2]=z[r+w>>2];z[k+260>>2]=z[r+A>>2];p=p+72|0;z[k-248>>2]=z[p+w>>2];z[k-244>>2]=z[p+A>>2];i=z[q>>2];p=g+o|0;t=z[p>>2];h=z[q+4>>2];n=C(C(m*i)-C(t*h));z[l+16>>2]=n;m=C(C(t*i)+C(m*h));z[l>>2]=m;r=f<<2;f=1;while(1){g=f<<2;t=z[g+k>>2];y=z[g+p>>2];z[g+(l+16|0)>>2]=C(t*i)-C(y*h);z[g+l>>2]=C(y*i)+C(t*h);f=f+1|0;if((f|0)!=4){continue}break}k=(r<<2)+H|0;p=k-3584|0;r=k-256|0;i=z[q+12>>2];h=z[q+8>>2];f=0;while(1){g=f<<2;t=z[g+p>>2];y=z[g+r>>2];z[g+(l+16|0)>>2]=C(C(t*i)-C(y*h))+n;z[g+l>>2]=C(C(t*h)+C(y*i))+m;f=f+1|0;if((f|0)!=4){g=f<<2;n=z[g+(l+16|0)>>2];m=z[g+l>>2];continue}break}p=k-3328|0;r=k-512|0;i=z[q+20>>2];h=z[q+16>>2];f=0;while(1){g=f<<2;x=g+l|0;m=z[g+p>>2];n=z[g+r>>2];z[x>>2]=C(C(m*h)+C(n*i))+z[x>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(n*h)-C(m*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=k-3072|0;r=k-768|0;i=z[q+28>>2];h=z[q+24>>2];f=0;while(1){g=f<<2;x=g+l|0;m=z[g+p>>2];n=z[g+r>>2];z[x>>2]=C(C(m*h)+C(n*i))+z[x>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(m*i)-C(n*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=k-2816|0;r=k-1024|0;i=z[q+36>>2];h=z[q+32>>2];f=0;while(1){g=f<<2;x=g+l|0;m=z[g+p>>2];n=z[g+r>>2];z[x>>2]=C(C(m*h)+C(n*i))+z[x>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(n*h)-C(m*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=k-2560|0;r=k-1280|0;i=z[q+44>>2];h=z[q+40>>2];f=0;while(1){g=f<<2;x=g+l|0;m=z[g+p>>2];n=z[g+r>>2];z[x>>2]=C(C(m*h)+C(n*i))+z[x>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(m*i)-C(n*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=k-2304|0;r=k-1536|0;i=z[q+52>>2];h=z[q+48>>2];f=0;while(1){g=f<<2;x=g+l|0;m=z[g+p>>2];n=z[g+r>>2];z[x>>2]=C(C(m*h)+C(n*i))+z[x>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(n*h)-C(m*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}g=k-2048|0;p=k-1792|0;i=z[q+60>>2];h=z[q+56>>2];f=0;while(1){k=f<<2;r=k+l|0;m=z[g+k>>2];n=z[k+p>>2];z[r>>2]=C(C(m*h)+C(n*i))+z[r>>2];k=k+(l+16|0)|0;z[k>>2]=C(C(m*i)-C(n*h))+z[k>>2];f=f+1|0;if((f|0)!=4){continue}break}f=B(j,15-s|0)<<1;Q=f+E|0,R=xj(z[l+20>>2]),u[Q>>1]=R;k=B(j,s+17|0)<<1;Q=k+E|0,R=xj(z[l+4>>2]),u[Q>>1]=R;Q=f+D|0,R=xj(z[l+16>>2]),u[Q>>1]=R;Q=k+D|0,R=xj(z[l>>2]),u[Q>>1]=R;f=B(j,47-s|0)<<1;Q=f+E|0,R=xj(z[l+28>>2]),u[Q>>1]=R;k=B(j,s+49|0)<<1;Q=k+E|0,R=xj(z[l+12>>2]),u[Q>>1]=R;Q=f+D|0,R=xj(z[l+24>>2]),u[Q>>1]=R;Q=k+D|0,R=xj(z[l+8>>2]),u[Q>>1]=R;f=s-1|0;q=q- -64|0;if(s){continue}break}gb=l+32|0;v=v+2|0;if((v|0)<(c|0)){continue}break}b=c<<6;a:{if((d|0)==1){v=0;while(1){z[(v<<2)+a>>2]=z[(b+v<<2)+I>>2];c=v>>>0<958;v=v+2|0;if(c){continue}break}break a}hc(a,(b<<2)+I|0,3840)}}function Ega(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=gb-160|0;gb=d;vc(c);a:{b:{c:{d:{e:{if(!(!Ar(c,d+144|0)|v[d+144>>2]!=1297239878|!((w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24))!=1146437965?v[d+152>>2]==1482052408|(w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24))==1448293937:1))){n=Xi(d+120|0,c);v[22640]=0;R(1169,d+104|0,n|0);c=v[22640];v[22640]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{if((c|0)!=1){v[22640]=0;j=T(251,d+80|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break n}l=Pc(d+76|0,8,1,1,0);if((w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24))!=1146437965){break k}v[22640]=0;U(1170,d+56|0,d+104|0,1296581714);c=v[22640];v[22640]=0;if((c|0)==1){break m}v[22640]=0;U(1170,d+32|0,d+104|0,1296318804);c=v[22640];v[22640]=0;if((c|0)==1){break j}od(j,d+32|0);yb(d+32|0);v[22640]=0;c=T(1171,d+56|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break j}if(!c){break i}v[22640]=0;c=T(307,j|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break j}if(!c){break i}v[22640]=0;f=T(453,d+56|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break j}v[22640]=0;i=T(444,d+56|0)|0;c=v[22640];v[22640]=0;o:{if((c|0)==1){break o}v[22640]=0;Q(350,d+56|0,2)|0;c=v[22640];v[22640]=0;if((c|0)==1){break o}v[22640]=0;c=T(453,d+56|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){break l}}break j}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}v[22640]=0;R(1172,d+32|0,d+56|0);g=v[22640];v[22640]=0;e=1;if((g|0)==1){break j}g=d+38|0;h=d+32|0;p:{if(!Ib(w[h|0]|w[h+1|0]<<8)){break p}k=ec(d+32|0);m=Re(d+32|0);c=(c>>>0)/(Ib(w[h|0]|w[h+1|0]<<8)>>>0)|0;if((Ib(w[k|0]|w[k+1|0]<<8)|0)!=(Ib(w[m|0]|w[m+1|0]<<8)+1|0)){break p}if((Ib(w[k|0]|w[k+1|0]<<8)|0)==2){Bp(l,2)}q:{if((i|0)!=16){if((i|0)!=8){break p}if(!Ib(w[g|0]|w[g+1|0]<<8)){zf(l,1);break q}if((Ib(w[g|0]|w[g+1|0]<<8)|0)==2){zf(l,18);break q}if((Ib(w[g|0]|w[g+1|0]<<8)|0)!=3){break p}zf(l,17);break q}if(Ib(w[g|0]|w[g+1|0]<<8)){break p}Vi(l,16)}e=0}h=!e;break h}v[22640]=0;U(1170,d+56|0,d+104|0,1447576658);c=v[22640];v[22640]=0;r:{s:{t:{if((c|0)!=1){v[22640]=0;U(1170,d+32|0,d+104|0,1128808782);c=v[22640];v[22640]=0;if((c|0)==1){break t}v[22640]=0;U(1170,d+8|0,d+104|0,1112491097);c=v[22640];v[22640]=0;if((c|0)==1){break s}od(j,d+8|0);yb(d+8|0);v[22640]=0;e=T(307,j|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break s}c=0;f=0;u:{if(!e){break u}v[22640]=0;e=T(307,d+56|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break s}c=0;f=0;if(!e){break u}v[22640]=0;e=Q(1173,d+56|0,d+8|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break s}c=0;f=0;if(!e){break u}c=w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24);v[22640]=0;e=T(453,d+32|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break s}g=(c|0)!=1482052408;if(g){Pc(d+4|0,16,1,0,0);v[d+76>>2]=v[d+4>>2]}if((e|0)==6){Bp(l,3)}c=d+8|0;h=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));c=d+8|4;i=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));c=d+20|0;c=Ib(w[c|0]|w[c+1|0]<<8);f=d+24|0;k=Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));v[22640]=0;m=T(232,j|0)|0;f=v[22640];v[22640]=0;o=1;if((f|0)==1){break s}f=B((e|0)==6?2:1,g?2:1);g=(h>>>0)/(f>>>0)|0;i=(i>>>0)/(f>>>0)|0;f=(m>>>0)/(f>>>0)|0}yb(d+32|0);yb(d+56|0);e=0;if(o){break g}break f}e=P()|0;O()|0;break c}e=P()|0;O()|0;break r}e=P()|0;O()|0;yb(d+32|0)}yb(d+56|0);break c}e=P()|0;O()|0;yb(d+56|0);break c}c=0;h=0}yb(d+56|0);k=0;i=0;g=0;e=0;if(!h){break f}}v[22640]=0;Q(1149,a|0,b|0)|0;e=v[22640];v[22640]=0;v:{w:{if((e|0)!=1){v[22640]=0;h=B(b,104)+a|0;e=h+484380|0;R(352,e|0,0);m=v[22640];v[22640]=0;if((m|0)==1){break w}v[e>>2]=f;i=g+i|0;v[h+484388>>2]=i;v[h+484384>>2]=g;if(!(f>>>0<i>>>0|i>>>0<=g+4>>>0)){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]|2}f=B(b,104)+a|0;v[f+484404>>2]=c?c:22050;c=k>>>8|0;u[f+484410>>1]=c&65535?(k&16776960)>>>0>65536?256:c:256;c=v[a+480180>>2];v[22640]=0;U(1151,e|0,32,c|0);c=v[22640];v[22640]=0;x:{y:{z:{A:{if((c|0)!=1){v[22640]=0;U(1170,d+56|0,d+104|0,1312902469);c=v[22640];v[22640]=0;if((c|0)==1){break A}v[22640]=0;c=T(307,d+56|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break e}if(!c){break z}v[22640]=0;c=T(232,d+56|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break e}v[22640]=0;W(354,d+56|0,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break y}break e}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}v[22640]=0;c=Q(112,d+32|0,18693)|0;f=v[22640];v[22640]=0;if((f|0)==1){break x}v[22640]=0;Q(333,((b<<5)+a|0)+946304|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break v}vb(c)}v[22640]=0;W(363,l|0,e|0,j|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;Zh(e,a,0);a=v[22640];v[22640]=0;if((a|0)==1){break e}yb(d+56|0);e=1;break f}e=P()|0;O()|0;break d}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(c);break d}yb(j);Cd(d+104|0);yb(n)}gb=d+160|0;return e|0}e=P()|0;O()|0}yb(d+56|0)}yb(j)}Cd(d+104|0)}yb(n);S(e|0);L()}function ala(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;d=gb-752|0;gb=d;vc(b);f=gb-32|0;gb=f;h=d+144|0;tU(f+24|0,h);i=xb(f+24|0);e=v[f+28>>2];g=v[f+24>>2];v[f+8>>2]=g;v[f+12>>2]=e;v[f>>2]=g;v[f+4>>2]=e;e=b;fc(f+16|0,e,f);g=xb(f+16|0);if((g|0)==(i|0)){Yb(e,xb(f+24|0))}gb=f+32|0;e=(g|0)==(i|0);if(!e){sU(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if(!e){break m}if(!vU(d+144|0)){break m}if(!Pb(b,Uc(uU(d+144|0),jb))){break m}if(!c){o=1;break m}Gd(a,262144);Hk(d+104|0,2,d+144|0);Bc(d+24|0,d+104|0);Eb(a+1298268|0,d+24|0);vb(d+24|0);e=Tb(d+24|0,5530);Eb(a+1298304|0,e);vb(e);e=Tb(d+24|0,7451);Eb(a+1298316|0,e);vb(e);e=gb-16|0;gb=e;f=Tb(e,1302);Dc(d+104|0,f);vb(f);gb=e+16|0;t[d+8|0]=w[d+174|0];e=w[d+173|0];v[22640]=0;t[d+127|0]=e;R(891,d+128|0,d+127|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}v[22640]=0;Y(412,d+24|0,d+104|0,d+8|0,d+128|0);e=v[22640];v[22640]=0;if((e|0)==1){break d}Eb(a+1298328|0,d+24|0);vb(d+24|0);vb(d+128|0);Hb(d+104|0);v[a+480208>>2]=12;v[a+1298364>>2]=5;u[a+480188>>1]=w[d+182|0]|w[d+183|0]<<8;u[d+24>>1]=w[d+178|0]|w[d+179|0]<<8;u[d+104>>1]=3999;A=a,C=x[Oc(d+24|0,d+104|0)>>1],u[A+480190>>1]=C;FX(Rb(a+484360|0),d+240|0,w[d+176|0]|w[d+177|0]<<8);if(x[a+480188>>1]){e=0;while(1){f=(e<<5)+a|0;Se(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+208|0]<<4|4)&244;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}rd(d+104|0,b,B(w[d+178|0]|w[d+179|0]<<8,80));if(x[a+480190>>1]){i=c&2;h=d+72|0;e=0;while(1){v[22640]=0;R(892,d+104|0,d+24|0);f=v[22640];v[22640]=0;if((f|0)==1){break l}v[22640]=0;Hk(d+8|0,2,h);f=v[22640];v[22640]=0;n:{o:{p:{if((f|0)==1){break p}v[22640]=0;R(377,d+128|0,d+8|0);f=v[22640];v[22640]=0;if((f|0)==1){break p}v[22640]=0;e=e+1|0;Q(333,((e<<5)+a|0)+946304|0,d+128|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break o}vb(d+128|0);v[22640]=0;f=(B(e,104)+a|0)+484380|0;U(893,d+128|0,d+24|0,f|0);g=v[22640];v[22640]=0;q:{if((g|0)==1){break q}if(!i|!v[f>>2]){break n}g=w[d+42|0]|w[d+43|0]<<8|(w[d+44|0]<<16|w[d+45|0]<<24);v[22640]=0;g=Q(227,b|0,g|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break q}if(!g){break n}v[22640]=0;W(363,d+128|0,f|0,b|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){break n}}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(d+128|0);break e}if(x[a+480190>>1]>e>>>0){continue}break}}o=1;r:{if(!(c&1)){break r}c=w[d+180|0]|w[d+181|0]<<8;g=0;v[22640]=0;l=a+484344|0;R(364,l|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break k}if(!(w[d+180|0]|w[d+181|0]<<8)){break r}p=d+24|4;q=d+24|2;r=d+24|5;s=d+24|3;y=d+24|1;while(1){v[22640]=0;c=W(365,l|0,g&65535,64)|0;e=v[22640];v[22640]=0;if((e|0)==1){break j}s:{if(!c){break s}c=(g<<1)+d|0;e=c+496|0;if(!(w[e|0]|w[e+1|0]<<8)){break s}c=w[c+496|0]|w[c+497|0]<<8;v[22640]=0;c=Q(227,b|0,c<<4)|0;e=v[22640];v[22640]=0;if((e|0)==1){break j}if(!c){break s}m=0;c=_b(l,g);v[22640]=0;c=Tc(c,0,0);e=v[22640];v[22640]=0;if((e|0)==1){break f}while(1){v[22640]=0;e=Q(228,b|0,1)|0;f=v[22640];v[22640]=0;t:{u:{v:{if((f|0)!=1){if(!e){break s}v[22640]=0;k=T(353,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break v}if(k){break u}m=m+1|0;c=B(x[a+480188>>1],6)+c|0;break t}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}u[d+28>>1]=0;v[d+24>>2]=0;e=k&31;i=B(e,6)+c|0;n=Zi(d+24|0);h=e>>>0<x[a+480188>>1];w:{if(!(k&32)){break w}v[22640]=0;R(431,d+128|0,b|0);e=v[22640];v[22640]=0;if((e|0)==1){break i}f=md(d+128|0);j=h?i:d+24|0;e=w[d+128|0];t[j|0]=e;t[(h?i+1|0:y)|0]=w[f|0];x:{if(e){if((e|0)==254){break x}if(e>>>0<121){break w}}e=0}t[j|0]=e}y:{if(!(k&64)){break y}v[22640]=0;R(431,d+128|0,b|0);e=v[22640];v[22640]=0;if((e|0)==1){break h}z=md(d+128|0);e=h?i+3|0:s;f=w[d+128|0];t[e|0]=f;j=h?i+5|0:r;t[j|0]=w[z|0];z:{A:{B:{if(f>>>0<=15){v[22640]=0;Mf(h?i:n);f=v[22640];v[22640]=0;if((f|0)!=1){break B}a=P()|0;O()|0;break e}if(f>>>0>23){break z}n=e;e=w[f+33687|0];t[n|0]=e;break A}e=w[e|0]}e=e&255;if((e|0)!=23){if((e|0)!=9){break y}e=w[j|0];C:{D:{if(e>>>0>=136){f=e&127;break D}f=128;if(e>>>0<129){break C}}t[j|0]=f;e=f}t[j|0]=(B(e&127,255)>>>0)/127;break y}v[22640]=0;t[d+8|0]=64;e=ac(j,d+8|0);f=v[22640];v[22640]=0;if((f|0)!=1){t[j|0]=w[e|0]<<1;break y}a=P()|0;O()|0;break e}t[e|0]=0}if(!(k&128)){break t}t[(h?i+2|0:q)|0]=1;v[22640]=0;e=T(353,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break g}t[(h?i+4|0:p)|0]=e}if(m>>>0<64){continue}break}}g=g+1|0;if(g>>>0<(w[d+180|0]|w[d+181|0]<<8)>>>0){continue}break}}yb(d+104|0)}gb=d+752|0;return o|0}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}yb(d+104|0);break a}a=P()|0;O()|0;vb(d+128|0);break b}a=P()|0;O()|0}Hb(d+104|0)}S(a|0);L()}function Zja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;g=gb-208|0;gb=g;vc(b);a:{b:{c:{d:{e:{if(!OC(b,g+160|0)){break e}if(!rT(g+160|0)){break e}if(!c){h=1;break e}if(!Pb(b,Uc(qT(g+160|0),jb))){break e}Gd(a,128);_e(g+144|0,2,g+175|0);Bc(g+72|0,g+144|0);Eb(a+1298268|0,g+72|0);vb(g+72|0);d=Tb(g+72|0,5680);Eb(a+1298304|0,d);vb(d);d=Tb(g+72|0,3145);Eb(a+1298316|0,d);vb(d);d=Tb(g+144|0,14612);v[22640]=0;U(962,g+72|0,d|0,v[(w[g+174|0]<<2)+33548>>2]);e=v[22640];v[22640]=0;h=1;if((e|0)==1){break b}Eb(a+1298328|0,g+72|0);vb(g+72|0);vb(d);v[a+480208>>2]=12;v[a+1298364>>2]=5;cB(a+1298292|0,b,w[g+207|0]<<5,32,0);y=a,z=de(b),u[y+480190>>1]=z;if(x[a+480190>>1]){j=1;while(1){f:{if(w[g+174|0]>=52){d=g+72|0;if(!iY(b,d)){ZC(d)}break f}e=gb-48|0;gb=e;v[e+44>>2]=64;v[e+24>>2]=66;d=b;i=v[Fb(e+44|0,e+24|0)>>2];if(!Pb(d,i)){i=xf(d)}f=g+72|0;zv(e+24|0,f);l=Wd(e+32|0,v[e+24>>2],i);m=v[l+4>>2];v[e+8>>2]=v[l>>2];v[e+12>>2]=m;fc(e+16|0,d,e+8|0);zv(e+24|0,f);Qb(v[e+24>>2]+i|0,0,66-i|0);Yb(d,v[e+44>>2]);gb=e+48|0;d=w[g+134|0]|w[g+135|0]<<8;t[g+136|0]=d;t[g+137|0]=d>>>8;t[g+134|0]=171;t[g+135|0]=32}i=gb-32|0;gb=i;e=(B(h,104)+a|0)+484380|0;td(e,0);d=g+72|0;Gk(i,2,d+32|0);Bc(i+16|0,i);v[22640]=0;Q(335,e+43|0,i+16|0)|0;f=v[22640];v[22640]=0;g:{if((f|0)!=1){vb(i+16|0);h:{if((w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))>>>0<=(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24))>>>0){break h}v[e>>2]=(w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))-(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24));v[e+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[i+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);y=e,z=v[Fb(i+16|0,e)>>2],v[y+16>>2]=z;u[e+30>>1]=w[d+60|0];v[e+24>>2]=w[d+62|0]|w[d+63|0]<<8;f=d- -64|0;if(w[f|0]|w[f+1|0]<<8){No(e,+((w[f|0]|w[f+1|0]<<8)<<16>>16)*25431315104166665e-22)}if(w[d+61|0]&8){u[e+34>>1]=x[e+34>>1]|8}if(w[d+61|0]&16){u[e+34>>1]=x[e+34>>1]|16}if(!(w[d+61|0]&4)){break h}u[e+34>>1]=x[e+34>>1]|1;v[e+12>>2]=v[e+12>>2]>>>1;v[e+16>>2]=v[e+16>>2]>>>1}gb=i+32|0;break g}a=P()|0;O()|0;vb(i+16|0);S(a|0);L()}_e(g+56|0,2,g+72|0);Bc(g+144|0,g+56|0);v[22640]=0;Q(333,((h<<5)+a|0)+946304|0,g+144|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}vb(g+144|0);j=j+1|0;h=j&65535;if(h>>>0<=x[a+480190>>1]){continue}break}}hp(Rb(a+484360|0),b,256,255,254);h=0;d=de(b);if(d>>>0>=127){break e}u[a+480188>>1]=d+1;e=de(b);r=e+1|0;if(x[a+480188>>1]){while(1){d=(h<<5)+a|0;Se(d+480280|0);i=d+480284|0;i:{if(w[g+174|0]>=51){d=(de(b)<<4|8)&248;break i}d=h&1?192:64}u[i>>1]=d;h=h+1|0;if(h>>>0<x[a+480188>>1]){continue}break}}l=a+484344|0;vg(l,r);h=0;j=0;while(1){d=j&65535;if(!qh(l,d,64)){break e}j=j+1|0;if(d>>>0<e>>>0){continue}break}if(x[a+480188>>1]){while(1){i=Zi(g+72|0);m=0;while(1){if(Pb(b,5)){j=0;h=Tc(_b(l,m),0,o&65535);while(1){s=64-j|0;n=w[g+174|0];f=gb-16|0;gb=f;p=1;d=i;q=d;e=b;k=de(e);if((k|0)==252){p=de(e);k=de(e)}t[q|0]=(k-1&255)>>>0<60?k+36|0:0;xn(f+8|0,e);e=md(f+8|0);k=Re(f+8|0);q=aj(f+8|0);t[d+1|0]=w[f+8|0];t[f+7|0]=w[e|0]&15;t[f+6|0]=w[e|0]>>>4;t[f+5|0]=w[k|0];t[f+4|0]=w[q|0];pT(f+7|0,f+5|0,n);pT(f+6|0,f+4|0,n);k=w[f+7|0];n=(k|0)!=10;e=w[f+6|0];j:{if(!(n|(e|0)!=10)){t[f+7|0]=0;y=f,z=dm((w[f+4|0]|w[f+5|0]<<8)>>>6|0),t[y+5|0]=z;break j}k:{l:{m:{if(!n){y=f,z=dm(w[f+5|0]<<2),t[y+5|0]=z;break m}if((e|0)==10){y=f,z=dm(w[f+4|0]<<2),t[y+4|0]=z;break j}if((e|0)!=(k|0)){break m}t[f+6|0]=0;break l}if((e|0)==13){break k}if(e){break j}}if((k|0)==13){break j}}Dh(f+7|0,f+6|0);Dh(f+5|0,f+4|0)}dz(f+6|0,f+4|0,f+7|0,f+5|0);so(f,f+7|0,f+5|0,f+6|0,f+4|0);t[d+2|0]=w[f+7|0];t[d+4|0]=w[f+5|0];t[d+3|0]=w[f+6|0];t[d+5|0]=w[f+4|0];gb=f+16|0;e=j+p|0;j=e>>>0>64?s:p;if(j){while(1){d=v[g+72>>2];t[h|0]=d;t[h+1|0]=d>>>8;t[h+2|0]=d>>>16;t[h+3|0]=d>>>24;d=x[g+76>>1];t[h+4|0]=d;t[h+5|0]=d>>>8;h=B(x[a+480188>>1],6)+h|0;j=j-1|0;if(j){continue}break}d=e>>>0<64;j=d?e:64;if(d){continue}}break}m=m+1|0;if((r|0)!=(m|0)){continue}}break}o=o+1|0;if(x[a+480188>>1]>(o&65535)>>>0){continue}break}}e=x[a+480188>>1];d=g+8|0;i=Vu(d);t[d+16|0]=0;u[d+14>>1]=0;u[d+12>>1]=e;v[22640]=0;U(964,i|0,e|0,0);e=v[22640];v[22640]=0;if((e|0)==1){a=P()|0;O()|0;Ce(i);S(a|0);L()}v[22640]=0;U(963,g+32|0,l|0,d|0);e=v[22640];v[22640]=0;h=1;if((e|0)==1){break d}Ce(g+32|0);Ce(d);if(!(c&2)|!x[a+480190>>1]){break e}j=1;while(1){c=B(j&65535,104)+a|0;zg(Pc(g+72|0,u[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);j=j+1|0;if(x[a+480190>>1]>=(j&65535)>>>0){continue}break}}gb=g+208|0;return h|0}h=P()|0;O()|0;Ce(d);break a}h=P()|0;O()|0;vb(g+144|0);break a}h=P()|0;O()|0;vb(d)}S(h|0);L()}function Dd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;l=gb-96|0;gb=l;p=c;u=(g&131071)<<15|f>>>17;j=i&65535;s=j;k=h;C=k<<15|g>>>17;n=(e^i)&-2147483648;o=e&65535;x=o;m=d;y=o;o=0;D=(j&131071)<<15|k>>>17;F=i>>>16&32767;M=e>>>16&32767;a:{b:{if(M-1>>>0<=32765){j=0;if(F-1>>>0<32766){break b}}q=e&2147483647;w=q;j=d;if(!(!j&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){z=d;n=e|32768;break a}e=i&2147483647;q=e;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){z=h;n=i|32768;b=f;c=g;break a}if(!(b|j|(w^2147418112|c))){if(!(d|f|(g|q))){n=2147450880;b=0;c=0;break a}n=n|2147418112;b=0;c=0;break a}if(!(d|f|(q^2147418112|g))){d=b|j;e=c|w;b=0;c=0;if(!(d|e)){n=2147450880;break a}n=n|2147418112;break a}if(!(b|j|(c|w))){b=0;c=0;break a}if(!(d|f|(g|q))){b=0;c=0;break a}if((w|0)==65535|w>>>0<65535){h=b;i=c;d=!(m|x);e=d<<6;j=E(d?b:m)+32|0;b=E(d?c:x);b=e+((b|0)==32?j:b)|0;If(l+80|0,h,i,m,x,b-15|0);m=v[l+88>>2];p=v[l+84>>2];y=v[l+92>>2];t=16-b|0;b=v[l+80>>2]}j=t;if(q>>>0>65535){break b}c=!(k|s);d=c<<6;e=E(c?f:k)+32|0;c=E(c?g:s);c=d+((c|0)==32?e:c)|0;i=c;If(l- -64|0,f,g,k,s,c-15|0);e=v[l+76>>2];c=e;h=v[l+72>>2];d=h;d=d<<15;e=v[l+68>>2];C=e>>>17|d;d=0;f=v[l+64>>2];u=d|((e&131071)<<15|f>>>17);D=(c&131071)<<15|h>>>17;j=(t-i|0)+16|0}t=j;d=u;c=b;s=0;q=mqa(d,0,b,s);b=jb;G=b;e=f;A=e<<15&-32768;k=p;g=mqa(A,0,k,0);f=g+q|0;e=jb+b|0;e=f>>>0<g>>>0?e+1|0:e;h=f;j=f;i=0;g=mqa(c,s,A,B);f=i+g|0;b=j;j=j+jb|0;j=f>>>0<g>>>0?j+1|0:j;u=f;g=j;J=(b|0)==(j|0)&f>>>0<i>>>0|b>>>0>j>>>0;N=mqa(d,r,k,H);K=jb;p=m;f=mqa(A,B,m,0);b=f+N|0;j=jb+K|0;O=b;m=mqa(C,0,c,s);i=b+m|0;b=b>>>0<f>>>0?j+1|0:j;f=b+jb|0;w=i;f=i>>>0<m>>>0?f+1|0:f;x=f;j=f;f=(e|0)==(G|0)&h>>>0<q>>>0|e>>>0<G>>>0;h=e+w|0;j=f+j|0;q=h;j=h>>>0<e>>>0?j+1|0:j;m=j;e=h;h=j;Q=mqa(d,r,p,P);G=jb;f=A;I=y|65536;A=o;i=mqa(f,B,I,o);f=i+Q|0;j=jb+G|0;j=f>>>0<i>>>0?j+1|0:j;R=f;B=mqa(C,S,k,H);i=f+B|0;o=j;f=j+jb|0;f=i>>>0<B>>>0?f+1|0:f;L=i;D=D&2147483647|-2147483648;i=mqa(c,s,D,0);c=L+i|0;s=f;j=f+jb|0;B=c;c=c>>>0<i>>>0?j+1|0:j;y=J;i=0;f=i+e|0;j=h+B|0;J=f;h=f;e=y+f|0;y=f>>>0<i>>>0?j+1|0:j;f=y;f=e>>>0<h>>>0?f+1|0:f;h=e;i=f;t=(t+(F+M|0)|0)-16383|0;f=mqa(p,P,C,S);e=jb;r=mqa(d,r,I,A);d=r+f|0;j=jb+e|0;j=d>>>0<r>>>0?j+1|0:j;r=d;f=(e|0)==(j|0)&f>>>0>d>>>0|e>>>0>j>>>0;e=j;F=f;f=mqa(D,T,k,H);d=f+d|0;j=jb+j|0;j=d>>>0<f>>>0?j+1|0:j;f=d;d=j;k=(j|0)==(e|0)&f>>>0<r>>>0|e>>>0>j>>>0;j=F+k|0;e=0;e=j>>>0<k>>>0?1:e;r=f;k=d;F=j;f=(b|0)==(x|0)&w>>>0<O>>>0|b>>>0>x>>>0;b=f+((b|0)==(K|0)&N>>>0>O>>>0|b>>>0<K>>>0)|0;j=0;j=b>>>0<f>>>0?1:j;f=b;b=r+f|0;j=d+j|0;j=b>>>0<f>>>0?j+1|0:j;H=b;d=j;j=(j|0)==(k|0)&b>>>0<r>>>0|j>>>0<k>>>0;b=F+j|0;f=e;f=b>>>0<j>>>0?f+1|0:f;e=mqa(D,T,I,A);b=e+b|0;j=jb+f|0;r=b;e=b>>>0<e>>>0?j+1|0:j;k=mqa(D,T,p,P);f=jb;p=mqa(C,S,I,A);b=p+k|0;j=jb+f|0;j=b>>>0<p>>>0?j+1|0:j;p=b;b=j;j=(f|0)==(j|0)&k>>>0>p>>>0|f>>>0>j>>>0;k=b+r|0;e=e+j|0;e=k>>>0<b>>>0?e+1|0:e;r=k;k=0;b=k+H|0;j=d+p|0;j=b>>>0<k>>>0?j+1|0:j;f=j;k=(d|0)==(j|0)&b>>>0<H>>>0|d>>>0>j>>>0;d=r+k|0;j=e;C=d;d=d>>>0<k>>>0?j+1|0:j;p=b;k=f;f=(o|0)==(s|0)&R>>>0>L>>>0|o>>>0>s>>>0;e=f+((o|0)==(G|0)&Q>>>0>R>>>0|o>>>0<G>>>0)|0;f=e;e=f+((c|0)==(s|0)&B>>>0<L>>>0|c>>>0<s>>>0)|0;f=e;b=c+b|0;e=f+k|0;e=b>>>0<c>>>0?e+1|0:e;o=b;c=b;b=e;e=(e|0)==(k|0)&c>>>0<p>>>0|e>>>0<k>>>0;c=e+C|0;j=d;j=c>>>0<e>>>0?j+1|0:j;d=c;k=d;e=(m|0)==(y|0)&q>>>0>J>>>0|m>>>0>y>>>0;d=e+((m|0)==(x|0)&q>>>0<w>>>0|m>>>0<x>>>0)|0;f=0;f=d>>>0<e>>>0?1:f;m=d;d=d+o|0;e=b+f|0;e=d>>>0<m>>>0?e+1|0:e;c=(b|0)==(e|0)&d>>>0<o>>>0|b>>>0>e>>>0;b=k+c|0;j=b>>>0<c>>>0?j+1|0:j;c=j;c:{if(j&65536){t=t+1|0;break c}m=g>>>31|0;j=c<<1|b>>>31;b=b<<1|e>>>31;c=j;j=e<<1|d>>>31;d=d<<1|i>>>31;e=j;o=u;j=g<<1|o>>>31;u=o<<1;g=j;j=i<<1|h>>>31;h=h<<1|m;i=j}if((t|0)>=32767){n=n|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){f=1-t|0;if(f>>>0>=128){b=0;c=0;break a}j=t+127|0;If(l+48|0,u,g,h,i,j);If(l+32|0,d,e,b,c,j);lm(l+16|0,u,g,h,i,f);lm(l,d,e,b,c,f);u=(v[l+48>>2]|v[l+56>>2])!=0|(v[l+52>>2]|v[l+60>>2])!=0|(v[l+32>>2]|v[l+16>>2]);g=v[l+36>>2]|v[l+20>>2];h=v[l+40>>2]|v[l+24>>2];i=v[l+44>>2]|v[l+28>>2];d=v[l>>2];e=v[l+4>>2];c=v[l+12>>2];b=v[l+8>>2];break d}c=c&65535|t<<16}z=b|z;n=c|n;if(!(!h&(i|0)==-2147483648?!(g|u):(i|0)>-1)){j=e;b=d+1|0;j=b>>>0<1?j+1|0:j;f=b;c=j;f=(e|0)==(j|0)&d>>>0>f>>>0|e>>>0>j>>>0;d=f+z|0;e=n;z=d;n=d>>>0<f>>>0?e+1|0:e;break a}if(h|u|(i^-2147483648|g)){b=d;c=e;break a}c=d&1;b=c+d|0;j=e;j=b>>>0<c>>>0?j+1|0:j;f=b;c=j;e=(e|0)==(j|0)&d>>>0>f>>>0|e>>>0>j>>>0;d=e+z|0;j=n;z=d;n=d>>>0<e>>>0?j+1|0:j}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=z;v[a+12>>2]=n;gb=l+96|0}function oma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=gb-224|0;gb=d;vc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!Ar(b,d+208|0)){break h}if(!rV(d+208|0)){break h}i=Ih(d+184|0);j=Kb(d+168|0);XC(d+104|0);v[22640]=0;f=Q(799,b|0,d+96|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break d}i:{if(!f){break i}f=d+96|4;g=Xb(Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))-4|0);t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;g=0;while(1){e=Xb(Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))-8|0);t[f|0]=e;t[f+1|0]=e>>>8;t[f+2|0]=e>>>16;t[f+3|0]=e>>>24;j:{if(c){break j}e=d+96|0;if((Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|0)!=1347699796){break j}g=1;break i}e=Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));v[22640]=0;U(320,d|0,b|0,e|0);e=v[22640];v[22640]=0;k:{l:{m:{n:{o:{if((e|0)!=1){v[22640]=0;e=T(307,d|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break n}if(e){break o}yb(d);break k}a=P()|0;O()|0;break a}e=d+96|0;e=Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));if((e|0)<=1347699795){if((e|0)==1129139796){break m}if((e|0)!=1229866575){break l}v[22640]=0;k=Q(800,d|0,d+104|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break n}break l}if((e|0)!=1347699796){if((e|0)!=1447383635){break l}v[22640]=0;Q(350,d|0,4)|0;e=v[22640];v[22640]=0;if((e|0)==1){break n}v[22640]=0;e=T(801,d|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break n}if(!e){break l}if(Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<7){break l}e=Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));v[22640]=0;U(802,d|0,j|0,e-6|0);e=v[22640];v[22640]=0;if((e|0)==1){break n}break l}v[22640]=0;g=W(803,a|0,d|0,c|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){break l}}a=P()|0;O()|0;yb(d);break a}uw(i,d)}yb(d);v[22640]=0;e=Q(799,b|0,d+96|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break e}if(e){continue}}break}if(dd(j)){v[22640]=0;b=Q(2,d|0,12091)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}Eb(j,b);vb(b)}p:{l=g&1;if(!l|(k^1)&1){break p}b=d+146|0;b=Ib(w[b|0]|w[b+1|0]<<8);v[22640]=0;c=b&256;W(437,a+1074312|0,5,!c|0)|0;b=v[22640];v[22640]=0;q:{r:{if((b|0)!=1){b=d+142|0;if(Ib(w[b|0]|w[b+1|0]<<8)){u[d>>1]=64;b=Ib(w[b|0]|w[b+1|0]<<8);v[22640]=0;u[d+80>>1]=b;b=Oc(d,d+80|0);f=v[22640];v[22640]=0;if((f|0)==1){break r}v[a+480228>>2]=x[b>>1]}b=d+144|0;if(!(!Ib(w[b|0]|w[b+1|0]<<8)|!c)){n=a,o=B(Ib(w[b|0]|w[b+1|0]<<8),1e4),v[n+480204>>2]=o}if(w[d+104|0]){v[22640]=0;_e(d+80|0,2,d+104|0);b=v[22640];v[22640]=0;if((b|0)==1){break q}v[22640]=0;R(377,d|0,d+80|0);b=v[22640];v[22640]=0;if((b|0)==1){break q}Eb(a+1298268|0,d);vb(d)}v[d>>2]=1;v[d+80>>2]=12;c=d+150|0;if(!fr(c,d,d+80|0)){break p}v[d+72>>2]=31;v[d+76>>2]=1;f=d+148|0;if(!fr(f,d+76|0,d+72|0)){break p}v[d+64>>2]=23;v[d+68>>2]=0;e=d+154|0;if(!fr(e,d+68|0,d- -64|0)){break p}v[d+56>>2]=59;v[d+60>>2]=0;h=d+156|0;if(!fr(h,d+60|0,d+56|0)){break p}v[d+48>>2]=59;v[d+52>>2]=0;k=d+158|0;if(!fr(k,d+52|0,d+48|0)){break p}b=Er(d);m=d+152|0;n=b,o=Ib(w[m|0]|w[m+1|0]<<8),v[n+20>>2]=o;n=b,o=Ib(w[c|0]|w[c+1|0]<<8)-1|0,v[n+16>>2]=o;n=b,o=Ib(w[f|0]|w[f+1|0]<<8),v[n+12>>2]=o;n=b,o=Ib(w[e|0]|w[e+1|0]<<8),v[n+8>>2]=o;n=b,o=Ib(w[h|0]|w[h+1|0]<<8),v[n+4>>2]=o;n=b,o=Ib(w[k|0]|w[k+1|0]<<8),v[n>>2]=o;v[22640]=0;R(621,a+1298368|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break p}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}if(l){v[22640]=0;b=T(307,i|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break d}if(b){b=Kb(d);v[22640]=0;W(441,i|0,b|0,32)|0;c=v[22640];v[22640]=0;if((c|0)==1){break b}if(xr(b,11123)){v[22640]=0;U(13,d+80|0,2,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}Eb(a+1298280|0,d+80|0);vb(d+80|0)}v[22640]=0;c=T(804,i|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}if(!c){v[22640]=0;c=T(492,i|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}v[22640]=0;ga(498,a+1298292|0,i|0,c|0,40,0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break b}}vb(b)}v[22640]=0;b=Q(2,d+80|0,14600)|0;c=v[22640];v[22640]=0;if((c|0)==1){break g}v[22640]=0;U(671,d|0,b|0,j|0);c=v[22640];v[22640]=0;if((c|0)==1){break f}Eb(a+1298328|0,d);vb(d);vb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[22640]=0;a=a+1074312|0;W(437,a|0,84,1)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}v[22640]=0;W(437,a|0,83,1)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}v[22640]=0;Q(438,a|0,85)|0;a=v[22640];v[22640]=0;if((a|0)==1){break d}}vb(j);yb(i)}gb=d+224|0;return g&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(b)}vb(j);yb(i);S(a|0);L()}function jqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-3056|0;gb=e;vc(b);f=gb-32|0;gb=f;k=e+1096|0;VY(f+24|0,k);i=xb(f+24|0);g=v[f+28>>2];j=v[f+24>>2];v[f+8>>2]=j;v[f+12>>2]=g;v[f>>2]=j;v[f+4>>2]=g;g=b;fc(f+16|0,g,f);j=xb(f+16|0);if((j|0)==(i|0)){Yb(g,xb(f+24|0))}gb=f+32|0;g=(i|0)==(j|0);if(!g){UY(k)}a:{if(!g){break a}if(!rD(e+1096|0)){break a}if(!c){d=1;break a}if(!Pb(b,Uc(1024,0))){break a}XY(b,e+576|0);XY(b,e- -64|0);while(1){g=h<<2;f=g+(e+576|0)|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0>16777215){break a}g=g+(e- -64|0)|0;if((w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))>>>0<3|(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))>>>0>4096){break a}if(!ks(b,((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))+(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))|0)+2978|0)){break a}h=h+1|0;if((h|0)!=128){continue}break}Gd(a,2);wg(a);d=Tb(e+24|0,11204);Eb(a+1298304|0,d);vb(d);d=Tb(e+24|0,12003);Eb(a+1298316|0,d);vb(d);d=Tb(e+24|0,12642);Eb(a+1298328|0,d);vb(d);v[a+1298364>>2]=5;d=w[e+1096|0];v[a+480204>>2]=143e4;v[a+480196>>2]=d;i=a+484360|0;af(Rb(i),w[e+1097|0]);v[a+480188>>2]=4194317;Ob(a+1074312|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;while(1){u[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;if((d|0)!=4){continue}break}d=0;b:{c:{d:{e:{while(1){g=d+1|0;h=B(g,104)+a|0;f=h+484380|0;td(f,2);Yj(e+48|0,1,(B(d,13)+e|0)+1098|0);Bc(e+24|0,e+48|0);v[22640]=0;Q(333,((g<<5)+a|0)+946304|0,e+24|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break e}vb(e+24|0);m=f;d=(e+1096|0)+(d<<4)|0;f=d+422|0;v[m>>2]=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);if((w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24))>>>0<=(w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24))>>>0){v[h+484384>>2]=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);d=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);u[h+484414>>1]=2;v[h+484388>>2]=d}v[h+484404>>2]=8287;d=g;if((d|0)!=32){continue}break}h=0;while(1){d=h+33|0;g=(B(d,104)+a|0)+484380|0;td(g,2);Yj(e+48|0,1,(B(h,13)+e|0)+2026|0);Bc(e+24|0,e+48|0);v[22640]=0;Q(333,((d<<5)+a|0)+946304|0,e+24|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}vb(e+24|0);v[e+32>>2]=0;v[e+24>>2]=0;v[e+28>>2]=0;d=(e+1096|0)+B(h,11)|0;f=w[d+1347|0];o=lc(e+24|0,0),p=f,t[o|0]=p;f=w[d+1352|0];o=lc(e+24|0,1),p=f,t[o|0]=p;f=w[d+1348|0];o=lc(e+24|0,2),p=f,t[o|0]=p;f=w[d+1353|0];o=lc(e+24|0,3),p=f,t[o|0]=p;f=w[d+1349|0];o=lc(e+24|0,4),p=f,t[o|0]=p;f=w[d+1354|0];o=lc(e+24|0,5),p=f,t[o|0]=p;f=w[d+1350|0];o=lc(e+24|0,6),p=f,t[o|0]=p;f=w[d+1355|0];o=lc(e+24|0,7),p=f,t[o|0]=p;f=w[d+1351|0];o=lc(e+24|0,8),p=f,t[o|0]=p;f=w[d+1356|0];o=lc(e+24|0,9),p=f,t[o|0]=p;d=w[d+1346|0];o=lc(e+24|0,10),p=d,t[o|0]=p;v[e+16>>2]=v[e+32>>2];d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;Po(g,1,e+8|0);h=h+1|0;if((h|0)!=32){continue}break}Or(Rb(i),e+2794|0,256,255,65535);k=a+484344|0;vg(k,128);m=c&1;g=0;f:{while(1){h=g<<2;d=h+(e+576|0)|0;Xc(b,(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+2978|0);d=h+(e- -64|0)|0;rd(e+24|0,b,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));g:{if(!m){break g}v[22640]=0;d=W(365,k|0,g&65535,64)|0;h=v[22640];v[22640]=0;if((h|0)==1){break c}if(!d){break g}h=0;f=_b(k,g);while(1){v[22640]=0;d=Q(228,e+24|0,1)|0;i=v[22640];v[22640]=0;h:{i:{if((i|0)!=1){if(!d){break g}v[22640]=0;d=T(353,e+24|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break c}if(d>>>0>12){break i}v[22640]=0;i=Tc(f,h,d);j=v[22640];v[22640]=0;if((j|0)==1){break c}v[22640]=0;R(431,e+48|0,e+24|0);j=v[22640];v[22640]=0;if((j|0)==1){break c}j=md(e+48|0);l=e+48|0;n=w[l|0];d=d>>>0>3;t[i|0]=((n&15)+(d?13:37)|0)+B(n>>>4&7,12);t[i+1|0]=((w[j|0]>>>4|0)+(d?33:1)|0)+(w[l|0]>>>3&16);WY(i,w[j|0],d);break h}break c}i=d-32|0;if((i&255)>>>0<=12){v[22640]=0;i=Tc(f,h,i&65535);j=v[22640];v[22640]=0;if((j|0)==1){break c}v[22640]=0;j=T(353,e+24|0)|0;l=v[22640];v[22640]=0;if((l|0)==1){break c}WY(i,j,d>>>0>35);break h}if((d|0)!=64){if((d|0)!=96){break f}if(!h){break g}v[22640]=0;d=Tc(f,h-1|0,0);h=v[22640];v[22640]=0;if((h|0)==1){break c}t[d+3|0]=14;break g}v[22640]=0;d=T(353,e+24|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break c}h=d+h|0}if(h>>>0<64){continue}break}}yb(e+24|0);g=g+1|0;if((g|0)!=128){continue}break}d=1;if(!(c&2)){break a}h=1;while(1){zg(Pc(e+24|0,8,1,0,1),(B(h,104)+a|0)+484380|0,b);h=h+1|0;if((h|0)!=33){continue}break}break a}yb(e+24|0);d=0;break a}d=P()|0;O()|0;vb(e+24|0);break b}d=P()|0;O()|0;vb(e+24|0);break b}d=P()|0;O()|0;yb(e+24|0)}S(d|0);L()}gb=e+3056|0;return d|0}function Toa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;d=gb-320|0;gb=d;vc(b);g=gb-32|0;gb=g;wX(g+24|0,d+96|0);i=xb(g+24|0);f=v[g+28>>2];h=v[g+24>>2];v[g+8>>2]=h;v[g+12>>2]=f;v[g>>2]=h;v[g+4>>2]=f;f=b;fc(g+16|0,f,g);h=xb(g+16|0);if((h|0)==(i|0)){Yb(f,xb(g+24|0))}gb=g+32|0;a:{b:{c:{d:{if((i|0)!=(h|0)){break d}if(!AX(d+96|0)){break d}if(!Pb(b,Uc(zX(d+96|0),jb))){break d}if(!c){e=1;break d}Gd(a,2);wg(a);v[a+480204>>2]=455e3;v[a+480188>>2]=524296;Ob(a+1074312|0,110,1);v[a+480208>>2]=v[a+480208>>2]|16777216;_e(d- -64|0,2,d+127|0);Bc(d+80|0,d- -64|0);Eb(a+1298268|0,d+80|0);vb(d+80|0);e:{f:{g:{h:{i:{while(1){f=(d+96|0)+B(e,19)|0;NC(d+80|0,f+63|0);Bc(d- -64|0,d+80|0);v[22640]=0;Q(427,((e<<5)+a|0)+480289|0,d- -64|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break h}vb(d- -64|0);e=e+1|0;h=B(e,104)+a|0;j=h+484380|0;td(j,2);v[d+72>>2]=0;v[d+64>>2]=0;v[d+68>>2]=0;g=d- -64|0;i=w[f+78|0]|w[f+79|0]<<8|(w[f+80|0]<<16|w[f+81|0]<<24);t[g+7|0]=i;t[g+8|0]=i>>>8;t[g+9|0]=i>>>16;t[g+10|0]=i>>>24;i=w[f+75|0]|w[f+76|0]<<8|(w[f+77|0]<<16|w[f+78|0]<<24);f=w[f+71|0]|w[f+72|0]<<8|(w[f+73|0]<<16|w[f+74|0]<<24);t[g|0]=f;t[g+1|0]=f>>>8;t[g+2|0]=f>>>16;t[g+3|0]=f>>>24;t[g+4|0]=i;t[g+5|0]=i>>>8;t[g+6|0]=i>>>16;t[g+7|0]=i>>>24;v[d+8>>2]=v[d+72>>2];f=v[d+68>>2];v[d>>2]=v[d+64>>2];v[d+4>>2]=f;Po(j,1,d);v[h+484404>>2]=8215;Bc(d+48|0,d+80|0);v[22640]=0;Q(333,((e<<5)+a|0)+946304|0,d+48|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break i}vb(d+48|0);if((e|0)!=8){continue}break}p=w[d+312|0];n=p+1|0;k=a+484360|0;hp(Rb(k),b,n,65535,65535);f=nc(d+80|0);v[22640]=0;W(398,b|0,f|0,n|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break g}z=d,A=Sb(f),v[z+64>>2]=A;z=d,A=Wb(f),v[z+48>>2]=A;if(Gb(d- -64|0,d+48|0)){while(1){if((w[v[d- -64>>2]]-1&255)>>>0>7){break f}Me(d- -64|0);if(Gb(d- -64|0,d+48|0)){continue}break}}z=a,A=w[kc(f,0)|0],v[z+480196>>2]=A;e=w[d+311|0];q=w[d+313|0];g=nc(d- -64|0);v[22640]=0;h=q+1|0;W(398,b|0,g|0,h|0)|0;i=v[22640];v[22640]=0;j:{if((i|0)==1){break j}v[22640]=0;i=a+484344|0;R(364,i|0,h|0);h=v[22640];v[22640]=0;if((h|0)==1){break j}r=e+1|0;k:{l:{if(!(c&1)){break l}h=0;while(1){c=w[kc(g,h)|0];v[22640]=0;c=W(365,i|0,c|0,r|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break k}if(!c){break l}l=0;c=1;o=_b(i,w[kc(g,h)|0]);while(1){e=0;if(v[o+12>>2]){while(1){v[22640]=0;j=T(353,b|0)|0;m=v[22640];v[22640]=0;m:{n:{if((m|0)!=1){if(!(j&128)){break n}e=(j&127)+e|0;break m}e=P()|0;O()|0;break c}v[22640]=0;m=Tc(o,e,l&65535);s=v[22640];v[22640]=0;o:{if((s|0)!=1){p:{switch(j|0){case 0:break m;case 1:break p;default:break o}}t[m|0]=254;break m}e=P()|0;O()|0;break c}if(j>>>0>97){break m}t[m+1|0]=c;t[m|0]=j+12}e=e+1|0;if(e>>>0<y[o+12>>2]){continue}break}}if((l&65535)>>>0<=6){l=l+1|0;c=l+1|0;continue}break}c=(h|0)==(q|0);h=h+1|0;if(!c){continue}break}}b=0;e=0;q:{r:{s:{t:{u:{v:{w:{while(1){c=Rb(k);v[22640]=0;h=e&65535;c=Q(497,c|0,h|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break w}x:{if(!c){v[22640]=0;c=W(564,i|0,r|0,0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break v}if((c|0)==65535){break x}z=rc(Rb(k),b),A=c,u[z>>1]=A}z=d,A=Wb(_b(i,x[rc(Rb(k),b)>>1])),v[z+32>>2]=A;z=d,A=MC(d+32|0,1),v[z+48>>2]=A;b=w[kc(f,(b+1>>>0)%(n>>>0)|0)|0];if((b|0)==w[v[d+48>>2]+5|0]){break x}y:{if(w[v[d+48>>2]+3|0]!=16){break y}c=Rb(k);v[22640]=0;c=Q(565,c|0,h|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break q}if((c|0)==65535){break y}z=d,A=Wb(_b(i,c)),v[z+32>>2]=A;z=d,A=MC(d+32|0,1),v[z+48>>2]=A}t[v[d+48>>2]+3|0]=16;t[v[d+48>>2]+5|0]=b}e=e+1|0;b=e&65535;if(p>>>0>=b>>>0){continue}break}v[22640]=0;b=Q(2,d+48|0,5827)|0;c=v[22640];v[22640]=0;if((c|0)==1){break u}Eb(a+1298304|0,b);vb(b);v[22640]=0;b=Q(2,d+48|0,3141)|0;c=v[22640];v[22640]=0;if((c|0)==1){break t}Eb(a+1298316|0,b);vb(b);v[22640]=0;Vj(d+16|0,2,d+107|0);b=v[22640];v[22640]=0;if((b|0)==1){break s}v[22640]=0;R(377,d+32|0,d+16|0);b=v[22640];v[22640]=0;if((b|0)==1){break s}v[22640]=0;U(13,d+48|0,5,d+32|0);b=v[22640];v[22640]=0;e=1;if((b|0)==1){break r}Eb(a+1298328|0,d+48|0);vb(d+48|0);vb(d+32|0);v[a+1298364>>2]=5;gc(g);break e}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+32|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;vb(d+48|0);break a}e=P()|0;O()|0;vb(d- -64|0);break a}e=P()|0;O()|0;break b}e=0}gc(f)}gb=d+320|0;return e|0}gc(g)}gc(f)}S(e|0);L()}function wZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-112|0;gb=e;vc(b);a:{if(!Mr(b,9078)){break a}if(!Vv(b,e+96|0)){break a}if(!MD(e+96|0)){break a}if(!Pb(b,Uc(LD(e+96|0),jb))){break a}if(!Yb(b,w[e+105|0]|w[e+106|0]<<8)){break a}b:{if(!c){break b}Gd(a,4096);v[a+480208>>2]=12;d=1;u[a+480188>>1]=(w[e+96|2]&31)+1;i=e+96|3;u[a+480190>>1]=w[i|0];rh(a,1);f=Tb(e,5703);Eb(a+1298304|0,f);vb(f);f=Tb(e,4113);Eb(a+1298316|0,f);vb(f);f=gb-16|0;gb=f;g=Tb(f,1356);Dc(e+80|0,g);vb(g);gb=f+16|0;v[22640]=0;Y(389,e|0,e+80|0,e+96|1,e+96|0);f=v[22640];v[22640]=0;c:{d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){Eb(a+1298328|0,e);vb(e);Hb(e+80|0);v[a+1298364>>2]=5;g=w[i|0];f=gb-16|0;gb=f;i=e+80|0;v[i>>2]=0;v[i+4>>2]=0;v[f+12>>2]=0;cf(i+8|0,f+12|0,f+8|0);if(g){Tr(i,g);NE(i,g,0)}gb=f+16|0;k:{if(x[a+480190>>1]){f=1;while(1){v[22640]=0;R(390,b|0,e|0);g=v[22640];v[22640]=0;if((g|0)==1){break k}v[22640]=0;R(391,e|0,(B(d,104)+a|0)+484380|0);g=v[22640];v[22640]=0;if((g|0)==1){break k}g=w[e+16|0];oe(e- -64|0,i,d-1|0);Af(e- -64|0,(g&3)!=0);f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}v[22640]=0;W(392,b|0,a+1298268|0,-1)|0;f=v[22640];v[22640]=0;d=1;l:{m:{if((f|0)!=1){if(x[a+480190>>1]){while(1){v[22640]=0;W(393,b|0,(((d&65535)<<5)+a|0)+946304|0,-1)|0;f=v[22640];v[22640]=0;if((f|0)==1){break m}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}if(x[a+480188>>1]){d=0;while(1){v[22640]=0;f=(d<<5)+a|0;Se(f+480280|0);g=v[22640];v[22640]=0;if((g|0)==1){break e}v[22640]=0;U(395,b|0,f+480289|0,-1);f=v[22640];v[22640]=0;if((f|0)==1){break e}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}f=e+96|4;g=w[f|0]|w[f+1|0]<<8;d=0;v[22640]=0;k=a+484344|0;R(364,k|0,g|0);g=v[22640];v[22640]=0;if((g|0)!=1){break l}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}if(w[f|0]|w[f+1|0]<<8){while(1){v[22640]=0;U(396,b|0,e|0,-1);g=v[22640];v[22640]=0;n:{o:{if((g|0)==1){break o}v[22640]=0;g=W(365,k|0,d&65535,64)|0;h=v[22640];v[22640]=0;if((h|0)==1){break o}if(!g){break n}g=_b(k,d);v[22640]=0;R(397,g|0,e|0);g=v[22640];v[22640]=0;if((g|0)!=1){break n}}b=P()|0;O()|0;break d}d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}v[22640]=0;h=T(319,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break f}p:{if(!h){break p}v[22640]=0;d=Q(228,b|0,h|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break f}if(!d){break p}g=nc(e);v[22640]=0;W(398,b|0,g|0,h|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break h}d=Kb(e- -64|0);v[22640]=0;R(102,d|0,h|0);h=v[22640];v[22640]=0;if((h|0)==1){break i}l=e,m=Sb(g),v[l+24>>2]=m;l=e,m=Wb(g),v[l+56>>2]=m;if(Gb(e+24|0,e+56|0)){while(1){q:{h=w[v[e+24>>2]];if(h&128){l=e,m=df(d),v[l+40>>2]=m;Fd(e+48|0,e+40|0);v[22640]=0;ca(399,d|0,v[e+48>>2],h&127,32)|0;h=v[22640];v[22640]=0;if((h|0)!=1){break q}break i}v[22640]=0;R(103,d|0,h<<24>>24);h=v[22640];v[22640]=0;if((h|0)!=1){break q}break i}Me(e+24|0);if(Gb(e+24|0,e+56|0)){continue}break}}v[22640]=0;Y(400,e+24|0,5,6,d|0);h=v[22640];v[22640]=0;if((h|0)==1){break i}Eb(d,e+24|0);vb(e+24|0);h=zb(Jb(d));j=Ab(d);v[22640]=0;ga(401,a+1298292|0,h|0,j|0,76,0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break i}vb(d);gc(g)}g=Rb(a+484360|0);d=e+96|6;h=w[d|0]|w[d+1|0]<<8;d=0;v[22640]=0;ga(402,g|0,b|0,h|0,65535,65535)|0;g=v[22640];v[22640]=0;if((g|0)==1){break f}r:{s:{t:{u:{if(!(w[f|0]|w[f+1|0]<<8)){break u}g=c&1;while(1){v[22640]=0;h=Q(228,b|0,4)|0;j=v[22640];v[22640]=0;v:{if((j|0)!=1){if(h){break v}break u}b=P()|0;O()|0;break d}v[22640]=0;h=T(229,b|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break s}v[22640]=0;U(320,e|0,b|0,h|0);h=v[22640];v[22640]=0;if((h|0)==1){break r}w:{if(!g){break w}v[22640]=0;h=ke(k,d&65535);j=v[22640];v[22640]=0;if((j|0)==1){break t}if(!h){break w}h=_b(k,d);v[22640]=0;U(404,h|0,0,e|0);h=v[22640];v[22640]=0;if((h|0)==1){break t}}yb(e);d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}if(!(!(c&2)|!x[a+480190>>1])){d=1;c=1;while(1){f=B(d,104)+a|0;g=x[f+484414>>1];oe(e,i,d-1|0);d=Pc(e- -64|0,g&1?16:8,1,0,Cb(e)?6:0);v[22640]=0;W(363,d|0,f+484380|0,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break j}c=c+1|0;d=c&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}Ce(i);break b}b=P()|0;O()|0;yb(e);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;Hb(e+80|0);break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(d);break g}b=P()|0;O()|0}gc(g);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0}Ce(i)}S(b|0);L()}d=1}gb=e+112|0;return d|0}function wpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-336|0;gb=d;vc(b);a:{if(!Ar(b,d+320|0)){break a}if(!ZX(d+320|0)){break a}if(v[d+320>>2]==1179472708){Yb(b,4)}if(!Hh(b,d+312|0)|v[d+312>>2]!=1196314451){break a}if(!c){e=1;break a}l=d+312|4;g=l;ED(b,d+120|0,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));if((w[d+156|0]|w[d+157|0]<<8)>>>0>128|(w[d+162|0]|w[d+163|0]<<8)>>>0>16|((w[d+160|0]|w[d+161|0]<<8)>>>0>256|(w[d+154|0]|w[d+155|0]<<8)>>>0>128)){break a}Gd(a,8192);e=Tb(d+32|0,3602);Eb(a+1298304|0,e);vb(e);e=Tb(d+32|0,7467);Eb(a+1298316|0,e);vb(e);v[a+1298364>>2]=5;Hk(d+96|0,2,d+120|0);Bc(d+32|0,d+96|0);Eb(a+1298268|0,d+32|0);vb(d+32|0);u[d+32>>1]=w[d+162|0]|w[d+163|0]<<8;u[d+96>>1]=1;p=a,q=x[Ie(d+32|0,d+96|0)>>1],u[p+480188>>1]=q;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+32|0]=w[d+164|0];t[d+96|0]=64;e=w[ac(d+32|0,d+96|0)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}e=a;b:{if(w[d+165|0]==128){v[d+32>>2]=256/x[a+480188>>1];v[d+96>>2]=128;g=v[Fb(d+32|0,d+96|0)>>2];break b}g=w[d+165|0]&127}v[e+480228>>2]=g;e=0;while(1){g=(e<<5)+a|0;Se(g+480280|0);f=d+e|0;if(w[f+168|0]<=128){u[g+480284>>1]=w[f+168|0]<<1}e=e+1|0;if((e|0)!=16){continue}break}h=a+484360|0;i=Rb(h);k=d+184|0;e=gb-16|0;gb=e;v[e+12>>2]=w[d+156|0]|w[d+157|0]<<8;tc(e+12|0,128);tc(e+12|0,65535);j=x[e+12>>1];yf(i,j);if(j){g=0;while(1){f=w[g+k|0];c:{if((f|0)==255){f=65535;break c}if((f|0)!=254){break c}f=65534}p=bj(i,g),q=f,u[p>>1]=q;g=g+1|0;if((j|0)!=(g|0)){continue}break}}gb=e+16|0;if((w[d+154|0]|w[d+155|0]<<8)>>>0<(w[d+156|0]|w[d+157|0]<<8)>>>0){af(Rb(h),w[d+154|0]|w[d+155|0]<<8)}e=1;if(!Hh(b,d+312|0)){break a}k=c&2;j=a+484344|0;n=c&1;o=d+68|0;i=0;while(1){c=l;rd(d+96|0,b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));d:{e:{f:{if(!(!n|v[d+312>>2]!=1414807888)){v[22640]=0;m=i&65535;c=W(365,j|0,m|0,64)|0;e=v[22640];v[22640]=0;if((e|0)==1){break f}if(!c){break d}v[22640]=0;Q(350,d+96|0,2)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}gi(d+32|0);g=0;g:{while(1){v[22640]=0;c=Q(228,d+96|0,1)|0;e=v[22640];v[22640]=0;h:{i:{if((e|0)!=1){if(!(c&g>>>0<64)){break g}v[22640]=0;e=T(353,d+96|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break i}if(e){break h}g=g+1|0;continue}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}c=d+32|0;j:{k:{l:{f=e&15;m:{if(f>>>0<x[a+480188>>1]){c=_b(j,m);v[22640]=0;c=Tc(c,g,f);f=v[22640];v[22640]=0;if((f|0)==1){break m}}n:{if(!(e&128)){break n}v[22640]=0;f=T(353,d+96|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break l}if(!f){break n}t[c|0]=f>>>0<109?f+12|0:f}if(!(e&64)){break j}v[22640]=0;f=T(353,d+96|0)|0;h=v[22640];v[22640]=0;if((h|0)!=1){break k}}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}t[c+1|0]=f}o:{p:{q:{r:{s:{t:{u:{v:{if(e&32){t[c+2|0]=1;v[22640]=0;f=T(353,d+96|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break v}t[d+16|0]=f;v[22640]=0;t[d|0]=64;f=ac(d+16|0,d);h=v[22640];v[22640]=0;if((h|0)==1){break u}t[c+4|0]=w[f|0]}if(!(e&16)){continue}v[22640]=0;R(431,d+16|0,d+96|0);e=v[22640];v[22640]=0;if((e|0)==1){break t}h=md(d+16|0);f=d+16|0;e=w[f|0];switch(e-17|0){case 2:break r;case 0:case 1:break s;default:break q}}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}e=e&15;break p}t[f|0]=33;t[h|0]=145;e=w[f|0];break o}if(e>>>0<17){break o}e=(e&240)==32?9:-1}t[f|0]=e}t[c+3|0]=e;t[c+5|0]=w[h|0];v[22640]=0;Mf(c);c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}b=P()|0;O()|0;break e}i=i+1|0;break d}if(v[d+312>>2]!=1414745673){break d}if(!ei(a)){break d}c=x[a+480190>>1]+1|0;u[a+480190>>1]=c;v[22640]=0;R(520,d+96|0,d+32|0);e=v[22640];v[22640]=0;w:{x:{y:{if((e|0)==1){break y}v[22640]=0;f=(B(c&65535,104)+a|0)+484380|0;R(521,d+32|0,f|0);c=v[22640];v[22640]=0;if((c|0)==1){break y}v[22640]=0;Hk(d,2,o);c=v[22640];v[22640]=0;if((c|0)==1){break x}v[22640]=0;R(377,d+16|0,d|0);c=v[22640];v[22640]=0;if((c|0)==1){break x}c=x[a+480190>>1];v[22640]=0;Q(333,((c<<5)+a|0)+946304|0,d+16|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break w}vb(d+16|0);if(!k){break d}c=Pc(d+16|0,8,1,0,1);e=2;g=d+45|0;z:{if(!(w[g|0]&64)){e=0;if(!(w[g|0]&2)){break z}}zf(c,e)}if(w[g|0]&4){Vi(c,16)}v[22640]=0;W(363,d+16|0,f|0,d+96|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;vb(d+16|0);break e}b=P()|0;O()|0}yb(d+96|0);S(b|0);L()}yb(d+96|0);e=1;if(Hh(b,d+312|0)){continue}break}}gb=d+336|0;return e|0}function Qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-176|0;gb=d;vc(b);a:{if(!OC(b,d+128|0)){break a}if(!lU(d+128|0)){break a}if(!Pb(b,Uc(kU(d+128|0),jb))){break a}b:{if(!c){break b}Gd(a,256);Vj(d+16|0,2,d+128|0);Bc(d+48|0,d+16|0);Eb(a+1298268|0,d+48|0);vb(d+48|0);e=Tb(d+48|0,12508);Eb(a+1298304|0,e);vb(e);e=Tb(d+48|0,7446);Eb(a+1298316|0,e);vb(e);Df(d+16|0,1380);v[22640]=0;R(411,d+112|0,d+159|0);e=v[22640];v[22640]=0;c:{d:{e:{f:{g:{if((e|0)!=1){v[22640]=0;Y(902,d+48|0,d+16|0,d+158|0,d+112|0);e=v[22640];v[22640]=0;if((e|0)==1){break g}Eb(a+1298328|0,d+48|0);vb(d+48|0);vb(d+112|0);Hb(d+16|0);v[a+1298364>>2]=5;v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;f=w[d+160|0];if(w[d+159|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-B(e,10)}g=(f&255?f:96)&255;e=RP(g);v[a+480196>>2]=g>>>4;v[a+480204>>2]=e;if(w[d+159|0]>10){break e}break d}f=P()|0;O()|0;break f}f=P()|0;O()|0;vb(d+112|0)}Hb(d+16|0);break c}t[d+48|0]=64;p=a,q=w[ac(d+162|0,d+48|0)|0]<<2,v[p+480200>>2]=q}f=0;while(1){e=(f<<5)+a|0;Se(e+480280|0);u[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;h:{i:{while(1){Xu(b,d+16|0);if(w[d+28|0]!=46?w[d+28|0]:0){break i}i=gb-32|0;gb=i;h=(B(f,104)+a|0)+484380|0;td(h,0);g=d+16|0;Gk(i,2,g);Bc(i+16|0,i);v[22640]=0;Q(335,h+43|0,i+16|0)|0;e=v[22640];v[22640]=0;j:{k:{if((e|0)!=1){vb(i+16|0);e=g+24|0;v[h+24>>2]=w[e|0]|w[e+1|0]<<8;t[i+16|0]=w[g+22|0];t[i|0]=64;p=h,q=w[ac(i+16|0,i)|0]<<2,u[p+30>>1]=q;e=g+16|0;v[h>>2]=w[e|0]|w[e+1|0]<<8;e=g+18|0;v[h+4>>2]=w[e|0]|w[e+1|0]<<8;e=g+20|0;j=w[e|0]|w[e+1|0]<<8;v[h+8>>2]=j;g=v[h>>2];if(g>>>0>1){break k}v[h>>2]=0;break j}a=P()|0;O()|0;vb(i+16|0);S(a|0);L()}e=v[h+4>>2];if(g>>>0<=e>>>0|e>>>0>=j>>>0|(j|0)==65535){break j}u[h+34>>1]=2;p=h,q=v[Fb(h+8|0,h)>>2],v[p+8>>2]=q}gb=i+32|0;Gk(d,2,d+16|0);Bc(d+112|0,d);v[22640]=0;Q(333,((f<<5)+a|0)+946304|0,d+112|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break h}vb(d+112|0);u[((f<<1)+d|0)+46>>1]=w[d+30|0]|w[d+31|0]<<8;f=f+1|0;if((f|0)!=32){continue}break}e=a+484360|0;hp(Rb(e),b,w[d+159|0]?128:64,65535,65535);e=Rb(e);p=d,q=Sb(e),v[p+16>>2]=q;p=d,q=Wb(e),v[p+112>>2]=q;if(Gb(d+16|0,d+112|0)){while(1){e=v[d+16>>2];g=x[e>>1];l:{if(!((g|0)!=99?(g|0)!=255:0)){u[e>>1]=65535;break l}if(g>>>0>63){break i}}mf(d+16|0);if(Gb(d+16|0,d+112|0)){continue}break}}i=c&1;if(i){vg(a+484344|0,w[d+161|0])}if(w[d+161|0]){n=a+484344|0;while(1){m:{n:{if(i){if(qh(n,l&65535,64)){break n}}f=0;while(1){if((de(b)+5&255)>>>0>=3){Yb(b,3)}f=f+1|0;if((f|0)!=256){continue}break}break m}p=d,q=Sb(_b(n,l)),v[p+112>>2]=q;v[d>>2]=63;k=65535;m=0;while(1){f=0;while(1){g=f;j=0;f=0;o=0;h=0;o:{p:{q:{r:{s:{t:{e=de(b);switch(e-251|0){case 1:break o;case 0:break r;case 2:break t;default:break s}}t[v[d+112>>2]]=254;break o}Pr(d+16|0,b);f=w[lc(d+16|0,0)|0];o=w[lc(d+16|0,1)|0];h=w[lc(d+16|0,2)|0];j=254;if((e|0)==254){break q}j=e;if(e>>>0>95){break p}}j=(B(j>>>4|0,12)+(j&15)|0)+37|0}e=j;t[v[d+112>>2]]=e}t[v[d+112>>2]+1|0]=(f&248)>>>3;if(w[v[d+112>>2]+1|0]>=32){t[v[d+112>>2]+1|0]=0}e=o>>>1&120|f&7;if(e>>>0<=64){t[v[d+112>>2]+2|0]=1;t[v[d+112>>2]+4|0]=e}t[v[d+112>>2]+3|0]=w[(o&15)+33712|0];t[v[d+112>>2]+5|0]=h;u:{switch(w[v[d+112>>2]+3|0]-11|0){case 0:j=v[d+112>>2];e=w[j+5|0];if(w[v[d+112>>2]+5|0]&15){t[j+5|0]=e&15;break o}t[j+5|0]=e&240;break o;case 3:t[v[d+112>>2]+5|0]=B(w[v[d+112>>2]+5|0]&240,10)|w[v[d+112>>2]+5|0]&15;v:{if((k|0)!=65535){if(w[v[d+112>>2]+5|0]){break v}t[v[d+112>>2]+3|0]=12;t[v[d+112>>2]+5|0]=k}k=65535}tc(d,m);break o;case 1:k=w[v[d+112>>2]+5|0];v[d>>2]=63;t[v[d+112>>2]+3|0]=0;break o;case 5:if(w[d+159|0]<=20){t[v[d+112>>2]+5|0]=w[v[d+112>>2]+5|0]%10|w[v[d+112>>2]+5|0]/10<<4}if(w[v[d+112>>2]+5|0]){break o}t[v[d+112>>2]+3|0]=0;break o;case 7:break o;default:break u}}if(w[v[d+112>>2]+5|0]){break o}t[v[d+112>>2]+3|0]=0}Wj(d+112|0);f=g+1|0;if((g&65535)>>>0<3){continue}break}m=m+1|0;if((m|0)!=64){continue}break}if((k|0)==65535){break m}Gm(_b(n,l),op(Qe(Be(d+16|0,12,k&255),v[d>>2])))}l=l+1|0;if(l>>>0<w[d+161|0]){continue}break}}f=1;if(!(c&2)){break a}g=Pc(d+16|0,8,1,0,0);while(1){c=B(f,104)+a|0;e=c+484380|0;w:{if(!v[e>>2]|!x[c+484410>>1]){break w}c=x[((f<<1)+d|0)+46>>1];if(c>>>0<4){break w}if(!Xc(b,c<<4)){break w}zg(g,e,b)}f=f+1|0;if((f|0)!=32){continue}break}break b}f=0;break a}f=P()|0;O()|0;vb(d+112|0)}S(f|0);L()}f=1}gb=d+176|0;return f|0}function Noa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-704|0;gb=k;a:{b:{if(d>>>0<=511){d=0;a=gb-32|0;gb=a;i=k+24|0;bc(a+24|0,i,554);h=xb(a+24|0);f=v[a+28>>2];e=v[a+24>>2];v[a+8>>2]=e;v[a+12>>2]=f;v[a>>2]=e;v[a+4>>2]=f;fc(a+16|0,b,a);f=xb(a+16|0);if((f|0)==(h|0)){Yb(b,xb(a+24|0))}gb=a+32|0;a=(f|0)==(h|0);if(!a){Qb(i,0,554)}if(!a){break b}d=gb-32|0;gb=d;c:{d:{a=k+24|0;e:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1229999433){break e}Cp(d,3,a+32|0);Bc(d+16|0,d);v[22640]=0;Q(333,c+492|0,d+16|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}vb(d+16|0);Yj(d,1,a+4|0);Bc(d+16|0,d);v[22640]=0;Q(333,c+524|0,d+16|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}vb(d+16|0);b=w[a+24|0]|w[a+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=b<<6;t[c+16|0]=w[a+26|0];t[c+17|0]=w[a+27|0];i=c+108|0;e=c+236|0;b=0;h=a- -64|0;while(1){g=b<<1;f=w[g+h|0];g=w[h+(g|1)|0];o=sd(e,b),p=g,u[o>>1]=p;o=lc(i,b),p=(f>>>0<120?f:b)+1|0,t[o|0]=p;b=b+1|0;if((b|0)!=120){continue}break}t[c+60|0]=w[c+60|0]&254|t[a+17|0]&1;t[c+60|0]=w[c+60|0]&253|w[a+17|0]&2;t[c+60|0]=w[c+60|0]&251|w[a+17|0]&4;i=c+61|0;t[i|0]=w[a+18|0];e=c+62|0;t[e|0]=w[a+19|0];g=c+63|0;t[g|0]=w[a+20|0];j=c- -64|0;t[j|0]=w[a+21|0];h=c+48|0;hh(h,25);b=0;while(1){f:{l=b<<1;f=w[(l+a|0)+504|0];o=Mb(h,b),p=f,u[o>>1]=p;if((f|0)==255){hh(h,b);break f}f=w[(a+(l|1)|0)+504|0];o=Mb(h,b),p=f,t[o+2|0]=p;b=b+1|0;if((b|0)!=25){continue}}break}a=w[Bf(i,e)|0];if(Nb(h)>>>0<=a>>>0){t[c+60|0]=w[c+60|0]&253}a=w[Bf(g,j)|0];if(Nb(h)>>>0>a>>>0){break e}t[c+60|0]=w[c+60|0]&251}gb=d+32|0;break c}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}d=554;break b}h=v[b+8>>2];f=gb-48|0;gb=f;v[f+44>>2]=674;v[f+24>>2]=674;d=b;i=v[Fb(f+44|0,f+24|0)>>2];if(!Pb(d,i)){i=xf(d)}e=k+24|0;TW(f+24|0,e);g=Wd(f+32|0,v[f+24>>2],i);j=v[g+4>>2];v[f+8>>2]=v[g>>2];v[f+12>>2]=j;fc(f+16|0,d,f+8|0);TW(f+24|0,e);Qb(v[f+24>>2]+i|0,0,674-i|0);Yb(d,v[f+44>>2]);gb=f+48|0;f=b;i=c;d=c;l=v[a+480180>>2];a=0;g=gb-32|0;gb=g;g:{h:{j=k+24|0;e=j;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))==1229999433){Cp(g,3,e+32|0);Bc(g+16|0,g);v[22640]=0;Q(333,d+492|0,g+16|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break h}vb(g+16|0);Yj(g,1,e+4|0);Bc(g+16|0,g);v[22640]=0;Q(333,d+524|0,g+16|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break h}vb(g+16|0);v[d>>2]=(w[e+20|0]|w[e+21|0]<<8)<<5;v[d+4>>2]=w[e+24|0]>>>1;tc(d+4|0,64);a=w[e+25|0]&127;v[d+8>>2]=a>>>0>64?128:a<<2;t[d+15|0]=w[d+15|0]&254|((w[e+25|0]^-1)&128)>>>7;t[g+16|0]=w[e+26|0];t[g|0]=100;o=d,p=w[ac(g+16|0,g)|0],t[o+20|0]=p;t[g+16|0]=w[e+27|0];t[g|0]=64;o=d,p=w[ac(g+16|0,g)|0],t[o+19|0]=p;t[d+16|0]=w[e+17|0];t[d+17|0]=w[e+18|0];t[d+18|0]=w[e+19|0];t[d+26|0]=w[e+22|0];t[d+27|0]=w[e+23|0];fm(d,w[e+58|0]&127,w[e+58|0]>>>7|0);em(d,w[e+59|0]&127,w[e+59|0]>>>7|0);i:{j:{k:{if(!((w[e+28|0]|w[e+29|0]<<8)==514|(w[e+28|0]|w[e+29|0]<<8)==529|(w[e+28|0]|w[e+29|0]<<8)==544)){if((w[e+28|0]|w[e+29|0]<<8)!=532){break k}}if(w[e+61|0]==255){break k}if(w[e+61|0]<=128){t[d+30|0]=w[e+61|0]}a=w[e+62|0]|w[e+63|0]<<8;if(a>>>0<129){break j}break i}a=0;if(t[e+61|0]>=0){t[d+30|0]=w[e+61|0]+1}a=t[e+62|0]>=0?w[e+62|0]+1|0:a;if(t[e+63|0]<0){break j}a=(w[e+63|0]<<7)+a|0}u[d+28>>1]=a}a=t[e+60|0];t[d+31|0]=a;if((a|0)<=-1){t[d+31|0]=0;t[d+34|0]=a^128}a=0;l=l&16777216?240:25;nw(e+304|0,d+48|0,0,l);nw(e+386|0,d+68|0,32,l);nw(e+468|0,d+88|0,32,l);t[d+100|0]=w[d+100|0]&239|w[e+468|0]>>>3&16;l=d+108|0;n=d+236|0;d=e- -64|0;while(1){m=a<<1;e=w[m+d|0];m=w[d+(m|1)|0];o=sd(n,a),p=m,u[o>>1]=p;o=lc(l,a),p=(e>>>0<120?e:a)+1|0,t[o|0]=p;a=a+1|0;if((a|0)!=120){continue}break}a=554}gb=g+32|0;break g}a=P()|0;O()|0;vb(g+16|0);S(a|0);L()}if(a){if(!((w[j+550|0]|w[j+551|0]<<8|(w[j+552|0]<<16|w[j+553|0]<<24))!=1297110104?(w[j+550|0]|w[j+551|0]<<8|(w[j+552|0]<<16|w[j+553|0]<<24))!=1481920589:0)){d=i+236|0;a=0;while(1){i=w[(a+j|0)+554|0];e=sd(d,a);u[e>>1]=x[e>>1]|i<<8;a=a+1|0;if((a|0)!=120){continue}break}a=674}}else{a=0}d=a;Xc(f,h+d|0);if(!Fh(b,11347)){break b}rd(k,b,og(b));v[22640]=0;b=T(232,k|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break a}v[22640]=0;a=Q(575,k|0,11138)|0;h=v[22640];v[22640]=0;if((h|0)==1){break a}if(a){v[22640]=0;a=T(353,k|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break a}t[c+34|0]=a>>>0>250?0:a}d=(b+d|0)+8|0;yb(k)}gb=k+704|0;return d|0}a=P()|0;O()|0;yb(k);S(a|0);L()}function mL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-416|0;gb=e;t[e+415|0]=c;a:{if(nk(b)){break a}f=w[wl(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Kl(e+160|0,b,v[b+4>>2]-1|0);f=v[e+164>>2];v[b>>2]=v[e+160>>2];v[b+4>>2]=f}Kd(e+160|0);f=v[e+160>>2];Kd(e+376|0);h=vl(f,v[e+380>>2],b);Kd(e+160|0);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==v[e+164>>2]){v[e+400>>2]=f;v[e+404>>2]=g;a=uc(e+392|0,18693);c=v[e+404>>2];v[e+8>>2]=v[e+400>>2];v[e+12>>2]=c;c=v[a+4>>2];v[e>>2]=v[a>>2];v[e+4>>2]=c;if(Fc(e+8|0,e)){c=aa(8)|0;v[22640]=0;R(2056,e+376|0,e+415|0);a=v[22640];v[22640]=0;if((a|0)==1){break g}v[22640]=0;U(2037,e+160|0,14695,e+376|0);a=v[22640];v[22640]=0;if((a|0)==1){break f}qc(c,e+160|0);a=0;v[22640]=0;U(223,c|0,55256,1936);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+160|0);break e}if(!d){break h}c=aa(8)|0;v[22640]=0;d=Q(2057,e+344|0,b|0)|0;b=v[22640];v[22640]=0;a=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[22640]=0;U(2037,e+360|0,14731,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break q}v[22640]=0;R(2054,e+376|0,e+360|0);b=v[22640];v[22640]=0;a=1;if((b|0)==1){break p}v[22640]=0;R(2056,e+328|0,e+415|0);a=v[22640];v[22640]=0;if((a|0)==1){break o}v[22640]=0;U(2058,e+160|0,e+376|0,e+328|0);b=v[22640];v[22640]=0;a=1;if((b|0)==1){break n}qc(c,e+160|0);v[22640]=0;U(223,c|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+160|0);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}vb(e+328|0)}vb(e+376|0)}vb(e+360|0)}vb(d)}if(a){break d}break c}v[e+320>>2]=f;v[e+324>>2]=g;d=uc(e+312|0,18693);f=v[e+324>>2];v[e+152>>2]=v[e+320>>2];v[e+156>>2]=f;f=v[d+4>>2];v[e+144>>2]=v[d>>2];v[e+148>>2]=f;if(Fc(e+152|0,e+144|0)){c=aa(8)|0;v[22640]=0;R(2056,e+376|0,e+415|0);a=v[22640];v[22640]=0;r:{s:{if((a|0)!=1){v[22640]=0;U(2037,e+160|0,14695,e+376|0);a=v[22640];v[22640]=0;if((a|0)==1){break s}qc(c,e+160|0);a=0;v[22640]=0;U(223,c|0,55256,1936);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+160|0);break r}b=P()|0;O()|0;break d}b=P()|0;a=1;O()|0}vb(e+376|0);if(a){break d}break c}d=v[b+4>>2];v[e+304>>2]=v[b>>2];v[e+308>>2]=d;d=uc(e+296|0,4500);f=v[e+308>>2];v[e+136>>2]=v[e+304>>2];v[e+140>>2]=f;f=v[d+4>>2];v[e+128>>2]=v[d>>2];v[e+132>>2]=f;t:{if(!Fc(e+136|0,e+128|0)){d=v[b+4>>2];v[e+288>>2]=v[b>>2];v[e+292>>2]=d;d=uc(e+280|0,4482);f=v[e+292>>2];v[e+120>>2]=v[e+288>>2];v[e+124>>2]=f;f=v[d+4>>2];v[e+112>>2]=v[d>>2];v[e+116>>2]=f;if(!Fc(e+120|0,e+112|0)){break t}}t[a+60|0]=c;break h}d=v[b+4>>2];v[e+272>>2]=v[b>>2];v[e+276>>2]=d;d=uc(e+264|0,3997);f=v[e+276>>2];v[e+104>>2]=v[e+272>>2];v[e+108>>2]=f;f=v[d+4>>2];v[e+96>>2]=v[d>>2];v[e+100>>2]=f;u:{if(!Fc(e+104|0,e+96|0)){d=v[b+4>>2];v[e+256>>2]=v[b>>2];v[e+260>>2]=d;d=uc(e+248|0,3978);f=v[e+260>>2];v[e+88>>2]=v[e+256>>2];v[e+92>>2]=f;f=v[d+4>>2];v[e+80>>2]=v[d>>2];v[e+84>>2]=f;if(!Fc(e+88|0,e+80|0)){break u}}t[a+61|0]=c;break h}d=v[b+4>>2];v[e+240>>2]=v[b>>2];v[e+244>>2]=d;d=uc(e+232|0,4081);f=v[e+244>>2];v[e+72>>2]=v[e+240>>2];v[e+76>>2]=f;f=v[d+4>>2];v[e+64>>2]=v[d>>2];v[e+68>>2]=f;if(Fc(e+72|0,e- -64|0)){t[a+62|0]=c;break h}d=v[b+4>>2];v[e+224>>2]=v[b>>2];v[e+228>>2]=d;d=uc(e+216|0,3153);f=v[e+228>>2];v[e+56>>2]=v[e+224>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Fc(e+56|0,e+48|0)){t[a+63|0]=c;break h}d=v[b+4>>2];v[e+208>>2]=v[b>>2];v[e+212>>2]=d;d=uc(e+200|0,4549);f=v[e+212>>2];v[e+40>>2]=v[e+208>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Fc(e+40|0,e+32|0)){t[a+64|0]=c;break h}d=v[b+4>>2];v[e+192>>2]=v[b>>2];v[e+196>>2]=d;b=uc(e+184|0,10754);d=v[e+196>>2];v[e+24>>2]=v[e+192>>2];v[e+28>>2]=d;d=v[b+4>>2];v[e+16>>2]=v[b>>2];v[e+20>>2]=d;if(!Fc(e+24|0,e+16|0)){break h}d=a+24|0;b=v[d>>2];f=b+24664|0;g=v[f+4>>2];v[e+176>>2]=v[f>>2];v[e+180>>2]=g;f=b+24656|0;g=v[f+4>>2];v[e+168>>2]=v[f>>2];v[e+172>>2]=g;f=v[b+24652>>2];v[e+160>>2]=v[b+24648>>2];v[e+164>>2]=f;b=e;if(c){a=BK(v[a+56>>2])}else{a=0}v[b+180>>2]=a;if(!Dy(e+160|0,v[d>>2]+24648|0)){break h}Hz(v[d>>2],e+160|0)}gb=e+416|0;return}b=P()|0;O()|0;break d}b=P()|0;a=1;O()|0}vb(e+376|0);if(!a){break c}}da(c|0)}S(b|0)}L()}function Kla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=gb-80|0;gb=f;vc(b);a:{b:{c:{d:{e:{if(VU(b,11463)){g=nc(f- -64|0);h=nc(f+48|0);l=Vu(f+32|0);v[22640]=0;R(407,a|0,32768);d=v[22640];v[22640]=0;if((d|0)==1){break b}v[22640]=0;d=Q(2,f|0,5382)|0;i=v[22640];v[22640]=0;if((i|0)==1){break c}Eb(a+1298304|0,d);vb(d);v[22640]=0;d=Q(2,f|0,3149)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}Eb(a+1298316|0,d);vb(d);v[a+1298364>>2]=2;j=a+484360|0;i=f+24|4;f:{g:{h:{i:{j:{while(1){v[22640]=0;d=Q(228,b|0,8)|0;e=v[22640];v[22640]=0;if((e|0)==1){break i}k:{l:{m:{n:{if(!d){break n}v[22640]=0;d=Q(843,b|0,f+24|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break m}if(!d){break n}d=i;d=Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));v[22640]=0;U(320,f|0,b|0,d|0);d=v[22640];v[22640]=0;if((d|0)==1){break l}v[22640]=0;d=T(307,f|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break e}if(d){break k}yb(f)}if(x[a+480188>>1]){break j}e=0;break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}o:{p:{q:{r:{s:{t:{d=f+24|0;d=Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));if((d|0)<=1347175757){if((d|0)==1129140036){break t}if((d|0)==1346458708){break r}if((d|0)!=1346522948){break p}if(Ze(g)>>>0>255){break p}v[22640]=0;R(556,g|0,f|0);d=v[22640];v[22640]=0;if((d|0)==1){break e}break p}if((d|0)<=1396854595){if((d|0)==1347175758){break s}if(x[a+480190>>1]|(d|0)!=1396788560){break p}v[22640]=0;U(844,f|0,l|0,a|0);d=v[22640];v[22640]=0;if((d|0)==1){break e}break p}if((d|0)==1396854596){break q}if((d|0)!=1397769541){break p}v[22640]=0;d=T(232,f|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break e}if(d>>>0<2){break p}v[22640]=0;d=T(444,f|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break e}o=a,p=Jd(d,1,255),v[o+480196>>2]=p;break p}if(x[a+480188>>1]){break p}v[22640]=0;e=T(232,f|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break e}d=0;if(e>>>0<8){break p}while(1){v[22640]=0;k=T(353,f|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break o}v[22640]=0;m=T(353,f|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break e}e=x[a+480188>>1];if(k|m){v[22640]=0;Se(((e<<5)+a|0)+480280|0);e=v[22640];v[22640]=0;if((e|0)==1){break e}k=x[a+480188>>1];e=k+1|0;u[a+480188>>1]=e;u[((k<<5)+a|0)+480284>>1]=d-1>>>0<2?192:64}v[22640]=0;Se((((e&65535)<<5)+a|0)+480280|0);e=v[22640];v[22640]=0;if((e|0)==1){break e}e=x[a+480188>>1];u[a+480188>>1]=e+1;u[((e<<5)+a|0)+480284>>1]=d-1>>>0<2?192:64;d=d+1|0;if((d|0)!=4){continue}break}if(c){break p}yb(f);break g}v[22640]=0;d=T(232,f|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break e}if(d>>>0<2){break p}v[22640]=0;n=T(444,f|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break e}break p}d=Rb(j);v[22640]=0;e=T(232,f|0)|0;k=v[22640];v[22640]=0;if((k|0)==1){break e}v[22640]=0;ga(540,d|0,f|0,e|0,255,254)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break p}break e}if(Ze(h)>>>0>3998){break p}v[22640]=0;d=T(232,f|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break e}if(!d){break p}v[22640]=0;R(556,h|0,f|0);d=v[22640];v[22640]=0;if((d|0)==1){break e}}yb(f);continue}break}break e}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=Rb(j);v[22640]=0;R(527,b|0,n&65535);b=v[22640];v[22640]=0;if((b|0)==1){break b}u:{if(!(c&1)){break u}d=0;b=Ze(g);v[22640]=0;R(364,a+484344|0,b&65535);b=v[22640];v[22640]=0;if((b|0)==1){break b}if(!Ze(g)){break u}b=0;while(1){d=Hg(g,d);v[22640]=0;U(845,d|0,b&65535,a|0);d=v[22640];v[22640]=0;if((d|0)==1){break h}b=b+1|0;d=b&65535;if(Ze(g)>>>0>d>>>0){continue}break}}b=1;if(x[a+480190>>1]<2){break g}i=c&2;d=0;v:{while(1){if(!i|Ze(h)>>>0<=d>>>0){break g}w:{c=(B(b,104)+a|0)+484380|0;if(v[c>>2]){e=Hg(h,d);v[22640]=0;e=T(232,e|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break w}tc(c,e);oe(f,l,b-1|0);e=Pc(f+24|0,8,1,1,Cb(f)?10:0);j=Hg(h,d);v[22640]=0;W(363,e|0,c|0,j|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break v}d=d+1|0}e=1;b=b+1|0;if(b>>>0<x[a+480190>>1]){continue}break f}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}e=1}Ce(l);fd(h);fd(g)}gb=f+80|0;return e|0}a=P()|0;O()|0;yb(f);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Ce(l);fd(h);fd(g);S(a|0);L()}function Ula(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=gb-256|0;gb=e;vc(b);a:{if(!uY(b,e+184|0)){break a}if(!$U(e+184|0)){break a}if(!Pb(b,Uc(_U(e+184|0),jb))){break a}b:{if(!c){break b}Gd(a,16);Vj(e+8|0,2,e+184|4);Bc(e+32|0,e+8|0);Eb(a+1298268|0,e+32|0);vb(e+32|0);u[a+480190>>1]=w[e+214|0];u[a+480188>>1]=w[e+217|0];d=Tb(e+32|0,5592);Eb(a+1298304|0,d);vb(d);d=Tb(e+32|0,7455);Eb(a+1298316|0,d);vb(d);Df(e+8|0,1320);d=e+184|3;v[e+168>>2]=w[d|0]>>>4;d=w[d|0];v[22640]=0;v[e+180>>2]=d&15;Y(485,e+32|0,e+8|0,e+168|0,e+180|0);f=v[22640];v[22640]=0;d=1;c:{d:{e:{if((f|0)!=1){Eb(a+1298328|0,e+32|0);vb(e+32|0);Hb(e+8|0);v[a+1298364>>2]=5;if(x[a+480190>>1]){f=1;while(1){qE(b,e+32|0);i=gb-16|0;gb=i;g=(B(d,104)+a|0)+484380|0;td(g,0);h=e+32|0;u[i+14>>1]=w[h+35|0]<<2;u[i+12>>1]=256;p=g,q=x[Oc(i+14|0,i+12|0)>>1],u[p+30>>1]=q;f:{if((w[h+22|0]|w[h+23|0]<<8|(w[h+24|0]<<16|w[h+25|0]<<24))>>>0<3){break f}v[g>>2]=w[h+22|0]|w[h+23|0]<<8|(w[h+24|0]<<16|w[h+25|0]<<24);v[g+4>>2]=w[h+26|0]|w[h+27|0]<<8|(w[h+28|0]<<16|w[h+29|0]<<24);v[i+8>>2]=w[h+30|0]|w[h+31|0]<<8|(w[h+32|0]<<16|w[h+33|0]<<24);v[i+4>>2]=1;p=g,q=v[Jc(i+8|0,i+4|0)>>2]-1|0,v[p+8>>2]=q;tc(g+8|0,v[g>>2]);g:{if(y[g+8>>2]<=v[g+4>>2]+4>>>0){v[g+4>>2]=0;v[g+8>>2]=0;break g}u[g+34>>1]=x[g+34>>1]|2}t[g+37|0]=w[h+34|0];p=g,q=Au(0,t[h+34|0]<<4),v[p+24>>2]=q;if(!(t[h+36|0]&1)){break f}u[g+34>>1]=x[g+34>>1]|1;v[g>>2]=v[g>>2]>>>1;v[g+4>>2]=v[g+4>>2]>>>1;v[g+8>>2]=v[g+8>>2]>>>1}gb=i+16|0;Mk(e+168|0,2,e+32|0);Bc(e+8|0,e+168|0);v[22640]=0;Q(333,((d<<5)+a|0)+946304|0,e+8|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break e}vb(e+8|0);f=f+1|0;d=f&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}if(x[a+480188>>1]){d=0;while(1){f=(d<<5)+a|0;Se(f+480280|0);u[f+480284>>1]=(w[(e+d|0)+218|0]<<4|8)&248;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}f=e+32|0;g=gb-32|0;gb=g;d=b;h:{if(Pb(d,128)){DW(g+24|0,f);f=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=f;gd(g+16|0,d,g+8|0);break h}d=gb-16|0;gb=d;h=f+128|0;while(1){Kf(f);f=f+1|0;if((h|0)!=(f|0)){continue}break}gb=d+16|0}gb=g+32|0;AE(Rb(a+484360|0),e+32|0,w[e+211|0]+1|0);i=w[e+216|0]?w[e+216|0]:64;rd(e+8|0,b,B(w[e+208|0]|w[e+209|0]<<8,192));d=c&1;if(d){f=w[e+210|0];v[22640]=0;R(364,a+484344|0,f+1|0);f=v[22640];v[22640]=0;if((f|0)==1){break d}}i:{j:{if(!d){break j}n=a+484344|0;while(1){v[22640]=0;f=W(365,n|0,k&65535,i|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break i}d=0;if(!f){break j}while(1){v[22640]=0;f=T(319,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break d}l=d;k:{if(!f|f>>>0>(w[e+208|0]|w[e+209|0]<<8)>>>0){break k}d=l&65535;if(d>>>0>=x[a+480188>>1]){break k}v[22640]=0;Q(227,e+8|0,B(f,192)-192|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break d}f=_b(n,k);v[22640]=0;d=Tc(f,0,d);f=v[22640];v[22640]=0;if((f|0)==1){break d}m=0;if(!i){break k}while(1){v[22640]=0;R(740,e+168|0,e+8|0);f=v[22640];v[22640]=0;if((f|0)==1){break d}j=md(e+168|0);h=Re(e+168|0);g=d;f=w[e+168|0];if(f>>>0>=4){t[d|0]=(f>>>2|0)+37;f=w[e+168|0]}t[g+1|0]=f<<4&48|w[j|0]>>>4;f=w[h|0];g=0;h=0;l:{m:{n:{o:{p:{q:{j=w[j|0]&15;switch(j-8|0){case 0:break n;case 6:break p;case 2:break q;default:break o}}f=f&240?f&-16:f&15;j=10;break m}j=14;o=(f+16&240)>>>4|0;if(o>>>0>8){break m}if(1<<o&435){break n}break m}g=j;h=f}j=g;f=h;if(!((g|f)&255)){break l}}t[d+5|0]=f;t[d+3|0]=j;v[22640]=0;Mf(d);f=v[22640];v[22640]=0;if((f|0)!=1){break l}break d}d=B(x[a+480188>>1],6)+d|0;m=m+1|0;if((m|0)!=(i|0)){continue}break}}d=l+1|0;if((l&65535)>>>0<31){continue}break}d=w[e+210|0]>k>>>0;k=k+1|0;if(d){continue}break}}if(w[e+212|0]|w[e+213|0]<<8){d=w[e+212|0]|w[e+213|0]<<8;v[22640]=0;ga(498,a+1298292|0,b|0,d|0,39,1)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}}if(!(!(c&2)|!x[a+480190>>1])){d=1;while(1){c=B(d&65535,104)+a|0;f=Pc(e+168|0,u[c+484414>>1]&1?16:8,1,0,1);v[22640]=0;W(363,f|0,c+484380|0,b|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break d}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}v[a+480260>>2]=64;v[a+480264>>2]=32767;yb(e+8|0);break b}break d}d=P()|0;O()|0;Hb(e+8|0);break c}d=P()|0;O()|0;vb(e+8|0);break c}d=P()|0;O()|0;yb(e+8|0)}S(d|0);L()}d=1}gb=e+256|0;return d|0}function Kja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-192|0;gb=e;a:{if(!Pb(c,8)){break a}Yb(c,4);while(1){n=lv(c);if(n){break a}o=gb-288|0;gb=o;f=WR(o);g=0;h=gb-384|0;gb=h;WR(h+96|0);k=hc(f,h+96|0,282);j=c;b:{c:{d:{e:{f:{g:{h:{if(Fh(c,11039)){lg(j,4);l=Je(h+72|0,j);v[22640]=0;f=Q(1114,l|0,k|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break e}i:{if(!f){break i}f=w[k+26|0];v[22640]=0;f=Q(228,l|0,f|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break e}if(!f){break i}i=0;j:{k:{l:{if(w[k+26|0]){while(1){v[22640]=0;f=T(341,l|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break l}t[(i+k|0)+27|0]=f;g=f+g|0;i=i+1|0;if(i>>>0<w[k+26|0]){continue}break}i=g&65535}g=0;v[22640]=0;f=Q(228,l|0,i|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break d}if(!f){break i}v[22640]=0;Q(350,l|0,i|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break d}lg(l,XR(k));f=Ui(h- -64|0);IA(h+96|0);v[22640]=0;R(1115,l|0,h+96|0);g=v[22640];v[22640]=0;if((g|0)==1){break k}u[h+118>>1]=0;u[h+120>>1]=0;VR(f,h+96|0,h+123|0);g=w[k+26|0];v[22640]=0;Q(350,l|0,g|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break k}g=k+27|0;VR(f,g,g+w[k+26|0]|0);v[22640]=0;U(320,h+40|0,l|0,i|0);g=v[22640];v[22640]=0;if((g|0)!=1){break j}i=P()|0;O()|0;break c}i=P()|0;O()|0;break c}i=P()|0;O()|0;break c}v[22640]=0;R(774,h+16|0,h+40|0);g=v[22640];v[22640]=0;if((g|0)==1){break h}v[22640]=0;Xv(h+8|0,h+16|0);g=v[22640];v[22640]=0;if((g|0)==1){break g}i=f;m=h+8|0;g=v[m>>2];m=v[m+4>>2];if((g|0)!=(m|0)){while(1){TR(i,zb(w[g|0]));g=g+1|0;if((m|0)!=(g|0)){continue}break}}xc(h+16|0);yb(h+40|0);g=0;if(v[f>>2]!=(w[k+22|0]|w[k+23|0]<<8|(w[k+24|0]<<16|w[k+25|0]<<24))){break i}g=XR(k);v[22640]=0;Q(350,j|0,g|0)|0;f=v[22640];v[22640]=0;g=1;if((f|0)==1){break d}}yb(l)}gb=h+384|0;break b}i=P()|0;O()|0;break f}i=P()|0;O()|0;xc(h+16|0)}yb(h+40|0);break c}i=P()|0;O()|0;break c}i=P()|0;O()|0}yb(l);S(i|0);L()}gb=o+288|0;if(g){continue}break}}t[d|0]=w[d|0]!=0|n;vc(c);m:{n:{o:{p:{q:{r:{if(n){d=og(c);rd(e+168|0,c,xf(c));u[a+34>>1]=x[a+34>>1]&65534|w[b|0]>15;b=x[a+34>>1]&-65|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=d>>>(b&1)>>>(b>>>6&1);v[e+164>>2]=0;v[e+160>>2]=0;v[22640]=0;R(774,e+136|0,e+168|0);b=v[22640];v[22640]=0;if((b|0)==1){break r}v[22640]=0;b=Rd(e+136|0);c=v[22640];v[22640]=0;if((c|0)!=1){c=v[e+136>>2];d=zb(b);g=Si(c);v[22640]=0;g=ga(773,d|0,g|0,e+164|0,e+160|0,0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break o}v[22640]=0;Q(350,e+168|0,v[e+164>>2])|0;d=v[22640];v[22640]=0;if((d|0)==1){break o}if(!g){break p}f=v[e+164>>2];v[22640]=0;T(424,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break o}d=c-f|0;b=b+f|0;n=v[e+160>>2];c=0;while(1){s:{if(n){if(!d|(n|0)!=1){break q}if(y[a>>2]>c>>>0){break s}break q}if(y[a>>2]<=c>>>0){break q}}if(!Ld(a)){break q}v[e+132>>2]=0;v[e+128>>2]=0;f=zb(b);j=Si(d);v[22640]=0;f=la(775,g|0,f|0,j|0,e+132|0,e+124|0,e+128|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break o}v[22640]=0;v[e+164>>2]=f;Q(350,e+168|0,f|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break o}i=v[e+164>>2];Zj(e+128|0,Si(v[a>>2]-c|0));t:{if(v[e+128>>2]<1){break t}if(v[e+132>>2]!=(bd(a)|0)){break t}if(t[a+34|0]&1){f=ig(e+112|0,v[a+20>>2]+(B(bd(a),c)<<1)|0,bd(a),v[e+128>>2]);j=ig(e+96|0,v[e+124>>2],v[e+132>>2],v[e+128>>2]);v[22640]=0;v[e+56>>2]=v[f+8>>2];h=v[f+4>>2];v[e+48>>2]=v[f>>2];v[e+52>>2]=h;v[e+40>>2]=v[j+8>>2];f=v[j+4>>2];v[e+32>>2]=v[j>>2];v[e+36>>2]=f;R(776,e+48|0,e+32|0);f=v[22640];v[22640]=0;if((f|0)!=1){break t}break o}f=ig(e+80|0,v[a+20>>2]+B(bd(a),c)|0,bd(a),v[e+128>>2]);j=ig(e- -64|0,v[e+124>>2],v[e+132>>2],v[e+128>>2]);v[22640]=0;v[e+24>>2]=v[f+8>>2];h=v[f+4>>2];v[e+16>>2]=v[f>>2];v[e+20>>2]=h;v[e+8>>2]=v[j+8>>2];f=v[j+4>>2];v[e>>2]=v[j>>2];v[e+4>>2]=f;R(777,e+16|0,e|0);f=v[22640];v[22640]=0;if((f|0)==1){break o}}v[22640]=0;f=v[e+128>>2];n=ey(g);j=v[22640];v[22640]=0;if((j|0)==1){break o}d=d-i|0;b=b+i|0;v[e+160>>2]=n;c=c+f|0;continue}}break o}zg(b,a,c);a=1;break m}a=P()|0;O()|0;break n}v[22640]=0;fy(g);a=v[22640];v[22640]=0;if((a|0)!=1){break p}break o}a=(g|0)!=0;xc(e+136|0);yb(e+168|0);break m}a=P()|0;O()|0;xc(e+136|0)}yb(e+168|0);S(a|0);L()}gb=e+192|0;return a|0}function OP(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;i=gb-16|0;gb=i;a:{if(!ve(d&255)){break a}j=(B(b,872)+a|0)+1074992|0;b:{if(!(e?1:!(v[a+480180>>2]&17825824)|!x[a+480192>>1])){break b}if(rk(j)){break b}c=B(b,872)+a|0;d=c+1075068|0;if(!v[d>>2]){break a}c=v[c+1075080>>2];if(c&1024){break a}e=B(b,872)+a|0;f=e+1075012|0;e=e+1075016|0;if(!(v[f>>2]|v[e>>2])){break a}c:{if(!(c&512)){break c}c=a+1298260|0;if(!Bd(c)){break c}Mi(v[c>>2],b,0);break a}c=gA(a,b);if((c|0)==65535){break a}l=B(c,872);c=a+1074992|0;a=l+c|0;hu(a,j);t[a+831|0]=0;t[a+805|0]=0;u[a+786>>1]=b+1;v[a+88>>2]=v[a+88>>2]&-918529;Yo(a+788|0);v[a+696>>2]=0;v[a+88>>2]=v[a+88>>2]|2101248;v[d>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=c+B(b,872)|0;v[a+92>>2]=0;v[a+96>>2]=0;v[f>>2]=0;v[e>>2]=0;break a}e=B(b,872)+a|0;m=v[e+1075096>>2];c=x[a+480192>>1]<c>>>0?0:c;g=v[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!g){break d}h=d-1|0;c=x[sd(g+236|0,h)>>1];f=a+1074312|0;Db(i+8|0,f,104);e:{if(Cb(i+8|0)){Db(i,f,34);if(Cb(i)){break e}}d=w[lc(g+108|0,h)|0]}if((c-1&65535)>>>0<=3998){m=(B(c,104)+a|0)+484380|0;break d}Db(i+8|0,f,43);if(!Cb(i+8|0)){break d}if(!Fj(g)){break a}}if(w[e+1075081|0]&4){break a}f=a+1298260|0;n=a+1074312|0;if(b>>>0<256){q=b+1|0;c=b;while(1){f:{if((b|0)!=(c|0)?x[a+480188>>1]>c>>>0:0){break f}e=B(c,872)+a|0;if((b|0)!=(c|0)?x[e+1075778>>1]!=(q|0):0){break f}p=e+1075648|0;h=v[p>>2];if(!h){break f}k=e+1074992|0;g:{h:{i:{j:{k:{l:{m:{switch(w[h+17|0]-1|0){case 0:if(!d){break f}l=w[e+1075789|0]==(d|0)&(g|0)==(h|0);o=l;if(!g){break l}if(l){break i}break f;case 1:if(!m|v[e+1075096>>2]!=(m|0)){break f}if((g|0)==(h|0)){break g}Db(i+8|0,n,104);if(!Cb(i+8|0)){break g}break f;case 3:break k;case 2:break m;default:break f}}if(g){break j}o=(g|0)==(h|0)}if(o){break g}break f}if(!g){break f}l=w[g+34|0];if(!l){break f}if((l|0)==w[h+34|0]){break h}break f}if((g|0)!=(h|0)){break f}}if(!w[g+34|0]){break g}}if(!w[e+1075789|0]|w[h+18|0]>2){break g}Db(i+8|0,n,34);Jm(a,c&65535,PS(k,Cb(i+8|0))+255|0,0);t[e+1075792|0]=0}n:{o:{switch(w[v[p>>2]+18|0]){case 0:Bo(a,k);v[e+1075680>>2]=0;if(!(w[e+1075081|0]&2)){break n}if(!Bd(f)){break n}Mi(v[f>>2],c&65535,1);break n;case 1:Bo(a,k);if(!(w[e+1075081|0]&2)){break n}if(!Bd(f)){break n}uk(v[f>>2],c&65535);break n;case 2:break o;default:break n}}k=e+1075080|0;h=v[k>>2];v[k>>2]=h|4096;if(!(h&512)){break n}if(!Bd(f)){break n}Db(i+8|0,n,105);if(Cb(i+8|0)){break n}uk(v[f>>2],c&65535)}if(v[e+1075680>>2]){break f}v[e+1075688>>2]=0;e=e+1075080|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}c=0;e=0;p:{if(!rk(j)){break p}if(!ve(w[(B(b,872)+a|0)+1075789|0])){break p}q:{d=Im(a,b,2,1);if(d-251>>>0<5){break q}if(!d){break p}e=v[(B(d,160)+a|0)+906140>>2];if(!e){break q}Db(i+8|0,n,34);c=(s=e,y=PS(j,Cb(i+8|0)),z=b,r=v[v[e>>2]+100>>2],kb[r](s|0,y|0,z|0)|0);break p}e=0}if(!(r=1,z=Ki(j),y=c,y?r:z)){break a}g=gA(a,b);if((g|0)==65535){break a}h=B(g,872)+a|0;d=h+1075080|0;m=h+1074992|0;r:{if(!(w[h+1075081|0]&2)){break r}if(!Bd(f)){break r}Mi(v[f>>2],g,1)}hu(m,j);v[d>>2]=v[d>>2]&-917505;t[h+1075823|0]=0;k=x[a+480188>>1];t[h+1075797|0]=0;u[h+1075778>>1]=b>>>0<k>>>0?b+1|0:0;s:{if(!((e|0)!=0&c)){break s}c=w[(B(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break s}Jm(a,b,255,0);t[(B(b,872)+a|0)+1075792|0]=0}t:{u:{switch(w[(B(b,872)+a|0)+1075790|0]){case 2:Bo(a,m);if(!(w[d+1|0]&2)){break t}if(!Bd(f)){break t}uk(v[f>>2],b);Db(i+8|0,n,105);if(!Cb(i+8|0)){break t}KA(v[f>>2],b,g);break t;case 0:v[(B(g,872)+a|0)+1075688>>2]=0;c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}if(!Bd(f)){break t}Mi(v[f>>2],b,1);break t;case 3:c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}if(!Bd(f)){break t}Db(i+8|0,n,105);e=Cb(i+8|0);c=v[f>>2];if(e){KA(c,b,g);break t}uk(c,b);break t;case 1:break u;default:break t}}if(!(w[d+1|0]&2)){break t}if(!Bd(f)){break t}KA(v[f>>2],b,g)}if(!v[(B(g,872)+a|0)+1075680>>2]){v[(B(g,872)+a|0)+1075688>>2]=0;v[d>>2]=v[d>>2]|2101248}a=B(b,872)+a|0;v[a+1075068>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=a+1075084|0;v[a>>2]=0;v[a+4>>2]=0}gb=i+16|0}function cfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-112|0;gb=e;h=a+140|0;Sm(e+88|0,h,1296125513);v[22640]=0;f=T(307,e+88|0)|0;g=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((g|0)!=1){if(f){f=Kb(e+32|0);v[22640]=0;g=T(232,e+88|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break o}v[22640]=0;U(1444,e+88|0,f|0,g|0);g=v[22640];v[22640]=0;if((g|0)==1){break o}g=x[a+174>>1];v[22640]=0;Y(1445,e+72|0,g|0,8,f|0);g=v[22640];v[22640]=0;if((g|0)==1){break n}v[22640]=0;U(9,e+8|0,c|0,e+72|0);c=v[22640];v[22640]=0;if((c|0)==1){break m}v[22640]=0;Q(333,d|0,e+8|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break l}vb(e+8|0);vb(e+72|0);vb(f)}if(w[a+176|0]){v[22640]=0;R(1446,e+32|0,d|0);c=v[22640];v[22640]=0;if((c|0)==1){break i}v[22640]=0;Q(335,b+43|0,e+32|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break h}vb(e+32|0)}v[22640]=0;U(1436,e+32|0,h|0,1413894985);c=v[22640];v[22640]=0;if((c|0)==1){break g}v[22640]=0;h=T(1447,e+32|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}yb(e+32|0);c=a+40|0;vc(c);v[22640]=0;f=Q(1448,c|0,e+32|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}if(!f){break d}f=e+60|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<2){break e}v[22640]=0;f=Q(1449,c|0,e+8|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break b}if(!f){break e}f=v[b>>2];v[22640]=0;kz(e+8|0,b+12|0,b+16|0,f,b+34|0,8,16,h);f=v[22640];v[22640]=0;if((f|0)!=1){break e}break b}c=P()|0;O()|0;break a}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break k}c=P()|0;O()|0;vb(e+8|0)}vb(e+72|0)}vb(f);break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(e+32|0);break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;yb(e+32|0);break a}v[22640]=0;c=Q(1449,c|0,e+8|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}if(c){c=v[b>>2];v[22640]=0;kz(e+8|0,b+4|0,b+8|0,c,b+34|0,2,4,h);c=v[22640];v[22640]=0;if((c|0)==1){break b}}c=e+44|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b+42|0]=c&128?0:c+1|0;v[22640]=0;wk(b);c=v[22640];v[22640]=0;if((c|0)==1){break b}}p:{q:{r:{s:{t:{if(w[b+42|0]){break t}v[22640]=0;c=a+60|0;f=Q(880,c|0,7)|0;h=v[22640];v[22640]=0;if((h|0)==1){break c}if(!f){break t}vc(c);v[22640]=0;c=Q(1451,c|0,e+8|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break s}if(!c){break t}c=t[e+8|0];t[b+42|0]=(c|0)<0?0:c+1|0}v[22640]=0;g=a+120|0;c=T(307,g|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break c}if(!c){break p}c=0;v[22640]=0;f=T(229,g|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break q}v[e+72>>2]=f;i=b+68|0;tc(e+72|0,9);if(!v[e+72>>2]){f=0;break r}h=e+8|4;while(1){u:{v[22640]=0;R(1452,g|0,e+8|0);f=v[22640];v[22640]=0;if((f|0)==1){break u}f=h;v[((c<<2)+b|0)+68>>2]=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);c=c+1|0;f=v[e+72>>2];if(c>>>0<f>>>0){continue}break r}break}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}v[22640]=0;Zz(i+(f<<2)|0,i+36|0,36904);c=v[22640];v[22640]=0;if((c|0)!=1){break p}}c=P()|0;O()|0;break a}a=a+80|0;vc(a);v[22640]=0;c=Q(1454,a|0,e+8|0)|0;f=v[22640];v[22640]=0;v:{w:{x:{y:{z:{if((f|0)==1){break z}if(!c){break w}if(w[e+8|0]&32){u[b+34>>1]=x[b+34>>1]|32}c=e+8|4;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;v[22640]=0;u[e+6>>1]=256;c=Oc(e+72|0,e+6|0);f=v[22640];v[22640]=0;if((f|0)==1){break v}u[b+28>>1]=x[c>>1];c=e+8|6;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;v[22640]=0;u[e+6>>1]=256;c=Oc(e+72|0,e+6|0);f=v[22640];v[22640]=0;if((f|0)==1){break y}u[b+30>>1]=x[c>>1];c=e+16|0;u[e+72>>1]=w[c|0]|w[c+1|0]<<8;v[22640]=0;u[e+6>>1]=64;c=Oc(e+72|0,e+6|0);f=v[22640];v[22640]=0;if((f|0)==1){break x}u[b+32>>1]=x[c>>1];t[b+38|0]=w[e+20|0];t[b+39|0]=w[e+21|0];t[b+40|0]=w[e+22|0];t[b+41|0]=w[e+23|0];v[22640]=0;c=Q(228,a|0,32)|0;f=v[22640];v[22640]=0;if((f|0)==1){break z}if(!c){break w}v[22640]=0;W(1455,a|0,d|0,32)|0;c=v[22640];v[22640]=0;if((c|0)==1){break z}v[22640]=0;c=T(492,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break z}v[22640]=0;W(355,a|0,b+43|0,c|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break w}}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}yb(e+88|0);gb=e+112|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0}yb(e+88|0);S(c|0);L()}function XO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;a:{b:{if(!ve(c)|(!d|v[b+480180>>2]!=16777216)|x[b+480192>>1]<d>>>0){break b}d=v[((d<<2)+b|0)+900380>>2];if(!d){break b}e=v[d+44>>2];if(!e){break b}u[i+14>>1]=c-61;d=gb-80|0;gb=d;c=u[e+28>>1];g=i+14|0;b=u[g>>1];f=e+4|0;Nb(f);c:{d:{if((b|0)>=(c|0)){if((b|0)<=(x[e+28>>1]+Nb(f)<<16)-65536>>16){break d}}Kb(a);break c}e:{b=x[e+30>>1];if(!b){b=e+52|0;k=d,l=Yy(b,g),v[k+56>>2]=l;k=d,l=zh(b),v[k+40>>2]=l;if(!kg(d+56|0,d+40|0)){break e}cg(a,ue(d+56|0)+4|0);break c}c=qo(u[g>>1],b<<16>>16);u[d+78>>1]=c;b=Kb(a);a=e+52|0;k=d,l=Yy(a,d+78|0),v[k+72>>2]=l;k=d,l=zh(a),v[k+56>>2]=l;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if(kg(d+72|0,d+56|0)){a=ue(d+72|0);v[22640]=0;Q(193,b|0,a+4|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break v}a=u[e+30>>1];c=u[g>>1];v[22640]=0;k=d,l=Xy(c,a)+5|0,v[k+40>>2]=l;R(190,d+56|0,d+40|0);a=v[22640];v[22640]=0;if((a|0)==1){break g}v[22640]=0;Q(155,b|0,d+56|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){vb(d+56|0);break c}a=P()|0;O()|0;vb(d+56|0);break f}if(u[e+30>>1]>26){break s}v[22640]=0;c=W(733,d+40|0,1,(c<<24)+1090519040>>24)|0;a=v[22640];v[22640]=0;if((a|0)==1){break u}v[22640]=0;U(13,d+56|0,0,c|0);a=v[22640];v[22640]=0;if((a|0)==1){break t}Eb(b,d+56|0);vb(d+56|0);vb(c);v[22640]=0;Q(191,b|0,11887)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break r}}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c);break f}v[22640]=0;a=(c<<16>>16)/16|0;v[d+36>>2]=c-(a<<4)<<16>>16;R(1507,d+40|0,d+36|0);f=v[22640];v[22640]=0;if((f|0)==1){break q}v[22640]=0;v[d+20>>2]=(a<<16>>16)%16;R(1507,d+24|0,d+20|0);a=v[22640];v[22640]=0;if((a|0)==1){break p}v[22640]=0;U(3,d+56|0,d+40|0,d+24|0);a=v[22640];v[22640]=0;if((a|0)==1){break o}Eb(b,d+56|0);vb(d+56|0);vb(d+24|0);vb(d+40|0);if(c<<16>>16<256){break r}v[22640]=0;U(9,d+8|0,0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break m}v[22640]=0;bz(d+40|0,d+8|0);a=v[22640];v[22640]=0;if((a|0)==1){break l}v[22640]=0;U(13,d+56|0,0,d+40|0);a=v[22640];v[22640]=0;if((a|0)==1){break k}Eb(b,d+56|0);vb(d+56|0);vb(d+40|0);vb(d+8|0)}a=u[e+30>>1];c=u[g>>1];v[22640]=0;k=d,l=Xy(c,a)+5|0,v[k+40>>2]=l;R(190,d+56|0,d+40|0);a=v[22640];v[22640]=0;if((a|0)==1){break i}v[22640]=0;Q(155,b|0,d+56|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break h}vb(d+56|0);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;break n}a=P()|0;O()|0;vb(d+24|0)}vb(d+40|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(d+40|0)}vb(d+8|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+56|0);break f}a=P()|0;O()|0}vb(b);S(a|0);L()}b=a;a=gb-16|0;gb=a;c=a;f=gb-32|0;gb=f;e=Ge(f+16|0,1,0);yL(f+8|0,Jb(e),Jb(e)+Ab(e)|0,u[g>>1]);w:{x:{if(v[f+12>>2]){while(1){h=Ab(e);v[22640]=0;v[f+4>>2]=h;h=wf(f+4|0);j=v[22640];v[22640]=0;if((j|0)==1){break x}v[22640]=0;U(117,e|0,h|0,0);h=v[22640];v[22640]=0;if((h|0)==1){break x}yL(f+8|0,Jb(e),Jb(e)+Ab(e)|0,u[g>>1]);if(v[f+12>>2]){continue}break}}g=v[f+8>>2];h=Jb(e);v[22640]=0;R(118,e|0,g-h|0);g=v[22640];v[22640]=0;if((g|0)==1){break x}v[22640]=0;R(128,c|0,e|0);c=v[22640];v[22640]=0;if((c|0)!=1){break w}}a=P()|0;O()|0;vb(e);S(a|0);L()}vb(e);gb=f+32|0;v[22640]=0;R(127,b|0,a|0);b=v[22640];v[22640]=0;y:{if((b|0)!=1){vb(a);gb=a+16|0;break y}b=P()|0;O()|0;vb(a);S(b|0);L()}}gb=d+80|0;break a}e=v[b>>2];b=gb-32|0;gb=b;d=gb-16|0;gb=d;t[d+15|0]=c;t[d+14|0]=251;t[d+13|0]=255;f=Av(d+15|0,d+14|0,d+13|0);gb=d+16|0;z:{if(f){v[b+16>>2]=v[9680];d=v[9679];v[b+8>>2]=v[9678];v[b+12>>2]=d;d=v[9677];v[b>>2]=v[9676];v[b+4>>2]=d;Tb(a,(b+(c<<2)|0)-1004|0);break z}if(ve(c)){d=Kb(b);v[22640]=0;f=c-1|0;c=(f<<16>>16)/12|0;e=Q(1329,d|0,e+(f-B(c,12)<<16>>16<<2)|0)|0;f=v[22640];v[22640]=0;A:{if((f|0)==1){break A}v[22640]=0;c=Q(1330,e|0,c+48&65535)|0;e=v[22640];v[22640]=0;if((e|0)==1){break A}v[22640]=0;Q(4,a|0,c|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break A}vb(d);break z}a=P()|0;O()|0;vb(d);S(a|0);L()}if(!c){Tb(a,13874);break z}Tb(a,11858)}gb=b+32|0}gb=i+16|0}function fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-144|0;gb=e;d=-1;a:{b:{c:{d:{if(!_l(v[v[b>>2]-12>>2]+b|0)){b=wm(e+40|0,b);v[22640]=0;d=Q(640,e+24|0,11317)|0;f=v[22640];v[22640]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((f|0)!=1){v[22640]=0;v[e+16>>2]=83886084;v[e+20>>2]=0;U(641,b|0,d|0,e+16|0);f=v[22640];v[22640]=0;if((f|0)==1){break E}Hb(d);t[e+15|0]=0;v[22640]=0;d=Q(640,e+24|0,11986)|0;f=v[22640];v[22640]=0;if((f|0)==1){break D}v[22640]=0;W(642,b|0,e+15|0,d|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break C}Hb(d);v[22640]=0;f=w[e+15|0];d=Q(640,e+24|0,12943)|0;g=v[22640];v[22640]=0;if((g|0)==1){break B}v[22640]=0;f=f?0:c;Y(1510,b|0,a+40|0,d|0,f|0);c=v[22640];v[22640]=0;if((c|0)==1){break A}Hb(d);u[e+12>>1]=65535;v[22640]=0;c=Q(640,e+24|0,12624)|0;d=v[22640];v[22640]=0;if((d|0)==1){break z}v[22640]=0;W(1103,b|0,e+12|0,c|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break y}Hb(c);u[e+10>>1]=0;v[22640]=0;c=Q(640,e+24|0,12523)|0;d=v[22640];v[22640]=0;if((d|0)==1){break x}v[22640]=0;W(1103,b|0,e+10|0,c|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break w}Hb(c);u[a>>1]=x[e+10>>1];v[22640]=0;c=Q(640,e+24|0,12260)|0;d=v[22640];v[22640]=0;if((d|0)==1){break v}v[22640]=0;Y(1511,b|0,a+52|0,c|0,f|0);d=v[22640];v[22640]=0;if((d|0)==1){break u}Hb(c);v[22640]=0;c=Q(640,e+24|0,12195)|0;d=v[22640];v[22640]=0;if((d|0)==1){break t}v[22640]=0;W(1483,b|0,a+36|0,c|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break s}Hb(c);v[22640]=0;c=Q(640,e+24|0,12626)|0;d=v[22640];v[22640]=0;if((d|0)==1){break r}v[22640]=0;f=a+4|0;U(1512,b|0,f|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break q}Hb(c);v[22640]=0;c=Q(640,e+24|0,12525)|0;d=v[22640];v[22640]=0;if((d|0)==1){break p}v[22640]=0;g=a+28|0;U(1513,b|0,g|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break o}Hb(c);v[22640]=0;c=Q(640,e+24|0,12361)|0;d=v[22640];v[22640]=0;if((d|0)==1){break n}v[22640]=0;U(1513,b|0,a+30|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break m}Hb(c);v[22640]=0;c=Q(640,e+24|0,12219)|0;d=v[22640];v[22640]=0;if((d|0)==1){break l}v[22640]=0;U(1514,b|0,a+32|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break k}Hb(c);u[e+8>>1]=0;v[22640]=0;c=Q(640,e+24|0,12174)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}v[22640]=0;W(1103,b|0,e+8|0,c|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break j}Hb(c);d=-1;if(v[b>>2]&1073741824){break e}c=u[g>>1];if((c|0)<-300|(c|0)>=301){break e}c=x[a>>1];if(c>>>0>3|(c|0)==2|u[a+30>>1]<0){break e}i=e,j=Si(v[a+36>>2]),v[i+24>>2]=j;v[22640]=0;v[e+16>>2]=0;c=Tm(e+24|0,e+16|0,50008);h=v[22640];v[22640]=0;if((h|0)==1){break c}v[a+36>>2]=v[c>>2];if(Nb(f)>>>0>32767){break e}switch(x[a>>1]-1|0){case 2:break i;case 0:break h;default:break g}}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(c);break a}a=P()|0;O()|0;Hb(c);break a}c=u[e+8>>1];if((c|0)<1){break e}u[e+6>>1]=x[a+30>>1];z[e+24>>2]=z[a+32>>2];f=x[a+28>>1];u[e+16>>1]=f;v[22640]=0;u[e+18>>1]=(c+f|0)-1;a=ca(1515,a|0,e+6|0,e+24|0,e+16|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){if(a){break f}break e}a=P()|0;O()|0;break a}c=u[e+8>>1];if((c|0)<1){break e}z[e+24>>2]=z[a+32>>2];h=x[a+28>>1];u[e+16>>1]=h;v[22640]=0;u[e+18>>1]=(c+h|0)-1;a=ga(1516,a|0,f|0,e+24|0,e+16|0,g|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){if(a){break f}break e}a=P()|0;O()|0;break a}v[22640]=0;_(1517,a|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}}d=1}ch(b)}gb=e+144|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}ch(b);S(a|0);L()}function NL(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0;m=gb-48|0;gb=m;v[m+44>>2]=0;if(i?1:d|g|h){k=g?m+44|0:0;a:{if(!k){break a}j=v[k>>2];if(!j){break a}Zb(j);v[k>>2]=0}v[22640]=0;X(2027);j=v[22640];v[22640]=0;b:{c:{if((j|0)==1){l=Sa(88880,55040,55096,55256,89056,89160,89108,89e3,88988,89304,89272,89240,89228,88856,0)|0;d:{e:{n=O()|0;if((n|0)==(ea(88880)|0)){j=Z(l|0)|0;v[22640]=0;R(2028,k|0,j|0);k=v[22640];v[22640]=0;j=277;if((k|0)==1){break e}break b}if((ea(55040)|0)==(n|0)){j=Z(l|0)|0;v[22640]=0;R(2028,k|0,j|0);k=v[22640];v[22640]=0;j=358;if((k|0)!=1){break b}j=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break d}if((ea(55096)|0)==(n|0)){j=Z(l|0)|0;v[22640]=0;R(2028,k|0,j|0);k=v[22640];v[22640]=0;j=359;if((k|0)!=1){break b}j=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break d}if((ea(55256)|0)==(n|0)){j=Z(l|0)|0;v[22640]=0;R(2028,k|0,j|0);k=v[22640];v[22640]=0;j=357;if((k|0)!=1){break b}j=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break d}if((ea(89056)|0)==(n|0)){j=Z(l|0)|0;v[22640]=0;R(2028,k|0,j|0);k=v[22640];v[22640]=0;j=300;if((k|0)!=1){break b}j=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break d}if((ea(89160)|0)==(n|0)){j=Z(l|0)|0;v[22640]=0;R(2028,k|0,j|0);k=v[22640];v[22640]=0;j=299;if((k|0)!=1){break b}j=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break d}if((ea(89108)|0)==(n|0)){j=Z(l|0)|0;v[22640]=0;R(2028,k|0,j|0);k=v[22640];v[22640]=0;j=298;if((k|0)!=1){break b}j=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break d}if((ea(89e3)|0)==(n|0)){j=Z(l|0)|0;v[22640]=0;R(2028,k|0,j|0);k=v[22640];v[22640]=0;j=297;if((k|0)!=1){break b}j=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break d}if((ea(88988)|0)==(n|0)){j=Z(l|0)|0;v[22640]=0;R(2028,k|0,j|0);k=v[22640];v[22640]=0;j=296;if((k|0)!=1){break b}j=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break d}if((ea(89304)|0)==(n|0)){j=Z(l|0)|0;v[22640]=0;R(2028,k|0,j|0);k=v[22640];v[22640]=0;j=289;if((k|0)!=1){break b}j=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break d}if((ea(89272)|0)==(n|0)){j=Z(l|0)|0;v[22640]=0;R(2028,k|0,j|0);k=v[22640];v[22640]=0;j=288;if((k|0)!=1){break b}j=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break d}if((ea(89240)|0)==(n|0)){j=Z(l|0)|0;v[22640]=0;R(2028,k|0,j|0);k=v[22640];v[22640]=0;j=287;if((k|0)!=1){break b}j=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break d}if((ea(89228)|0)==(n|0)){j=Z(l|0)|0;v[22640]=0;R(2028,k|0,j|0);k=v[22640];v[22640]=0;j=286;if((k|0)!=1){break b}j=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break d}o=ea(88856)|0;j=257;l=Z(l|0)|0;if((n|0)!=(o|0)){break b}v[22640]=0;R(2028,k|0,l|0);k=v[22640];v[22640]=0;j=267;if((k|0)!=1){break b}j=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)==1){break d}break c}j=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break c}}V(0)|0;O()|0;Bb()}L()}S(j|0);L()}$()}l=!g;if(d){k=kb[d|0](j,e)|0}else{k=3}if(!(l|!(k&2))){v[g+16>>2]=j;l=v[m+44>>2];f:{if(l){l=ie(l);break f}l=ie(18693)}v[g+20>>2]=l}if(h){v[h>>2]=j}if(i){g=v[m+44>>2];g:{if(g){g=ie(g);break g}g=ie(18693)}v[i>>2]=g}g=v[m+44>>2];if(g){Zb(g);v[m+44>>2]=0}h:{if(!(k&1)){break h}v[22640]=0;R(1912,m+32|0,a|0);g=v[22640];v[22640]=0;i:{j:{if((g|0)!=1){k:{if(f){v[22640]=0;R(1913,f|0,m+32|0);g=v[22640];v[22640]=0;if((g|0)!=1){break k}break j}g=Jb(m+32|0);if(b){v[22640]=0;R(b|0,g|0,c|0);g=v[22640];v[22640]=0;if((g|0)==1){break j}break k}It(g,m)}vb(m+32|0);break h}g=V(0)|0;O()|0;break i}g=V(0)|0;O()|0;vb(m+32|0)}Z(g|0)|0;v[m+28>>2]=f;v[m+24>>2]=e;v[m+20>>2]=d;v[m+16>>2]=c;v[m+12>>2]=b;v[m+8>>2]=a?a:18693;v[m+4>>2]=248;v[m>>2]=6349;_I(14909,m);ht(89864);$()}gb=m+48|0}function $da(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0;d=gb-128|0;gb=d;h=-1;a:{b:{c:{d:{if(!Tf(v[v[b>>2]-12>>2]+b|0)){break d}se(d+112|0,b);e=v[d+120>>2];f=v[d+124>>2];ak(d+104|0);ol(b,d+104|0,8);if((w[d+104|0]|w[d+105|0]<<8|(w[d+106|0]<<16|w[d+107|0]<<24))!=1414681667|(w[d+108|0]|w[d+109|0]<<8|(w[d+110|0]<<16|w[d+111|0]<<24))!=776101705){a=Bh(d+88|0,e,f);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;gk(b,d+8|0);break d}u[d+86>>1]=0;Xf(b,d+86|0);if((x[d+86>>1]&65534)!=2){break d}ak(d+78|0);ol(b,d+78|0,8);if((w[d+78|0]|w[d+79|0]<<8|(w[d+80|0]<<16|w[d+81|0]<<24))!=1933333571|(w[d+82|0]|w[d+83|0]<<8|(w[d+84|0]<<16|w[d+85|0]<<24))!=1111389030){break d}u[d+76>>1]=0;Xf(b,d+76|0);e=u[d+76>>1];if((e-3&65535)>>>0>1){break d}e:{f:{g:{h:{i:{j:{k:{if((e|0)<=3){e=Kb(d+112|0);v[22640]=0;f=W(672,b|0,e|0,65535)|0;i=v[22640];v[22640]=0;if((i|0)==1){break b}if(!f){break j}v[22640]=0;U(13,d- -64|0,c|0,e|0);f=v[22640];v[22640]=0;if((f|0)!=1){break k}break b}e=Kb(d+112|0);v[22640]=0;f=W(674,b|0,e|0,255)|0;i=v[22640];v[22640]=0;if((i|0)==1){break c}if(!f){break i}v[22640]=0;U(13,d- -64|0,c|0,e|0);f=v[22640];v[22640]=0;if((f|0)==1){break c}}Eb(a+40|0,d- -64|0);vb(d- -64|0);vb(e);u[d+62>>1]=0;Xf(b,d+62|0);u[d+60>>1]=0;Xf(b,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;l:{if(u[d+76>>1]<=3){v[d+112>>2]=0;Bk(b,d+112|0);e=v[d+112>>2];if(e>>>0>65535){break d}e=Ev(e);u[d+58>>1]=e;break l}Xf(b,d+58|0);e=x[d+58>>1]}m:{n:{o:{p:{if(e&65535){i=a+52|0;f=0;while(1){e=Kb(d+112|0);v[22640]=0;u[d+40>>1]=0;Q(1518,b|0,d+40|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break g}q:{if(u[d+76>>1]<=3){v[22640]=0;g=W(672,b|0,e|0,65535)|0;j=v[22640];v[22640]=0;if((j|0)==1){break g}if(g){break q}break e}v[22640]=0;g=W(674,b|0,e|0,255)|0;j=v[22640];v[22640]=0;if((j|0)==1){break g}if(!g){break e}}v[22640]=0;U(13,d- -64|0,c|0,e|0);g=v[22640];v[22640]=0;if((g|0)==1){break p}v[22640]=0;g=Q(1519,i|0,d+40|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break o}Eb(g,d- -64|0);vb(d- -64|0);vb(e);f=f+1|0;if(x[d+58>>1]>(f&65535)>>>0){continue}break}}ak(d- -64|0);ol(b,d- -64|0,8);if((w[d+64|0]|w[d+65|0]<<8|(w[d+66|0]<<16|w[d+67|0]<<24))!=1933333571|(w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24))!=1161720678){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;if(u[d+86>>1]>2){break n}if(pN(b,c)){break m}break d}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(d- -64|0);break f}if(!oN(b,c)){break d}}e=a+16|0;r:{if(u[d+86>>1]<=2){if(pN(b,e)){break r}break d}if(!oN(b,e)){break d}}l=a,m=Nb(e),v[l+36>>2]=m;u[d+56>>1]=0;Xf(b,d+56|0);e=x[d+56>>1];u[a+28>>1]=e;if((e+200&65535)>>>0>400){break d}u[d+54>>1]=0;Xf(b,d+54|0);e=u[d+54>>1];u[a+30>>1]=e;if((e|0)<0){break d}v[d+48>>2]=0;qq(b,d+48|0);k=z[d+48>>2];z[a+32>>2]=k;if(k<C(0)){break d}ak(d+40|0);ol(b,d+40|0,8);if((w[d+40|0]|w[d+41|0]<<8|(w[d+42|0]<<16|w[d+43|0]<<24))!=1414681667|(w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24))!=776298313){break d}if(Nb(c)>>>0>32767){break d}b=x[a>>1];if(!(b?u[a+30>>1]>0&z[a+32>>2]>C(0):1)){break d}s:{switch(b-1|0){case 0:case 2:if(Nb(c)>>>0<u[a+30>>1]>>>0){break d}break;default:break s}}b=0;e=v[a+36>>2];if(e){b=e-1|0;v[a+36>>2]=b}l=d,m=Si(b),v[l+112>>2]=m;v[d+32>>2]=0;l=a,m=v[Tm(d+112|0,d+32|0,50008)>>2],v[l+36>>2]=m;rq(a);h=1;if(x[a>>1]!=3){break d}if((tN(Nb(c))|0)<(u[a+30>>1]-u[a+28>>1]|0)){break d}e=nc(d+112|0);b=0;if(u[a+30>>1]>0){while(1){h=Mb(c,b-u[a+28>>1]|0);v[22640]=0;R(1520,e|0,h|0);h=v[22640];v[22640]=0;if((h|0)==1){break h}b=b+1|0;if((b|0)<u[a+30>>1]){continue}break}}b=x[a+28>>1];u[d+32>>1]=b;l=d,m=(Nb(c)+b|0)-1|0,u[l+34>>1]=m;v[22640]=0;u[d+30>>1]=0;ga(1516,a|0,e|0,a+32|0,d+32|0,d+30|0)|0;a=v[22640];v[22640]=0;h=1;if((a|0)!=1){Lc(e);break d}break h}vb(e);break d}vb(e);break d}b=P()|0;O()|0;Lc(e);break a}b=P()|0;O()|0}vb(e);break a}vb(e)}gb=d+128|0;return h|0}b=P()|0;O()|0;vb(e);break a}b=P()|0;O()|0;vb(e)}S(b|0);L()}function SI(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;i=gb-560|0;gb=i;g=c;c=(c-3|0)/24|0;r=(c|0)>0?c:0;l=g+B(r,-24)|0;n=v[(e<<2)+71024>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=r-j|0;while(1){A[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+v[(c<<2)+71040>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=l-24|0;h=(n|0)>0?n:0;g=0;while(1){f=0;if((d|0)>0){k=g+j|0;c=0;while(1){f=f+A[(c<<3)+a>>3]*A[(i+320|0)+(k-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;c=(g|0)==(h|0);g=g+1|0;if(!c){continue}break}y=47-l|0;t=48-l|0;z=l-25|0;g=n;while(1){f=A[(g<<3)+i>>3];c=0;h=g;o=(g|0)<1;if(!o){while(1){k=(i+480|0)+(c<<2)|0;m=f;f=f*5.960464477539063e-8;a:{if(D(f)<2147483648){j=~~f;break a}j=-2147483648}f=+(j|0);m=m+f*-16777216;b:{if(D(m)<2147483648){j=~~m;break b}j=-2147483648}v[k>>2]=j;h=h-1|0;f=A[(h<<3)+i>>3]+f;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=$i(f,q);f=f+H(f*.125)*-8;c:{if(D(f)<2147483648){k=~~f;break c}k=-2147483648}f=f-+(k|0);d:{e:{f:{u=(q|0)<1;g:{if(!u){h=(g<<2)+i|0;j=v[h+476>>2];c=j>>t;s=h;h=j-(c<<t)|0;v[s+476>>2]=h;k=c+k|0;j=h>>y;break g}if(q){break f}j=v[((g<<2)+i|0)+476>>2]>>23}if((j|0)<1){break d}break e}j=2;if(f>=.5){break e}j=0;break d}h:{if(o){h=0;break h}c=0;w=1;while(1){h=(i+480|0)+(c<<2)|0;o=v[h>>2];s=h;i:{if(w){h=0;if(!o){break i}h=16777216-o|0}else{h=16777215-o|0}v[s>>2]=h;h=1}c=c+1|0;if((g|0)==(c|0)){break h}w=!h;continue}}j:{if(u){break j}c=8388607;k:{switch(z|0){case 1:c=4194303;break;case 0:break k;default:break j}}o=(g<<2)+i|0;v[o+476>>2]=v[o+476>>2]&c}k=k+1|0;if((j|0)!=2){break d}f=1-f;j=2;if(!h){break d}f=f-$i(1,q)}l:{m:{if(f==0){h=0;c=g;if((n|0)>=(c|0)){break l}while(1){c=c-1|0;h=v[(i+480|0)+(c<<2)>>2]|h;if((c|0)>(n|0)){continue}break}if(!h){break l}l=q;while(1){l=l-24|0;g=g-1|0;if(!v[(i+480|0)+(g<<2)>>2]){continue}break}break m}f=$i(f,24-l|0);n:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;m=f;f=f*5.960464477539063e-8;o:{if(D(f)<2147483648){c=~~f;break o}c=-2147483648}f=m+ +(c|0)*-16777216;p:{if(D(f)<2147483648){a=~~f;break p}a=-2147483648}v[d>>2]=a;g=g+1|0;break n}if(D(f)<2147483648){c=~~f}else{c=-2147483648}l=q}v[(i+480|0)+(g<<2)>>2]=c}f=$i(1,l);if((g|0)>=0){c=g;while(1){A[(c<<3)+i>>3]=f*+v[(i+480|0)+(c<<2)>>2];f=f*5.960464477539063e-8;a=(c|0)>0;c=c-1|0;if(a){continue}break}c=g;while(1){a=c;d=g-c|0;f=0;c=0;while(1){q:{f=f+A[(c<<3)+73808>>3]*A[(a+c<<3)+i>>3];if((c|0)>=(n|0)){break q}h=c>>>0<d>>>0;c=c+1|0;if(h){continue}}break}A[(i+160|0)+(d<<3)>>3]=f;c=a-1|0;if((a|0)>0){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<1){break u}d=(i+160|0)+(g<<3)|0;f=A[d>>3];c=g;while(1){m=f;a=c-1|0;e=(i+160|0)+(a<<3)|0;x=A[e>>3];f=f+x;A[(i+160|0)+(c<<3)>>3]=m+(x-f);A[e>>3]=f;e=(c|0)>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=A[d>>3];c=g;while(1){m=f;a=c-1|0;d=(i+160|0)+(a<<3)|0;p=A[d>>3];f=f+p;A[(i+160|0)+(c<<3)>>3]=m+(p-f);A[d>>3]=f;d=(c|0)>2;c=a;if(d){continue}break}p=0;while(1){p=p+A[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[i+160>>3];if(j){break s}A[b>>3]=f;f=A[i+168>>3];A[b+16>>3]=p;A[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){f=f+A[(i+160|0)+(g<<3)>>3];a=(g|0)>0;g=g-1|0;if(a){continue}break}}A[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){c=g;while(1){f=f+A[(i+160|0)+(c<<3)>>3];a=(c|0)>0;c=c-1|0;if(a){continue}break}}A[b>>3]=j?-f:f;f=A[i+160>>3]-f;c=1;if((g|0)>=1){while(1){f=f+A[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break r}A[b>>3]=-f;f=A[i+168>>3];A[b+16>>3]=-p;A[b+8>>3]=-f}gb=i+560|0;return k&7}c=1;while(1){h=c;c=c+1|0;if(!v[(i+480|0)+(n-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;A[(i+320|0)+(j<<3)>>3]=v[(r+g<<2)+71040>>2];c=0;f=0;if((d|0)>=1){while(1){f=f+A[(c<<3)+a>>3]*A[(i+320|0)+(j-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}}function Voa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-976|0;gb=e;vc(b);f=gb-32|0;gb=f;j=e+872|0;EX(f+24|0,j);h=xb(f+24|0);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;d=b;fc(f+16|0,d,f);i=xb(f+16|0);if((i|0)==(h|0)){Yb(d,xb(f+24|0))}gb=f+32|0;d=(h|0)==(i|0);if(!d){DX(j)}a:{if(!d){break a}if(!HX(e+872|0)){break a}if(!Pb(b,Uc(GX(e+872|0),jb))){break a}b:{if(!c){break b}Gd(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[e+947|0];v[a+480208>>2]=16;v[a+480200>>2]=256;v[a+480204>>2]=8e5;Ob(a+1074312|0,7,1);d=Tb(e+96|0,5437);Eb(a+1298304|0,d);vb(d);d=Tb(e+96|0,6123);Eb(a+1298316|0,d);vb(d);v[a+1298364>>2]=5;PC(e+24|0,2,e+872|4);Bc(e+96|0,e+24|0);Eb(a+1298268|0,e+96|0);vb(e+96|0);while(1){d=(g<<5)+a|0;f=d+480280|0;Se(f);h=f;f=(e+872|0)+g|0;v[h>>2]=!w[f+50|0]<<10;u[d+480284>>1]=(w[f+76|0]<<4|8)&248;g=g+1|0;if((g|0)!=16){continue}break}if(w[e+968|0]|w[e+969|0]<<8){cB(a+1298292|0,b,w[e+968|0]|w[e+969|0]<<8,132,0)}g=0;f=gb-32|0;gb=f;j=e+96|0;bc(f+24|0,j,771);h=xb(f+24|0);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;d=b;fc(f+16|0,d,f);i=xb(f+16|0);if((i|0)==(h|0)){Yb(d,xb(f+24|0))}gb=f+32|0;d=(h|0)==(i|0);if(!d){Qb(j,0,771)}if(!d){break a}d=a+484360|0;FX(Rb(d),e+96|0,w[e+353|0]);af(Rb(d),w[e+354|0]);Xc(b,w[e+919|0]|w[e+920|0]<<8);i=a+484344|0;q=c&1;f=0;c:{d:{while(1){d=(f<<1)+e|0;if(w[d+355|0]|w[d+356|0]<<8){rd(e+24|0,b,w[d+355|0]|w[d+356|0]<<8);d=w[d+355|0]|w[d+356|0]<<8;j=(d-2|0)/64|0;e:{if(!q){break e}v[22640]=0;g=W(365,i|0,f&65535,j|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break d}if(!g){break e}v[22640]=0;m=T(353,e+24|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break d}v[22640]=0;Q(350,e+24|0,1)|0;g=v[22640];v[22640]=0;if((g|0)==1){break d}if(d>>>0>=66){r=j>>>0>1?j:1;l=0;while(1){d=_b(i,f);v[22640]=0;n=Pf(d,l);d=v[22640];v[22640]=0;g=0;if((d|0)==1){break d}f:{while(1){g:{v[22640]=0;R(550,e+80|0,e+24|0);d=v[22640];v[22640]=0;if((d|0)==1){break g}h=md(e+80|0);d=Re(e+80|0);o=aj(e+80|0);k=w[e+80|0];if((k-1&255)>>>0<=71){p=B(g,6)+n|0;t[p|0]=k+36;t[p+1|0]=w[h|0]+1}if((w[d|0]-1&255)>>>0<=15){h=B(g,6)+n|0;t[h+2|0]=1;t[h+4|0]=((w[d|0]<<6)+-64>>>0)/15}d=B(g,6)+n|0;k=w[o|0];h=k&15;t[d+5|0]=h;h:{i:{switch((w[o|0]>>>4|0)-1|0){case 0:case 1:t[d+5|0]=k|240;break h;case 2:t[d+5|0]=h<<2;break h;case 3:t[d+5|0]=(6/(h+1>>>0)|0)+1;break h;case 5:case 6:t[d+5|0]=h<<3;break h;case 9:t[d+4|0]=(h<<2)+4;t[d+2|0]=1;break h;case 10:t[d+5|0]=h|128;break h;case 11:break i;default:break h}}t[d+5|0]=(6/(h+1>>>0)|0)+1|13}t[d+3|0]=w[(w[o|0]>>>4|0)+28976|0];g=g+1|0;if((g|0)!=16){continue}break f}break}break d}l=l+1|0;if((r|0)!=(l|0)){continue}break}}d=_b(i,f);v[22640]=0;g=Be(e+80|0,14,0);h=v[22640];v[22640]=0;if((h|0)==1){break d}g=Eh(Qe(g,m?j-2>>>0>m>>>0?m+1|0:-1:-1));v[22640]=0;Q(458,d|0,g|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}}yb(e+24|0)}f=f+1|0;if((f|0)!=256){continue}break}g=1;if(!(c&2)){break a}QY(b,e+72|0);g=0;while(1){j:{k:{if(!(w[e+72+(g>>>3)|0]>>>(g&7)&1)){g=g+1|0;break k}if(!OC(b,e+24|0)){break b}g=g+1|0;u[a+480190>>1]=g;_e(e+8|0,1,e+24|0);Bc(e+80|0,e+8|0);c=x[a+480190>>1];v[22640]=0;Q(333,((c<<5)+a|0)+946304|0,e+80|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break j}vb(e+80|0);f=(B(g,104)+a|0)+484380|0;d=f;td(d,0);c=e+24|0;v[d>>2]=w[c+32|0]|w[c+33|0]<<8|(w[c+34|0]<<16|w[c+35|0]<<24);v[d+4>>2]=w[c+38|0]|w[c+39|0]<<8|(w[c+40|0]<<16|w[c+41|0]<<24);h=w[c+42|0]|w[c+43|0]<<8|(w[c+44|0]<<16|w[c+45|0]<<24);v[d+24>>2]=16726;v[d+8>>2]=h;u[d+30>>1]=w[c+37|0]<<4;if(t[c+46|0]&1){v[d>>2]=v[d>>2]>>>1;v[d+4>>2]=v[d+4>>2]>>>1;v[d+8>>2]=v[d+8>>2]>>>1}if(!(!(w[c+47|0]&8)|y[d+8>>2]<=y[d+4>>2])){u[d+34>>1]=x[d+34>>1]|2}Pc(e+80|0,t[e+70|0]&1?16:8,1,0,0);zg(e+80|0,f,b)}if((g|0)!=64){continue}break b}break}g=P()|0;O()|0;vb(e+80|0);break c}g=P()|0;O()|0;yb(e+24|0)}S(g|0);L()}g=1}gb=e+976|0;return g|0}function T2(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=gb+-64|0;gb=h;v[h+56>>2]=b;v[e>>2]=0;Ec(h,d);v[22640]=0;i=T(2458,h|0)|0;j=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Vb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Vb(h);S(a|0);L()}gH(a,f+24|0,h+56|0,c,e,i);break b}fH(a,f+16|0,h+56|0,c,e,i);break b}g=a;a=kb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=ek(g,b,c,d,e,f,Jb(a),Jb(a)+(Ab(a)<<2)|0),v[k+56>>2]=l;break b}a=e;b=lj(h+56|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<1|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}g=v[20819];v[h+24>>2]=v[20818];v[h+28>>2]=g;g=v[20817];v[h+16>>2]=v[20816];v[h+20>>2]=g;g=v[20815];v[h+8>>2]=v[20814];v[h+12>>2]=g;g=v[20813];v[h>>2]=v[20812];v[h+4>>2]=g;k=h,l=ek(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}g=v[20827];v[h+24>>2]=v[20826];v[h+28>>2]=g;g=v[20825];v[h+16>>2]=v[20824];v[h+20>>2]=g;g=v[20823];v[h+8>>2]=v[20822];v[h+12>>2]=g;g=v[20821];v[h>>2]=v[20820];v[h+4>>2]=g;k=h,l=ek(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=lj(h+56|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=lj(h+56|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<1|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=lj(h+56|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=lj(h+56|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=lj(h+56|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=h+56|0;H:{if(!sm(b,a+8|0)){break H}while(1){if(!ml(i,8192,rm(b))){break H}qm(b);if(sm(b,a+8|0)){continue}break}}if(ll(b,a+8|0)){v[e>>2]=v[e>>2]|2}gb=a+16|0;break b}b=h+56|0;a=kb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Ab(a)|0)==(0-Ab(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=Js(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=hc(h,83312,44);k=g,l=ek(a,b,c,d,e,f,g,g+44|0),v[k+56>>2]=l;break b}v[h+16>>2]=v[20844];g=v[20843];v[h+8>>2]=v[20842];v[h+12>>2]=g;g=v[20841];v[h>>2]=v[20840];v[h+4>>2]=g;k=h,l=ek(a,b,c,d,e,f,h,h+20|0),v[k+56>>2]=l;break b}a=e;b=lj(h+56|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}g=v[20855];v[h+24>>2]=v[20854];v[h+28>>2]=g;g=v[20853];v[h+16>>2]=v[20852];v[h+20>>2]=g;g=v[20851];v[h+8>>2]=v[20850];v[h+12>>2]=g;g=v[20849];v[h>>2]=v[20848];v[h+4>>2]=g;k=h,l=ek(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=lj(h+56|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=kb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=ek(g,b,c,d,e,f,Jb(a),Jb(a)+(Ab(a)<<2)|0),v[k+56>>2]=l;break b}eH(f+20|0,h+56|0,c,e,i);break b}a=lj(h+56|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(ll(c,a+8|0)){break M}b=4;if((Qn(i,rm(c))|0)!=37){break M}b=2;if(!ll(qm(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}gb=a+16|0}a=v[h+56>>2]}gb=h- -64|0;return a|0}function L8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-128|0;gb=e;a:{if(dd(b)){break a}f=w[oL(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}vs(e+112|0,b,0,Ab(b)-1|0);Eb(b,e+112|0);vb(e+112|0)}Kd(e+112|0);f=v[e+112>>2];Kd(e+96|0);f=nL(f,v[e+100>>2],b);Kd(e+112|0);b:{c:{d:{e:{if((f|0)==v[e+116>>2]){if(ne(b,18693)){a=aa(8)|0;v[22640]=0;U(2053,e+112|0,14695,c|0);b=v[22640];v[22640]=0;if((b|0)==1){break d}qc(a,e+112|0);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+112|0);break c}if(!d){break e}a=aa(8)|0;v[22640]=0;U(2053,e+80|0,14731,b|0);b=v[22640];v[22640]=0;f:{g:{h:{i:{j:{if((b|0)!=1){v[22640]=0;R(2054,e+96|0,e+80|0);b=v[22640];v[22640]=0;if((b|0)==1){break j}v[22640]=0;U(735,e+112|0,e+96|0,c|0);b=v[22640];v[22640]=0;d=1;if((b|0)==1){break i}qc(a,e+112|0);v[22640]=0;U(223,a|0,55256,1936);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+112|0);d=0;break h}b=P()|0;O()|0;break f}b=P()|0;d=1;O()|0;break g}b=P()|0;O()|0}vb(e+96|0)}vb(e+80|0);if(!d){break c}}da(a|0);break c}k:{switch(v[f+4>>2]){case 0:ug(e+72|0,b);b=gb-192|0;gb=b;Vf(b+16|0,c);v[22640]=0;R(141,b+32|0,b+16|0);c=v[22640];v[22640]=0;l:{m:{n:{o:{p:{if((c|0)!=1){v[22640]=0;c=W(142,b+48|0,b+32|0,8)|0;f=v[22640];v[22640]=0;if((f|0)==1){break p}vb(b+32|0);vb(b+16|0);f=v[v[c>>2]-12>>2];v[22640]=0;g=fa(121)|0;h=v[22640];v[22640]=0;if((h|0)==1){break n}v[22640]=0;U(122,b+8|0,f+(b+48|0)|0,g|0);f=v[22640];v[22640]=0;if((f|0)==1){break n}Vb(b+8|0);v[22640]=0;f=Q(2055,c|0,b+32|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break n}g=v[v[f>>2]-12>>2];v[22640]=0;f=_l(f+g|0);g=v[22640];v[22640]=0;if((g|0)==1){break n}g=w[b+32|0];tf(c);gb=b+192|0;b=(f^-1)&(g|0)!=0;break l}a=P()|0;O()|0;break o}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break m}a=P()|0;O()|0;tf(c)}S(a|0);L()}c=v[e+76>>2];v[e>>2]=v[e+72>>2];v[e+4>>2]=c;mL(a,e,b,d);break e;case 1:ug(e- -64|0,b);b=gb-192|0;gb=b;Vf(b+16|0,c);v[22640]=0;R(141,b+32|0,b+16|0);c=v[22640];v[22640]=0;q:{r:{s:{t:{u:{if((c|0)!=1){v[22640]=0;c=W(142,b+48|0,b+32|0,8)|0;f=v[22640];v[22640]=0;if((f|0)==1){break u}vb(b+32|0);vb(b+16|0);f=v[v[c>>2]-12>>2];v[22640]=0;g=fa(121)|0;h=v[22640];v[22640]=0;if((h|0)==1){break s}v[22640]=0;U(122,b+8|0,f+(b+48|0)|0,g|0);f=v[22640];v[22640]=0;if((f|0)==1){break s}Vb(b+8|0);v[22640]=0;f=Q(152,c|0,b+32|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break s}g=v[v[f>>2]-12>>2];v[22640]=0;f=_l(f+g|0);g=v[22640];v[22640]=0;if((g|0)==1){break s}g=v[b+32>>2];h=v[b+36>>2];tf(c);gb=b+192|0;b=f?0:g;c=f?0:h;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break r}a=P()|0;O()|0;tf(c)}S(a|0);L()}f=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=f;lL(a,e+8|0,b,c,d);break e;case 2:ug(e+56|0,b);b=gb-192|0;gb=b;Vf(b+16|0,c);v[22640]=0;R(141,b+32|0,b+16|0);c=v[22640];v[22640]=0;v:{w:{x:{y:{z:{if((c|0)!=1){v[22640]=0;c=W(142,b+48|0,b+32|0,8)|0;f=v[22640];v[22640]=0;if((f|0)==1){break z}vb(b+32|0);vb(b+16|0);f=v[v[c>>2]-12>>2];v[22640]=0;g=fa(121)|0;h=v[22640];v[22640]=0;if((h|0)==1){break x}v[22640]=0;U(122,b+8|0,f+(b+48|0)|0,g|0);f=v[22640];v[22640]=0;if((f|0)==1){break x}Vb(b+8|0);v[22640]=0;f=Q(153,c|0,b+32|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break x}g=v[v[f>>2]-12>>2];v[22640]=0;f=_l(f+g|0);g=v[22640];v[22640]=0;if((g|0)==1){break x}i=A[b+32>>3];tf(c);gb=b+192|0;i=f?0:i;break v}a=P()|0;O()|0;break y}a=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break w}a=P()|0;O()|0;tf(c)}S(a|0);L()}b=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=b;kL(a,e+16|0,i,d);break e;case 3:break k;default:break e}}ug(e+48|0,b);ug(e+40|0,c);b=v[e+52>>2];v[e+32>>2]=v[e+48>>2];v[e+36>>2]=b;b=v[e+44>>2];v[e+24>>2]=v[e+40>>2];v[e+28>>2]=b;jL(a,e+32|0,e+24|0,d)}gb=e+128|0;return}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function Jo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=gb-112|0;gb=d;p=EA(a);q=Qi(p);f=q;c=a;e=Cc(c);a:{if(f>>>0>e>>>0){m=gb-32|0;gb=m;b:{h=f-e|0;c:{if(h>>>0<=(v[wb(c)>>2]-v[c+4>>2]|0)/12>>>0){f=gb-16|0;gb=f;h=Mp(f,c,h);i=v[h+4>>2];e=v[h+8>>2];if((i|0)!=(e|0)){while(1){wb(c);qR(i);i=i+12|0;v[h+4>>2]=i;if((e|0)!=(i|0)){continue}break}}$b(h);gb=f+16|0;break c}e=wb(c);j=Nu(m+8|0,BB(c,Cc(c)+h|0),Cc(c),e);v[22640]=0;R(1141,j|0,h|0);e=v[22640];v[22640]=0;if((e|0)==1){break b}Qp(c);wb(c);f=j+4|0;l=f;k=v[c+4>>2];e=v[c>>2];if((k|0)!=(e|0)){h=v[l>>2];while(1){k=k-12|0;EB(h-12|0,k);h=v[l>>2]-12|0;v[l>>2]=h;if((e|0)!=(k|0)){continue}break}}wc(c,f);wc(c+4|0,j+8|0);wc(wb(c),cc(j));v[j>>2]=v[j+4>>2];Lw(c,Cc(c));rR(j)}gb=m+32|0;break a}a=P()|0;O()|0;rR(j);S(a|0);L()}if(e>>>0>f>>>0){f=v[c>>2]+B(f,12)|0;Cc(c);uR(c,f);sR(c)}}if(b){c=a+12|0;Qq(c,Vd(c));r=wb(c),s=0,v[r>>2]=s;r=c,s=ec(c),v[r>>2]=s;r=ec(c),s=0,v[r>>2]=s;v[a+28>>2]=0}n=nc(d+96|0);c=v[a+24>>2];v[22640]=0;e=sq(c+484344|0);c=v[22640];v[22640]=0;d:{e:{f:{g:{if((c|0)==1){break g}v[22640]=0;j=W(812,d+80|0,e|0,36892)|0;c=v[22640];v[22640]=0;if((c|0)==1){break g}u[d+78>>1]=0;if(q){o=a+12|0;i=0;while(1){l=x[rc(p,i)>>1];c=FR(a,l);v[d+72>>2]=c;f=xd(a,x[d+78>>1]);h:{if(b){v[22640]=0;t[d+32|0]=0;U(1135,f|0,c|0,d+32|0);c=v[22640];v[22640]=0;if((c|0)!=1){break h}g=P()|0;O()|0;break e}v[22640]=0;U(964,f|0,c|0,0);c=v[22640];v[22640]=0;if((c|0)==1){break f}}v[22640]=0;e=Q(497,p|0,x[d+78>>1])|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}i:{if(!e){break i}g=0;g=b?g:v[f+4>>2];v[22640]=0;v[d+32>>2]=g;e=Fb(d+32|0,d+72|0);c=v[22640];v[22640]=0;j:{k:{if((c|0)!=1){v[d+68>>2]=v[e>>2];h=zh(o);if(x[rc(j,l)>>1]!=65535){e=DR(o,Um(d+32|0,rc(j,l),d+68|0));v[d+64>>2]=e;r=d,s=zh(o),v[r+8>>2]=s;f=d;l:{if(kg(d- -64|0,d+8|0)){c=DR(o,Um(d+32|0,rc(j,l),d+72|0));break l}c=zh(o)}v[f+56>>2]=c;v[d+48>>2]=e;if(!kg(d+48|0,d+56|0)){break i}while(1){m:{f=ad(d+32|0);c=pg(ue(d+48|0)+8|0);v[22640]=0;R(1136,f|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break m}kB(d+16|0,h);c=Um(d+8|0,d+78|0,ue(d+48|0)+4|0);v[22640]=0;e=ca(1137,o|0,v[d+16>>2],c|0,f|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break m}v[d+24>>2]=e;CR(d+24|0);h=v[d+24>>2];Rq(f);if(kg(CR(d+48|0),d+56|0)){continue}break i}break}g=P()|0;O()|0;Rq(f);break e}f=_b(v[a+24>>2]+484344|0,l);v[22640]=0;e=Hi(f);c=v[22640];v[22640]=0;n:{o:{if((c|0)!=1){v[22640]=0;t[d+32|0]=0;U(1139,n|0,e|0,d+32|0);c=v[22640];v[22640]=0;if((c|0)==1){break o}k=v[d+72>>2];if((k|0)!=v[d+68>>2]){break n}break j}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}p:while(1){q:{i=0;v[22640]=0;k=k-1|0;v[d+64>>2]=k;g=Pf(f,k);c=v[22640];v[22640]=0;m=1;if((c|0)==1){break k}while(1){r:{v[22640]=0;e=Hi(f);c=v[22640];v[22640]=0;s:{if((c|0)!=1){if(m>>>0<16?e>>>0>i>>>0:0){break s}if(m>>>0>1){e=ad(d+32|0);v[22640]=0;R(1136,e|0,m|0);c=v[22640];v[22640]=0;if((c|0)==1){break r}kB(d,h);c=Um(d+8|0,d+78|0,d- -64|0);v[22640]=0;h=ca(1137,o|0,v[d>>2],c|0,e|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break q}Rq(e)}if(v[d+68>>2]==(k|0)){break j}continue p}g=P()|0;O()|0;break e}e=w[kc(n,i)|0];t:{u:{v:{switch(w[g+3|0]-19|0){case 1:c=w[g+5|0];if((c&240)==176){break u}break t;case 0:break v;default:break t}}c=w[g+5|0];if((c&240)!=96){break t}}r=kc(n,i),s=c&15,t[r|0]=s;if(!w[kc(n,i)|0]){break t}e=w[kc(n,i)|0]}m=B(e?e+1|0:1,m);g=g+6|0;i=i+1|0;continue}break}}break}g=P()|0;O()|0;Rq(e);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}if(k){break i}c=x[d+78>>1];r=rc(j,l),s=c,u[r>>1]=s}c=x[d+78>>1]+1|0;u[d+78>>1]=c;i=c&65535;if(q>>>0>i>>>0){continue}break}}Ue(j);gc(n);gb=d+112|0;return}g=P()|0;O()|0;break d}g=P()|0;O()|0}Ue(j)}gc(n);S(g|0);L()}function Z2(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;v[h+24>>2]=b;v[e>>2]=0;Ec(h+8|0,d);v[22640]=0;i=T(21,h+8|0)|0;j=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Vb(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Vb(h+8|0);S(a|0);L()}jH(a,f+24|0,h+24|0,c,e,i);break b}iH(a,f+16|0,h+24|0,c,e,i);break b}g=a;a=kb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=fk(g,b,c,d,e,f,Jb(a),Jb(a)+Ab(a)|0),v[k+24>>2]=l;break b}a=e;b=mj(h+24|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<1|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;k=h,l=fk(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;k=h,l=fk(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=mj(h+24|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=mj(h+24|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<1|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=mj(h+24|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=mj(h+24|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=mj(h+24|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=h+24|0;H:{if(!ik(b,a+8|0)){break H}while(1){if(!jh(i,8192,rl(b))){break H}ql(b);if(ik(b,a+8|0)){continue}break}}if(hk(b,a+8|0)){v[e>>2]=v[e>>2]|2}gb=a+16|0;break b}b=h+24|0;a=kb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Ab(a)|0)==(0-Ab(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=Ks(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=w[83236]|w[83237]<<8|(w[83238]<<16|w[83239]<<24);t[h+15|0]=g;t[h+16|0]=g>>>8;t[h+17|0]=g>>>16;t[h+18|0]=g>>>24;g=w[83233]|w[83234]<<8|(w[83235]<<16|w[83236]<<24);v[h+8>>2]=w[83229]|w[83230]<<8|(w[83231]<<16|w[83232]<<24);v[h+12>>2]=g;k=h,l=fk(a,b,c,d,e,f,h+8|0,h+19|0),v[k+24>>2]=l;break b}t[h+12|0]=w[83244];v[h+8>>2]=w[83240]|w[83241]<<8|(w[83242]<<16|w[83243]<<24);k=h,l=fk(a,b,c,d,e,f,h+8|0,h+13|0),v[k+24>>2]=l;break b}a=e;b=mj(h+24|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;k=h,l=fk(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=mj(h+24|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=kb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=fk(g,b,c,d,e,f,Jb(a),Jb(a)+Ab(a)|0),v[k+24>>2]=l;break b}hH(f+20|0,h+24|0,c,e,i);break b}a=mj(h+24|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=gb-16|0;gb=a;v[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(hk(c,a+8|0)){break M}b=4;if((Rn(i,rl(c))|0)!=37){break M}b=2;if(!hk(ql(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}gb=a+16|0}a=v[h+24>>2]}gb=h+32|0;return a|0}function me(a,b){var c=C(0),d=0,e=C(0),f=0,g=0,h=0,i=C(0),k=0,m=C(0),n=C(0),o=0,r=0,s=C(0),t=C(0),u=C(0);i=C(1);a:{b:{c:{h=(p(b),j(2));d=h&2147483647;d:{if(!d){break d}k=(p(a),j(2));if((k|0)==1065353216){break d}g=k&2147483647;c=C(a+b);if(!(d>>>0<2139095041?g>>>0<=2139095040:0)){break a}e:{f:{if((k|0)>-1){break f}o=2;if(d>>>0>1266679807){break e}if(d>>>0<1065353216){break f}f=150-(d>>>23|0)|0;r=d>>>f|0;o=0;if((d|0)!=r<<f){break e}o=2-(r&1)|0;break e}o=0}f=o;g:{if((d|0)!=1065353216){if((d|0)!=2139095040){break g}if((g|0)==1065353216){break d}c=(h|0)>-1?b:C(0);if(g>>>0>=1065353217){break a}c=(h|0)>-1?C(0):C(-b);break a}c=(h|0)>-1?a:C(C(1)/a);break a}c=C(a*a);if((h|0)==1073741824){break a}c=C(K(a));if(!((h|0)!=1056964608|(k|0)<0)){break a}e=C(D(a));if(!(g?(k&1073741823)!=1065353216:0)){i=(h|0)<0?C(C(1)/e):e;if((k|0)>-1){break d}if(!(f|g-1065353216)){a=C(i-i);c=C(a/a);break a}c=(f|0)==1?C(-i):i;break a}h:{if((k|0)>-1){break h}i:{switch(f|0){case 0:a=C(a-a);c=C(a/a);break a;case 1:break i;default:break h}}i=C(-1)}j:{if(d>>>0>=1291845633){c=(h|0)<0?C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(g>>>0<=1065353207){break a}c=(h|0)>0?C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(g>>>0>=1065353224){break a}a=C(e+C(-1));c=C(C(a*C(7052607543300837e-21))+C(C(C(a*a)*C(C(.5)-C(a*C(C(a*C(-.25))+C(.3333333432674408)))))*C(-1.4426950216293335)));e=c;a=C(a*C(1.44268798828125));c=(l(2,(p(C(c+a)),j(2))&-4096),q());e=C(e-C(c-a));break j}d=g>>>0<8388608;k=d?(p(C(e*C(16777216))),j(2)):g;g=k&8388607;f=g|1065353216;k=(k>>23)+(d?-151:-127)|0;d=0;k:{if(g>>>0<1885298){break k}if(g>>>0<6140887){d=1;break k}f=g|1056964608;k=k+1|0}g=d<<2;a=z[g+89824>>2];n=(l(2,f),q());m=C(C(1)/C(a+n));s=C(n-a);e=C(s*m);c=(l(2,(p(e),j(2))&-4096),q());t=C(c*c);u=m;m=(l(2,((f>>>1&536866816)+(d<<21)|0)+541065216|0),q());n=C(u*C(C(s-C(m*c))-C(C(n-C(m-a))*c)));a=C(e*e);m=C(C(n*C(e+c))+C(C(a*a)*C(C(a*C(C(a*C(C(a*C(C(a*C(C(a*C(.20697501301765442))+C(.23066075146198273)))+C(.2727281153202057)))+C(.3333333432674408)))+C(.4285714328289032)))+C(.6000000238418579))));a=(l(2,(p(C(C(t+C(3))+m)),j(2))&-4096),q());e=C(C(n*a)+C(e*C(m-C(C(a+C(-3))-t))));c=C(c*a);a=(l(2,(p(C(e+c)),j(2))&-4096),q());n=z[g+89840>>2];e=C(z[g+89832>>2]+C(C(C(e-C(a-c))*C(.9617967009544373))+C(a*C(-.00011736857413779944))));a=C(a*C(.9619140625));m=C(k|0);c=(l(2,(p(C(C(n+C(e+a))+m)),j(2))&-4096),q());e=C(e-C(C(C(c-m)-n)-a))}n=(l(2,h&-4096),q());a=C(c*n);b=C(C(e*b)+C(C(b-n)*c));c=C(a+b);f=(p(c),j(2));if((f|0)>=1124073473){break c}l:{m:{if((f|0)==1124073472){o=134;if(!(C(b+C(4.299566569443414e-8))>C(c-a))){break m}break c}h=f&2147483647;if(!(!(b<=C(c-a))|(f|0)!=-1021968384)|h>>>0>=1125515265){break b}d=0;if(h>>>0<1056964609){break l}o=h>>>23|0}h=(8388608>>>o-126|0)+f|0;g=h>>>23&255;d=(h&8388607|8388608)>>>150-g|0;d=(f|0)<0?0-d|0:d;a=C(a-(l(2,h&-8388608>>g-127),q()));f=(p(C(b+a)),j(2))}c=(l(2,f&-32768),q());e=C(c*C(.693145751953125));c=C(C(c*C(14286065379565116e-22))+C(C(b-C(c-a))*C(.6931471824645996)));a=C(e+c);b=C(a*a);b=C(a-C(b*C(C(b*C(C(b*C(C(b*C(C(b*C(4.138136944220605e-8))+C(-16533901998627698e-22)))+C(661375597701408e-19)))+C(-.0027777778450399637)))+C(.1666666716337204))));m=C(C(a*b)/C(b+C(-2)));b=C(c-C(a-e));a=C(C(a-C(m-C(b+C(a*b))))+C(1));f=(p(a),j(2))+(d<<23)|0;n:{if((f|0)<=8388607){a=VI(a,d);break n}a=(l(2,f),q())}i=C(i*a)}c=i;break a}c=C(C(i*C(1.0000000150474662e30))*C(1.0000000150474662e30));break a}c=C(C(i*C(1.0000000031710769e-30))*C(1.0000000031710769e-30))}return c}function Qga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=gb-11360|0;gb=g;vc(c);a:{b:{if(!Pb(c,4)){break b}c:{while(1){d:{d=g+16|0;f=gb-32|0;gb=f;h=c;e:{if(Pb(c,3)){$X(f+24|0,d);d=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=d;gd(f+16|0,h,f+8|0);break e}i=gb-16|0;gb=i;k=d+3|0;while(1){Kf(d);d=d+1|0;if((k|0)!=(d|0)){continue}break}gb=i+16|0}gb=f+32|0;f:{if(!yd(g+16|0,12224,3)){d=g+4648|0;f=gb-32|0;gb=f;g:{if(Pb(c,7)){un(f+24|0,d);d=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=d;gd(f+16|0,h,f+8|0);break g}h=gb-16|0;gb=h;i=d+7|0;while(1){Kf(d);d=d+1|0;if((i|0)!=(d|0)){continue}break}gb=h+16|0}gb=f+32|0;f=3;d=0;while(1){h=w[(g+4648|0)+f|0];if(h&128){break c}d=h|d<<7;f=f+1|0;if((f|0)!=7){continue}break}Yb(c,d);break f}h:{if(yd(g+16|0,11493,3)){break h}if(!yV(c,10917)){break h}Yb(c,og(c)+16|0);break f}if(!yd(g+16|0,36895,3)){break f}if(!yd(g+16|0,36899,3)){break f}if(w[g+16|0]){break d}lg(c,2)}if(Pb(c,4)){continue}break b}break}if(WS(g+16|0)){break b}}f=0;break a}vc(c);CC(g+11336|0,c);k=v[g+11336>>2];v[22640]=0;c=Rd(g+11336|0);d=v[22640];v[22640]=0;i:{j:{k:{l:{if((d|0)!=1){c=zb(c);j=nc(g+11320|0);Qb(g+4648|0,0,6668);v[22640]=0;ot(g+4648|0);d=v[22640];v[22640]=0;if((d|0)!=1){d=g+4640|0;v[d>>2]=0;v[d+4>>2]=0;d=g+4632|0;v[d>>2]=0;v[d+4>>2]=0;v[g+4624>>2]=0;v[g+4628>>2]=0;h=0;d=0;while(1){f=zc(k,l);v[22640]=0;m=ga(1146,g+4648|0,c|0,f|0,g+16|0,g+4624|0)|0;f=v[22640];v[22640]=0;m:{n:{if((f|0)!=1){if((m|0)<0){break k}f=v[g+4624>>2];if((f|0)<0){break k}n=(m|0)<1;if(!(f?1:n)|!(f|m)){break k}if((f|0)<1){break m}i=v[g+4636>>2];if((i|0)!=(h|0)?h:0){break k}f=v[g+4632>>2];if((f|0)!=(d|0)?d:0){break k}if((i|0)<1|f-1>>>0>1){break l}v[g+12>>2]=0;d=zc(k,l);v[22640]=0;v[g+8>>2]=d;d=Tm(g+4624|0,g+12|0,g+8|0);h=v[22640];v[22640]=0;o:{if((h|0)!=1){d=v[d>>2];v[g+12>>2]=0;h=zc(k,l);v[22640]=0;v[g+8>>2]=h;h=Tm(g+4624|0,g+12|0,g+8|0);o=v[22640];v[22640]=0;if((o|0)==1){break o}c=c+d|0;d=k;h=v[h>>2];k=d-h|0;l=l-((h>>31)+(d>>>0<h>>>0)|0)|0;if(n){break n}v[22640]=0;U(1148,j|0,g+16|0,(g+16|0)+(B(f,m)<<1)|0);d=v[22640];v[22640]=0;if((d|0)!=1){break n}d=V(88880)|0;if((O()|0)!=(ea(88880)|0)){break j}Z(d|0)|0;v[22640]=0;X(20);c=v[22640];v[22640]=0;h=i;d=f;if((c|0)!=1){break k}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}h=i;d=f}if((sc(j)>>>0)/(d>>>0)>>>0>268435456){break k}if((l|0)>0?1:(l|0)>=0?k:0){continue}break}break k}d=P()|0;O()|0;break j}d=P()|0;O()|0;break i}h=i;d=f}f=0;p:{q:{r:{s:{t:{if(!h|!d){break t}if($c(j)){break t}if((sc(j)>>>0)/(d>>>0)>>>0>268435456){break t}v[22640]=0;Q(1149,a|0,b|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break p}if(!e){v[22640]=0;c=Q(112,g+16|0,18693)|0;f=v[22640];v[22640]=0;if((f|0)==1){break s}v[22640]=0;Q(333,((b<<5)+a|0)+946304|0,c|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break r}vb(c);v[22640]=0;c=B(b,104)+a|0;R(352,c+484380|0,0);f=v[22640];v[22640]=0;if((f|0)==1){break p}v[c+484404>>2]=h}h=B(b,104)+a|0;c=h+484380|0;p=c,q=(sc(j)>>>0)/(d>>>0)|0,v[p>>2]=q;f=h+484414|0;h=x[f>>1];u[f>>1]=(d|0)==2?h|65:h&65470|1;v[22640]=0;T(424,c|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break p}if(Ld(c)){d=Sb(j);h=Wb(j);b=v[(B(b,104)+a|0)+484400>>2];v[22640]=0;W(1150,d|0,h|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break p}}if(!e){b=v[a+480180>>2];v[22640]=0;U(1151,c|0,32,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break q}v[22640]=0;Zh(c,a,0);a=v[22640];v[22640]=0;if((a|0)==1){break p}}f=Ld(c)}Ue(j);xc(g+11336|0);break a}d=P()|0;O()|0;break j}d=P()|0;O()|0;vb(c);break j}d=P()|0;O()|0;break j}d=P()|0;O()|0}Ue(j)}xc(g+11336|0);S(d|0);L()}gb=g+11360|0;return f|0}function TZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-576|0;gb=e;vc(b);f=gb-32|0;gb=f;h=e+72|0;xE(f+24|0,h);g=xb(f+24|0);d=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=d;v[f>>2]=i;v[f+4>>2]=d;d=b;fc(f+16|0,d,f);i=xb(f+16|0);if((i|0)==(g|0)){Yb(d,xb(f+24|0))}gb=f+32|0;d=(g|0)==(i|0);if(!d){wE(h)}a:{if(!d){break a}if(!CE(e+72|0)){break a}b:{if(!c){break b}if(!Pb(b,Uc(BE(e+72|0),jb))){break a}Gd(a,64);v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480204>>2]=78e4;v[a+480196>>2]=4;u[a+480188>>1]=8;f=1;Ob(a+1074312|0,7,1);d=Tb(e+40|0,11900);Eb(a+1298304|0,d);vb(d);d=Tb(e+40|0,11933);Eb(a+1298316|0,d);vb(d);Vc(a+1298328|0,x[e+72>>1]==26217?11900:11928);v[a+1298364>>2]=5;d=w[e+182|0];u[a+480190>>1]=d;c:{d:{e:{if(d){i=1;while(1){h=gb-32|0;gb=h;g=e+40|0;bc(h+24|0,g,25);k=xb(h+24|0);d=v[h+28>>2];j=v[h+24>>2];v[h+8>>2]=j;v[h+12>>2]=d;v[h>>2]=j;v[h+4>>2]=d;d=b;fc(h+16|0,d,h);j=xb(h+16|0);if((j|0)==(k|0)){Yb(d,xb(h+24|0))}gb=h+32|0;if((k|0)!=(j|0)){t[g|0]=0;t[g+1|0]=0;t[g+2|0]=0;t[g+3|0]=0;t[g+4|0]=0;t[g+5|0]=0;t[g+6|0]=0;t[g+7|0]=0;t[g+24|0]=0;t[g+16|0]=0;t[g+17|0]=0;t[g+18|0]=0;t[g+19|0]=0;t[g+20|0]=0;t[g+21|0]=0;t[g+22|0]=0;t[g+23|0]=0;t[g+8|0]=0;t[g+9|0]=0;t[g+10|0]=0;t[g+11|0]=0;t[g+12|0]=0;t[g+13|0]=0;t[g+14|0]=0;t[g+15|0]=0}if((w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24))>>>0>67108863){break a}d=(B(f,104)+a|0)+484380|0;td(d,0);v[d+24>>2]=8363;v[d>>2]=w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24);v[d+4>>2]=w[e+57|0]|w[e+58|0]<<8|(w[e+59|0]<<16|w[e+60|0]<<24);g=w[e+61|0]|w[e+62|0]<<8|(w[e+63|0]<<16|w[e+64|0]<<24);g=g>>>0>y[d>>2]?v[d+4>>2]?g:0:g;v[d+8>>2]=g;if(g){u[d+34>>1]=2;wk(d)}Yj(e+8|0,2,e+40|0);Bc(e+24|0,e+8|0);v[22640]=0;Q(333,((f<<5)+a|0)+946304|0,e+24|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break e}vb(e+24|0);i=i+1|0;f=i&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}d=e+72|2;Te(e+24|0,3,d,36);Bc(e+40|0,e+24|0);Eb(a+1298268|0,e+40|0);vb(e+40|0);f=0;VS(a+1298292|0,zb(d),108,36,0);d=a+484360|0;AE(Rb(d),e+185|0,128);if(x[rc(Rb(d),w[e+184|0])>>1]<w[e+183|0]){break d}break c}a=P()|0;O()|0;vb(e+24|0);S(a|0);L()}af(Rb(d),w[e+184|0])}while(1){d=(f<<5)+a|0;Se(d+480280|0);u[d+480284>>1]=f&1?208:48;f=f+1|0;if((f|0)!=8){continue}break}h=a+484344|0;vg(h,w[e+183|0]);n=1;if(w[e+183|0]){o=c&1;g=0;while(1){f:{g:{if(o){if(qh(h,g&65535,64)){break g}}Yb(b,1536);break f}v[e+24>>2]=-1;v[e+28>>2]=-1;j=0;while(1){f=Pf(_b(h,g),j);k=0;while(1){Pr(e+40|0,b);d=md(e+40|0);l=Re(e+40|0);i=w[d|0];d=w[e+40|0];if(d>>>0<=253){t[f|0]=(d>>>2|0)+37;t[f+1|0]=(d<<4&48|i>>>4)+1;t[(e+24|0)+k|0]=255;d=w[e+40|0]}if((d&255)!=255){t[f+2|0]=1;t[f+4|0]=(((i&15)<<6|8)>>>0)/15}m=(e+24|0)+k|0;h:{i:{i=w[l|0];j:{if((i|0)!=255){t[m|0]=i;d=i&15;if(d|(i|0)==48){break j}break i}i=w[m|0];if((i|0)==255){break h}d=i&15}t[f+5|0]=d;k:{if(i<<24>>24<0){break k}l=i>>>4|0;t[f+3|0]=w[l+28760|0];l:{switch(l-3|0){case 0:t[f+5|0]=d|32;break i;case 1:t[f+5|0]=B(d,17);break h;case 2:break i;case 3:break l;default:break h}}m:{switch(i&15){case 0:t[f+5|0]=79;break h;case 1:break m;default:break k}}t[f+5|0]=244;break h}t[f+3|0]=0;break h}t[m|0]=255}f=f+6|0;k=k+1|0;if((k|0)!=8){continue}break}j=j+1|0;if((j|0)!=64){continue}break}d=(e+72|0)+g|0;f=d;if(w[d+369|0]<63){Gm(_b(h,g),Eh(Qe(Be(e+40|0,14,0),w[f+369|0])))}Gm(_b(h,g),Eh(Be(e+40|0,16,w[d+241|0])))}g=g+1|0;if(g>>>0<w[e+183|0]){continue}break}}if(!(c&2)){break a}f=1;c=Pc(e+40|0,8,1,0,1);if(!x[a+480190>>1]){break b}while(1){zg(c,(B(f&65535,104)+a|0)+484380|0,b);f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}n=1}gb=e+576|0;return n|0}function kL(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=gb-256|0;gb=e;A[e+248>>3]=c;a:{if(nk(b)){break a}f=w[wl(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Kl(e+216|0,b,v[b+4>>2]-1|0);f=v[e+220>>2];v[b>>2]=v[e+216>>2];v[b+4>>2]=f}Kd(e+216|0);f=v[e+216>>2];Kd(e+200|0);h=vl(f,v[e+204>>2],b);Kd(e+216|0);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{if((h|0)==v[e+220>>2]){v[e+240>>2]=f;v[e+244>>2]=g;a=uc(e+232|0,18693);f=v[e+244>>2];v[e+16>>2]=v[e+240>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Fc(e+16|0,e+8|0)){d=aa(8)|0;v[22640]=0;R(2060,e+200|0,e+248|0);a=v[22640];v[22640]=0;f:{g:{h:{if((a|0)!=1){v[22640]=0;U(2037,e+216|0,14695,e+200|0);a=v[22640];v[22640]=0;if((a|0)==1){break h}qc(d,e+216|0);a=0;v[22640]=0;U(223,d|0,55256,1936);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+216|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}vb(e+200|0);if(!a){break c}}da(d|0);break c}if(!d){break e}d=aa(8)|0;v[22640]=0;f=Q(2057,e+168|0,b|0)|0;b=v[22640];v[22640]=0;a=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[22640]=0;U(2037,e+184|0,14731,f|0);a=v[22640];v[22640]=0;if((a|0)==1){break q}v[22640]=0;R(2054,e+200|0,e+184|0);b=v[22640];v[22640]=0;a=1;if((b|0)==1){break p}v[22640]=0;R(2060,e+152|0,e+248|0);a=v[22640];v[22640]=0;if((a|0)==1){break o}v[22640]=0;U(2058,e+216|0,e+200|0,e+152|0);b=v[22640];v[22640]=0;a=1;if((b|0)==1){break n}qc(d,e+216|0);v[22640]=0;U(223,d|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(e+216|0);a=0;break m}b=P()|0;O()|0;break i}b=P()|0;a=1;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}vb(e+152|0)}vb(e+200|0)}vb(e+184|0)}vb(f)}if(!a){break c}da(d|0);break c}v[e+144>>2]=f;v[e+148>>2]=g;d=uc(e+136|0,18693);f=v[e+148>>2];v[e+80>>2]=v[e+144>>2];v[e+84>>2]=f;f=v[d+4>>2];v[e+72>>2]=v[d>>2];v[e+76>>2]=f;if(Fc(e+80|0,e+72|0)){d=aa(8)|0;v[22640]=0;R(2060,e+200|0,e+248|0);a=v[22640];v[22640]=0;r:{s:{t:{if((a|0)!=1){v[22640]=0;U(2037,e+216|0,14695,e+200|0);a=v[22640];v[22640]=0;if((a|0)==1){break t}qc(d,e+216|0);a=0;v[22640]=0;U(223,d|0,55256,1936);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(e+216|0);break s}b=P()|0;O()|0;break r}b=P()|0;a=1;O()|0}vb(e+200|0);if(!a){break c}}da(d|0);break c}d=v[b+4>>2];v[e+128>>2]=v[b>>2];v[e+132>>2]=d;d=uc(e+120|0,4903);f=v[e+132>>2];v[e+64>>2]=v[e+128>>2];v[e+68>>2]=f;f=v[d+4>>2];v[e+56>>2]=v[d>>2];v[e+60>>2]=f;if(Fc(e- -64|0,e+56|0)){if(!w[a+28|0]){break e}if(c<=4?c<=0:1){a=aa(8)|0;v[22640]=0;d=Q(112,e+216|0,4998)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}qc(a,d);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d);break c}b=xh(65536/c);a=a+24|0;v[v[a>>2]+480244>>2]=b;Eq(v[a>>2]);break e}d=v[b+4>>2];v[e+112>>2]=v[b>>2];v[e+116>>2]=d;d=uc(e+104|0,4955);f=v[e+116>>2];v[e+48>>2]=v[e+112>>2];v[e+52>>2]=f;f=v[d+4>>2];v[e+40>>2]=v[d>>2];v[e+44>>2]=f;if(Fc(e+48|0,e+40|0)){if(!w[a+28|0]){break e}if(c<=4?c<=0:1){a=aa(8)|0;v[22640]=0;d=Q(112,e+216|0,5019)|0;b=v[22640];v[22640]=0;if((b|0)!=1){qc(a,d);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(d);break c}b=P()|0;O()|0;da(a|0);break c}b=xh(c*65536);a=a+24|0;v[v[a>>2]+480240>>2]=b;Eq(v[a>>2]);break e}d=v[b+4>>2];v[e+96>>2]=v[b>>2];v[e+100>>2]=d;b=uc(e+88|0,4973);d=v[e+100>>2];v[e+32>>2]=v[e+96>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(!Fc(e+32|0,e+24|0)){break e}b=Oo(c*65536);v[v[a+24>>2]+480236>>2]=b}gb=e+256|0;return}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function Yma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,B=0;e=gb-48|0;gb=e;a:{b:{c:{d:{if(!c){break d}A=e,B=de(a),t[A+32|0]=B;k=e+32|0;d=b;e:{if(y[d+4>>2]<y[wb(d)>>2]){h=gb-16|0;gb=h;f=Ri(h,d,1);wb(d);zd(v[f+4>>2],k);v[f+4>>2]=v[f+4>>2]+1;$b(f);gb=h+16|0;break e}f=gb-32|0;gb=f;h=wb(d);h=dh(f+8|0,vh(d,pc(d)+1|0),pc(d),h);zd(v[h+8>>2],k);v[h+8>>2]=v[h+8>>2]+1;v[22640]=0;R(328,d|0,h|0);d=v[22640];v[22640]=0;f:{if((d|0)!=1){ae(h);gb=f+32|0;break f}a=P()|0;O()|0;ae(h);S(a|0);L()}}h=c-1|0;if(!h){break c}c=0;while(1){g:{h:{i=c&254;i:{if(!i){if(!kf(a,e+32|0)){break d}c=w[e+32|0]<<1|1;i=c&255;if(c>>>0<256){break i}break h}if((c&65535)>>>0>255){break h}}if(!kf(a,e+32|0)){break d}g=e+32|0;c=b;j:{if(v[c+4>>2]!=v[wb(c)>>2]){iI(c,g);break j}k=gb-32|0;gb=k;f=wb(c);j=dh(k+8|0,vh(c,pc(c)+1|0),pc(c),f);d=v[j+8>>2];v[22640]=0;dl(f,d,g);d=v[22640];v[22640]=0;k:{if((d|0)==1){break a}v[j+8>>2]=v[j+8>>2]+1;v[22640]=0;R(328,c|0,j|0);c=v[22640];v[22640]=0;if((c|0)==1){break a}ae(j);gb=k+32|0;break k}}h=h-1|0;break g}d=1;while(1){l:{m:{n:{c=i<<1&254;o:{if(c){g=i>>>0>127}else{if(!kf(a,e+32|0)){break o}f=w[e+32|0]<<1|1;c=f&255;g=f>>>0>255}d=g|d<<1;i=c<<1&254;if(i){break m}if(kf(a,e+32|0)){break n}}i=0;break l}c=w[e+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break l}if(c>>>0>127){continue}}break}p:{if((d|0)<=2){f=0;g=d-2|0;break p}c=kf(a,e+32|0);if(!c){break d}c=c?(w[e+32|0]|d<<8)-768|0:s;f=((c|0)>1279?2:1)+((c|0)>31999)|0;s=c^-1;g=0}c=i<<1&254;if(c){d=i>>>0>127}else{if(!kf(a,e+32|0)){break d}d=w[e+32|0]<<1|1;c=d&255;d=d>>>0>255}k=h;i=c<<1&254;if(i){c=c>>>0>127}else{if(!kf(a,e+32|0)){break d}c=w[e+32|0]<<1|1;i=c&255;c=c>>>0>255}c=c|(g<<2|(d?2:0));if(!c){d=1;while(1){q:{r:{s:{c=i<<1&254;t:{if(c){g=i>>>0>127}else{if(!kf(a,e+32|0)){break t}g=w[e+32|0]<<1|1;c=g&255;g=g>>>0>255}d=g|d<<1;i=c<<1&254;if(i){break r}if(kf(a,e+32|0)){break s}}i=0;break q}c=w[e+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break q}if(c>>>0>127){continue}}break}c=d+2|0}g=k;k=c+f|0;d=0;if(g>>>0<k>>>0|(k|0)<1|(s|0)>-1){break b}d=0;if((0-pc(b)|0)>(s|0)){break b}A=e,B=Wb(b),v[A+32>>2]=B;Fd(e+40|0,e+32|0);t[e+24|0]=0;m=e+24|0;n=gb-32|0;gb=n;v[n+24>>2]=v[e+40>>2];c=b;d=v[c>>2];A=n,B=Sb(c),v[A>>2]=B;d=Xj(n+24|0,n)+d|0;u:{g=k;f=v[wb(c)>>2];l=v[c+4>>2];v:{if(g>>>0<=f-l>>>0){f=g;j=l-d|0;if(f>>>0>j>>>0){Cn(c,g-j|0,m);f=j;if(!f){break v}}x=gb-16|0;gb=x;o=c;r=l;j=d;q=v[c+4>>2];p=(q-(d+g|0)|0)+d|0;z=Ri(x,c,l-p|0);if(l>>>0>p>>>0){u=v[z+4>>2];l=p;while(1){wb(o);zd(u,l);u=u+1|0;v[z+4>>2]=u;l=l+1|0;if(r>>>0>l>>>0){continue}break}}$b(z);hn(j,p,q);gb=x+16|0;li(d,f,d>>>0<=m>>>0?m>>>0<y[c+4>>2]?g+m|0:m:m);break v}f=wb(c);j=dh(n,vh(c,pc(c)+g|0),d-v[c>>2]|0,f);v[22640]=0;U(657,j|0,g|0,m|0);f=v[22640];v[22640]=0;if((f|0)==1){break a}o=c;sv(c);r=j;f=v[j+4>>2];g=d;p=j+4|0;xk(wb(c),v[c>>2],d,p);wb(c);l=j+8|0;q=l;d=v[c+4>>2];if((g|0)!=(d|0)){c=v[q>>2];while(1){zd(c,g);c=v[q>>2]+1|0;v[q>>2]=c;g=g+1|0;if((d|0)!=(g|0)){continue}break}}jc(o,p);jc(o+4|0,l);jc(wb(o),cc(r));v[r>>2]=v[r+4>>2];Lu(o,pc(o));d=f;ae(j)}bh(d);gb=n+32|0;break u}A=e,B=Wb(b),v[A+16>>2]=B;A=e,B=NV(e+16|0,k),v[A+24>>2]=B;A=e,B=we(e+24|0,s),v[A+32>>2]=B;A=e,B=Wb(b),v[A+16>>2]=B;A=e,B=NV(e+16|0,k),v[A+24>>2]=B;c=k;while(1){A=e,B=MV(e+32|0),v[A+16>>2]=B;d=w[v[e+16>>2]];A=e,B=MV(e+24|0),v[A+8>>2]=B;t[v[e+8>>2]]=d;d=(c|0)>1;c=c-1|0;if(d){continue}break}h=h-k|0}if(!h){break c}c=i<<1;continue}}d=0;break b}d=1}gb=e+48|0;return d|0}a=P()|0;O()|0;ae(j);S(a|0);L()}function E7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-352|0;gb=d;a:{if(nk(b)){break a}e=w[wl(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Kl(d+320|0,b,v[b+4>>2]-1|0);e=v[d+324>>2];v[b>>2]=v[d+320>>2];v[b+4>>2]=e}Kd(d+320|0);e=v[d+320>>2];Kd(d+304|0);e=vl(e,v[d+308>>2],b);Kd(d+320|0);b:{c:{d:{e:{if((e|0)==v[d+324>>2]){a=v[b+4>>2];v[d+344>>2]=v[b>>2];v[d+348>>2]=a;a=uc(d+336|0,18693);e=v[d+348>>2];v[d+8>>2]=v[d+344>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Fc(d+8|0,d)){a=aa(8)|0;v[22640]=0;c=Q(112,d+320|0,7808)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}e=0;if(!c){break e}c=aa(8)|0;v[22640]=0;e=Q(2057,d+304|0,b|0)|0;a=v[22640];v[22640]=0;f:{g:{h:{if((a|0)!=1){v[22640]=0;U(2037,d+320|0,14731,e|0);a=v[22640];v[22640]=0;if((a|0)==1){break h}qc(c,d+320|0);a=0;v[22640]=0;U(223,c|0,55256,1936);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(d+320|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}vb(e);if(!a){break c}}da(c|0);break c}if(v[e+4>>2]){a=aa(8)|0;v[22640]=0;c=Q(112,d+320|0,8924)|0;b=v[22640];v[22640]=0;if((b|0)!=1){qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+296>>2]=v[b>>2];v[d+300>>2]=c;c=uc(d+288|0,18693);e=v[d+300>>2];v[d+152>>2]=v[d+296>>2];v[d+156>>2]=e;e=v[c+4>>2];v[d+144>>2]=v[c>>2];v[d+148>>2]=e;if(Fc(d+152|0,d+144|0)){a=aa(8)|0;v[22640]=0;c=Q(112,d+320|0,7808)|0;b=v[22640];v[22640]=0;if((b|0)!=1){qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+280>>2]=v[b>>2];v[d+284>>2]=c;c=uc(d+272|0,4500);e=v[d+284>>2];v[d+136>>2]=v[d+280>>2];v[d+140>>2]=e;e=v[c+4>>2];v[d+128>>2]=v[c>>2];v[d+132>>2]=e;i:{if(!Fc(d+136|0,d+128|0)){c=v[b+4>>2];v[d+264>>2]=v[b>>2];v[d+268>>2]=c;c=uc(d+256|0,4482);e=v[d+268>>2];v[d+120>>2]=v[d+264>>2];v[d+124>>2]=e;e=v[c+4>>2];v[d+112>>2]=v[c>>2];v[d+116>>2]=e;if(!Fc(d+120|0,d+112|0)){break i}}e=w[a+60|0]!=0;break e}c=v[b+4>>2];v[d+248>>2]=v[b>>2];v[d+252>>2]=c;c=uc(d+240|0,3997);e=v[d+252>>2];v[d+104>>2]=v[d+248>>2];v[d+108>>2]=e;e=v[c+4>>2];v[d+96>>2]=v[c>>2];v[d+100>>2]=e;j:{if(!Fc(d+104|0,d+96|0)){c=v[b+4>>2];v[d+232>>2]=v[b>>2];v[d+236>>2]=c;c=uc(d+224|0,3978);e=v[d+236>>2];v[d+88>>2]=v[d+232>>2];v[d+92>>2]=e;e=v[c+4>>2];v[d+80>>2]=v[c>>2];v[d+84>>2]=e;if(!Fc(d+88|0,d+80|0)){break j}}e=w[a+61|0]!=0;break e}c=v[b+4>>2];v[d+216>>2]=v[b>>2];v[d+220>>2]=c;c=uc(d+208|0,4081);e=v[d+220>>2];v[d+72>>2]=v[d+216>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Fc(d+72|0,d- -64|0)){e=w[a+62|0]!=0;break e}c=v[b+4>>2];v[d+200>>2]=v[b>>2];v[d+204>>2]=c;c=uc(d+192|0,3153);e=v[d+204>>2];v[d+56>>2]=v[d+200>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Fc(d+56|0,d+48|0)){e=w[a+63|0]!=0;break e}c=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=c;c=uc(d+176|0,4549);e=v[d+188>>2];v[d+40>>2]=v[d+184>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Fc(d+40|0,d+32|0)){e=w[a+64|0]!=0;break e}c=v[b+4>>2];v[d+168>>2]=v[b>>2];v[d+172>>2]=c;b=uc(d+160|0,10754);c=v[d+172>>2];v[d+24>>2]=v[d+168>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;if(!Fc(d+24|0,d+16|0)){break e}e=v[v[a+24>>2]+24668>>2]!=0}gb=d+352|0;return e|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function HP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-16|0;gb=g;h=a+1074376|0;f=B(b,872);d=(h+f|0)+616|0;e=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+f|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((e|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}if(Hj(d)){a=B(b,872)+a|0;u[a+1075764>>1]=e-8;a=a+1075843|0;t[a|0]=w[a|0]|32;break a}if(v[a+480180>>2]!=64){b=B(b,872)+a|0;u[b+1075764>>1]=e<<28>>24;c=x[(e<<1)+40096>>1];v[b+1075696>>2]=c;d=b+1075692|0;if(!v[d>>2]){break a}k=d,l=Yg(a,w[b+1075789|0],e<<28>>24,c),v[k>>2]=l;break a}a=B(b,872)+a|0;b=v[a+1075096>>2];if(!b){break a}v[a+1075696>>2]=v[b+24>>2]+B(e,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075814|0]=c&3;break a}Db(g+8|0,a+1074312|0,21);if(Cb(g+8|0)){t[(B(b,872)+a|0)+1075814|0]=e>>>0<4?e:0;break a}t[(B(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075817|0]=c&3;break a}Db(g+8|0,a+1074312|0,21);if(Cb(g+8|0)){t[(B(b,872)+a|0)+1075817|0]=e>>>0<4?e:0;break a}t[(B(b,872)+a|0)+1075817|0]=c&7;break a;case 4:Db(g+8|0,a+1074312|0,21);if(Cb(g+8|0)){a=B(b,872)+a|0;t[a+1075813|0]=0;t[a+1075820|0]=e>>>0<4?e:0;break a}t[(B(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+e;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(e>>>0<=2){e=x[a+480188>>1];if(e>>>0>255){break a}d=a+1298260|0;i=b+1|0;j=(c&15)-1|0;while(1){c=B(e,872)+a|0;c:{if((i|0)!=x[c+1075778>>1]){break c}d:{e:{switch(j|0){case 0:Bo(a,c+1074992|0);if(!(w[c+1075081|0]&2)){break d}if(!Bd(d)){break d}uk(v[d>>2],e&65535);break d;case 1:f=c+1075080|0;h=v[f>>2];v[f>>2]=h|4096;if(!(h&512)){break d}if(!Bd(d)){break d}uk(v[d>>2],e&65535);break d;default:break e}}v[c+1075688>>2]=0;f=c+1075080|0;h=v[f>>2];v[f>>2]=h|4096;if(!(h&512)){break d}if(!Bd(d)){break d}Mi(v[d>>2],e&65535,1)}h=v[c+1075648>>2];if(!h){break c}f=w[h+34|0];if(!f){break c}f=v[(B(f,160)+a|0)+906140>>2];if(!f){break c}kb[v[v[f>>2]+92>>2]](f,h,w[c+1075789|0]+255|0,0,b)}e=e+1|0;if((e&65535)!=256){continue}break}break a}YA(d,e,a);break a;case 7:if(!(w[a+480209|0]&16)){break a}Nm(a,d,e,4);break a;case 8:b=v[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(e&15){case 0:v[d+88>>2]=v[d+88>>2]&-257;break f;case 1:v[d+692>>2]=128;v[d+88>>2]=v[d+88>>2]|256;break f;case 8:v[d+88>>2]=v[d+88>>2]&-25165825|16777216;break f;case 9:v[d+88>>2]=v[d+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=b&-16385;break f;case 11:v[a+480208>>2]=b|16384;break f;case 12:v[a+480208>>2]=b&-8193;break f;case 13:v[a+480208>>2]=b|8192;break f;case 14:v[d+88>>2]=v[d+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(!v[d+76>>2]|(v[d>>2]|v[d+4>>2])){break h}if(!(k=ce(d+788|0),l=1,m=w[d+88|0]&2,m?k:l)){break h}a=d;b=v[a+76>>2]-1|0;v[a>>2]=-1;v[a+4>>2]=b}v[d+88>>2]=v[d+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,872)+a|0;t[c+1075828|0]=e;Db(g+8|0,a+1074312|0,35);if(Cb(g+8|0)){break a}if(!ce(c+1075780|0)){break a}b=v[(B(b,872)+a|0)+1075068>>2];a=e<<16;if(b>>>0<=a>>>0){break a}v[d+4>>2]=a;break a;case 10:if(!(w[a+480209|0]&16)){break a}lu(a,h,d,e);break a;case 11:i:{if(e){break i}if(v[a+480180>>2]&16777248){e=1;break i}if(v[a+480180>>2]==2){break a}e=0}Db(g+8|0,a+1074312|0,30);c=a;if(Cb(g+8|0)){a=1}else{a=v[a+480180>>2]==2}fA(c,b,e,a);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,872)+a|0)+1075836|0]=e}gb=g+16|0}function moa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-288|0;gb=e;d=e+128|0;g=gb-48|0;gb=g;CC(g+24|0,b);v[22640]=0;Nr(g+16|0,g+24|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)==1){break b}v[22640]=0;b=v[g+20>>2];v[g+8>>2]=v[g+16>>2];v[g+12>>2]=b;R(659,d|0,g+8|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}xc(g+24|0);gb=g+48|0;break a}a=P()|0;O()|0;xc(g+24|0);S(a|0);L()}v[22640]=0;R(630,e+24|0,e+128|0);b=v[22640];v[22640]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((b|0)!=1){v[22640]=0;g=W(142,e+144|0,e+24|0,8)|0;b=v[22640];v[22640]=0;if((b|0)==1){break D}vb(e+24|0);gc(e+128|0);if(c>>>0<2189){break i}v[22640]=0;b=Q(639,e+24|0,g|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break e}v[22640]=0;c=Q(640,e+8|0,7450)|0;d=v[22640];v[22640]=0;if((d|0)==1){break B}v[22640]=0;v[e>>2]=19923012;v[e+4>>2]=0;U(641,b|0,c|0,e|0);d=v[22640];v[22640]=0;if((d|0)==1){break A}Hb(c);t[e|0]=0;v[22640]=0;c=Q(640,e+8|0,8348)|0;d=v[22640];v[22640]=0;if((d|0)==1){break k}d=0;v[22640]=0;W(642,b|0,e|0,c|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break z}Hb(c);if(!w[e|0]){v[22640]=0;d=Dk(a);c=v[22640];v[22640]=0;if((c|0)==1){break y}}f=v[a+4>>2];v[22640]=0;c=Q(640,e+8|0,12943)|0;h=v[22640];v[22640]=0;if((h|0)==1){break x}v[22640]=0;Y(644,b|0,f|0,c|0,d|0);f=v[22640];v[22640]=0;if((f|0)==1){break w}Hb(c);v[22640]=0;c=Q(640,e+8|0,12624)|0;f=v[22640];v[22640]=0;if((f|0)==1){break v}v[22640]=0;Y(645,b|0,a|0,c|0,d|0);d=v[22640];v[22640]=0;if((d|0)==1){break u}Hb(c);v[22640]=0;c=Q(640,e+8|0,12523)|0;d=v[22640];v[22640]=0;if((d|0)==1){break t}v[22640]=0;d=a+484360|0;U(646,b|0,d|0,c|0);f=v[22640];v[22640]=0;if((f|0)==1){break s}Hb(c);v[22640]=0;c=Q(640,e+8|0,29238)|0;f=v[22640];v[22640]=0;if((f|0)==1){break r}v[22640]=0;U(647,b|0,a+484344|0,c|0);f=v[22640];v[22640]=0;if((f|0)==1){break q}Hb(c);v[22640]=0;f=Dk(a);c=v[22640];v[22640]=0;if((c|0)==1){break p}v[22640]=0;c=Q(640,e+8|0,29244)|0;h=v[22640];v[22640]=0;if((h|0)==1){break o}v[22640]=0;Y(648,b|0,d|0,c|0,f|0);d=v[22640];v[22640]=0;if((d|0)==1){break n}Hb(c);if(v[b>>2]&1073741824){v[22640]=0;c=Q(2,e+8|0,13417)|0;d=v[22640];v[22640]=0;if((d|0)==1){break m}v[22640]=0;U(580,a|0,1,c|0);a=v[22640];v[22640]=0;if((a|0)==1){break l}vb(c)}ch(b);break h}a=P()|0;O()|0;break C}a=P()|0;O()|0;vb(e+24|0)}gc(e+128|0);break c}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Hb(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c);break j}a=P()|0;O()|0}ch(b);break d}b=Kb(e+24|0);d=v[a+4>>2];v[22640]=0;f=Dk(a);h=v[22640];v[22640]=0;if((h|0)==1){break g}v[22640]=0;d=ca(649,d|0,g|0,b|0,f|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break g}E:{if((d|0)!=1){v[22640]=0;c=Q(2,e+8|0,13723)|0;d=v[22640];v[22640]=0;F:{if((d|0)!=1){v[22640]=0;U(580,a|0,1,c|0);a=v[22640];v[22640]=0;if((a|0)==1){break F}vb(c);break E}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c);break f}v[22640]=0;d=Dk(a);f=v[22640];v[22640]=0;if((f|0)==1){break g}v[22640]=0;Y(650,g|0,a|0,d|0,c>>>0<2188|0);a=v[22640];v[22640]=0;if((a|0)==1){break g}}vb(b)}tf(g);gb=e+288|0;return}a=P()|0;O()|0}vb(b);break d}a=P()|0;O()|0}tf(g)}S(a|0);L()}function tg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=gb-112|0;gb=k;l=h;o=i&2147483647;m=c-(b>>>0<1)|0;j=b-1|0;q=(j|0)==-1&(m|0)==-1;r=d;p=(c|0)==(m|0)&b>>>0>j>>>0|c>>>0>m>>>0;n=d+p|0;m=e&2147483647;j=m;j=n>>>0<p>>>0?j+1|0:j;p=n-1|0;a:{b:{j=j-(n>>>0<1)|0;if(!((p|0)==-1&(j|0)==2147418111?q:j>>>0>2147418111)){j=f;n=g-(j>>>0<1)|0;j=j-1|0;q=(j|0)!=-1|(n|0)!=-1;p=(g|0)==(n|0)&f>>>0>j>>>0|g>>>0>n>>>0;n=p+l|0;j=o;j=n>>>0<p>>>0?j+1|0:j;p=n;n=n-1|0;j=j-(p>>>0<1)|0;if((n|0)==-1&(j|0)==2147418111?q:(j|0)==2147418111&(n|0)!=-1|j>>>0<2147418111){break b}}if(!(!r&(m|0)==2147418112?!(b|c):m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!l&(o|0)==2147418112?!(f|g):o>>>0<2147418112)){i=i|32768;break a}if(!(b|r|(m^2147418112|c))){j=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:j;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|l|(o^2147418112|g))){break a}if(!(b|r|(c|m))){if(f|l|(g|o)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|l|(g|o)){break b}f=b;g=c;h=d;i=e;break a}q=(l|0)==(r|0)&(m|0)==(o|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:(m|0)==(o|0)&l>>>0>r>>>0|m>>>0<o>>>0;j=q;n=j?f:b;o=j?g:c;l=j?i:e;r=l;m=j?h:d;j=l&65535;i=q?e:i;e=i;h=q?d:h;p=i>>>16&32767;l=l>>>16&32767;if(!l){d=!(j|m);i=d<<6;l=E(d?n:m)+32|0;d=E(d?o:j);d=i+((d|0)==32?l:d)|0;If(k+96|0,n,o,m,j,d-15|0);m=v[k+104>>2];n=v[k+96>>2];o=v[k+100>>2];l=16-d|0;j=v[k+108>>2]}f=q?b:f;g=q?c:g;i=e&65535;if(!p){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;If(k+80|0,f,g,h,i,b-15|0);p=16-b|0;h=v[k+88>>2];i=v[k+92>>2];g=v[k+84>>2];f=v[k+80>>2]}b=h;c=i<<3|b>>>29;h=b<<3|g>>>29;i=c|524288;b=m;d=j<<3|b>>>29;m=b<<3|o>>>29;s=d;q=e^r;b=f;j=g<<3|b>>>29;b=b<<3;c=j;d=l-p|0;e=b;c:{if(!d){break c}if(d>>>0>127){h=0;i=0;j=0;e=1;break c}If(k- -64|0,b,c,h,i,128-d|0);lm(k+48|0,b,c,h,i,d);h=v[k+56>>2];i=v[k+60>>2];j=v[k+52>>2];e=v[k+48>>2]|((v[k+64>>2]|v[k+72>>2])!=0|(v[k+68>>2]|v[k+76>>2])!=0)}f=j;d=m;p=s|524288;b=n;j=o<<3|b>>>29;c=b<<3;d:{if((q|0)<-1?1:(q|0)<=-1){o=e;b=c-e|0;m=h;n=d-h|0;e=(f|0)==(j|0)&c>>>0<e>>>0|f>>>0>j>>>0;h=n-e|0;c=j-((c>>>0<o>>>0)+f|0)|0;i=(p-((d>>>0<m>>>0)+i|0)|0)-(e>>>0>n>>>0)|0;if(!(b|h|(c|i))){f=0;g=0;h=0;i=0;break a}if(i>>>0>524287){break d}f=b;d=!(h|i);e=d<<6;g=E(d?b:h)+32|0;b=E(d?c:i);b=e+((b|0)==32?g:b)|0;b=b-12|0;If(k+32|0,f,c,h,i,b);l=l-b|0;h=v[k+40>>2];i=v[k+44>>2];b=v[k+32>>2];c=v[k+36>>2];break d}b=c;g=b+e|0;c=f+j|0;c=b>>>0>g>>>0?c+1|0:c;b=g;g=(c|0)==(f|0)&e>>>0>b>>>0|c>>>0<f>>>0;e=d;f=d+h|0;d=i+p|0;d=e>>>0>f>>>0?d+1|0:d;e=g+f|0;h=e;i=h>>>0<f>>>0?d+1|0:d;if(!(i&1048576)){break d}b=b&1|((c&1)<<31|b>>>1);c=h<<31|c>>>1;l=l+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}o=0;r=r&-2147483648;if((l|0)>=32767){h=o;i=r|2147418112;f=0;g=0;break a}if((l|0)>=1){e=l}else{If(k+16|0,b,c,h,i,l+127|0);lm(k,b,c,h,i,1-l|0);b=v[k>>2]|((v[k+16>>2]|v[k+24>>2])!=0|(v[k+20>>2]|v[k+28>>2])!=0);c=v[k+4>>2];h=v[k+8>>2];i=v[k+12>>2];e=0}j=(c&7)<<29|b>>>3;l=b&7;b=j+(l>>>0>4)|0;d=h<<29|c>>>3;c=b>>>0<j>>>0?d+1|0:d;f=b;g=c;b=(d|0)==(c|0)&b>>>0<j>>>0|c>>>0<d>>>0;d=o|((i&7)<<29|h>>>3);b=b+d|0;j=r|(i>>>3&65535|e<<16);h=b;i=b>>>0<d>>>0?j+1|0:j;e:{if((l|0)==4){j=i;c=0;d=g+c|0;e=f&1;b=f+e|0;d=b>>>0<f>>>0?d+1|0:d;f=b;g=d;c=(c|0)==(d|0)&b>>>0<e>>>0|c>>>0>d>>>0;b=c+h|0;h=b;i=b>>>0<c>>>0?j+1|0:j;break e}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;gb=k+112|0}function o_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=gb-160|0;gb=d;vc(b);ls(a);f=gb-32|0;gb=f;h=d+120|0;hF(f+24|0,h);g=xb(f+24|0);e=v[f+28>>2];i=v[f+24>>2];v[f+8>>2]=i;v[f+12>>2]=e;v[f>>2]=i;v[f+4>>2]=e;e=b;fc(f+16|0,e,f);i=xb(f+16|0);if((i|0)==(g|0)){Yb(e,xb(f+24|0))}gb=f+32|0;e=(g|0)==(i|0);if(!e){gF(h)}a:{if(!e){break a}if(!dO(d+120|0)){break a}f=b;l=Lf(10485);if(l){q=v[f+8>>2];if(Xc(f,w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))){b:{if(!(w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))){break b}h=l?0:-1;while(1){if(!Pb(f,5)){break b}c:{if((w[d+124|0]|w[d+125|0]<<8)>>>0>=64){if((Ii(f)|0)<1){break c}}e=de(f);d:{if(e){g=1;j=0;while(1){r=tq(e<<24>>24);m=j>>>0>=l>>>0;i=m&g;e=i;e:{if(m){break e}e=i;if(!(g&1)){break e}e=w[j+10485|0]==(r&255)}g=e;j=j+1|0;e=de(f);if(e){continue}break}e=(j|0)==(l|0)&g;break d}e=h}Yb(f,4);n=e&1?1:n}o=o+1|0;if(o>>>0<(w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))>>>0){continue}break}}j=n&1}Xc(f,q)}if(!j){break a}if(!Pb(b,cO(d+120|0))){break a}if(!c){k=1;break a}f=gb-16|0;gb=f;c=b;e=d+120|0;Xc(c,w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24));g=nc(d+104|0);h=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24);v[22640]=0;R(1427,g|0,h|0);h=v[22640];v[22640]=0;f:{g:{h:{if((h|0)!=1){i:{j:{k:{if(!(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))){break k}while(1){v[22640]=0;h=Q(228,c|0,5)|0;i=v[22640];v[22640]=0;if((i|0)==1){break h}if(!h){break k}h=w[e+4|0]|w[e+5|0]<<8;v[22640]=0;U(1428,f|0,c|0,h|0);h=v[22640];v[22640]=0;if((h|0)==1){break j}v[22640]=0;R(1429,g|0,f|0);h=v[22640];v[22640]=0;if((h|0)==1){break i}vb(f);p=p+1|0;if(p>>>0<(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0){continue}break}}gb=f+16|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(f);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0}vd(g);S(a|0);L()}v[22640]=0;Y(305,d+88|0,b|0,d+120|0,d+104|0);c=v[22640];v[22640]=0;l:{m:{if((c|0)!=1){c=w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24);v[22640]=0;Q(227,b|0,c|0)|0;c=v[22640];v[22640]=0;n:{if((c|0)!=1){if(!(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))){break l}e=d+36|0;o:{p:{q:{r:{while(1){v[22640]=0;c=Q(228,b|0,8)|0;f=v[22640];v[22640]=0;s:{if((f|0)!=1){if(c){break s}break l}b=P()|0;O()|0;break n}v[22640]=0;ka(306,d- -64|0,b|0,d+120|0,d+88|0,d+104|0,10485);c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;f=d- -64|0;c=T(307,f|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break r}if(c){v[22640]=0;c=T(308,d+24|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break q}g=v[d+84>>2];t:{if((g|0)<0){break t}if(Cc(d+104|0)>>>0<=g>>>0){break t}g=xd(d+104|0,v[d+84>>2]);v[22640]=0;U(13,d+8|0,2,g|0);g=v[22640];v[22640]=0;if((g|0)==1){break p}Eb(d+24|0,d+8|0);vb(d+8|0)}uw(e,f);v[22640]=0;R(309,a|0,c|0);f=v[22640];v[22640]=0;if((f|0)==1){break p}zw(c)}yb(d- -64|0);k=k+1|0;if(k>>>0<(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))>>>0){continue}break l}break}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;zw(c)}yb(d- -64|0);break n}b=P()|0;O()|0}Lc(d+88|0);break m}b=P()|0;O()|0}vd(d+104|0);S(b|0);L()}k=$c(a)^1;Lc(d+88|0);vd(d+104|0)}gb=d+160|0;return k|0}function Xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-176|0;gb=e;se(e+160|0,b);m=a;k=c;g=d;i=gb-48|0;gb=i;v[i+44>>2]=0;f=b;Bk(f,i+44|0);a:{b:{c:{if(v[i+44>>2]!=(An(11439)|0)){break c}v[i+40>>2]=0;h=gb-16|0;gb=h;v[h+12>>2]=0;kj(h,f,h+12|0,4);xb(h);v[h>>2]=v[h+12>>2];v[i+40>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);gb=h+16|0;h=-1;j=v[i+40>>2];if(j-1>>>0>1){break c}d:{e:{f:{if((j|0)<=1){j=Kb(i+24|0);v[22640]=0;l=W(672,f|0,j|0,256)|0;n=v[22640];v[22640]=0;if((n|0)==1){break b}if(!l){break e}v[22640]=0;U(13,i+8|0,g|0,j|0);l=v[22640];v[22640]=0;if((l|0)!=1){break f}break b}j=Kb(i+24|0);v[22640]=0;l=W(674,f|0,j|0,255)|0;n=v[22640];v[22640]=0;if((n|0)==1){break b}if(!l){break d}v[22640]=0;U(13,i+8|0,g|0,j|0);l=v[22640];v[22640]=0;if((l|0)==1){break b}}Eb(k,i+8|0);vb(i+8|0);vb(j);u[i+8>>1]=0;Xf(f,i+8|0);v[i+24>>2]=0;Bk(f,i+24|0);k=v[i+24>>2];if(k>>>0>50){break c}g:{if(!k){break g}k=1;while(1){if(!fN(m,f,g)){break c}if(y[i+24>>2]<=k>>>0){break g}k=k+1|0;continue}}v[i+24>>2]=0;Bk(f,i+24|0);h=v[i+24>>2]==(An(11477)|0)?1:-1;break c}vb(j);break c}vb(j)}gb=i+48|0;f=h;break a}a=P()|0;O()|0;vb(j);S(a|0);L()}h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(!f){sp(v[v[b>>2]-12>>2]+b|0,0);f=v[e+172>>2];v[e+8>>2]=v[e+168>>2];v[e+12>>2]=f;f=v[e+164>>2];v[e>>2]=v[e+160>>2];v[e+4>>2]=f;gk(b,e);b=wm(e+56|0,b);v[22640]=0;f=Q(640,e+40|0,11546)|0;g=v[22640];v[22640]=0;if((g|0)==1){break i}v[22640]=0;v[e+32>>2]=3;v[e+36>>2]=0;U(641,b|0,f|0,e+32|0);g=v[22640];v[22640]=0;if((g|0)==1){break j}Hb(f);t[e+31|0]=0;v[22640]=0;f=Q(640,e+40|0,11986)|0;g=v[22640];v[22640]=0;if((g|0)==1){break k}v[22640]=0;W(642,b|0,e+31|0,f|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break l}Hb(f);v[22640]=0;f=w[e+31|0];g=T(1524,b|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break m}v[22640]=0;h=T(1525,b|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break n}v[e+32>>2]=h;v[e+24>>2]=g;if(Gb(e+24|0,e+32|0)){f=f?0:d;while(1){u[e+22>>1]=65535;v[22640]=0;d=Q(640,e+40|0,12943)|0;g=v[22640];v[22640]=0;if((g|0)==1){break q}v[22640]=0;g=W(1526,b|0,e+24|0,d|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break p}Hb(d);t:{if(!g){v[22640]=0;Y(1527,b|0,e+24|0,c|0,f|0);d=v[22640];v[22640]=0;if((d|0)==1){break o}break t}v[22640]=0;d=Q(640,e+40|0,12624)|0;g=v[22640];v[22640]=0;u:{v:{if((g|0)!=1){v[22640]=0;g=W(1526,b|0,e+24|0,d|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break v}Hb(d);if(g){break u}v[22640]=0;U(1528,b|0,e+24|0,e+22|0);d=v[22640];v[22640]=0;if((d|0)!=1){break t}break o}a=P()|0;O()|0;break h}a=P()|0;O()|0;Hb(d);break h}v[22640]=0;d=Q(640,e+40|0,12523)|0;g=v[22640];v[22640]=0;if((g|0)==1){break s}v[22640]=0;g=W(1526,b|0,e+24|0,d|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break r}Hb(d);if(g){break t}v[22640]=0;Y(1529,b|0,e+24|0,a|0,f|0);d=v[22640];v[22640]=0;if((d|0)==1){break o}}Wo(e+24|0);if(Gb(e+24|0,e+32|0)){continue}break}}a=v[b>>2];ch(b);f=a&1073741824?-1:1}gb=e+176|0;return f|0}a=P()|0;O()|0;break h}a=P()|0;O()|0;Hb(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Hb(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Hb(f);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Hb(f);break h}a=P()|0;O()|0}ch(b);S(a|0);L()}function L1(){var a=0,b=0,c=0;Ud(465568);v[116392]=83432;v[22640]=0;X(2504);a=v[22640];v[22640]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22640]=0;Q(112,465760,11550)|0;a=v[22640];v[22640]=0;if((a|0)==1){break e}Nd(465584);Ud(465248);v[116312]=84756;v[22640]=0;X(2505);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465256);v[116314]=84788;v[22640]=0;X(2506);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465264);v[116316]=83452;t[465276]=0;v[116318]=0;b=465272,c=Yp(),v[b>>2]=c;v[22640]=0;X(2507);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465280);v[116320]=83936;v[22640]=0;X(2508);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465288);v[116322]=84084;v[22640]=0;X(2509);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;X(2510);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;X(2511);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465312);v[116328]=84232;v[22640]=0;X(2512);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465320);v[116330]=84348;v[22640]=0;X(2513);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465328);u[232668]=11310;v[116332]=83552;Kb(465340);v[22640]=0;X(2514);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465360);v[116342]=46;v[116343]=44;v[116340]=83592;Kb(465376);v[22640]=0;X(2515);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465392);v[116348]=84820;v[22640]=0;X(2516);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465400);v[116350]=85064;v[22640]=0;X(2517);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465408);v[116352]=85276;v[22640]=0;X(2518);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465416);v[116354]=85508;v[22640]=0;X(2519);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465424);v[116356]=86492;v[22640]=0;X(2520);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465432);v[116358]=86640;v[22640]=0;X(2521);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465440);v[116360]=86756;v[22640]=0;X(2522);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465448);v[116362]=86872;v[22640]=0;X(2523);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465456);v[116364]=86988;v[22640]=0;X(2524);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465464);v[116366]=87152;v[22640]=0;X(2525);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465472);v[116368]=87316;v[22640]=0;X(2526);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465480);v[116370]=87480;v[22640]=0;X(2527);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465488);v[116374]=88736;v[116374]=85756;v[116372]=85708;v[22640]=0;X(2528);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465504);v[116378]=88772;v[116378]=86020;v[116376]=85972;v[22640]=0;X(2529);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;X(2530);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;X(2531);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;X(2532);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;X(2533);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465552);v[116388]=87644;v[22640]=0;X(2534);a=v[22640];v[22640]=0;if((a|0)==1){break d}Ud(465560);v[116390]=87764;v[22640]=0;X(2535);a=v[22640];v[22640]=0;if((a|0)==1){break d}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(465760)}ex(465584)}S(a|0);L()}v[115990]=465568}function kO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if(b){h=a+327720|0;c=gb-400|0;gb=c;SR(c+384|0,8);v[22640]=0;ta(1117,c+368|0,9);g=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((g|0)!=1){v[22640]=0;g=Q(1118,c+352|0,14)|0;e=v[22640];v[22640]=0;if((e|0)==1){break l}v[22640]=0;R(1119,c+384|0,g|0);e=v[22640];v[22640]=0;if((e|0)==1){break k}v[22640]=0;R(1119,c+368|0,g|0);e=v[22640];v[22640]=0;if((e|0)==1){break k}RR(c+280|0,4900);RR(c+208|0,32e3);OR(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[22640]=0;e=Q(1120,c+104|0,c+384|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break j}vu(c+120|0,c+280|0,e);Jf(e);v[22640]=0;e=Q(1120,c+72|0,c+368|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break i}vu(c+88|0,c+208|0,e);Jf(e);v[22640]=0;e=Q(1120,c+40|0,c+120|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break h}vu(c+56|0,c+136|0,e);Jf(e);v[22640]=0;e=Q(1120,c+8|0,c+88|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break g}vu(c+24|0,c+136|0,e);Jf(e);Uq(c+120|0);Uq(c+56|0);Uq(c+88|0);Uq(c+24|0);Uq(c+368|0);Tq(c+120|0,Ej(h,0));Tq(c+56|0,Ej(h,1));Tq(c+88|0,Ej(h,2));Tq(c+24|0,Ej(h,3));Tq(c+368|0,Ej(h,4));Jf(c+24|0);Jf(c+56|0);Jf(c+88|0);Jf(c+120|0);Sq(g);Jf(c+368|0);Jf(c+384|0);gb=c+400|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;Jf(c+56|0)}Jf(c+88|0)}Jf(c+120|0)}Sq(g)}Jf(c+368|0)}Jf(c+384|0);S(a|0);L()}uz(a+131112|0,9.6377,.97);uz(a+196648|0,8.5,.5);uz(a+262184|0,2.7625,.425)}g=a+368680|0;if(!(r=0,s=jO(g,a),t=b,t?r:s)){i=a+24|0;o=A[a+8>>3];c=w[a+16|0];e=gb+-64|0;gb=e;while(1){p=+(k-4096|0)*.0001220703125;l=0;b=0;while(1){j=o;h=c;f=1;m=e+(b<<3)|0;d=+(b|0)-p;n=d+-3.5;if(!(D(n)<1e-8)){m:{n:{switch(h|0){case 0:f=.5-Ke(d*.8975979010256552)*.5;break m;case 1:f=Ke(d*.8975979010256552)*-.46+.54;break m;case 2:f=Ke(d*1.7951958020513104);f=Ke(d*.8975979010256552)*-.5+.42+f*.08;break m;case 3:f=Ke(d*1.7951958020513104);f=Ke(d*.8975979010256552)*-.49364+.44959+f*.05677;break m;case 4:f=Ke(d*1.7951958020513104);f=Ke(d*.8975979010256552)*-.49755+.42323+f*.07922;break m;case 5:f=Ke(d*1.7951958020513104);f=Ke(d*.8975979010256552)*-.48829+.35875+f*.14128+Ke(d*2.6927937030769655)*-.01168;break m;case 6:f=Ke(d*1.7951958020513104);f=Ke(d*.8975979010256552)*-.49703+.40217+f*.09392+Ke(d*2.6927937030769655)*-.00183;break m;case 7:break n;default:break m}}f=Ke(d*1.7951958020513104);f=Ke(d*.8975979010256552)*-.49804+.40243+f*.09831+Ke(d*2.6927937030769655)*-.00122}d=n*3.141592653589793;j=pi(d*j)/d}j=j*f;A[m>>3]=j;l=j+l;b=b+1|0;if((b|0)!=8){continue}break}j=1/l;m=k<<3;b=0;while(1){q=i+(b+m<<1)|0;d=G(F(H(A[e+(b<<3)>>3]*32768*j+.5),32768),-32768);o:{if(D(d)<2147483648){h=~~d;break o}h=-2147483648}u[q>>1]=h;b=b+1|0;if((b|0)!=8){continue}break}k=k+1|0;if((k|0)!=8193){continue}break}gb=e- -64|0;b=v[a+20>>2];v[g+16>>2]=v[a+16>>2];v[g+20>>2]=b;b=v[a+12>>2];v[g+8>>2]=v[a+8>>2];v[g+12>>2]=b;b=v[a+4>>2];v[g>>2]=v[a>>2];v[g+4>>2]=b}}function rka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;f=gb-4144|0;gb=f;a:{b:{if(!Ib(w[a+14|0]|w[a+15|0]<<8)){break b}h=a;if(Ib(w[a+14|0]|w[a+15|0]<<8)>>>0>20|x[b+480190>>1]<=w[a+23|0]){break b}td(d,32);u[d+34>>1]=1;a=a+20|0;pd(f+24|0,a,a+80|0);OT(f+4136|0,f+24|0,Ib(w[h+14|0]|w[h+15|0]<<8));a=Sl(b,w[Mb(f+4136|0,0)+3|0]+1|0);v[f+24>>2]=1;n=1/+y[Jc(a+24|0,f+24|0)>>2];g=f+24|0;i=f+4136|0;if(c){a=cr(f+4136|0)}else{a=1}OT(g,i,a);a=v[f+24>>2];g=v[f+28>>2];if((a|0)!=(g|0)){while(1){if(!(t[a+1|0]<0|x[b+480190>>1]<=w[a+3|0])){i=Sl(b,w[a+3|0]+1|0);j=v[i>>2];k=t[a+1|0];l=Mb(f+4136|0,0);s=d,z=xh(n*+(j>>>0)*+y[i+24>>2]*Ag(+(k-t[l+1|0]|0)*-.08333333333333333))+v[d>>2]|0,v[s>>2]=z}a=a+4|0;if((g|0)!=(a|0)){continue}break}}q=_m(d);if(q){j=(e<<12>>>0)/1e4|0;e=cr(f+4136|0);a=f+4120|0;i=mh(a);c:{if(!e){break c}v[22640]=0;R(955,a|0,e|0);g=v[22640];v[22640]=0;if((g|0)!=1){v[22640]=0;R(956,a|0,e|0);e=v[22640];v[22640]=0;if((e|0)!=1){break c}}break a}i=a;d:{if(!cr(f+4136|0)){break d}a=0;while(1){e:{e=Mb(f+4136|0,a);g=NT(i,a);if(!(t[e+1|0]<0|x[b+480190>>1]<=w[e+3|0])){if(w[e+2|0]<=241|w[e+2|0]>=248){m=0}else{m=+t[w[e+2|0]+33486|0]}l=Sl(b,w[e+3|0]+1|0);e=t[e+1|0];k=Mb(f+4136|0,0);o=v[l+24>>2];k=t[k+1|0];v[22640]=0;p=Na(950,+(n*+(o>>>0)*Ag(+(e-k|0)*.08333333333333333+m*.010416666666666666)))|0;e=O()|0;o=p|0;k=v[22640];v[22640]=0;p=g;f:{g:{if((k|0)!=1){v[g+8>>2]=o;v[g+12>>2]=e;v[g+16>>2]=v[l+20>>2];e=v[l>>2];v[g+76>>2]=e;v[g+88>>2]=x[l+34>>1]&1023;if(!c){break g}v[g+664>>2]=r;m=zB(g+8|0);v[22640]=0;e=xh(+(e>>>0)/m);l=v[22640];v[22640]=0;if((l|0)==1){break e}r=e+r|0;e=j;break f}break a}e=(j>>>0)/(Ib(w[h+14|0]|w[h+15|0]<<8)>>>0)|0}v[p+20>>2]=e;v[g+24>>2]=e}a=a+1|0;if(cr(f+4136|0)>>>0>a>>>0){continue}break d}break}break a}a=v[d>>2];if(a){k=b+24648|0;c=0;while(1){Qb(f+24|0,0,4096);v[f+16>>2]=512;v[22640]=0;v[f+8>>2]=a-c;a=Fb(f+16|0,f+8|0);b=v[22640];v[22640]=0;h:{i:{if((b|0)!=1){g=v[a>>2];s=f,z=Sb(i),v[s+16>>2]=z;s=f,z=Wb(i),v[s+8>>2]=z;if(Gb(f+16|0,f+8|0)){break i}break h}break a}while(1){j:{a=v[f+16>>2];if(!v[a+16>>2]){break j}b=v[a+664>>2];if(b>>>0>=g>>>0){v[a+664>>2]=b-g;break j}e=v[a+88>>2];v[f+4>>2]=g-b;b=v[a+76>>2];n=zB(a);m=zB(a+8|0);v[22640]=0;b=xh((+(b>>>0)-n)/m);h=v[22640];v[22640]=0;if((h|0)==1){break a}v[22640]=0;v[f>>2]=b;b=Fb(f+4|0,f);h=v[22640];v[22640]=0;if((h|0)==1){break a}b=v[b>>2];h=v[a+664>>2];v[22640]=0;Y(v[((e&1|(e&64?18:16))<<2)+34064>>2],a|0,k|0,(f+24|0)+(h<<3)|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){v[a+664>>2]=0;if(y[a+76>>2]>y[a+4>>2]){break j}v[a+16>>2]=0;break j}break a}v[f+16>>2]=v[f+16>>2]+872;if(Gb(f+16|0,f+8|0)){continue}break}}e=v[d+20>>2]+(c<<1)|0;h=f+24|0;b=gb-16|0;gb=b;v[b+12>>2]=g;tc(b+12|0,512);a=v[b+12>>2];v[b+12>>2]=a-1;if(a){while(1){a=e;j=ed(v[h>>2]+2048|0,12);if((j|0)<-32768){j=-32768}u[a>>1]=(j|0)>32767?32767:j;a=v[b+12>>2];v[b+12>>2]=a-1;h=h+8|0;e=e+2|0;if(a){continue}break}}gb=b+16|0;a=v[d>>2];c=c+g|0;if(a>>>0>c>>>0){continue}break}}HT(i)}i=(q|0)!=0}gb=f+4144|0;return i|0}a=P()|0;O()|0;HT(i);S(a|0);L()}function cM(a){var b=0,c=C(0),d=C(0),e=0,f=C(0),g=0,h=C(0),i=C(0),j=0,k=0,l=0,m=C(0),n=C(0),o=0,p=C(0),q=0,r=C(0),s=C(0),u=0,w=0,x=C(0);k=gb-16|0;gb=k;u=a,w=Gj(C(z[a+4256>>2]*C(3))),v[u+4264>>2]=w;u=a,x=C(uf(v[a+16>>2])>>>((v[a+4264>>2]>>>1^-1)&1)>>>0),z[u+4268>>2]=x;z[a+4272>>2]=C(z[a+4244>>2]*C(100))*C(.0061803399585187435);u=k,x=me(C(10),C(C(bM(a)+C(C(z[a+4228>>2]*C(11e3))+C(-1e4)))*C(.0005000000237487257))),z[u+12>>2]=x;v[k+8>>2]=1065353216;u=a,x=C(z[Cm(k+12|0,k+8|0)>>2]*C(.7609999775886536)),z[u+4280>>2]=x;e=a;c=me(C(10),C(C(C(z[a+4212>>2]*C(1e4))+C(-1e4))*C(.0010000000474974513)));if(c!=C(1)){d=Rp(C(C(aM(a)*C(6.2831854820251465))/z[a+4268>>2]));i=C(c+c);f=C(c*c);c=C(c*C(8));c=Fo(C(C(C(C(d*i)+C(-2))+C(K(C(C(C(f*C(-4))+c)+C(C(C(C(f*C(4))*d)-c)*d)))))/C(i+C(-2))),C(0),C(1))}else{c=C(0)}z[e+4276>>2]=c;j=gb-16|0;gb=j;e=a;c=z[a+4268>>2];d=C(z[a+4232>>2]*C(.30000001192092896));z[j+12>>2]=z[a+4240>>2]*C(.10000000149011612);v[j+8>>2]=1000593162;b=a;i=z[Qy(j+12|0,j+8|0)>>2];f=C(c*C(C(d+C(.007000000216066837))+i));a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}v[b+4352>>2]=g;b=1;while(1){l=((B(b&1,24)+e|0)+(b<<1&-4)|0)+4352|0;f=C(C(C(z[(b<<2)+53056>>2]*i)+d)*c);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}v[l>>2]=g;b=b+1|0;if((b|0)!=12){continue}break}z[j+12>>2]=C(C(z[e+4248>>2]*C(100))*C(.009091000072658062))+C(.09091000258922577);v[j+8>>2]=1065353216;d=C(z[Cm(j+12|0,j+8|0)>>2]*c);b=0;while(1){g=(b<<2)+e|0;q=g+4316|0;i=C(me(C(.9300000071525574),C(o|0))*d);f=C(i*C(.07500000298023224));c:{if(C(D(f))<C(2147483648)){l=~~f;break c}l=-2147483648}v[q>>2]=l;l=g+4292|0;i=C(i*C(.06700000166893005));d:{if(C(D(i))<C(2147483648)){g=~~i;break d}g=-2147483648}v[l>>2]=g;b=b+1|0;if((b|0)!=6){o=b+o|0;continue}break}g=e+4348|0;d=C(c*C(.0035299998708069324));e:{if(C(D(d))<C(2147483648)){b=~~d;break e}b=-2147483648}v[g>>2]=b;g=e+4344|0;d=C(c*C(.0032500000670552254));f:{if(C(D(d))<C(2147483648)){b=~~d;break f}b=-2147483648}v[g>>2]=b;g=e+4340|0;c=C(c*C(.009999999776482582));g:{if(C(D(c))<C(2147483648)){b=~~c;break g}b=-2147483648}v[g>>2]=b;b=0;while(1){dM((B(b,24)+e|0)+4504|0,v[((b<<2)+e|0)+4292>>2]);b=b+1|0;if((b|0)!=15){continue}break}gb=j+16|0;b=gb-16|0;gb=b;d=ph(a,5);f=ph(a,11);c=C(d*ph(a,4));i=C(C(c*C(.03999999910593033))+C(d*C(.02250000089406967)));d=C(f*ph(a,10));f=C(C(d*C(.03999999910593033))+C(f*C(.02250000089406967)));if(t[a+4264|0]&1){h=ph(e,3);m=ph(e,9);h=C(h*c);c=C(ph(e,2)*h);i=C(C(C(h*C(.12250000238418579))+i)+C(c*C(.1444000005722046)));h=C(m*d);d=C(ph(e,8)*h);f=C(C(C(h*C(.12250000238418579))+f)+C(d*C(.1444000005722046)))}ph(e,12);h=z[e+4496>>2];m=ph(e,1);n=ph(e,7);r=ph(e,0);s=ph(e,6);u=b,x=me(C(10),C(C(bM(e)+C(C(z[e+4236>>2]*C(12e3))+C(-1e4)))*C(.0005000000237487257))),z[u+12>>2]=x;v[b+8>>2]=1065353216;p=z[Cm(b+12|0,b+8|0)>>2];h=C(h*h);d=C(n*C(h*d));n=C(s*d);c=C(m*C(h*c));h=C(r*c);m=C(C(C(n+h)*C(-.5))+C(1));z[e+4284>>2]=p*C(K(C(m/C(C(C(h+d)*C(.1444000005722046))+i))));z[e+4288>>2]=p*C(K(C(m/C(C(C(n+c)*C(.1444000005722046))+f))));gb=b+16|0;t[a+5046|0]=0;gb=k+16|0}function Zb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[116453]){break a}a=a+b|0;if(v[116454]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=465796,j=v[116449]&qqa(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+466100|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=465800,j=v[116450]&qqa(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[116451]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[116455]==(f|0)){v[116455]=d;a=v[116452]+a|0;v[116452]=a;v[d+4>>2]=a|1;if(v[116454]!=(d|0)){break a}v[116451]=0;v[116454]=0;return}if(v[116454]==(f|0)){v[116454]=d;a=v[116451]+a|0;v[116451]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=465796,j=v[116449]&qqa(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+466100|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=465800,j=v[116450]&qqa(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[116454]!=(d|0)){break f}v[116451]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+465836|0;c=v[116449];a=1<<a;k:{if(!(c&a)){v[116449]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;v[d+16>>2]=0;v[d+20>>2]=0;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;g=(e<<2)+466100|0;l:{m:{c=v[116450];b=1<<e;n:{if(!(c&b)){v[116450]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[116457]-1|0;v[116457]=a?a:-1}}function dA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0;f=gb-16|0;gb=f;i=B(b,872)+a|0;l=i+1075800|0;j=w[l|0];k=a+1074312|0;Db(f+8|0,k,23);g=c&15;a:{b:{c:{d:{e:{f:{if(Cb(f+8|0)){if(!(v[a+1074392>>2]|!w[(B(b,872)+a|0)+1075780|0])){t[l|0]=g;break f}e=w[l|0];if(e){h=e-1|0;t[l|0]=h;e=0;if(h&255){break c}}t[l|0]=g;e=1;break c}Db(f+8|0,k,52);h=c&256;if(!(!Cb(f+8|0)|!h)){g:{if(!(w[a+480209|0]&16)){break g}e=B(b,872)+a|0;if(w[e+1075781|0]){j=LC(e+1075780|0)?1:j}if(w[e+1075782|0]!=1){break g}if(w[(B(b,872)+a|0)+1075784|0]){break b}}e=0;if((j&255)>>>0<g>>>0){break c}if(w[a+480209|0]&16){if(ce((B(b,872)+a|0)+1075780|0)){break c}}j=0;e=1;break c}if(v[a+480180>>2]&16777250){e=j&255;if(e){e=(e>>>0)%((g?g:1)>>>0)|0}else{e=1}e=!e;j=j+1|0;break c}if(v[a+480180>>2]!=1){break d}e=y[a+1074392>>2]%y[a+1074416>>2]|0;if(!e){if(ce((B(b,872)+a|0)+1075780|0)){break a}}if(g){break e}}e=0;break c}e=!((e>>>0)%(g>>>0)|0);break c}if(v[a+480180>>2]==16){e=v[a+1074392>>2]==(g|0)&(g|0)!=0;break c}h:{i:{j:{k:{l:{if(h){e=B(b,872)+a|0;if(w[e+1075782|0]==1){g=(w[e+1075785|0]>15)+g|0}g=g?g:1;break l}if(w[a+480209|0]&16){break i}g=g?g:1;if(v[a+1074416>>2]){break k}}e=0;break j}e=!(y[a+1074392>>2]%(g>>>0)|0)}j=j+1|0;break h}j=v[a+480180>>2]&1048580?0:j}if(!(!(w[(B(b,872)+a|0)+1075780|0]|!h?v[a+1074392>>2]:1)|(j&255)<(g|0))){e=1}Db(f+8|0,k,52);if(!Cb(f+8|0)|c){break c}e=!v[a+1074392>>2]}g=i+1074992|0;i=(B(b,872)+a|0)+1075068|0;m:{if(v[i>>2]){break m}Db(f+8|0,k,38);if(!Cb(f+8|0)){break m}if(!rk(g)){break a}}Db(f+8|0,k,106);if(u=0,z=Cb(f+8|0),A=v[(B(b,872)+a|0)+1075688>>2],A?u:z){break a}if(e){h=B(b,872)+a|0;o=h+1075680|0;v[f+4>>2]=v[o>>2];e=c>>>4&15;if(e){Db(f+8|0,k,52);n:{if(u=Cb(f+8|0),z=0,A=w[(B(b,872)+a|0)+1075782|0]==1,A?u:z){break n}if(!(16191>>>e&1)){v[f+4>>2]=B(v[f+4>>2],t[e+40512|0])>>4;break n}v[f+4>>2]=v[f+4>>2]+(t[e+40528|0]<<2)}Qd(f+4|0,0,256);e=(B(b,872)+a|0)+1075080|0;v[e>>2]=v[e>>2]|2097152}p=h+1075692|0;q=v[p>>2];e=w[h+1075794|0];o:{if(!v[i>>2]|(e-1&255)>>>0>119){break o}if(!(!(w[(B(b,872)+a|0)+1075081|0]&2)|v[a+480180>>2]!=2)){Db(f+8|0,k,108);if(!Cb(f+8|0)){break o}}OP(a,b,0,e,1)}h=0;p:{if(!(v[a+480180>>2]&1048580)){break p}i=w[(B(b,872)+a|0)+1075781|0];h=(c|0)<256;if(!i|(c|0)>255){break p}Do(a,g,i,0,0,1);h=1}i=B(b,872)+a|0;m=i+1075652|0;r=v[m>>2];v[m>>2]=0;n=i+1075080|0;s=v[n>>2];Db(f+8|0,k,23);ku(a,g,e,Cb(f+8|0),h,0,b);if(!w[i+1075781|0]){v[m>>2]=r}if(!(!(s&4096)|v[a+480180>>2]!=4)){v[n>>2]=v[n>>2]|4096}h=i+1075780|0;v[o>>2]=v[f+4>>2];if(x[a+480192>>1]){t[h|0]=e;tO(a,b)}if(!(!(v[a+480180>>2]&16777248)|(w[h|0]|!q))){v[p>>2]=q}e=v[a+480180>>2];Db(f+8|0,k,23);if(Cb(f+8|0)){v[g>>2]=0;v[g+4>>2]=0}e=e&16777250;q:{if((d|0)<1){break q}h=(B(b,872)+a|0)+1075096|0;i=d-1|0;if((i|0)>9){break q}h=v[h>>2];if(!h){break q}r:{if(!i){b=v[(B(b,872)+a|0)+1075656>>2];break r}i=(B(b,872)+a|0)+1075656|0;b=v[(h+(d<<2)|0)+60>>2];v[i>>2]=b}Mm(a,g,b)}j=e?j:0}Db(f+8|0,k,52);a=Cb(f+8|0);Db(f+8|0,k,23);if(Cb(f+8|0)){break a}j=(a&(c&256)>>>8)+j|0}t[l|0]=j}gb=f+16|0}function Rpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-720|0;gb=e;vc(b);g=gb-32|0;gb=g;j=e+104|0;yY(g+24|0,j);i=xb(g+24|0);f=v[g+28>>2];k=v[g+24>>2];v[g+8>>2]=k;v[g+12>>2]=f;v[g>>2]=k;v[g+4>>2]=f;f=b;fc(g+16|0,f,g);k=xb(g+16|0);if((k|0)==(i|0)){Yb(f,xb(g+24|0))}gb=g+32|0;f=(i|0)==(k|0);if(!f){xY(j)}a:{if(!f){break a}if(!zY(e+104|0)){break a}b:{if(!c){break b}Gd(a,67108864);wg(a);d=w[e+129|0];u[a+480190>>1]=31;u[a+480188>>1]=d;v[a+480228>>2]=256/(d>>>0);d=Tb(e,5392);Eb(a+1298304|0,d);vb(d);d=Tb(e,8114);Eb(a+1298316|0,d);vb(d);Df(e+72|0,1283);v[e+100>>2]=w[e+128|0]>>>4;d=w[e+128|0];v[22640]=0;v[e+96>>2]=d&15;Y(485,e|0,e+72|0,e+100|0,e+96|0);d=v[22640];v[22640]=0;c:{d:{if((d|0)!=1){Eb(a+1298328|0,e);vb(e);Hb(e+72|0);v[a+1298364>>2]=2;Fr(Rb(a+484360|0),e+152|0,w[e+151|0]+1|0);while(1){d=h+1|0;g=B(d,104)+a|0;i=g+484380|0;td(i,1);f=(e+104|0)+(h<<2)|0;o=i,p=Xb(w[f+176|0]|w[f+177|0]<<8|(w[f+178|0]<<16|w[f+179|0]<<24)),v[o>>2]=p;j=Xb(w[f+300|0]|w[f+301|0]<<8|(w[f+302|0]<<16|w[f+303|0]<<24));v[g+484384>>2]=j;o=g+484388|0,p=Xb(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24))+j|0,v[o>>2]=p;if(Xb(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24))){f=g+484414|0;u[f>>1]=x[f>>1]|2}wk(i);h=(e+104|0)+h|0;t[e|0]=w[h+548|0];t[e+72|0]=64;o=g+484410|0,p=w[ac(e,e+72|0)|0]<<2,u[o>>1]=p;t[g+484417|0]=w[h+579|0]<<4;h=d;if((d|0)!=31){continue}break}pD(b,a+1298268|0,32);d=1;while(1){mE(b,((d<<5)+a|0)+946304|0,30);d=d+1|0;if((d|0)!=32){continue}break}k=c&1;if(k){vg(a+484344|0,w[e+150|0]+1|0)}j=a+484344|0;d=0;e:{while(1){f=d;g=Ih(e+72|0);f:{if(w[e+130|0]){v[22640]=0;d=T(444,b|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break e}v[22640]=0;U(320,e|0,b|0,d|0);d=v[22640];v[22640]=0;if((d|0)==1){break e}break f}d=x[a+480188>>1];v[22640]=0;U(320,e|0,b|0,d<<8);d=v[22640];v[22640]=0;if((d|0)==1){break d}}od(g,e);yb(e);g:{if(!k){break g}v[22640]=0;d=W(365,j|0,f&65535,64)|0;h=v[22640];v[22640]=0;if((h|0)==1){break d}if(!d){break g}if(!w[e+130|0]){h=0;if(!x[a+480188>>1]){break g}while(1){d=0;while(1){i=_b(j,f);v[22640]=0;i=Tc(i,d,h&65535);l=v[22640];v[22640]=0;if((l|0)==1){break d}v[22640]=0;R(486,g|0,i|0);i=v[22640];v[22640]=0;if((i|0)==1){break d}d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if(x[a+480188>>1]>(h&65535)>>>0){continue}break}break g}i=0;v[22640]=0;R(487,g|0,e|0);d=v[22640];v[22640]=0;if((d|0)==1){break d}while(1){d=_b(j,f);v[22640]=0;l=Pf(d,i);d=v[22640];v[22640]=0;if((d|0)==1){break d}if(x[a+480188>>1]){m=e+i|0;d=128;h=0;while(1){h:{if(!(w[m|0]&d)){break h}v[22640]=0;R(486,g|0,l+B(h,6)|0);n=v[22640];v[22640]=0;if((n|0)!=1){break h}break d}d=d>>>1|0;h=h+1|0;if(h>>>0<x[a+480188>>1]){continue}break}}i=i+1|0;if((i|0)!=64){continue}break}}yb(g);d=f+1|0;if(f>>>0<w[e+150|0]){continue}break}d=1;if(!(c&2)){break a}c=Pc(e,8,1,1,0);while(1){zg(c,(B(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break b}break d}d=P()|0;O()|0;Hb(e+72|0);break c}d=P()|0;O()|0;yb(g)}S(d|0);L()}d=1}gb=e+720|0;return d|0}function eX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=gb-128|0;gb=g;j=Ck(g+112|0);a:{b:{c:{if(d){v[22640]=0;U(664,a|0,j|0,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){break c}break b}v[22640]=0;U(665,a|0,j|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}}k=nc(g+96|0);if(x[b+480192>>1]){d=1;c=1;while(1){v[22640]=0;u[g+94>>1]=0;Q(666,a|0,g+94|0)|0;f=v[22640];v[22640]=0;d:{e:{f:{if((f|0)!=1){l=gb-16|0;gb=l;p=l+8|0;i=gb-16|0;gb=i;f=j;m=f;o=g+94|0;q=o;e=Vd(f);h=ec(f);n=gb-16|0;gb=n;if(e){wb(m);while(1){m=AC(e+16|0,q);h=m?h:e;e=v[(m?4:0)+e>>2];if(e){continue}break}}e=v[yc(n+8|0,h)>>2];gb=n+16|0;v[i+8>>2]=e;r=i,s=yh(f),v[r>>2]=s;g:{if(Xl(i+8|0,i)){if(!BC(wb(f),o,ue(i+8|0))){break g}}e=yh(f)}gb=i+16|0;f=v[yc(p,e)>>2];gb=l+16|0;v[g+88>>2]=f;i=((d<<2)+b|0)+900380|0;if(!v[i>>2]){break d}r=g,s=zh(j),v[r+72>>2]=s;if(kg(g+88|0,g+72|0)){d=ue(g+88|0);v[22640]=0;d=Q(4,g+72|0,d+4|0)|0;f=v[22640];v[22640]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((f|0)!=1){v[22640]=0;f=Q(2,g+56|0,13890)|0;e=v[22640];v[22640]=0;if((e|0)==1){break i}e=vr(d,f);vb(f);if(e){break r}f=v[b+4>>2];v[22640]=0;f=Q(667,f|0,d|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break x}v[v[i>>2]+44>>2]=f;if(!v[v[i>>2]+44>>2]){break y}break e}b=P()|0;O()|0;break f}v[22640]=0;f=Q(2,g+56|0,10785)|0;e=v[22640];v[22640]=0;if((e|0)==1){break w}z:{A:{if(vr(d,f)){vb(f);break A}v[22640]=0;e=Q(2,g+40|0,11023)|0;h=v[22640];v[22640]=0;if((h|0)==1){break v}h=vr(d,e);vb(e);vb(f);if(!h){break z}}v[22640]=0;f=T(668,d|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break u}v[g+56>>2]=f;f=v[b+4>>2];ni(g+32|0,g+56|0);v[22640]=0;f=Q(669,f|0,v[g+32>>2])|0;e=v[22640];v[22640]=0;if((e|0)==1){break t}Dg(g+56|0);if(f){break e}}h=Sb(k);l=Wb(k);f=d;e=gb-16|0;gb=e;v[e>>2]=l;v[e+8>>2]=h;if(Gb(e+8|0,e)){while(1){if(!vr(v[e+8>>2],f)){sr(e+8|0);if(Gb(e+8|0,e)){continue}}break}h=v[e+8>>2]}gb=e+16|0;v[g+56>>2]=h;r=g,s=Wb(k),v[r+40>>2]=s;if(Gb(g+56|0,g+40|0)){break r}v[22640]=0;R(670,k|0,d|0);f=v[22640];v[22640]=0;if((f|0)!=1){break s}}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(f);break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;Dg(g+56|0);break h}v[22640]=0;f=Q(2,g+16|0,14524)|0;e=v[22640];v[22640]=0;if((e|0)==1){break q}v[22640]=0;U(671,g+40|0,f|0,d|0);e=v[22640];v[22640]=0;if((e|0)==1){break p}v[22640]=0;e=Q(2,g|0,13466)|0;h=v[22640];v[22640]=0;if((h|0)==1){break o}v[22640]=0;U(3,g+56|0,g+40|0,e|0);h=v[22640];v[22640]=0;if((h|0)==1){break n}v[22640]=0;U(580,b|0,2,g+56|0);h=v[22640];v[22640]=0;if((h|0)==1){break m}vb(g+56|0);vb(e);vb(g+40|0);vb(f)}v[v[i>>2]+44>>2]=0;break e}b=P()|0;O()|0;break h}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(g+56|0)}vb(e)}vb(g+40|0)}vb(f);break h}b=P()|0;O()|0}vb(d);break f}if(!v[i>>2]){break d}v[v[i>>2]+44>>2]=0;break d}b=P()|0;O()|0}jm(k);break a}vb(d)}c=c+1|0;d=c&65535;if(d>>>0<=x[b+480192>>1]){continue}break}}jm(k);aX(j);gb=g+128|0;return}b=P()|0;O()|0}aX(j);S(b|0);L()}function lL(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-224|0;gb=f;v[f+216>>2]=c;v[f+220>>2]=d;a:{if(nk(b)){break a}g=w[wl(b)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}Kl(f+184|0,b,v[b+4>>2]-1|0);g=v[f+188>>2];v[b>>2]=v[f+184>>2];v[b+4>>2]=g}Kd(f+184|0);g=v[f+184>>2];Kd(f+168|0);i=vl(g,v[f+172>>2],b);Kd(f+184|0);g=v[b>>2];h=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==v[f+188>>2]){v[f+208>>2]=g;v[f+212>>2]=h;a=uc(f+200|0,18693);c=v[f+212>>2];v[f+16>>2]=v[f+208>>2];v[f+20>>2]=c;c=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=c;if(Fc(f+16|0,f+8|0)){a=aa(8)|0;v[22640]=0;R(2059,f+168|0,f+216|0);b=v[22640];v[22640]=0;if((b|0)==1){break g}v[22640]=0;U(2037,f+184|0,14695,f+168|0);b=v[22640];v[22640]=0;if((b|0)==1){break f}qc(a,f+184|0);e=0;v[22640]=0;U(223,a|0,55256,1936);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(f+184|0);break e}if(!e){break h}a=aa(8)|0;v[22640]=0;c=Q(2057,f+136|0,b|0)|0;b=v[22640];v[22640]=0;e=1;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){v[22640]=0;U(2037,f+152|0,14731,c|0);b=v[22640];v[22640]=0;if((b|0)==1){break q}v[22640]=0;R(2054,f+168|0,f+152|0);b=v[22640];v[22640]=0;if((b|0)==1){break p}v[22640]=0;R(2059,f+120|0,f+216|0);b=v[22640];v[22640]=0;if((b|0)==1){break o}v[22640]=0;U(2058,f+184|0,f+168|0,f+120|0);b=v[22640];v[22640]=0;if((b|0)==1){break n}qc(a,f+184|0);v[22640]=0;U(223,a|0,55256,1936);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(f+184|0);e=0;break m}b=P()|0;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0}vb(f+120|0)}vb(f+168|0)}vb(f+152|0)}vb(c)}if(e){break d}break c}v[f+112>>2]=g;v[f+116>>2]=h;e=uc(f+104|0,18693);g=v[f+116>>2];v[f+64>>2]=v[f+112>>2];v[f+68>>2]=g;g=v[e+4>>2];v[f+56>>2]=v[e>>2];v[f+60>>2]=g;if(Fc(f- -64|0,f+56|0)){a=aa(8)|0;v[22640]=0;R(2059,f+168|0,f+216|0);b=v[22640];v[22640]=0;r:{s:{if((b|0)!=1){v[22640]=0;U(2037,f+184|0,14695,f+168|0);b=v[22640];v[22640]=0;if((b|0)==1){break s}qc(a,f+184|0);e=0;v[22640]=0;U(223,a|0,55256,1936);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(f+184|0);break r}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0}vb(f+168|0);if(e){break d}break c}e=v[b+4>>2];v[f+96>>2]=v[b>>2];v[f+100>>2]=e;e=uc(f+88|0,8263);g=v[f+100>>2];v[f+48>>2]=v[f+96>>2];v[f+52>>2]=g;g=v[e+4>>2];v[f+40>>2]=v[e>>2];v[f+44>>2]=g;if(Fc(f+48|0,f+40|0)){$K(a,zc(c,d));break h}e=v[b+4>>2];v[f+80>>2]=v[b>>2];v[f+84>>2]=e;b=uc(f+72|0,5838);e=v[f+84>>2];v[f+32>>2]=v[f+80>>2];v[f+36>>2]=e;e=v[b+4>>2];v[f+24>>2]=v[b>>2];v[f+28>>2]=e;if(!Fc(f+32|0,f+24|0)){break h}b=jC(c,d);c=gb-16|0;gb=c;a=v[a+32>>2];b=b>>>0<4?b:1;t:{if((xy(a)|0)==(b|0)){d=a+120|0;yi(d);b=gb-16|0;gb=b;v[b+8>>2]=c+8;a=gb-16|0;gb=a;e=v[14853];v[a+8>>2]=v[14852];v[a+12>>2]=e;e=v[14851];v[a>>2]=v[14850];v[a+4>>2]=e;kb[v[Th(a,Vg(d))>>2]](b+8|0,d);gb=a+16|0;gb=b+16|0;break t}zK(a,b,AK(a))}gb=c+16|0}gb=f+224|0;return}b=P()|0;O()|0;break d}b=P()|0;e=1;O()|0}vb(f+168|0);if(!e){break c}}da(a|0)}S(b|0)}L()}function YL(a){var b=C(0),c=C(0),d=0,e=C(0),f=0,g=C(0),h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=C(0),r=C(0),s=0,t=C(0);cQ(a+4208|0,z[a+4272>>2]);c=C(C(z[a+4208>>2]*C(15920))+C(80));d=uf(v[a+16>>2]);o=me(C(10),C(C(C(z[a+4216>>2]*C(30))+C(-15))*C(.02500000037252903)));b=C(C(c*C(6.2831854820251465))/C(d>>>0));c=rG(b);r=Rp(b);s=a;t=c;k=C(C(C(b*C(.02888113260269165))*C(C(z[a+4212>>2]*C(35))+C(1)))/c);i=(l(2,(p(k),j(2))&-2147483648|1056964608),q());h=(p(k),j(2))&2147483647;c=(l(2,h),q());a:{if(h>>>0<=1118925334){b:{c:{d:{e:{f:{g:{f=(p(c),j(2));d=f&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((f|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(1.7014118346046923e38));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((f|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=b;c=C(c-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}m=C(c*C(.5));g=C(c*m);b=C(C(g*C(C(g*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));n=b;b=C(C(3)-C(m*b));m=C(g*C(C(n-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*m)-g));if(!d){break b}e=C(C(C(c*C(m-e))-e)-g);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}c=C(c-e);b=C(C(c+c)+C(1));break b;default:break i}}f=d<<23;b=(l(2,f+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(1.7014118346046923e38)):C(c*b))+C(-1));break b}g=(l(2,1065353216-f|0),q());c=C(((d|0)<=22?C(C(C(1)-g)+C(c-e)):C(C(c-C(e+g))+C(1)))*b)}b=c}if(h>>>0<=1065353215){if(h>>>0<964689920){break a}k=C(i*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}k=C(i*C(b+C(b/C(b+C(1)))));break a}g=C(i+i);i=C(0);c=C(c+C(-162.88958740234375));h=(p(c),j(2));f=h>>>31|0;j:{k:{l:{m:{n:{n=c;o:{p:{d=h&2147483647;q:{if(d>>>0>=1118743632){b=c;if(d>>>0>2139095040){break j}b=C(c*C(1.7014118346046923e38));if(!((h|0)<0|d>>>0<1118925336)){break j}if(d>>>0<=1120924084|(h|0)>-1){break q}break l}if(d>>>0<1051816473){break n}if(d>>>0<1065686419){break p}}c=C(C(c*C(1.4426950216293335))+z[(f<<2)+71008>>2]);if(C(D(c))<C(2147483648)){d=~~c;break o}d=-2147483648;break o}d=!f-f|0}b=C(d|0);c=C(n+C(b*C(-.693145751953125)));i=C(b*C(1428606765330187e-21));b=C(c-i);break m}if(d>>>0<=956301312){break k}d=0;b=c}n=c;e=C(b*b);c=C(b-C(e*C(C(e*C(-.0027667332906275988))+C(.16666625440120697))));e=C(C(n+C(C(C(b*c)/C(C(2)-c))-i))+C(1));if(!d){break l}e=VI(e,d)}b=e;break j}b=C(c+C(1))}k=C(g*C(C(b*C(1.661534994731145e35))*C(1.661534994731145e35)))}b=C(t*k);e=C(b/o);c=C(e+C(1));z[s+4236>>2]=C(C(1)-e)/c;e=C(C(r*C(-2))/c);z[a+4232>>2]=e;b=C(b*o);z[a+4228>>2]=C(C(1)-b)/c;z[a+4224>>2]=e;z[a+4220>>2]=C(b+C(1))/c}function Sfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+8>>2]=49776;v[a+4>>2]=0;v[a>>2]=38800;b=a+24596|0;v[b>>2]=0;v[b+4>>2]=0;_q(a+24604|0);pP(a+24648|0,0);b=a+393352|0;v[b>>2]=8;v[b+4>>2]=0;u[b+4128>>1]=0;c=b+4120|0;v[c>>2]=0;v[c+4>>2]=0;c=b+4112|0;v[c>>2]=0;v[c+4>>2]=0;v[b+4104>>2]=0;v[b+4108>>2]=0;Qb(b+4132|0,0,40);TS(b+8|0,1024);Qb(b+4172|0,0,49824);Qb(b+53996|0,0,32832);t[a+480224|0]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;b=a+480186|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;k=Ho(a+480248|0);v[a+480272>>2]=0;b=a+484344|0;c=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){v[22640]=0;c=oP(c);e=v[22640];v[22640]=0;if((e|0)==1){break k}c=c+32|0;if((b|0)!=(c|0)){continue}break}e=a+484344|0;ad(e);v[e+12>>2]=a;v[22640]=0;l=Q(1290,a+484360|0,a|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break j}b=a+900380|0;c=a+484380|0;while(1){v[22640]=0;c=Q(912,c|0,0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break i}c=c+104|0;if((b|0)!=(c|0)){continue}break}v[22640]=0;T(1291,a+901404|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break h}c=a+946300|0;f=a+906300|0;b=f;while(1){b=nP(b)+160|0;if((c|0)!=(b|0)){continue}break}v[a+946300>>2]=0;d=a+1074304|0;g=a+946304|0;b=g;while(1){v[22640]=0;b=Yq(b);h=v[22640];v[22640]=0;if((h|0)==1){break g}b=b+32|0;if((d|0)!=(b|0)){continue}break}v[a+1074304>>2]=0;v[a+1074308>>2]=0;bA(a+1074312|0);v[22640]=0;b=fa(1292)|0;d=v[22640];v[22640]=0;if((d|0)==1){break f}v[22640]=0;b=T(1293,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break f}v[a+1074328>>2]=b;v[22640]=0;qO(a+1074332|0);b=v[22640];v[22640]=0;if((b|0)==1){break f}v[22640]=0;T(1295,a+1074376|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break f}v[22640]=0;d=W(1256,a+1298224|0,a|0,255)|0;b=v[22640];v[22640]=0;if((b|0)==1){break f}h=th(a+1298260|0);b=gb-16|0;gb=b;v[b+12>>2]=0;i=a+1298264|0;Cq(i,b+12|0);gb=b+16|0;m=Kb(a+1298268|0);n=Kb(a+1298280|0);j=a+1298292|0;Kb(j);o=mP(a+1298304|0);p=ad(a+1298368|0);t[a+1298380|0]=0;b=a+1298384|0;v[b>>2]=0;v[b+4>>2]=0;v[b+32>>2]=0;v[b+36>>2]=1072693248;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[a+1298424>>2]=0;Gq(a+12|0);Uo(a+8204|0);v[22640]=0;Uo(a+12300|0);b=v[22640];v[22640]=0;if((b|0)==1){break e}v[a+480216>>2]=4;v[a+480220>>2]=16;b=a+1074408|0;v[b>>2]=4;v[b+4>>2]=16;jP(a+900380|0);v[22640]=0;$z(g);b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;b=T(1298,12)|0;g=v[22640];v[22640]=0;if((g|0)==1){break e}v[b>>2]=0;v[b+4>>2]=0;v[b+8>>2]=0;eh(b);v[a+4>>2]=b;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;aA(p);du(o);vb(j);vb(n);vb(m);cu(i);bu(h);Jq(d)}while(1){c=Hq(c-160|0);if((f|0)!=(c|0)){continue}break}}zu(l)}_z(e)}Lc(k);S(b|0);L()}function zs(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[116454]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=465796,j=v[116449]&qqa(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+466100|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=465800,j=v[116450]&qqa(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[116451]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[116455]==(f|0)){v[116455]=a;b=v[116452]+b|0;v[116452]=b;v[a+4>>2]=b|1;if(v[116454]!=(a|0)){break a}v[116451]=0;v[116454]=0;return}if(v[116454]==(f|0)){v[116454]=a;b=v[116451]+b|0;v[116451]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=465796,j=v[116449]&qqa(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+466100|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=465800,j=v[116450]&qqa(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[116454]!=(a|0)){break g}v[116451]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){b=b>>>3|0;c=(b<<3)+465836|0;d=v[116449];b=1<<b;l:{if(!(d&b)){v[116449]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;v[a+16>>2]=0;v[a+20>>2]=0;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;g=(e<<2)+466100|0;m:{d=v[116450];c=1<<e;n:{if(!(d&c)){v[116450]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}function C8(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=gb-192|0;gb=d;v[d+184>>2]=c;a:{b:{c:{d:{if(!(b<.8)){v[22640]=0;c=fa(2070)|0;e=v[22640];v[22640]=0;e:{f:{g:{if((e|0)!=1){v[d+88>>2]=c;c=v[d+184>>2];v[22640]=0;c=T(2071,c|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break f}v[d+72>>2]=c;lo(v[d+88>>2],v[d+72>>2]);c=v[d+88>>2];a=Je(d+160|0,a);v[22640]=0;e=v[a+12>>2];v[d+56>>2]=v[a+8>>2];v[d+60>>2]=e;v[d- -64>>2]=v[a+16>>2];e=v[a+4>>2];v[d+48>>2]=v[a>>2];v[d+52>>2]=e;a=W(2061,c|0,d+48|0,15)|0;c=v[22640];v[22640]=0;if((c|0)==1){break g}if(a){a=v[d+88>>2];v[22640]=0;T(1299,a|0)|0;a=v[22640];v[22640]=0;f=1;if((a|0)==1){break g}}Ai(d+72|0);Bi(d+88|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Ai(d+72|0);break e}c=V(0)|0;O()|0}Bi(d+88|0);break d}if(!(b<.6)){v[22640]=0;c=fa(2070)|0;e=v[22640];v[22640]=0;h:{i:{j:{if((e|0)!=1){v[d+88>>2]=c;c=v[d+184>>2];v[22640]=0;c=T(2071,c|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break i}v[d+72>>2]=c;lo(v[d+88>>2],v[d+72>>2]);c=v[d+88>>2];a=Je(d+136|0,a);v[22640]=0;e=v[a+12>>2];v[d+32>>2]=v[a+8>>2];v[d+36>>2]=e;v[d+40>>2]=v[a+16>>2];e=v[a+4>>2];v[d+24>>2]=v[a>>2];v[d+28>>2]=e;a=W(2061,c|0,d+24|0,2)|0;c=v[22640];v[22640]=0;if((c|0)==1){break j}if(a){a=v[d+88>>2];v[22640]=0;T(1299,a|0)|0;a=v[22640];v[22640]=0;f=.8;if((a|0)==1){break j}}Ai(d+72|0);Bi(d+88|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Ai(d+72|0);break h}c=V(0)|0;O()|0}Bi(d+88|0);break d}f=.2;if(!(b<.2)){v[22640]=0;c=fa(2070)|0;e=v[22640];v[22640]=0;k:{l:{m:{if((e|0)!=1){v[d+88>>2]=c;c=v[d+184>>2];v[22640]=0;c=T(2071,c|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break l}v[d+72>>2]=c;lo(v[d+88>>2],v[d+72>>2]);c=v[d+88>>2];a=Je(d+112|0,a);v[22640]=0;e=v[a+12>>2];v[d+8>>2]=v[a+8>>2];v[d+12>>2]=e;v[d+16>>2]=v[a+16>>2];e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;a=W(2061,c|0,d|0,0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break m}f=0;if(a){a=v[d+88>>2];v[22640]=0;T(1299,a|0)|0;a=v[22640];v[22640]=0;f=.6;if((a|0)==1){break m}}Ai(d+72|0);Bi(d+88|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Ai(d+72|0);break k}c=V(0)|0;O()|0}Bi(d+88|0);break d}if(b<.1){break c}v[22640]=0;U(772,d+88|0,a|0,2048);c=v[22640];v[22640]=0;n:{o:{p:{if((c|0)!=1){v[22640]=0;c=Rd(d+88|0);e=v[22640];v[22640]=0;if((e|0)==1){break o}e=v[d+88>>2];v[22640]=0;a=T(232,a|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break o}v[22640]=0;a=pG(2072,3,0,c,e,a,0);c=v[22640];v[22640]=0;if((c|0)==1){break o}a=a+1|0;if(a>>>0>=3){break p}f=A[(a<<3)+59416>>3];xc(d+88|0);break c}c=V(0)|0;O()|0;break d}a=aa(8)|0;v[22640]=0;e=Q(112,d+72|0,18693)|0;c=v[22640];v[22640]=0;if((c|0)!=1){qc(a,e);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}c=V(0)|0;O()|0;vb(e);break n}c=V(0)|0;O()|0;da(a|0);break n}c=V(0)|0;O()|0}xc(d+88|0)}Z(c|0)|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;f=0;if((a|0)==1){break a}}bg(d+184|0);gb=d+192|0;return+f}L()}a=P()|0;O()|0;bg(d+184|0);S(a|0);L()}function DO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=C(0),l=0,m=0,n=0,o=C(0),p=0,q=0,r=C(0),s=0,t=0,w=0,A=0,E=C(0),G=0;if(b){Bq(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;YO(a)}CO(a+24648|0);s=v[a+24620>>2];h=gb-144|0;gb=h;f=a+393352|0;c=v[f+4>>2];a:{if(c>>>0<=28){g=B(c,44)+53616|0;break a}v[f+4>>2]=0;g=53616}if(!(b?0:(g|0)==v[f+4112>>2])){v[f+4112>>2]=g;r=C(s>>>0);i=r;c=h+8|0;d=v[g+24>>2];v[c>>2]=d;e=v[g+16>>2];v[c+4>>2]=e;v[c+8>>2]=v[g+4>>2];m=(d|0)>(e|0)?d:e;if((m|0)<=-601){j=e;e=m+600|0;v[c+4>>2]=j-e;v[c>>2]=d-e}e=c;k=C(z[g+36>>2]*C(79.30999755859375));b:{if(C(D(k))<C(2147483648)){d=~~k;break b}d=-2147483648}v[e+16>>2]=d- -8192;d=c;k=C(C(z[g+32>>2]*C(117.9612045288086))+C(4915.05029296875));c:{if(C(D(k))<C(2147483648)){e=~~k;break c}e=-2147483648}v[d+20>>2]=(e|0)<32512?e:32512;m=0;k=z[g+8>>2];e=c;o=C(C(F(z[g+20>>2],C(.10000000149011612)))*i);d:{if(C(D(o))<C(2147483648)){d=~~o;break d}d=-2147483648}j=(d|0)<96;p=j?96:d;l=(p|0)>7500;o=C(z[g+28>>2]*i);e:{if(C(D(o))<C(2147483648)){n=~~o;break e}n=-2147483648}d=(n+(j?d-96|0:0)|0)+(l?p-7500|0:0)|0;j=(d|0)<128;n=j?128:d;t=(n|0)>3800;w=t?3800:n;v[e+24>>2]=w;j=j?d-128|0:0;e=c;i=C(k*i);f:{if(C(D(i))<C(2147483648)){d=~~i;break f}d=-2147483648}j=(d+j|0)+(t?n-3800|0:0)|0;v[e+32>>2]=j;p=l?7500:p;while(1){d=B(m,12);e=d+c|0;u[e+42>>1]=x[d+54906>>1];u[e+36>>1]=x[d+54900>>1];l=d+54902|0;l=x[l>>1]|x[l+2>>1]<<16;u[e+38>>1]=l;u[e+40>>1]=l>>>16;v[e+44>>2]=p+((B(v[d+54896>>2],w)+50|0)/100|0);m=m+1|0;if((m|0)!=8){continue}break}e=c;i=C(j|0);k=C(me(C(.0010000000474974513),(j|0)<4721?C(1):C(C(4720)/i))*C(32768));g:{if(C(D(k))<C(2147483648)){d=~~k;break g}d=-2147483648}v[e+12>>2]=d;i=C(z[g+12>>2]*i);A=c,E=me(C(.0010000000474974513),i>C(4720)?C(C(4720)/i):C(1)),z[A+28>>2]=E;v[f+4124>>2]=v[h+40>>2];c=PL(QL(v[h+16>>2]),r);u[f+4190>>1]=c;u[f+4188>>1]=c;c=x[h+24>>1]<<1;u[f+4198>>1]=c;u[f+4196>>1]=c;while(1){c=(q<<4)+f|0;g=(h+8|0)+B(q,12)|0;d=v[g+44>>2];v[c+4204>>2]=d;v[c+4208>>2]=d;u[c+4212>>1]=x[g+36>>1];u[c+4214>>1]=x[g+42>>1];u[c+4216>>1]=x[g+40>>1];u[c+4218>>1]=x[g+38>>1];q=q+1|0;if((q|0)!=8){continue}break}v[f+53996>>2]=v[h+32>>2];e=f+4184|0;c=v[h+12>>2];if((c|0)>-9e3){c=OL(c)}else{c=0}v[e>>2]=c;e=f+54052|0;c=v[h+8>>2];if((c|0)>=-8999){c=OL(c)}else{c=0}v[e>>2]=c;c=v[h+28>>2];g=f+54036|0;v[g>>2]=268464128;v[g+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[f+54010>>1]=c;u[f+54008>>1]=c;u[f+54006>>1]=c;u[f+54004>>1]=c;v[h+4>>2]=v[h+20>>2];Qd(h+4|0,0,32752);c=x[h+4>>1];u[f+54018>>1]=c;g=f+54014|0;u[g>>1]=0;u[g+2>>1]=0;u[f+54012>>1]=c;i=z[h+36>>2];A=h,G=PL(C(i*i),r),v[A>>2]=G;Qd(h,256,32512);c=x[h>>1];u[f+54026>>1]=c;g=f+54022|0;u[g>>1]=0;u[g+2>>1]=0;u[f+54020>>1]=c}if(b){v[f+4120>>2]=0;SL(f)}b=B(s,5);if(b>>>0>y[f+4124>>2]){v[f+4124>>2]=b}gb=h+144|0;b=a+1298260|0;if(Bd(b)){_R(v[b>>2],v[a+24620>>2])}}function k_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-32|0;gb=e;v[e+28>>2]=b;a:{b:{if((d|0)<1){a=0}else{v[e+8>>2]=d;v[e+16>>2]=214748364;r=e,s=B(v[Fb(e+28|0,e+16|0)>>2],20),v[r+20>>2]=s;Ys(c,v[Fb(e+8|0,e+20|0)>>2]);v[e+8>>2]=a;v[e+12>>2]=v[e+28>>2];a=0;while(1){c:{f=ih(e+8|0,a);b=ih(e+8|0,a+4|0);i=ih(e+8|0,a+5|0);r=e,s=ih(e+8|0,a+6|0)<<8|ih(e+8|0,a+7|0),v[r+24>>2]=s;b=i|b<<8;p=a+8|0;d:{e:{switch(f|0){case 0:f:{if((b|0)<=(d|0)){i=0;o=0;if(b){break f}break d}a=aa(8)|0;v[22640]=0;T(315,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break a}break b}while(1){r=e,s=ih(e+8|0,i+p|0),t[r+20|0]=s;aq(c,e+20|0);i=i+1|0;if((b|0)!=(i|0)){continue}break};i=b;o=b;break d;case 1:break e;default:break c}}Zj(e+24|0,d);i=v[e+24>>2];m=ih(e+8|0,a+10|0);t[e+20|0]=m;aq(c,e+20|0);f=v[e+24>>2];v[e+24>>2]=f-1;o=b+3&65532;if((f|0)<2){break d}h=a+11|0;k=0;n=0;j=0;b=0;while(1){a=mg(h,b,1,e+8|0);g:{h:{i:{j:{k:{if((j|0)<=7){if(a){f=b;break h}b=b+1|0;k=8;break k}f=b+1|0;l:{if(!a){if(!mg(h,f,1,e+8|0)){break h}f=2;m:{n:{a=b+2|0;if(!mg(h,a,1,e+8|0)){break n}f=3;a=b+3|0;if(!mg(h,a,1,e+8|0)){break n}f=mg(h,a,3,e+8|0);b=b+6|0;break m}b=a+1|0}a=4;f=((k<<3)+f|0)-17|0;if((f|0)<=-1){a=aa(8)|0;v[22640]=0;T(315,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break a}break b}if(f>>>0>=56){a=aa(8)|0;v[22640]=0;T(315,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break a}break b}k=w[f+28704|0];if((k|0)!=8){break j}break l}a=4;b=f;if((k|0)!=8){break j}}k=8;a=1;if((n|0)>19){break j}}a=0;break i}n=n+8|0}g=v[e+24>>2];o:{if((g|0)<1){break o}while(1){f=e+8|0;l=(b|0)/8|0;g=l+h|0;q=ih(f,g);m=m-((ih(f,g+1|0)<<8|q<<16|ih(f,g+2|0))<<(b-(l<<3)|0)+8>>32-k)|0;t[e+20|0]=m;aq(c,e+20|0);f=v[e+24>>2];g=f-1|0;v[e+24>>2]=g;b=b+k|0;if((a|0)<1){break o}a=a-1|0;if((f|0)>1){continue}break}}j=(j|0)==31?31:j+1|0;break g}p:{q:{a=f+1|0;if(!mg(h,a,1,e+8|0)){f=2;break q}a=f+2|0;if(!mg(h,a,1,e+8|0)){f=4;break q}a=f+3|0;if(!mg(h,a,1,e+8|0)){f=6;break q}a=f+5|0;if(!mg(h,f+4|0,1,e+8|0)){b=f+8|0;a=mg(h,a,3,e+8|0)+8|0;break p}b=f+10|0;a=mg(h,a,5,e+8|0)+16|0;break p}b=a+2|0;a=mg(h,a+1|0,1,e+8|0)+f|0}r:{if(mg(h,b,1,e+8|0)){f=-256;g=12;break r}b=b+1|0;g=mg(h,b,1,e+8|0);f=g?-4352:0;g=g?14:8}b=b+1|0;l=mg(h,b,g,e+8|0);if((a|0)>=3){j=j-((a|0)!=3)|0;j=(j|0)>0?j-1|0:0}f=pc(c)+((l^-1)+f|0)|0;if(f>>>0<pc(c)>>>0){b=b+g|0;g=v[e+24>>2];if((a|0)<1|(g|0)<=0){break g}while(1){m=w[kc(c,f)|0];t[e+20|0]=m;aq(c,e+20|0);l=v[e+24>>2];g=l-1|0;v[e+24>>2]=g;if((a|0)<2){break g}f=f+1|0;a=a-1|0;if((l|0)>1){continue}break}break g}a=aa(8)|0;v[22640]=0;T(315,a|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break b}break a}n=n-(n>>3)|0;if((g|0)>0){continue}break}}a=o+p|0;d=d-i|0;if((d|0)>0){continue}}break}a=$c(c)^1}gb=e+32|0;return a|0}b=P()|0;O()|0;da(a|0);S(b|0);L()}ia(a|0,28664,242);L()}function yfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=gb-144|0;gb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((c|0)<=5){mz(a+96|0,c);v[22640]=0;c=Q(2,a+80|0,14831)|0;d=v[22640];v[22640]=0;if((d|0)==1){break E}v[22640]=0;U(3,a+112|0,a+96|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break D}v[22640]=0;d=Q(4,a+48|0,e|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break C}v[22640]=0;e=Q(2,a+32|0,16636)|0;f=v[22640];v[22640]=0;if((f|0)==1){break B}v[22640]=0;U(5,a- -64|0,d|0,e|0);f=v[22640];v[22640]=0;if((f|0)==1){break A}v[22640]=0;U(3,a+128|0,a+112|0,a- -64|0);f=v[22640];v[22640]=0;if((f|0)==1){break z}vb(a- -64|0);vb(e);vb(d);vb(a+112|0);vb(c);vb(a+96|0);c=v[b>>2];v[22640]=0;U(6,a+112|0,1,(c?c:18693)|0);c=v[22640];v[22640]=0;if((c|0)==1){break t}c=v[b+4>>2];v[22640]=0;U(6,a+96|0,1,(c?c:18693)|0);c=v[22640];v[22640]=0;if((c|0)==1){break s}b=v[b+8>>2];v[22640]=0;v[a+64>>2]=b;R(7,a+80|0,a- -64|0);b=v[22640];v[22640]=0;if((b|0)==1){break r}v[22640]=0;b=Q(8,463160,14710)|0;c=v[22640];v[22640]=0;if((c|0)==1){break q}v[22640]=0;U(9,a- -64|0,0,a+112|0);c=v[22640];v[22640]=0;if((c|0)==1){break p}v[22640]=0;b=Q(10,b|0,a- -64|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break o}v[22640]=0;b=Q(8,b|0,14522)|0;c=v[22640];v[22640]=0;if((c|0)==1){break o}v[22640]=0;U(9,a+32|0,0,a+80|0);c=v[22640];v[22640]=0;if((c|0)==1){break n}v[22640]=0;b=Q(10,b|0,a+32|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break m}v[22640]=0;b=Q(8,b|0,14519)|0;c=v[22640];v[22640]=0;if((c|0)==1){break m}v[22640]=0;b=Q(8,b|0,14831)|0;c=v[22640];v[22640]=0;if((c|0)==1){break m}v[22640]=0;U(9,a+16|0,0,a+128|0);c=v[22640];v[22640]=0;if((c|0)==1){break l}v[22640]=0;b=Q(10,b|0,a+16|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break k}v[22640]=0;b=Q(8,b|0,10811)|0;c=v[22640];v[22640]=0;if((c|0)==1){break k}v[22640]=0;U(9,a|0,0,a+96|0);c=v[22640];v[22640]=0;if((c|0)==1){break j}v[22640]=0;b=Q(10,b|0,a|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break i}v[22640]=0;b=Q(8,b|0,10809)|0;c=v[22640];v[22640]=0;if((c|0)==1){break i}v[22640]=0;Q(11,b|0,12)|0;b=v[22640];v[22640]=0;if((b|0)==1){break i}vb(a);vb(a+16|0);vb(a+32|0);vb(a- -64|0);vb(a+80|0);vb(a+96|0);vb(a+112|0);vb(a+128|0)}gb=a+144|0;return}b=P()|0;O()|0;break u}b=P()|0;O()|0;break v}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;break y}b=P()|0;O()|0;vb(a- -64|0)}vb(e)}vb(d)}vb(a+112|0)}vb(c)}vb(a+96|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(a)}vb(a+16|0)}vb(a+32|0)}vb(a- -64|0)}vb(a+80|0)}vb(a+96|0)}vb(a+112|0)}vb(a+128|0)}S(b|0);L()}function bn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-80|0;gb=c;f=nc(a);v[22640]=0;e=T(453,b|0)|0;a=v[22640];v[22640]=0;a:{b:{c:{d:{e:{if((a|0)==1){break e}v[22640]=0;a=Q(228,b|0,e|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break e}if(a){break d}v[22640]=0;a=T(492,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break e}v[22640]=0;Q(350,b|0,a|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break c}}b=P()|0;O()|0;break a}v[22640]=0;U(320,c+56|0,b|0,e|0);b=v[22640];v[22640]=0;f:{g:{a=c;h:{i:{if((b|0)!=1){if(e>>>0<10){break g}v[22640]=0;b=T(946,c+56|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}if(!b){break g}v[22640]=0;b=T(453,c+56|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}v[c+52>>2]=b;v[c+48>>2]=e-10;b=v[c+48>>2];if(b>>>0>25264513){break i}b=B(b,170);break h}b=P()|0;O()|0;break a}b=-1}v[a+48>>2]=b;tc(c+52|0,b);v[22640]=0;R(467,f|0,v[c+52>>2]);a=v[22640];v[22640]=0;if((a|0)==1){break b}e=v[c+52>>2];b=0;while(1){j:{v[22640]=0;a=T(947,c+56|0)|0;d=v[22640];v[22640]=0;k:{l:{m:{n:{if((d|0)!=1){if(a){break j}v[22640]=0;a=T(726,c+56|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}switch(a|0){case 3:break k;case 2:break l;case 1:break m;case 0:break n;default:break j}}break b}v[22640]=0;a=T(353,c+56|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}if(a>>>0>e>>>0){break j}v[22640]=0;d=Q(228,c+56|0,a|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break b}if(!d){break j}v[22640]=0;be(c+8|0,f);d=v[22640];v[22640]=0;if((d|0)==1){break b}v[22640]=0;Y(948,c+32|0,c+8|0,b|0,a|0);d=v[22640];v[22640]=0;if((d|0)==1){break b}v[22640]=0;d=v[c+36>>2];v[c>>2]=v[c+32>>2];v[c+4>>2]=d;U(653,c+24|0,c+56|0,c|0);d=v[22640];v[22640]=0;if((d|0)!=1){e=e-a|0;b=a+b|0;continue}break b}v[22640]=0;a=T(353,c+56|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}d=a<<2;if(d>>>0>e>>>0){break j}v[22640]=0;g=Q(949,c+56|0,c+40|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break b}if(!g){break j}e=e-d|0;if(!a){continue}while(1){d=ec(c+40|0);i=c,j=Sb(f),v[i+8>>2]=j;Ju(c+40|0,d,we(c+8|0,b));b=b+4|0;a=a-1|0;if(a&255){continue}break}continue}if(e>>>0<8){break j}v[22640]=0;a=Q(949,c+56|0,c+40|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}if(!a){break j}a=ec(c+40|0);i=c,j=Sb(f),v[i+8>>2]=j;Ju(c+40|0,a,we(c+8|0,b));a=ec(c+40|0);i=c,j=Sb(f),v[i+24>>2]=j;i=c,j=we(c+24|0,b),v[i+8>>2]=j;Ju(c+40|0,a,we(c+8|0,4));e=e-8|0;b=b+8|0;continue}v[22640]=0;a=T(353,c+56|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}if(a>>>0>e>>>0){break j}e=e-a|0;b=a+b|0;continue}break}if(!e){break f}a=nc(c+8|0);jc(a,f);jc(a+4|0,f+4|0);jc(wb(a),wb(f));wb(a);wb(f);gc(a);break f}v[22640]=0;W(528,c+56|0,f|0,e|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}}yb(c+56|0)}gb=c+80|0;return}b=P()|0;O()|0;yb(c+56|0)}gc(f);S(b|0);L()}function lka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-96|0;gb=d;a:{b:{c:{d:{if(w[a|0]==23){e=t[a+1|0];f=d,g=pA(c,+w[a+2|0]*41.666666666666664),t[f+8|0]=g;v[d+80>>2]=127;v[d+64>>2]=(B(w[a+3|0],127)>>>0)/185;f=d,g=v[ld(d+80|0,d- -64|0)>>2],t[f+95|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:Df(d- -64|0,12735);v[22640]=0;R(754,d+48|0,d+8|0);a=v[22640];v[22640]=0;f:{g:{h:{i:{j:{k:{if((a|0)!=1){v[22640]=0;R(754,d+32|0,d+95|0);a=v[22640];v[22640]=0;if((a|0)==1){break k}v[22640]=0;Y(755,d+80|0,d- -64|0,d+48|0,d+32|0);a=v[22640];v[22640]=0;if((a|0)==1){break j}v[22640]=0;R(471,d+16|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break i}v[22640]=0;Q(429,d+16|0,d+80|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break i}vb(d+80|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break b}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(d+80|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break c;case 1:Df(d- -64|0,12675);v[22640]=0;R(754,d+48|0,d+8|0);a=v[22640];v[22640]=0;l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[22640]=0;R(754,d+32|0,d+95|0);a=v[22640];v[22640]=0;if((a|0)==1){break q}v[22640]=0;Y(755,d+80|0,d- -64|0,d+48|0,d+32|0);a=v[22640];v[22640]=0;if((a|0)==1){break p}v[22640]=0;R(471,d+16|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break o}v[22640]=0;Q(429,d+16|0,d+80|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break o}vb(d+80|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break b}b=P()|0;O()|0;break l}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0;vb(d+80|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break c;default:break e}}a=Tb(d+80|0,12762);v[22640]=0;R(471,d- -64|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break d}v[22640]=0;Q(429,d- -64|0,a|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}vb(a);break b}if(w[a|0]==24){t[d+95|0]=t[a+1|0]<=4?w[a+1|0]:0;t[d+31|0]=t[a+2|0]>=0?w[a+2|0]:127;t[d+30|0]=t[a+3|0]>=0?w[a+3|0]:127;a=gb-16|0;gb=a;c=Tb(a,1157);Dc(d- -64|0,c);vb(c);gb=a+16|0;v[22640]=0;R(754,d+48|0,d+95|0);a=v[22640];v[22640]=0;r:{s:{t:{u:{v:{w:{x:{y:{if((a|0)!=1){v[22640]=0;R(754,d+32|0,d+31|0);a=v[22640];v[22640]=0;if((a|0)==1){break y}v[22640]=0;R(754,d+16|0,d+30|0);a=v[22640];v[22640]=0;if((a|0)==1){break x}v[22640]=0;ha(953,d+80|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[22640];v[22640]=0;if((a|0)==1){break w}v[22640]=0;R(471,d+8|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break v}v[22640]=0;Q(429,d+8|0,d+80|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break v}vb(d+80|0);vb(d+16|0);vb(d+32|0);vb(d+48|0);Hb(d- -64|0);break b}b=P()|0;O()|0;break r}b=P()|0;O()|0;break s}b=P()|0;O()|0;break t}b=P()|0;O()|0;break u}b=P()|0;O()|0;vb(d+80|0)}vb(d+16|0)}vb(d+32|0)}vb(d+48|0)}Hb(d- -64|0);break c}a=0;break a}b=P()|0;O()|0;vb(a)}S(b|0);L()}a=1}gb=d+96|0;return a|0}function nx(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-96|0;gb=e;a:{b:{c:{if(j=1,k=id(a,11),l=v[a+4>>2],l?j:k){g=v[a+28>>2];b=e;d=v[a+12>>2];f=v[a+64>>2];c=f+v[a+8>>2]|0;d=Bh(b+80|0,c,c>>>0<f>>>0?d+1|0:d);c=v[d+12>>2];v[b+32>>2]=v[d+8>>2];v[b+36>>2]=c;b=v[d+4>>2];v[e+24>>2]=v[d>>2];v[e+28>>2]=b;gk(g,e+24|0);b=v[a+28>>2];if(_l(v[v[b>>2]-12>>2]+b|0)){kh(a,1073741826);break a}d=v[a+92>>2];g=a+44|0;b=g;c=qf(b);d:{if(d>>>0>c>>>0){f=gb-32|0;gb=f;e:{c=d-c|0;f:{if(c>>>0<=v[wb(b)>>2]-v[b+4>>2]>>4>>>0){h=gb-16|0;gb=h;c=Zp(h,b,c);d=v[c+4>>2];i=v[c+8>>2];if((d|0)!=(i|0)){while(1){wb(b);zG(d);d=d+16|0;v[c+4>>2]=d;if((d|0)!=(i|0)){continue}break}}$b(c);gb=h+16|0;break f}d=wb(b);d=WG(f+8|0,fx(b,qf(b)+c|0),qf(b),d);v[22640]=0;VG(d,c);c=v[22640];v[22640]=0;if((c|0)==1){break e}ax(b);wb(b);c=d+4|0;cl(v[b>>2],v[b+4>>2],c);wc(b,c);wc(b+4|0,d+8|0);wc(wb(b),cc(d));v[d>>2]=v[d+4>>2];EG(b,qf(b));UG(d)}gb=f+32|0;break d}a=P()|0;O()|0;UG(d);S(a|0);L()}if(c>>>0>d>>>0){d=v[b>>2]+(d<<4)|0;qf(b);QG(b,d);si(b);qf(b)}}h=a+32|0;Ys(h,v[a+92>>2]<<2);if(v[a+92>>2]){c=0;while(1){b=v[a+28>>2];if(_l(v[v[b>>2]-12>>2]+b|0)){kh(a,1073741828);break a}b=x[a+16>>1];u[e+78>>1]=b;if((b|0)==65535){qx(v[a+28>>2],e+78|0);b=x[e+78>>1]}f=pc(h);v[e+72>>2]=f;g:{if(!b){break g}d=b;f=v[e+72>>2];if(b>>>0>-1-f>>>0){break g}mx(h,d+f|0);ol(v[a+28>>2],kc(h,v[e+72>>2]),d);f=v[e+72>>2]}j=Qc(g,c),k=b,u[j+12>>1]=k;j=Qc(g,c),k=f,v[j>>2]=k;if(id(a,6)){jl(v[a+28>>2],e+56|0);if(y[e+60>>2]>2147483647){break c}j=Qc(g,c),k=v[e+56>>2],v[j+4>>2]=k}b=v[a+4>>2];h:{if(b){j=Qc(g,c),k=b,v[j+8>>2]=k;break h}if(!id(a,7)){break h}jl(v[a+28>>2],e+56|0);if(y[e+60>>2]>2147483647){break b}j=Qc(g,c),k=v[e+56>>2],v[j+8>>2]=k}i:{if(v[Qc(g,c)+8>>2]==-1){break i}if(id(a,6)){break i}if(c){b=Qc(g,c-1|0);b=v[b+8>>2]+v[b+4>>2]|0}else{b=0}j=Qc(g,c),k=b,v[j+4>>2]=k}if(id(a,8)){u[e+56>>1]=0;qx(v[a+28>>2],e+56|0);b=id(a,9);tm(v[a+28>>2],x[e+56>>1]<<b,-1)}c=c+1|0;if(c>>>0<y[a+92>>2]){continue}break}}se(e+56|0,v[a+28>>2]);b=v[e+68>>2];v[a+72>>2]=v[e+64>>2];v[a+76>>2]=b}kl(a,4,1);g=v[a+76>>2];f=v[a+88>>2];c=f+v[a+8>>2]|0;d=v[a+12>>2];d=c>>>0<f>>>0?d+1|0:d;b=c;c=(f|0)==v[a+64>>2];f=c?v[a+72>>2]:b;v[a+80>>2]=f;b=c?g:d;v[a+84>>2]=b;d=v[a+28>>2];b=Bh(e+40|0,f,b);c=v[b+12>>2];v[e+16>>2]=v[b+8>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;gk(d,e+8|0);if(id(a,6)){break a}if(!(j=1,k=id(a,7),l=v[a+4>>2],l?j:k)){break a}b=v[a+92>>2];if(!b){break a}d=a+44|0;c=v[a+80>>2];a=v[a+8>>2];c=c-a|0;a=0;while(1){g=Qc(d,a);v[g+4>>2]=c+v[g+4>>2];a=a+1|0;if((b|0)!=(a|0)){continue}break}break a}kh(a,1073741829);break a}kh(a,1073741829)}gb=e+96|0}function yea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=gb-48|0;gb=c;if(hi(b)){h=Hi(b);j=v[b+12>>2];f=c+32|0;e=Gg(f);a:{d=h;if(!d){break a}v[22640]=0;R(637,f|0,d|0);g=v[22640];v[22640]=0;if((g|0)!=1){v[22640]=0;KN(f,d);d=v[22640];v[22640]=0;if((d|0)!=1){break a}}a=P()|0;O()|0;nv(e);S(a|0);L()}b:{if(!j){break b}while(1){d=v[v[a>>2]-12>>2];v[22640]=0;d=Tf(a+d|0);e=v[22640];v[22640]=0;c:{if((e|0)!=1){d:{if(!d){break b}v[22640]=0;t[c+31|0]=0;Q(1488,a|0,c+31|0)|0;d=v[22640];v[22640]=0;e:{if((d|0)!=1){d=t[c+31|0];if(d){break e}i=i+1|0;break c}break d}t[c+30|0]=0;f:{if((d|0)>-1){break f}v[22640]=0;Q(1488,a|0,c+30|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){break f}break d}t[c+29|0]=0;gi(c+16|0);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=d&127;d=(d?d-1|0:0)&65535;k=d>>>0>=h>>>0;B:{C:{if(!k){v[22640]=0;g=Tc(b,i,d);e=v[22640];v[22640]=0;if((e|0)==1){break d}if(t[c+30|0]&1){break C}break z}g=c+16|0;e=w[c+30|0];if(!(e&1)){break B}}v[22640]=0;Q(1488,a|0,c+29|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break A}e=w[c+30|0]}if(e&2){break y}break x}e=w[c+29|0];l=_c(f,d),m=e,t[l|0]=m}l=g,m=w[_c(f,d)|0],t[l|0]=m;if(!(w[c+30|0]&2)){break v}}v[22640]=0;Q(1488,a|0,c+29|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break w}e=w[c+30|0]}if(e&4){break u}break t}e=w[c+29|0];l=_c(f,d),m=e,t[l+1|0]=m}l=g,m=w[_c(f,d)+1|0],t[l+1|0]=m;if(!(w[c+30|0]&4)){break r}}v[22640]=0;Q(1488,a|0,c+29|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break s}e=w[c+30|0]}if(e&8){break q}break p}e=w[c+29|0];l=_c(f,d),m=e,t[l+2|0]=m}l=g,m=w[_c(f,d)+2|0],t[l+2|0]=m;if(!(w[c+30|0]&8)){break n}}v[22640]=0;Q(1488,a|0,c+29|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break o}e=w[c+30|0]}if(e&16){break m}break l}e=w[c+29|0];l=_c(f,d),m=e,t[l+4|0]=m}l=g,m=w[_c(f,d)+4|0],t[l+4|0]=m;if(!(w[c+30|0]&16)){break j}}v[22640]=0;Q(1488,a|0,c+29|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break k}e=w[c+30|0]}if(e&32){break i}break g}e=w[c+29|0];l=_c(f,d),m=e,t[l+3|0]=m}l=g,m=w[_c(f,d)+3|0],t[l+3|0]=m;if(!(w[c+30|0]&32)){break h}}v[22640]=0;Q(1488,a|0,c+29|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break d}if(k){break g}e=w[c+29|0];l=_c(f,d),m=e,t[l+5|0]=m}l=g,m=w[_c(f,d)+5|0],t[l+5|0]=m}if(!(w[c+30|0]&64)){break c}v[22640]=0;Q(1488,a|0,c+15|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){d=w[c+15|0];v[22640]=0;W(1489,a|0,d|0,-1)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break c}}}}a=P()|0;O()|0;kn(f);S(a|0);L()}if(i>>>0<j>>>0){continue}break}}kn(f)}gb=c+48|0}function C7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-192|0;gb=d;a:{if(nk(b)){break a}e=w[wl(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Kl(d+160|0,b,v[b+4>>2]-1|0);e=v[d+164>>2];v[b>>2]=v[d+160>>2];v[b+4>>2]=e}Kd(d+160|0);e=v[d+160>>2];Kd(d+144|0);e=vl(e,v[d+148>>2],b);Kd(d+160|0);b:{c:{d:{e:{if((e|0)==v[d+164>>2]){a=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=a;a=uc(d+176|0,18693);e=v[d+188>>2];v[d+8>>2]=v[d+184>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Fc(d+8|0,d)){a=aa(8)|0;v[22640]=0;c=Q(112,d+160|0,7808)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}f=0;if(!c){break e}a=aa(8)|0;v[22640]=0;e=Q(2057,d+144|0,b|0)|0;b=v[22640];v[22640]=0;f:{g:{h:{if((b|0)!=1){v[22640]=0;U(2037,d+160|0,14731,e|0);b=v[22640];v[22640]=0;if((b|0)==1){break h}qc(a,d+160|0);c=0;v[22640]=0;U(223,a|0,55256,1936);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(d+160|0);break g}b=P()|0;O()|0;break f}b=P()|0;c=1;O()|0}vb(e);if(!c){break c}}da(a|0);break c}if(v[e+4>>2]!=2){a=aa(8)|0;v[22640]=0;c=Q(112,d+160|0,8924)|0;b=v[22640];v[22640]=0;if((b|0)!=1){qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+136>>2]=v[b>>2];v[d+140>>2]=c;c=uc(d+128|0,18693);e=v[d+140>>2];v[d+72>>2]=v[d+136>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Fc(d+72|0,d- -64|0)){a=aa(8)|0;v[22640]=0;c=Q(112,d+160|0,7808)|0;b=v[22640];v[22640]=0;if((b|0)!=1){qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+120>>2]=v[b>>2];v[d+124>>2]=c;c=uc(d+112|0,4903);e=v[d+124>>2];v[d+56>>2]=v[d+120>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Fc(d+56|0,d+48|0)){f=1;if(!w[a+28|0]){break e}f=65536/+y[v[a+24>>2]+480244>>2];break e}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=uc(d+96|0,4955);e=v[d+108>>2];v[d+40>>2]=v[d+104>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Fc(d+40|0,d+32|0)){f=1;if(!w[a+28|0]){break e}f=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break e}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;b=uc(d+80|0,4973);c=v[d+92>>2];v[d+24>>2]=v[d+88>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;f=0;if(!Fc(d+24|0,d+16|0)){break e}f=+y[v[a+24>>2]+480236>>2]*152587890625e-16}gb=d+192|0;return+f}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function rma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;e=gb-560|0;gb=e;a:{if(!Xc(b,1464)){break a}if(!ep(b,e+556|0)){break a}Gd(a,1);d=a+1074312|0;Yf(d,83);Ob(d,84,1);Ob(d,85,1);b:{if(je(e+556|0,33570)){d=Tb(e+32|0,5657);Eb(a+1298304|0,d);vb(d);d=Tb(e+32|0,12030);Eb(a+1298316|0,d);vb(d);d=Tb(e+32|0,12095);Eb(a+1298328|0,d);break b}if(!je(e+556|0,12670)){break a}d=Tb(e+32|0,5815);Eb(a+1298304|0,d);vb(d);d=Tb(e+32|0,9566);Eb(a+1298316|0,d);vb(d);d=Tb(e+32|0,12587);Eb(a+1298328|0,d)}vb(d);v[a+1298364>>2]=2;d=0;Xc(b,0);IC(b,a+1298268|0,20);u[a+480190>>1]=31;f=1;while(1){d=SB(b,e+32|0,(B(f,104)+a|0)+484380|0,((f<<5)+a|0)+946304|0,1)+d|0;f=f+1|0;if((f|0)!=32){continue}break}if(d>>>0>40){break a}bw(e+552|0,b);m=md(e+552|0);i=e+552|0;if(w[i|0]>128){break a}g=e+32|0;f=gb-32|0;gb=f;d=b;c:{if(Pb(d,512)){qD(f+24|0,g);g=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=g;gd(f+16|0,d,f+8|0);break c}hV(g)}gb=f+32|0;d=e+544|0;f=e+32|0;g=w[m|0];d:{while(1){if(g>>>0>=w[f|0]){f=f+1|0;if((d|0)!=(f|0)){continue}break d}break}break a}o=1;if(!c){break a}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;rh(a,0);n=a+484360|0;yf(Rb(n),w[i|0]);u[e+30>>1]=0;j=a+484344|0;vg(j,w[i|0]);if(w[i|0]){g=0;while(1){s=rc(Rb(n),g),x=g,u[s>>1]=x;if(qh(j,g&65535,64)){p=g<<2;h=0;while(1){Xc(b,(w[e+32+(h+p)|0]<<8)+1468|0);f=Tc(_b(j,g),0,h&65535);d=0;while(1){_u(b,f);e:{f:{l=w[f+3|0];g:{if((l|0)!=14){if(!l){if(w[f+5|0]){break f}break g}if((l-5&255)>>>0<5){break g}break f}if(w[f+5|0]<=15){break f}}t[f+3|0]=0;break e}Mf(f)}f=f+24|0;d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if((h|0)!=4){continue}break}s=e,x=Sb(_b(j,g)),v[s+24>>2]=x;h=0;while(1){d=0;while(1){f=d;h:{if(w[v[e+24>>2]+3|0]!=17?w[v[e+24>>2]+3|0]!=16:0){break h}t[v[e+24>>2]+3|0]=16;k=0;if(w[v[e+24>>2]+5|0]<16){break h}if(!(!(w[v[e+24>>2]+5|0]&15)|(w[v[e+24>>2]+5|0]&15)==(w[v[e+24>>2]+5|0]>>>4|0))){q=w[v[e+24>>2]+5|0]>>>4|0;r=w[v[e+24>>2]+5|0]&15;k=1}d=v[e+24>>2];t[d+5|0]=w[d+5|0]>>>4}Wj(e+24|0);d=f+1|0;if((f&65535)>>>0<3){continue}break}t[e+31|0]=r;t[e+30|0]=q;d=k&255;if(d){Gm(_b(j,g),Qe(Be(e+8|0,16,w[(e+d|0)+29|0]),h));d=k+1|0;k=(d&255)==3?1:d}else{k=0}h=h+1|0;if((h|0)!=64){continue}break}}g=g+1|0;if(g>>>0<w[i|0]){continue}break}}if(!(c&2)){break a}Xc(b,(w[m|0]<<8)+1468|0);f=1;while(1){c=(B(f,104)+a|0)+484380|0;if(v[c>>2]){zg(Pc(e+8|0,8,1,0,0),c,b)}f=f+1|0;if((f|0)!=32){continue}break}}gb=e+560|0;return o|0}function ana(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{g=w[a+3|0];switch(g-4|0){case 23:break j;case 22:break k;case 21:break l;case 20:break m;case 18:break n;case 17:break o;case 16:break p;case 14:break q;case 13:break r;case 12:break s;case 11:break t;case 10:break u;case 9:break v;case 8:break w;case 5:break x;case 4:break y;case 0:break z;case 42:break c;case 37:break d;case 28:break e;case 27:break f;case 26:break g;case 25:break h;case 24:break i;default:break b}}t[a+3|0]=5;t[f+15|0]=w[a+5|0]>>>3;t[f+14|0]=15;b=w[ac(f+15|0,f+14|0)|0];t[f+13|0]=w[a+5|0]<<1&30;t[f+12|0]=15;h=a,i=w[ac(f+13|0,f+12|0)|0]|b<<4,t[h+5|0]=i;break a}t[a+3|0]=0;break a}if((w[a+5|0]-1&255)>>>0<=19){t[a+3|0]=16;break a}t[a+3|0]=0;break a}t[a+3|0]=13;b=w[a+5|0];A:{if(!e){if(b>>>0>152){break A}t[a+5|0]=B((b&240)>>>4|0,10)+(b&15);break a}t[a+5|0]=(b&127)+1>>>1;break a}t[a+3|0]=0;break a}t[a+3|0]=11;break a}t[a+3|0]=0;break a}e=w[a+5|0];if(!e){t[a+3|0]=14;break a}if(e>>>0<=240){t[a+3|0]=17;if(e>>>0<=2){t[a+5|0]=112;break a}h=a,i=fn(+(gW(e,b,c,d)>>>0)*1e-4),t[h+5|0]=i;break a}t[a+3|0]=0;break a}t[a+3|0]=31;t[a+5|0]=w[a+5|0]|128;break a}t[a+3|0]=19;t[f+11|0]=15;h=a,i=w[ac(a+5|0,f+11|0)|0]|16,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+10|0]=15;h=a,i=w[ac(a+5|0,f+10|0)|0]|32,t[h+5|0]=i;break a}t[a+3|0]=5;t[f+9|0]=(w[a+5|0]>>>4|0)+1;t[f+8|0]=15;b=ac(f+9|0,f+8|0);t[a+5|0]=w[a+5|0]&15|w[b|0]<<4;break a}t[a+3|0]=19;t[a+5|0]=w[a+5|0]&15|80;break a}t[a+3|0]=19;t[f+7|0]=15;h=a,i=w[ac(a+5|0,f+7|0)|0]|96,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+6|0]=15;h=a,i=w[ac(a+5|0,f+6|0)|0]|192,t[h+5|0]=i;break a}t[a+3|0]=10;break a}t[a+3|0]=19;t[f+5|0]=15;h=a,i=w[ac(a+5|0,f+5|0)|0]|160,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+4|0]=15;h=a,i=w[ac(a+5|0,f+4|0)|0]|176,t[h+5|0]=i;break a}b=(w[a+5|0]<<24)-16777216>>24;if((b|0)>=0){t[a+5|0]=b;t[a+3|0]=31;break a}t[a+3|0]=0;break a}t[a+3|0]=14;break a}t[a+3|0]=19;t[f+3|0]=15;h=a,i=w[ac(a+5|0,f+3|0)|0]|224,t[h+5|0]=i;break a}b=w[a+5|0];if(b&240){t[a+3|0]=19;t[a+5|0]=b>>>4|208;break a}if(b&15){t[a+3|0]=19;t[a+5|0]=b|144;break a}t[a+3|0]=0;break a}if(!(w[a+5|0]|w[a+4|0])){t[a+5|0]=159;t[a+3|0]=20;break a}t[a+3|0]=0;break a}b=w[a+4|0];if(b){t[a+3|0]=44;h=a,i=dm(Uc(((w[a+5|0]<<8&65280)>>>0)/(b>>>0)|0,0)),t[h+5|0]=i;break a}t[a+3|0]=0;break a}b=w[a+5|0];if((b-17&255)>>>0>=223){t[a+3|0]=9;h=a,i=di(((b^128)<<3)-896|0),t[h+5|0]=i;break a}t[a+3|0]=0;break a}if(g>>>0<=15){Mf(a);break a}t[a+3|0]=0}gb=f+16|0}function G8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=gb-192|0;gb=d;g=d+176|0;iL(g);v[g>>2]=55444;ad(g+4|0);h=a;lo(v[a+24>>2],g);e=w[a+62|0];f=w[a+61|0];j=w[a+60|0];k=v[a+24>>2];b=Je(d+152|0,b);v[22640]=0;i=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=i;v[d+16>>2]=v[b+16>>2];i=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=i;b=j?13:15;b=f?b&14:b;b=W(2061,k|0,d|0,(e?b&3:b)|0)|0;e=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((e|0)==1){break p}if(!b){b=aa(8)|0;v[22640]=0;c=Q(112,d+136|0,9314)|0;a=v[22640];v[22640]=0;if((a|0)!=1){qc(b,c);v[22640]=0;U(223,b|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=P()|0;O()|0;da(b|0);break b}if(!w[a+63|0]){v[22640]=0;R(2062,a|0,a+36|0);b=v[22640];v[22640]=0;if((b|0)==1){break p}}t[a+28|0]=1;lo(v[h+24>>2],v[a+4>>2]);v[22640]=0;R(2063,d+136|0,g|0);b=v[22640];v[22640]=0;if((b|0)==1){break o}l=d,m=Sb(d+136|0),v[l+128>>2]=m;l=d,m=Wb(d+136|0),v[l+120>>2]=m;if(Gb(d+128|0,d+120|0)){h=a+68|0;while(1){b=v[d+128>>2];e=v[b>>2];v[22640]=0;f=e;e=b+4|0;U(2064,a|0,f|0,e|0);f=v[22640];v[22640]=0;if((f|0)==1){break d}b=v[b>>2];v[22640]=0;R(2065,d+56|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;R(2039,d+72|0,d+56|0);b=v[22640];v[22640]=0;if((b|0)==1){break g}v[22640]=0;b=Q(112,d+40|0,14831)|0;f=v[22640];v[22640]=0;if((f|0)==1){break i}v[22640]=0;U(2058,d+88|0,d+72|0,b|0);f=v[22640];v[22640]=0;if((f|0)==1){break k}v[22640]=0;U(735,d+104|0,d+88|0,e|0);e=v[22640];v[22640]=0;if((e|0)==1){break m}v[22640]=0;R(1429,h|0,d+104|0);e=v[22640];v[22640]=0;if((e|0)==1){break n}vb(d+104|0);vb(d+88|0);vb(b);vb(d+72|0);vb(d+56|0);Wo(d+128|0);if(Gb(d+128|0,d+120|0)){continue}break}}l=d,m=or(c),v[l+104>>2]=m;l=d,m=zh(c),v[l+88>>2]=m;q:{while(1){v[22640]=0;b=kg(d+104|0,d+88|0);c=v[22640];v[22640]=0;r:{if((c|0)!=1){if(b){break r}Gt(d+136|0);Et(g);gb=d+192|0;return}a=P()|0;O()|0;break c}v[22640]=0;c=ue(d+104|0);b=v[22640];v[22640]=0;s:{if((b|0)==1){break s}v[22640]=0;b=Q(111,d+24|0,c|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break s}v[22640]=0;Y(2e3,a|0,b|0,c+12|0,0);c=v[22640];v[22640]=0;if((c|0)==1){break q}vb(b);Oj(d+104|0);continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(b);break c}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+104|0);break l}a=P()|0;O()|0}vb(d+88|0);break j}a=P()|0;O()|0}vb(b);break h}a=P()|0;O()|0}vb(d+72|0);break f}a=P()|0;O()|0}vb(d+56|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0}Gt(d+136|0)}Et(g);S(a|0)}L()}function QZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-384|0;gb=e;vc(b);f=gb-32|0;gb=f;j=e+344|0;aE(f+24|0,j);g=xb(f+24|0);d=v[f+28>>2];h=v[f+24>>2];v[f+8>>2]=h;v[f+12>>2]=d;v[f>>2]=h;v[f+4>>2]=d;d=b;fc(f+16|0,d,f);h=xb(f+16|0);if((h|0)==(g|0)){Yb(d,xb(f+24|0))}gb=f+32|0;d=(g|0)==(h|0);if(!d){$D(j)}a:{b:{if(!d){break b}if(!tE(e+344|0)){break b}if(!Pb(b,Uc(sE(e+344|0),jb))){break b}c:{if(!c){break c}Gd(a,2097152);wg(a);i=1;rh(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[e+376|0];v[a+480204>>2]=B(w[e+377|0],1e4);u[a+480190>>1]=w[e+378|0];if(w[e+381|0]<w[e+380|0]){af(Rb(a+484360|0),w[e+381|0])}d=Tb(e+80|0,3582);Eb(a+1298304|0,d);vb(d);d=Tb(e+80|0,8405);Eb(a+1298316|0,d);vb(d);v[a+1298364>>2]=5;cw(b,e+80|0);Or(Rb(a+484360|0),e+80|0,w[e+380|0],65535,65535);if(x[a+480190>>1]){j=1;while(1){qE(b,e+40|0);h=gb-16|0;gb=h;g=(B(i,104)+a|0)+484380|0;td(g,0);k=e+40|0;t[g+37|0]=w[k+22|0]<<4;t[h+15|0]=w[k+23|0];t[h+14|0]=64;m=g,n=w[ac(h+15|0,h+14|0)|0]<<2,u[m+30>>1]=n;t[g+36|0]=w[k+24|0];d=k+25|0;v[g>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);f=k+33|0;d:{if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<3){break d}l=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=k+29|0;if(l>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0){break d}u[g+34>>1]=x[g+34>>1]|2;v[g+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[g+8>>2]=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))}gb=h+16|0;Mk(e+8|0,2,e+40|0);Bc(e+24|0,e+8|0);v[22640]=0;Q(333,((i<<5)+a|0)+946304|0,e+24|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break a}vb(e+24|0);j=j+1|0;i=j&65535;if(i>>>0<=x[a+480190>>1]){continue}break}}Yb(b,B(64-w[e+378|0]|0,37));f=a+484344|0;vg(f,w[e+379|0]);if(w[e+379|0]){i=c&1;j=0;while(1){e:{f:{if(i){if(qh(f,j&65535,64)){break f}}Yb(b,2048);break e}d=_b(f,j);m=e,n=Sb(d),v[m+40>>2]=n;m=e,n=Wb(d),v[m+24>>2]=n;if(!Gb(e+40|0,e+24|0)){break e}while(1){d=v[e+40>>2];xn(e+8|0,b);g=md(e+8|0);h=Re(e+8|0);k=aj(e+8|0);l=w[e+8|0];if((l-1&255)>>>0<=106){t[d|0]=l+13}t[d+1|0]=w[g|0];t[d+3|0]=w[h|0];t[d+5|0]=w[k|0];Mf(d);Wj(e+40|0);if(Gb(e+40|0,e+24|0)){continue}break}}j=j+1|0;if(j>>>0<w[e+379|0]){continue}break}}if(!(c&2)){break c}i=1;c=Pc(e+40|0,8,1,0,0);if(!x[a+480190>>1]){break c}while(1){zg(c,(B(i&65535,104)+a|0)+484380|0,b);i=i+1|0;if(x[a+480190>>1]>=(i&65535)>>>0){continue}break}}i=1}gb=e+384|0;return i|0}a=P()|0;O()|0;vb(e+24|0);S(a|0);L()}function qG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;g=gb-48|0;gb=g;o(+a);d=j(1)|0;h=j(0)|0;a:{b:{e=d;d=e;f=e&2147483647;c:{if(f>>>0<=1074752122){if((d&1048575)==598523){break c}if(f>>>0<=1073928572){if((e|0)>0?1:(e|0)>=0){a=a+-1.5707963267341256;c=a+-6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+-6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0?1:(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(f>>>0<=1075594811){if(f>>>0<=1075183036){if((f|0)==1074977148){break c}if((e|0)>0?1:(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((f|0)==1075388923){break c}if((e|0)>0?1:(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(f>>>0>1094263290){break b}}k=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+k*-1.5707963267341256;i=k*6.077100506506192e-11;a=c-i;A[b>>3]=a;o(+a);d=j(1)|0;j(0)|0;h=f>>>20|0;e=(h-(d>>>20&2047)|0)<17;if(D(k)<2147483648){d=~~k}else{d=-2147483648}d:{if(e){break d}i=c;a=k*6.077100506303966e-11;c=c-a;i=k*2.0222662487959506e-21-(i-c-a);a=c-i;A[b>>3]=a;e=h;o(+a);h=j(1)|0;j(0)|0;if((e-(h>>>20&2047)|0)<50){break d}i=c;a=k*2.0222662487111665e-21;c=c-a;i=k*8.4784276603689e-32-(i-c-a);a=c-i;A[b>>3]=a}A[b+8>>3]=c-a-i;break a}if(f>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,h|0);l(1,e&1048575|1096810496);a=+n();d=g+16|0;h=g+16|8;m=1;while(1){if(D(a)<2147483648){p=~~a}else{p=-2147483648}c=+(p|0);A[d>>3]=c;a=(a-c)*16777216;if(m){m=0;d=h;continue}break}A[g+32>>3]=a;p=g+16|0;m=g;f=(f>>>20|0)-1046|0;e:{if(a==0){d=1;while(1){h=d;d=d-1|0;if(A[(g+16|0)+(h<<3)>>3]==0){continue}break}d=h+1|0;break e}d=3}d=SI(p,m,f,d,1);a=A[g>>3];if((e|0)<-1?1:(e|0)<=-1){A[b>>3]=-a;A[b+8>>3]=-A[g+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[g+8>>3]}gb=g+48|0;return d}function Ufa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0;f=gb-32|0;gb=f;p=a+4|0;o=v[p>>2];n=a+20|0;s=v[ze(n,b)>>2];a:{if(s+1>>>0<2){break a}h=(B(b,872)+o|0)+616|0;if(!Ki(h)){if(!w[ze(n,b)+4|0]){break a}}i=B(b,872)+o|0;if(!v[i+720>>2]){break a}A=v[(v[i+704>>2]&2?i+700|0:i+692|0)>>2];g=v[i+696>>2];j=v[i+700>>2];Db(f,v[a>>2]+1074312|0,31);u=Cb(f);y=i+1362|0;l=w[y|0];z=i+624|0;e=sw(z,c);k=jb;m=k;v[f+24>>2]=e;v[f+28>>2]=k;if(w[i+704|0]&128){v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+m|0)}k=j-g|0;D=k<<1;e=B(b,872)+o|0;E=e+1316|0;m=e+1467|0;F=(l&17)!=1;b:{while(1){c:{if(d>>>0>q>>>0){g=(w[y|0]&17)==1;break c}t[m|0]=w[m|0]&254;e=Tc(_b(v[a>>2]+484344|0,x[v[p>>2]+70>>1]),v[v[p>>2]+48>>2],b);j=w[e+3|0];if(w[e+2|0]==11){nA(f,v[a>>2],e,0);l=Re(f);zo(v[a>>2],h,x[f>>1]);g=1;if(w[l|0]){break c}}g=1;d:{switch(j-4|0){case 0:zo(v[a>>2],h,w[e+5|0]);break c;case 2:break d;default:break c}}zo(v[a>>2],h,0)}v[f+20>>2]=v[E>>2];if(u){Yt(v[a>>2],h)}if(!F){zO(v[a>>2],h,f+20|0);g=1}if(!u){Yt(v[a>>2],h)}v[f+16>>2]=0;AO(h,f+16|0);e:{f:{if(w[i+705|0]&2){break f}g:{if(!g){if(!w[ze(n,b)+4|0]){break g}}if(w[m|0]&48){OS(h,C(1),0,v[a>>2]);e=w[m|0];t[m|0]=(e&32?-33:-17)&e}Fz(f,v[a>>2],h,v[f+20>>2],0);g=v[f+4>>2];e=z;v[e>>2]=v[f>>2];v[e+4>>2]=g;G=ze(n,b),H=0,t[G+4|0]=H;e=sw(e,c);g=jb;j=g;v[f+24>>2]=e;v[f+28>>2]=g;if(!(w[i+704|0]&128)){break g}v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+j|0)}Ub(h,f+24|0);g=v[h+4>>2];j=g;l=v[h>>2];if(A>>>0>g>>>0){break f}e=v[i+704>>2];if(!(e&2)){break e}if(e&4){r=v[i+696>>2];l=r;e=l;if((e|0)>(j|0)?1:0){v[f>>2]=0;v[f+4>>2]=l<<1;G=h,H=Mg(f,h),v[G>>2]=H;v[h+4>>2]=jb;v[i+704>>2]=v[i+704>>2]^128;e=v[f+24>>2];g=0-(v[f+28>>2]+((e|0)!=0)|0)|0;v[f+24>>2]=0-e;v[f+28>>2]=g;r=v[i+696>>2];g=v[h+4>>2]}Db(f,v[a>>2]+1074312|0,33);e=(g-r>>>0)%(D-Cb(f)>>>0)|0;h:{if(e>>>0>=k>>>0){v[h+4>>2]=v[i+700>>2]+(k-e|0);g=v[i+704>>2];if(!(g&128)){break h}break f}v[h+4>>2]=e+v[i+696>>2];g=v[i+704>>2];if(!(g&128)){break f}}v[i+704>>2]=g^128;e=v[f+24>>2];g=0-(v[f+28>>2]+((e|0)!=0)|0)|0;v[f+24>>2]=0-e;v[f+28>>2]=g;break f}j=v[i+700>>2];if(j+k>>>0<=g>>>0){g=j+((g-j>>>0)%(k>>>0)|0)|0}while(1){e=g;g=e-k|0;if(e>>>0>=j>>>0){continue}break}v[h>>2]=l;v[h+4>>2]=e}q=q+1|0;if((s|0)!=(q|0)){continue}break b}break}_A(h);v[(B(b,872)+o|0)+1324>>2]=0}G=ze(n,b),H=0,v[G>>2]=H}gb=f+32|0}function E4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-320|0;gb=d;e=gb-16|0;gb=e;v[a>>2]=0;f=a+32|0;Ys(f,32);t[e+15|0]=0;aq(f,e+15|0);gb=e+16|0;e=v[a+28>>2];a:{if(!Tf(v[v[e>>2]-12>>2]+e|0)){kh(a,1073741825);break a}se(d+56|0,v[a+28>>2]);e=v[d+68>>2];v[a+8>>2]=v[d+64>>2];v[a+12>>2]=e;f=d+56|0;v[f>>2]=3;g=v[a+28>>2];h=d+16|0;e=0;if(v[f>>2]){while(1){Rh(g,e+h|0);e=e+1|0;if(e>>>0<y[f>>2]){continue}break}}if(yd(d+16|0,27744,3)){kh(a,1073741827);break a}e=0;t[d+319|0]=0;Rh(v[a+28>>2],d+319|0);Qb(d+56|0,0,256);g=w[d+319|0];b:{if(!g){f=d+56|0;break b}f=d+56|0;ol(v[a+28>>2],f,g);e=w[d+319|0]}g=b;b=Xn(d+16|0,f,e);e=xx(g,b);Hb(b);if(!e){kh(a,1073741830)}if(w[a+3|0]&64){break a}Rh(v[a+28>>2],d+55|0);e=w[d+55|0];b=e&3;u[a+16>>1]=(b|0)==3?4:b;if(pj(e,6)){kl(a,9,1)}v[d+48>>2]=0;wH(v[a+28>>2],d+48|0);b=v[d+48>>2];t[d+47|0]=0;if(b>>>0>=2){Rh(v[a+28>>2],d+55|0);f=w[d+55|0];if(!f){Rh(v[a+28>>2],d+47|0);f=w[d+55|0]}tm(v[a+28>>2],b+(f&255?-1:-2)|0,-1)}v[d+32>>2]=0;v[d+36>>2]=0;c:{if(!pj(e,4)){break c}jl(v[a+28>>2],d+32|0);b=v[d+36>>2];f=v[d+32>>2];v[a+56>>2]=f;v[a+60>>2]=b;g=v[c+4>>2];if((g|0)==(b|0)&y[c>>2]>=f>>>0|b>>>0<g>>>0){break c}kh(a,536871424)}if(pj(e,5)){Rh(v[a+28>>2],d+55|0);tm(v[a+28>>2],w[d+55|0],-1)}d:{if(!pj(w[d+47|0],0)){break d}Rh(v[a+28>>2],d+55|0);b=w[d+55|0];b=b&1?-1:b>>>1|0;u[a+16>>1]=b;if(b){break d}kh(a,536871168)}v[a+4>>2]=0;b=1;if(pj(w[d+47|0],1)){wH(v[a+28>>2],a+4|0)}kl(a,6,pj(e,2));kl(a,7,pj(e,3));kl(a,5,x[a+16>>1]!=0);kl(a,8,pj(e,7));e:{if(id(a,5)){break e}if(id(a,6)){break e}if(id(a,7)){break e}b=id(a,8)}kl(a,11,b);id(a,11);b=w[d+47|0];if(pj(b,2)){u[d+16>>1]=0;qx(v[a+28>>2],d+16|0);tm(v[a+28>>2],B(x[d+16>>1],id(a,9)?2:1),-1);b=w[d+47|0]}if(pj(b,3)){tm(v[a+28>>2],5,-1)}jl(v[a+28>>2],d+32|0);c=v[d+36>>2];b=v[d+32>>2];if(!c&b>>>0>=16001|c){kh(a,1073741831);break a}v[a+92>>2]=b;if(!b){kh(a,536871040)}f:{if(!id(a,11)){break f}jl(v[a+28>>2],d+32|0);b=v[d+36>>2];if((b|0)==2147483647|b>>>0<2147483647){break f}kh(a,1073741829);break a}se(d,v[a+28>>2]);XH(d+16|0,d,v[a+8>>2],v[a+12>>2]);b=v[d+28>>2];e=v[d+24>>2];if(!(b?0:(b|0)>0?1:(b|0)>=0)){kh(a,1073741832);break a}v[a+88>>2]=e;i=a,j=v[(id(a,11)?d+32|0:a+88|0)>>2],v[i+64>>2]=j;if(!id(a,11)){c=v[a+12>>2];e=v[a+88>>2];f=e+v[a+8>>2]|0;c=f>>>0<e>>>0?c+1|0:c;v[a+72>>2]=f;v[a+76>>2]=c}kl(a,10,1)}gb=d+320|0}function g3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=gb-16|0;gb=k;m=Hx(g);n=jx(g);Qg(k,n);v[f>>2]=d;a:{b:{c:{h=a;g=w[h|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[22640]=0;g=Q(2480,m|0,g<<24>>24)|0;h=v[22640];v[22640]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;h=a+1|0}d:{e:{f:{if(!(w[h|0]!=48|(c-h|0)<2|(w[h+1|0]|32)!=120)){v[22640]=0;g=Q(2480,m|0,48)|0;i=v[22640];v[22640]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=g;g=t[h+1|0];v[22640]=0;g=Q(2480,m|0,g|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=g;h=h+2|0;if(h>>>0>=c>>>0){break e}g=h;while(1){g:{i=t[g|0];v[22640]=0;j=fa(2454)|0;l=v[22640];v[22640]=0;if((l|0)==1){break g}v[22640]=0;i=wx(i,j);j=v[22640];v[22640]=0;if((j|0)==1){break g}if(!i){break d}g=g+1|0;if((g|0)!=(c|0)){continue}break f}break}break a}if(c>>>0<=h>>>0){break e}g=h;while(1){i=t[g|0];v[22640]=0;fa(2454)|0;j=v[22640];v[22640]=0;if((j|0)==1){break a}v[22640]=0;i=Sh(i);j=v[22640];v[22640]=0;if((j|0)==1){break a}if(!i){break d}g=g+1|0;if((g|0)!=(c|0)){continue}break}}g=c;break d}g=h}h:{if(dd(k)){i=v[f>>2];v[22640]=0;Y(2470,m|0,h|0,g|0,i|0);i=v[22640];v[22640]=0;if((i|0)==1){break a}v[f>>2]=v[f>>2]+(g-h<<2);break h}mm(h,g);i=0;v[22640]=0;o=T(2468,n|0)|0;j=v[22640];v[22640]=0;p=(h-a<<2)+d|0;i:{j:{if((j|0)!=1){if(g>>>0<=h>>>0){break j}j=0;while(1){k:{if(t[mc(k,i)|0]<1){break k}if(t[mc(k,i)|0]!=(j|0)){break k}j=v[f>>2];v[f>>2]=j+4;v[j>>2]=o;i=(Ab(k)-1>>>0>i>>>0)+i|0;j=0}l=t[h|0];v[22640]=0;q=Q(2480,m|0,l|0)|0;l=v[22640];v[22640]=0;if((l|0)==1){break a}l=v[f>>2];v[f>>2]=l+4;v[l>>2]=q;j=j+1|0;h=h+1|0;if((h|0)!=(g|0)){continue}break}h=l+4|0;break i}break a}h=v[f>>2]}Hs(p,h)}l:{if(c>>>0>g>>>0){while(1){h=w[g|0];if((h|0)==46){v[22640]=0;i=T(2471,n|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break a}j=v[f>>2];h=j+4|0;v[f>>2]=h;v[j>>2]=i;g=g+1|0;break l}v[22640]=0;i=Q(2480,m|0,h<<24>>24)|0;h=v[22640];v[22640]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=i;g=g+1|0;if((g|0)!=(c|0)){continue}break}h=h+4|0;g=c;break l}h=v[f>>2]}v[22640]=0;Y(2470,m|0,g|0,c|0,h|0);h=v[22640];v[22640]=0;if((h|0)==1){break a}h=f;f=v[f>>2]+(c-g<<2)|0;v[h>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;vb(k);gb=k+16|0;return}a=P()|0;O()|0;vb(k);S(a|0);L()}function TU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-80|0;gb=e;a:{if(v[b+4>>2]==v[d+4>>2]){f=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=f;b=v[c+4>>2];v[e+64>>2]=v[c>>2];v[e+68>>2]=b;f=le(e+56|0,d);b=v[e+76>>2];v[e+8>>2]=v[e+72>>2];v[e+12>>2]=b;b=v[e+68>>2];v[e>>2]=v[e+64>>2];v[e+4>>2]=b;b=gb-16|0;gb=b;d=Mj(e,e+8|0);v[b+12>>2]=d;b:{if((d|0)<1){break b}c=v[e+12>>2];c:{if(!c){c=v[f>>2];break c}g=32-c|0;v[b+8>>2]=g;c=v[ld(b+8|0,b+12|0)>>2];v[b+12>>2]=v[b+12>>2]-c;d=v[f>>2];g=-1<<v[e+12>>2]&-1>>>g-c;h=v[e+8>>2];v[d>>2]=v[d>>2]&(g^-1)|g&v[h>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;c=d+(c>>>3&536870908)|0;v[f>>2]=c;v[e+8>>2]=h+4;d=v[b+12>>2]}g=c;d=(d|0)/32|0;c=d<<2;sh(g,v[e+8>>2],c);d=v[b+12>>2]-(d<<5)|0;v[b+12>>2]=d;g=c+v[f>>2]|0;v[f>>2]=g;if((d|0)<1){break b}c=c+v[e+8>>2]|0;v[e+8>>2]=c;d=-1>>>32-d|0;v[g>>2]=v[g>>2]&(d^-1)|d&v[c>>2];v[f+4>>2]=v[b+12>>2]}le(a,f);gb=b+16|0;break a}f=v[b+4>>2];v[e+48>>2]=v[b>>2];v[e+52>>2]=f;b=v[c+4>>2];v[e+40>>2]=v[c>>2];v[e+44>>2]=b;g=le(e+32|0,d);b=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=b;b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;f=gb-16|0;gb=f;d=Mj(e+16|0,e+24|0);v[f+12>>2]=d;d:{if((d|0)<1){break d}b=v[e+28>>2];e:{if(!b){c=v[g+4>>2];break e}c=32-b|0;v[f+8>>2]=c;b=v[ld(f+8|0,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-b;d=v[g+4>>2];h=v[v[e+24>>2]>>2];j=v[e+28>>2];v[f+8>>2]=b;k=32-d|0;v[f+4>>2]=k;l=Fb(f+8|0,f+4|0);i=v[g>>2];j=h&(-1<<j&-1>>>c-b);c=v[g+4>>2];d=v[e+28>>2];h=v[l>>2];v[i>>2]=(c>>>0>d>>>0?j<<c-d:j>>>d-c|0)|v[i>>2]&(-1<<c&-1>>>k-h^-1);k=c+h|0;c=k&31;v[g+4>>2]=c;i=i+(k>>>3&536870908)|0;v[g>>2]=i;b=b-h|0;if((b|0)>=1){v[i>>2]=v[i>>2]&(-1>>>32-b^-1)|j>>>d+h;v[g+4>>2]=b;c=b}v[e+24>>2]=v[e+24>>2]+4;d=v[f+12>>2]}i=32-c|0;if((d|0)>=32){k=-1<<c;l=k^-1;h=v[e+24>>2];b=v[g>>2];j=v[b>>2];while(1){d=v[h>>2];v[b>>2]=j&l|d<<c;j=k&v[b+4>>2]|d>>>i;v[b+4>>2]=j;m=v[f+12>>2];d=m-32|0;v[f+12>>2]=d;h=h+4|0;b=b+4|0;if((m|0)>63){continue}break}v[e+24>>2]=h;v[g>>2]=b}if((d|0)<1){break d}j=v[v[e+24>>2]>>2];v[f+8>>2]=i;b=ld(f+12|0,f+8|0);c=v[g>>2];h=v[g+4>>2];b=v[b>>2];k=v[c>>2]&(-1<<h&-1>>>i-b^-1);i=j&-1>>>32-d;v[c>>2]=k|i<<h;d=b+h|0;v[g+4>>2]=d&31;c=c+(d>>>3&536870908)|0;v[g>>2]=c;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<1){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|i>>>b;v[g+4>>2]=v[f+12>>2]}le(a,g);gb=f+16|0}gb=e+80|0}function Cla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=gb-48|0;gb=l;f=v[a+4>>2];e=le(l+40|0,b);i=le(l+32|0,c);d=gb-16|0;gb=d;e=SU(le(d+8|0,e),le(d,i));gb=d+16|0;d=e+v[a+4>>2]|0;v[a+4>>2]=d;a:{b:{if(!f){e=d-1|0;break b}e=d-1|0;if((e^f-1)>>>0<32){break a}}i=v[a>>2];v[(d>>>0<33?i:i+(e>>>3&536870908)|0)>>2]=0}d=le(l+24|0,b);c=le(l+16|0,c);yp(l+8|0,a,f);b=l;i=gb-48|0;gb=i;a=l+8|0;c:{if(v[d+4>>2]==v[a+4>>2]){d=le(i+40|0,d);c=le(i+32|0,c);f=le(i+24|0,a);a=gb-16|0;gb=a;c=Mj(c,d);v[a+12>>2]=c;d:{if((c|0)<1){break d}e=v[d+4>>2];if(e){g=32-e|0;v[a+8>>2]=g;c=v[ld(a+8|0,a+12|0)>>2];v[a+12>>2]=v[a+12>>2]-c;e=v[f>>2];g=-1<<v[d+4>>2]&-1>>>g-c;v[e>>2]=v[e>>2]&(g^-1)|g&v[v[d>>2]>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;v[f>>2]=e+(c>>>3&536870908);v[d>>2]=v[d>>2]+4;c=v[a+12>>2]}e=(c|0)/32|0;c=e<<2;sh(v[f>>2],v[d>>2],c);e=v[a+12>>2]-(e<<5)|0;v[a+12>>2]=e;v[f>>2]=c+v[f>>2];if((e|0)<1){break d}c=c+v[d>>2]|0;v[d>>2]=c;d=v[f>>2];j=d;n=v[d>>2];d=-1>>>32-e|0;v[j>>2]=n&(d^-1)|d&v[c>>2];v[f+4>>2]=v[a+12>>2]}le(b,f);gb=a+16|0;break c}e=le(i+16|0,d);c=le(i+8|0,c);d=le(i,a);f=gb-16|0;gb=f;a=Mj(c,e);v[f+12>>2]=a;e:{if((a|0)<1){break e}c=v[e+4>>2];f:{if(!c){c=v[d+4>>2];break f}c=32-c|0;v[f+8>>2]=c;a=v[ld(f+8|0,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-a;g=v[d+4>>2];k=v[v[e>>2]>>2];j=v[e+4>>2];v[f+8>>2]=a;m=32-g|0;v[f+4>>2]=m;n=Fb(f+8|0,f+4|0);h=v[d>>2];k=k&(-1<<j&-1>>>c-a);c=v[d+4>>2];g=v[e+4>>2];j=c>>>0>g>>>0?k<<c-g:k>>>g-c|0;g=v[n>>2];v[h>>2]=j|v[h>>2]&(-1<<c&-1>>>m-g^-1);j=c+g|0;c=j&31;v[d+4>>2]=c;h=h+(j>>>3&536870908)|0;v[d>>2]=h;a=a-g|0;if((a|0)>=1){v[h>>2]=v[h>>2]&(-1>>>32-a^-1)|k>>>g+v[e+4>>2];v[d+4>>2]=a;c=a}v[e>>2]=v[e>>2]+4;a=v[f+12>>2]}g=32-c|0;if((a|0)>=32){k=-1<<c;j=k^-1;h=v[e>>2];while(1){a=v[d>>2];h=v[h>>2];v[a>>2]=j&v[a>>2]|h<<c;v[d>>2]=a+4;v[a+4>>2]=k&v[a+4>>2]|h>>>g;m=v[f+12>>2];a=m-32|0;v[f+12>>2]=a;h=v[e>>2]+4|0;v[e>>2]=h;if((m|0)>63){continue}break}}if((a|0)<1){break e}k=v[v[e>>2]>>2];v[f+8>>2]=g;c=ld(f+12|0,f+8|0);e=v[d>>2];h=v[d+4>>2];c=v[c>>2];j=v[e>>2]&(-1<<h&-1>>>g-c^-1);g=k&-1>>>32-a;v[e>>2]=j|g<<h;a=c+h|0;v[d+4>>2]=a&31;a=e+(a>>>3&536870908)|0;v[d>>2]=a;e=v[f+12>>2]-c|0;v[f+12>>2]=e;if((e|0)<1){break e}v[a>>2]=v[a>>2]&(-1>>>32-e^-1)|g>>>c;v[d+4>>2]=v[f+12>>2]}le(b,d);gb=f+16|0}gb=i+48|0;gb=l+48|0}function Dha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-48|0;gb=d;a:{b:{c:{d:{g=a+24|0;e:{if(Bd(g)){break e}f=a+4|0;i=Ab(f);a=gb-48|0;gb=a;c=a+40|0;b=c;v[b>>2]=-1;v[b+4>>2]=-1;v[22640]=0;b=nG(2268);e=v[22640];v[22640]=0;if((e|0)==1){break a}v[a+8>>2]=b;v[a+12>>2]=jb;b=v[a+12>>2];v[a+16>>2]=v[a+8>>2];v[a+20>>2]=b;b=gb-16|0;gb=b;j=b,k=mqa(v[a+16>>2],v[a+20>>2],1e3,0),v[j>>2]=k;v[b+4>>2]=jb;e=Jl(b+8|0,b);h=v[e+4>>2];gb=b+16|0;v[a+24>>2]=v[e>>2];v[a+28>>2]=h;b=xA(v[a+24>>2],v[a+28>>2]);t[a+32|0]=b;t[a+33|0]=b>>>8;t[a+34|0]=b>>>16;t[a+35|0]=b>>>24;b=jb;t[a+36|0]=b;t[a+37|0]=b>>>8;t[a+38|0]=b>>>16;t[a+39|0]=b>>>24;b=v[a+36>>2];v[a+24>>2]=v[a+32>>2];v[a+28>>2]=b;fR(c,a+24|0,wb(a+24|0));v[22640]=0;b=nG(2269);e=v[22640];v[22640]=0;if((e|0)==1){break a}v[a+8>>2]=b;v[a+12>>2]=jb;b=v[a+12>>2];v[a+16>>2]=v[a+8>>2];v[a+20>>2]=b;b=gb-16|0;gb=b;e=v[a+20>>2];v[b>>2]=v[a+16>>2];v[b+4>>2]=e;e=Jl(b+8|0,b);h=v[e+4>>2];gb=b+16|0;v[a+24>>2]=v[e>>2];v[a+28>>2]=h;b=xA(v[a+24>>2],v[a+28>>2]);t[a+32|0]=b;t[a+33|0]=b>>>8;t[a+34|0]=b>>>16;t[a+35|0]=b>>>24;b=jb;t[a+36|0]=b;t[a+37|0]=b>>>8;t[a+38|0]=b>>>16;t[a+39|0]=b>>>24;b=v[a+36>>2];v[a+24>>2]=v[a+32>>2];v[a+28>>2]=b;fR(c,a+24|0,wb(a+24|0));e=v[c>>2];c=v[c+4>>2];gb=a+48|0;if(i){b=nc(d+32|0);v[22640]=0;v[d+16>>2]=c;R(83,b|0,d+16|0);a=v[22640];v[22640]=0;f:{g:{h:{if((a|0)!=1){v[22640]=0;v[d+16>>2]=e;R(83,b|0,d+16|0);a=v[22640];v[22640]=0;if((a|0)==1){break h}if(Ab(f)){a=0;while(1){c=w[mc(f,a)|0];v[22640]=0;v[d+16>>2]=c;R(83,b|0,d+16|0);c=v[22640];v[22640]=0;if((c|0)==1){break c}a=a+1|0;if(Ab(f)>>>0>a>>>0){continue}break}}a=Sb(b);c=Wb(b);v[22640]=0;c=W(84,d+16|0,a|0,c|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break g}v[22640]=0;a=T(85,c|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break f}v[d+8>>2]=a;FA(g,d+8|0);Zm(d+8|0);Lc(c);Lc(b);break e}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Lc(c);break b}jb=e;v[d+16>>2]=c;v[d+20>>2]=jb;b=d+32|0;a=nc(b);v[22640]=0;U(92,b|0,d+16|0,d+24|0);c=v[22640];v[22640]=0;if((c|0)==1){b=P()|0;O()|0;Lc(a);S(b|0);L()}v[22640]=0;a=T(85,b|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break d}v[d+8>>2]=a;FA(g,d+8|0);Zm(d+8|0);Lc(b)}gb=d+48|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}Lc(b);S(a|0);L()}V(0)|0;O()|0;Bb();L()}function q3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=gb-16|0;gb=k;m=oD(g);o=px(g);Qg(k,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[22640]=0;g=Q(22,m|0,g<<24>>24)|0;i=v[22640];v[22640]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=g;i=a+1|0}d:{e:{f:{if(!(w[i|0]!=48|(c-i|0)<2|(w[i+1|0]|32)!=120)){v[22640]=0;g=Q(22,m|0,48)|0;h=v[22640];v[22640]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;g=t[i+1|0];v[22640]=0;g=Q(22,m|0,g|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;i=i+2|0;if(i>>>0>=c>>>0){break e}g=i;while(1){g:{h=t[g|0];v[22640]=0;j=fa(2454)|0;l=v[22640];v[22640]=0;if((l|0)==1){break g}v[22640]=0;h=wx(h,j);j=v[22640];v[22640]=0;if((j|0)==1){break g}if(!h){break d}g=g+1|0;if((g|0)!=(c|0)){continue}break f}break}break a}if(c>>>0<=i>>>0){break e}g=i;while(1){h=t[g|0];v[22640]=0;fa(2454)|0;j=v[22640];v[22640]=0;if((j|0)==1){break a}v[22640]=0;h=Sh(h);j=v[22640];v[22640]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;if((g|0)!=(c|0)){continue}break}}g=c;break d}g=i}h:{i:{if(dd(k)){h=v[f>>2];v[22640]=0;Y(2450,m|0,i|0,g|0,h|0);h=v[22640];v[22640]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break i}mm(i,g);j=0;v[22640]=0;q=T(2442,o|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break h}if(g>>>0>i>>>0){h=i;l=0;while(1){j:{if(t[mc(k,j)|0]<1){break j}if(t[mc(k,j)|0]!=(l|0)){break j}l=v[f>>2];v[f>>2]=l+1;t[l|0]=q;j=(Ab(k)-1>>>0>j>>>0)+j|0;l=0}p=t[h|0];v[22640]=0;p=Q(22,m|0,p|0)|0;n=v[22640];v[22640]=0;if((n|0)==1){break h}n=v[f>>2];v[f>>2]=n+1;t[n|0]=p;l=l+1|0;h=h+1|0;if((h|0)!=(g|0)){continue}break}}mm((i-a|0)+d|0,v[f>>2])}k:{if(c>>>0<=g>>>0){break k}while(1){i=w[g|0];if((i|0)==46){v[22640]=0;i=T(2451,o|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0;break k}v[22640]=0;i=Q(22,m|0,i<<24>>24)|0;h=v[22640];v[22640]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0;if((g|0)!=(c|0)){continue}break}g=c}i=v[f>>2];v[22640]=0;Y(2450,m|0,g|0,c|0,i|0);i=v[22640];v[22640]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g|0)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;vb(k);gb=k+16|0;return}}a=P()|0;O()|0;vb(k);S(a|0);L()}function D7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-160|0;gb=d;a:{if(nk(b)){break a}e=w[wl(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Kl(d+128|0,b,v[b+4>>2]-1|0);e=v[d+132>>2];v[b>>2]=v[d+128>>2];v[b+4>>2]=e}Kd(d+128|0);e=v[d+128>>2];Kd(d+112|0);e=vl(e,v[d+116>>2],b);Kd(d+128|0);b:{c:{d:{e:{if((e|0)==v[d+132>>2]){a=v[b+4>>2];v[d+152>>2]=v[b>>2];v[d+156>>2]=a;a=uc(d+144|0,18693);e=v[d+156>>2];v[d+8>>2]=v[d+152>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Fc(d+8|0,d)){a=aa(8)|0;v[22640]=0;c=Q(112,d+128|0,7808)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}e=0;f=0;if(!c){break e}c=aa(8)|0;v[22640]=0;e=Q(2057,d+112|0,b|0)|0;a=v[22640];v[22640]=0;f:{g:{h:{if((a|0)!=1){v[22640]=0;U(2037,d+128|0,14731,e|0);a=v[22640];v[22640]=0;if((a|0)==1){break h}qc(c,d+128|0);a=0;v[22640]=0;U(223,c|0,55256,1936);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;vb(d+128|0);break g}b=P()|0;O()|0;break f}b=P()|0;a=1;O()|0}vb(e);if(!a){break c}}da(c|0);break c}if(v[e+4>>2]!=1){a=aa(8)|0;v[22640]=0;c=Q(112,d+128|0,8924)|0;b=v[22640];v[22640]=0;if((b|0)!=1){qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=uc(d+96|0,18693);e=v[d+108>>2];v[d+56>>2]=v[d+104>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Fc(d+56|0,d+48|0)){a=aa(8)|0;v[22640]=0;c=Q(112,d+128|0,7808)|0;b=v[22640];v[22640]=0;if((b|0)!=1){qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}b=P()|0;O()|0;vb(c);break c}b=P()|0;O()|0;da(a|0);break c}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;c=uc(d+80|0,8263);e=v[d+92>>2];v[d+40>>2]=v[d+88>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Fc(d+40|0,d+32|0)){a=v[a+8>>2];e=a;f=a>>31;break e}c=v[b+4>>2];v[d+72>>2]=v[b>>2];v[d+76>>2]=c;b=uc(d- -64|0,5838);c=v[d+76>>2];v[d+24>>2]=v[d+72>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;f=0;if(!Fc(d+24|0,d+16|0)){break e}e=xy(v[a+32>>2]);f=0}a=f;gb=d+160|0;jb=a;return e|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function Iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-1184|0;gb=d;vc(b);a:{if(!Kw(b,d+1160|0)){break a}if(!SN(d+1160|0)){break a}e=d+1168|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=(hm(b)|0)){break a}f=d+1176|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))!=(xf(b)|0)){break a}if(!c){g=1;break a}Qb(d+1104|0,0,56);e=d+1104|0;i=-2;b:{if(!e){break b}v[e+44>>2]=0;v[e+48>>2]=0;v[e+52>>2]=0;v[e+20>>2]=0;v[e+24>>2]=0;v[e+8>>2]=0;h=v[e+32>>2];if(!h){v[e+32>>2]=2259;h=2259}if(!v[e+36>>2]){v[e+36>>2]=2260}h=kb[h|0](v[e+40>>2],1,43784)|0;i=-4;if(!h){break b}v[e+28>>2]=h;v[h+43780>>2]=1;v[h+10992>>2]=0;v[h+10996>>2]=0;v[h>>2]=0;v[h+11008>>2]=15;v[h+11e3>>2]=1;v[h+11004>>2]=0;i=0}if(i){break a}e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[d+1100>>2]=e;g=d+1180|0;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);f=(g|0)!=0;h=jX(d+1088|0,g);c:{d:{e:{f:{g:{h:{i:{j:{if(!e|!g){break j}while(1){v[22640]=0;v[d+48>>2]=1024;e=Fb(d+48|0,d+1100|0);f=v[22640];v[22640]=0;if((f|0)==1){break d}e=v[e>>2];f=Wd(d+56|0,d- -64|0,e);v[22640]=0;i=v[f+4>>2];v[d+24>>2]=v[f>>2];v[d+28>>2]=i;U(237,d+48|0,b|0,d+24|0);f=v[22640];v[22640]=0;if((f|0)==1){break h}v[22640]=0;j=xJ(j,d- -64|0,e);f=v[22640];v[22640]=0;if((f|0)==1){break i}v[d+1120>>2]=g;v[d+1108>>2]=e;v[d+1104>>2]=d- -64;f=v[h>>2];v[22640]=0;v[d+1116>>2]=f+k;l=Q(1475,d+1104|0,0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break i}i=v[d+1100>>2]-e|0;v[d+1100>>2]=i;e=v[d+1120>>2];f=(e|0)!=0;if(!i|!e){break j}k=(g+k|0)-e|0;g=e;if((l|0)!=1){continue}break}}v[22640]=0;T(1476,d+1104|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}g=0;b=d+1172|0;if(!((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=(j|0)|f|(l|0)!=1)){v[22640]=0;be(d+40|0,h);b=v[22640];v[22640]=0;if((b|0)==1){break f}b=Sd(d+32|0);v[22640]=0;g=v[d+44>>2];v[d+16>>2]=v[d+40>>2];v[d+20>>2]=g;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=W(749,d- -64|0,d+16|0,d+8|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break f}v[22640]=0;g=W(1390,a|0,b|0,c|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break e}yb(b)}gc(h);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(b);break c}a=P()|0;O()|0}gc(h);S(a|0);L()}gb=d+1184|0;return g|0}function xR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=gb-96|0;gb=f;t[f+95|0]=d;n=EA(a);o=Qi(n);u[b>>1]=0;a:{if(o){while(1){b:{if(!Mo(n,j&65535)){break b}j=x[b>>1];if(Cc(a)>>>0<=j>>>0){v[c>>2]=0;a=1;break a}m=xd(a,x[b>>1]);yk(f+72|0,m);Rl(f- -64|0,m);j=v[f+76>>2];v[f+32>>2]=v[f+72>>2];v[f+36>>2]=j;j=v[f+68>>2];v[f+24>>2]=v[f+64>>2];v[f+28>>2]=j;l=f+80|0;e=f+32|0;i=f+24|0;j=gb-32|0;gb=j;c:{if(w[f+95|0]){g=v[e+4>>2];v[j+24>>2]=v[e>>2];v[j+28>>2]=g;e=Mj(i,e);i=v[j+28>>2];v[j+8>>2]=v[j+24>>2];v[j+12>>2]=i;i=gb-16|0;gb=i;v[i+12>>2]=e;h=j+8|0;g=v[h+4>>2];d:{if(g){v[i+8>>2]=32-g;e=Fb(i+8|0,i+12|0);k=v[h>>2];e=v[e>>2];g=v[k>>2]&(-1<<g&-1>>>v[i+8>>2]-e);if(g){pd(l,k,lqa(g));break d}g=v[i+12>>2];if((g|0)==(e|0)){iR(l,h,e);break d}e=g-e|0;v[i+12>>2]=e;v[h>>2]=k+4}if(e>>>0>=32){g=v[h>>2];while(1){k=v[g>>2];if(k){pd(l,g,lqa(k));break d}g=g+4|0;v[h>>2]=g;e=e-32|0;v[i+12>>2]=e;if(e>>>0>31){continue}break}}e:{if(!e){g=v[h>>2];break e}g=v[h>>2];h=v[g>>2]&-1>>>32-e;if(!h){break e}pd(l,g,lqa(h));break d}pd(l,g,e)}gb=i+16|0;break c}g=v[e+4>>2];v[j+16>>2]=v[e>>2];v[j+20>>2]=g;e=Mj(i,e);i=v[j+20>>2];v[j>>2]=v[j+16>>2];v[j+4>>2]=i;g=gb-16|0;gb=g;v[g+12>>2]=e;i=j;h=v[i+4>>2];f:{if(h){v[g+8>>2]=32-h;e=v[Fb(g+8|0,g+12|0)>>2];k=-1<<h&-1>>>v[g+8>>2]-e;h=v[i>>2];k=k&(v[h>>2]^-1);if(k){pd(l,h,lqa(k));break f}k=v[g+12>>2];if((k|0)==(e|0)){iR(l,i,e);break f}e=k-e|0;v[g+12>>2]=e;v[i>>2]=h+4}if(e>>>0>=32){h=v[i>>2];while(1){k=v[h>>2];if((k|0)!=-1){pd(l,h,lqa(k^-1));break f}h=h+4|0;v[i>>2]=h;e=e-32|0;v[g+12>>2]=e;if(e>>>0>31){continue}break}}g:{if(!e){h=v[i>>2];break g}h=v[i>>2];i=(v[h>>2]^-1)&-1>>>32-e;if(!i){break g}pd(l,h,lqa(i));break f}pd(l,h,e)}gb=g+16|0}gb=j+32|0;if(d){Rl(f+56|0,m);if(!wR(f+80|0,f+56|0)){break b}v[c>>2]=0;a=1;break a}Rl(f+56|0,m);if(wR(f+80|0,f+56|0)^1){yk(f+48|0,m);a=v[f+84>>2];b=v[f+80>>2];v[f+40>>2]=b;v[f+44>>2]=a;d=v[f+52>>2];v[f+16>>2]=v[f+48>>2];v[f+20>>2]=d;v[f+8>>2]=b;v[f+12>>2]=a;p=c,q=yU(f+16|0,f+8|0),v[p>>2]=q;a=1;break a}if(y[m+4>>2]>=y[_b(v[a+24>>2]+484344|0,x[rc(n,x[b>>1])>>1])+12>>2]){break b}v[c>>2]=v[m+4>>2];a=1;break a}j=x[b>>1]+1|0;u[b>>1]=j;if((j&65535)>>>0<o>>>0){continue}break}}u[b>>1]=65535;v[c>>2]=-1;a=0}gb=f+96|0;return a|0}function Sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;v[22640]=0;e=T(804,a|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){a:{b:{if(e){break b}v[22640]=0;e=T(353,a|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break a}i=Jd(e+1|0,1,1024);v[22640]=0;k=d+484344|0;e=W(365,k|0,b|0,i|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break a}if(!e){break b}d=x[d+480188>>1];if(!d|!i){break b}l=d-1|0;while(1){v[22640]=0;d=Q(228,a|0,1)|0;e=v[22640];v[22640]=0;c:{d:{if((e|0)!=1){if(!d){break b}v[22640]=0;f=T(353,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break a}if(f){break d}j=j+1|0;break c}break a}d=_b(k,b);u[h+14>>1]=f&31;v[22640]=0;u[h+12>>1]=l;e=Oc(h+14|0,h+12|0);g=v[22640];v[22640]=0;if((g|0)==1){break a}e=x[e>>1];v[22640]=0;d=Tc(d,j,e);e=v[22640];v[22640]=0;if((e|0)==1){break a}if(!(f&224)){break c}e:{if(!(f&128)){break e}v[22640]=0;e=T(353,a|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break a}t[d+5|0]=e;v[22640]=0;e=T(353,a|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break a}f:{if(e>>>0>=26){break f}e=w[e+49376|0];t[d+3|0]=e;g:{switch(e-1|0){case 0:if(!w[d+5|0]){break f}break e;case 12:if(w[d+2|0]){break e}t[d+2|0]=1;e=Jd(w[d+5|0],0,64);t[d+5|0]=0;t[d+3|0]=0;t[d+4|0]=e;break e;case 5:case 6:case 10:case 23:case 28:e=w[d+5|0]&240;if(!e){break e}t[d+5|0]=e;break e;case 8:e=w[d+5|0];if(e>>>0<=128){n=d,o=di(e<<1),t[n+5|0]=o;break e}if((e|0)!=164){break e}t[d+5|0]=145;t[d+3|0]=20;break e;case 13:e=w[d+5|0];t[d+5|0]=B(e>>>4|0,10)+(e&15);break e;case 18:v[22640]=0;Ut(d);e=v[22640];v[22640]=0;if((e|0)!=1){break e}break a;case 16:if(w[d+5|0]>31){break e}t[d+3|0]=16;break e;case 27:break g;default:break e}}m=d;e=w[d+5|0];g=e&240;h:{if((g|0)==16){g=2}else{if((g|0)!=32){break h}g=3}t[m+3|0]=g}t[d+5|0]=e&15|224;break e}t[d+3|0]=0}i:{if(!(f&64)){break i}v[22640]=0;R(431,h+8|0,a|0);e=v[22640];v[22640]=0;if((e|0)==1){break a}e=md(h+8|0);t[d+1|0]=w[h+8|0];e=w[e|0];t[d|0]=e;g=255;if((e|0)!=128){g=253;if(e>>>0<129){break i}}t[d|0]=g}if(!(f&32)){break c}t[d+2|0]=1;v[22640]=0;e=T(353,a|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break a}t[d+4|0]=e;if(!c){break c}t[d+4|0]=(e<<6>>>0)/127}if(i>>>0>j>>>0){continue}break}}yb(a);gb=h+16|0;return}}b=P()|0;O()|0;yb(a);S(b|0);L()}function B7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-160|0;gb=e;a:{if(nk(c)){break a}f=w[wl(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Kl(e+128|0,c,v[c+4>>2]-1|0);f=v[e+132>>2];v[c>>2]=v[e+128>>2];v[c+4>>2]=f}Kd(e+128|0);f=v[e+128>>2];Kd(e+112|0);h=vl(f,v[e+116>>2],c);Kd(e+128|0);f=v[c>>2];g=v[c+4>>2];b:{c:{d:{e:{if((h|0)==v[e+132>>2]){v[e+152>>2]=f;v[e+156>>2]=g;b=uc(e+144|0,18693);f=v[e+156>>2];v[e+8>>2]=v[e+152>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;if(Fc(e+8|0,e)){a=aa(8)|0;v[22640]=0;b=Q(112,e+128|0,7808)|0;c=v[22640];v[22640]=0;if((c|0)==1){break d}qc(a,b);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(b);break c}if(d){a=aa(8)|0;v[22640]=0;b=Q(2057,e+112|0,c|0)|0;c=v[22640];v[22640]=0;f:{g:{h:{if((c|0)!=1){v[22640]=0;U(2037,e+128|0,14731,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break h}qc(a,e+128|0);d=0;v[22640]=0;U(223,a|0,55256,1936);c=v[22640];v[22640]=0;if((c|0)!=1){break b}c=P()|0;O()|0;vb(e+128|0);break g}c=P()|0;O()|0;break f}c=P()|0;d=1;O()|0}vb(b);if(!d){break c}}da(a|0);break c}Kb(a);break e}v[e+104>>2]=f;v[e+108>>2]=g;d=uc(e+96|0,18693);f=v[e+108>>2];v[e+56>>2]=v[e+104>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Fc(e+56|0,e+48|0)){a=aa(8)|0;v[22640]=0;b=Q(112,e+128|0,7808)|0;c=v[22640];v[22640]=0;if((c|0)!=1){qc(a,b);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(b);break c}c=P()|0;O()|0;da(a|0);break c}d=v[c+4>>2];v[e+88>>2]=v[c>>2];v[e+92>>2]=d;d=uc(e+80|0,9641);f=v[e+92>>2];v[e+40>>2]=v[e+88>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Fc(e+40|0,e+32|0)){i:{switch(v[b+52>>2]){case 0:Tb(a,2693);break e;case 1:Tb(a,8625);break e;case 2:Tb(a,6381);break e;default:break i}}Kb(a);break e}d=v[c+4>>2];v[e+72>>2]=v[c>>2];v[e+76>>2]=d;c=uc(e- -64|0,8862);d=v[e+76>>2];v[e+24>>2]=v[e+72>>2];v[e+28>>2]=d;d=v[c+4>>2];v[e+16>>2]=v[c>>2];v[e+20>>2]=d;if(Fc(e+24|0,e+16|0)){j:{switch(v[b+56>>2]){case 0:Tb(a,12724);break e;case 1:Tb(a,12729);break e;case 2:Tb(a,9946);break e;case 3:Tb(a,6445);break e;default:break j}}Kb(a);break e}Kb(a)}gb=e+160|0;return}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function mZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;f=gb-32|0;gb=f;j=Zi(f+24|0);if(v[a+12>>2]){q=b^1;r=j+3|0;s=j+5|0;x=j+4|0;z=j+2|0;A=j+1|0;C=f+16|5;D=f+16|3;while(1){E=Pf(a,n);while(1){a:{if(!Pb(c,1)){break a}k=de(c);if((k|0)==255){break a}h=k&31;d=Hi(a)>>>0>h>>>0;h=B(h,6)+E|0;if(k&64){l=1}else{e=de(c);i=e<<24>>24;g=255;b:{c:{d:{e=e&127;switch(e|0){case 0:break b;case 1:break c;default:break d}}if(!(e>>>0>121|q)){g=e-1|0;break c}if((e-12&255)>>>0>96|b){break b}g=e+13|0}t[(d?h:f+24|0)|0]=g}F=d?h+1|0:A,G=de(c),t[F|0]=G;l=(i|0)<0}if(l){p=d?h:j;g=d?h+3|0:r;e=d?h+5|0:s;o=d?h+4|0:x;m=d?h+2|0:z;h=d?h:f+24|0;while(1){d=h;v[f+16>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[f+20>>1]=w[d+4|0]|w[d+5|0]<<8;d=de(c);l=d&128;i=d&63;e:{if(d&64){t[m|0]=1;t[o|0]=i;break e}d=de(c);t[e|0]=d;f:{g:{if(i>>>0<=15){t[g|0]=i;Mf(p);h:{i:{j:{d=w[g|0];switch(d-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}t[g|0]=9;t[e|0]=B(w[e|0]&15,17);break f}t[g|0]=0;t[m|0]=1;v[f+12>>2]=w[e|0]+1>>>1;v[f+8>>2]=64;F=o,G=v[ld(f+12|0,f+8|0)>>2],t[F|0]=G;break f}if((d|0)!=19){break f}if(w[e|0]==128){break g}Ut(p);break f}if(i>>>0>44){break f}t[g|0]=w[i+28816|0];k:{switch(i-16|0){case 0:if(d>>>0>1){break g}t[e|0]=d|158;break f;case 1:case 2:t[f+12|0]=15;F=e,G=w[ac(f+12|0,e)|0]|224,t[F|0]=G;break f;case 5:case 6:v[f+12>>2]=16;v[f+8>>2]=d+1;F=e,G=v[ld(f+12|0,f+8|0)>>2]/2|240,t[F|0]=G;break f;case 14:l:{m:{n:{o:{p:{i=d>>>4|0;switch(i-1|0){case 1:break n;case 0:break o;default:break p}}switch(i-10|0){case 1:break l;case 0:break m;default:break g}}t[g|0]=2;t[e|0]=d|240;break f}t[g|0]=3;t[e|0]=d|240;break f}t[g|0]=11;t[e|0]=(d<<3&120)+8|15;break f}t[g|0]=11;t[e|0]=(d&15)+1>>>1|240;break f;case 12:break k;default:break f}}v[f+12>>2]=d+1>>>1;v[f+8>>2]=64;F=e,G=v[ld(f+12|0,f+8|0)>>2],t[F|0]=G;break f}t[g|0]=0}dz(g,e,D,C);if(to(w[f+19|0])>>>0<=to(w[g|0])>>>0){break e}q:{if(w[m|0]){break q}if(!ez(g,e,1)){break q}t[m|0]=w[g|0];t[o|0]=w[e|0]}t[g|0]=w[f+19|0];t[e|0]=w[f+21|0]}if(l){continue}break}}if(!(k&128)){continue}}break}n=n+1|0;if(n>>>0<y[a+12>>2]){continue}break}}gb=f+32|0}function g9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Kb(a);v[22640]=0;X(2027);c=v[22640];v[22640]=0;a:{b:{if((c|0)==1){c=Ra(55256,88880,88856,0)|0;c:{d:{e:{d=O()|0;if((d|0)==(ea(55256)|0)){c=Z(c|0)|0;v[22640]=0;Q(1917,a|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;Q(1917,a|0,14831)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;Q(1917,a|0,14807)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}b=kb[v[v[c>>2]+8>>2]](c)|0;v[22640]=0;Q(1917,a|0,(b?b:18693)|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((ea(88880)|0)==(d|0)){c=Z(c|0)|0;v[22640]=0;Q(1917,a|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break f}v[22640]=0;Q(1917,a|0,14831)|0;b=v[22640];v[22640]=0;if((b|0)==1){break f}v[22640]=0;Q(1917,a|0,14782)|0;b=v[22640];v[22640]=0;if((b|0)==1){break f}b=kb[v[v[c>>2]+8>>2]](c)|0;v[22640]=0;Q(1917,a|0,(b?b:18693)|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break f}v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=ea(88856)|0;c=Z(c|0)|0;g:{if((d|0)==(e|0)){v[22640]=0;Q(1917,a|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}v[22640]=0;Q(1917,a|0,14831)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}v[22640]=0;Q(1917,a|0,14798)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}b=kb[v[v[c>>2]+8>>2]](c)|0;v[22640]=0;Q(1917,a|0,(b?b:18693)|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[22640]=0;Q(1917,a|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}v[22640]=0;Q(1917,a|0,14831)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}v[22640]=0;Q(1917,a|0,11100)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[22640]=0;X(20);c=v[22640];v[22640]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[22640]=0;X(20);c=v[22640];v[22640]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[22640]=0;X(20);c=v[22640];v[22640]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[22640]=0;X(20);c=v[22640];v[22640]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Bb()}L()}return}vb(a);S(b|0);L()}function opa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;d=gb-1120|0;gb=d;v[d+1116>>2]=c;k=$k(d+56|0,b);v[22640]=0;p=mp(k);c=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((c|0)!=1){g=nc(a);v[22640]=0;a=T(492,b|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break h}v[d+16>>2]=a;v[22640]=0;v[d+48>>2]=85899345;a=Fb(d+16|0,d+48|0);c=v[22640];v[22640]=0;if((c|0)==1){break g}a=v[a>>2];v[22640]=0;v[d+32>>2]=B(a,50);a=Fb(d+1116|0,d+32|0);c=v[22640];v[22640]=0;if((c|0)==1){break g}a=v[a>>2];v[22640]=0;R(524,g|0,a|0);a=v[22640];v[22640]=0;if((a|0)==1){break g}v[22640]=0;e=T(535,d+32|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break f}a=0;v[22640]=0;h=Q(37,d+16|0,8192)|0;c=v[22640];v[22640]=0;if((c|0)==1){break e}while(1){s=Mb(e,a),z=8192,u[s>>1]=z;s=Mb(e,a),z=a,t[s+2|0]=z;a=a+1|0;if((a|0)!=256){continue}break}m=9;break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}i:{j:while(1){c=0;n=257;while(1){q=m&255;k:{while(1){j=n&65535;while(1){v[22640]=0;i=Q(236,k|0,q|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break i}l=i&65535;if((l|0)==257|j>>>0<l>>>0){break k}if(pc(g)>>>0>=y[d+1116>>2]){break k}if((l|0)==256){m=9;continue j}f=j>>>0>l>>>0?i:c;a=8191;while(1){f=f&65535;r=w[Mb(e,f)+2|0];o=a&65535;s=kc(h,o),z=r,t[s|0]=z;f=x[Mb(e,f)>>1];if(f>>>0<=8191){a=a-1|0;continue}break}s=d,z=Wb(g),v[s+48>>2]=z;Fd(d+8|0,d+48|0);s=d,z=Sb(h),v[s>>2]=z;a=we(d,o);f=Wb(h);v[22640]=0;Y(525,g|0,v[d+8>>2],a|0,f|0);a=v[22640];v[22640]=0;if((a|0)==1){break i}l:{if((j|0)!=(l|0)){break l}a=kc(h,o);v[22640]=0;R(536,g|0,a|0);a=v[22640];v[22640]=0;if((a|0)!=1){break l}break i}if(j>>>0>=8192){c=i;continue}if(pc(g)>>>0>=y[d+1116>>2]){continue}break}a=kc(h,o);s=Mb(e,j),z=w[a|0],t[s+2|0]=z;s=Mb(e,j),z=c,u[s>>1]=z;a=n+1|0;n=8192;c=i;i=a&65535;if((i|0)==8192){continue}break}m=((i|0)==1<<q)+m|0;n=a;continue}break}break}v[22640]=0;a=mp(k);c=v[22640];v[22640]=0;m:{if((c|0)!=1){v[22640]=0;Q(227,b|0,((a-p|0)+3&-4)+p|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break m}}break i}gc(h);WC(e);yb(k);gb=d+1120|0;return}a=P()|0;O()|0;gc(h)}WC(e)}gc(g)}yb(k);S(a|0);L()}function tu(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=gb-48|0;gb=f;v[f+32>>2]=c;u[f+38>>1]=b;g=EA(a);a:{if(sc(g)>>>0<=b>>>0){break a}if(FR(a,x[rc(g,b)>>1])>>>0<=c>>>0){break a}b:{if(Cc(a)>>>0>b>>>0){if(y[xd(a,b)+4>>2]>c>>>0){break b}}Jo(a,0);if(Cc(a)>>>0<=b>>>0){break a}}c=x[v[a+24>>2]+480188>>1];b=v[d>>2];v[f+16>>2]=b;v[f+20>>2]=b+B(c,872);d=f+24|0;b=d;v[b>>2]=-2078137563;v[b+4>>2]=-873292572;g=e?-2046629010:-2078137563;e=e?-1352371636:-873292572;c=f+16|0;if(HR(c)){while(1){b=w[NT(c,h)+841|0];k=b^mqa(g^h,e^j,435,256);b=!b;g=(o=g,p=mqa(k,jb,435,256),q=b,q?o:p);e=b?e:jb;b=h+1|0;j=b>>>0<1?j+1|0:j;h=b;if(!j&HR(c)>>>0>b>>>0){continue}break}}v[d>>2]=g;v[d+4>>2]=e;j=Um(f+16|0,f+38|0,f+32|0);e=gb-16|0;gb=e;c=e+8|0;h=gb-16|0;gb=h;k=a+12|0;g=k;b=Vd(g);b=pR(g,j,b,ec(g));v[h+8>>2]=b;o=h,p=yh(g),v[o>>2]=p;c:{if(Xl(h+8|0,h)){if(!Ml(wb(g),j,ue(h+8|0))){break c}}b=yh(g)}gb=h+16|0;b=v[yc(c,b)>>2];gb=e+16|0;v[f+8>>2]=b;o=f,p=zh(k),v[o+16>>2]=p;b=0;if(kg(f+8|0,f+16|0)){b=$c(ue(f+8|0)+8|0)^1}m=v[d>>2]!=-2078137563|v[d+4>>2]!=-873292572;oe(f+16|0,xd(a,x[f+38>>1]),v[f+32>>2]);n=1;g=b|m;j=Cb(f+16|0)^1;if(!(j?1:g)){break a}if(b){h=ue(f+8|0)+8|0;l=Sb(h);e=Wb(h);c=d;i=gb-16|0;gb=i;v[i>>2]=e;v[i+8>>2]=l;if(Gb(i+8|0,i)){while(1){e=v[i+8>>2];if(v[e>>2]!=v[c>>2]|v[e+4>>2]!=v[c+4>>2]){uu(i+8|0);if(Gb(i+8|0,i)){continue}}break}l=v[i+8>>2]}gb=i+16|0;v[f+16>>2]=l;o=f,p=Wb(h),v[o+40>>2]=p;if(Gb(f+16|0,f+40|0)){break a}}if(m){v[a+28>>2]=v[a+28>>2]+1}if(g){if(!(b|j)){d:{e=yR(k,Um(f+16|0,f+38|0,f+32|0));if(y[e+4>>2]<y[wb(e)>>2]){b=gb-16|0;gb=b;c=lR(b,e);wb(e);kR(v[c+4>>2]);v[c+4>>2]=v[c+4>>2]+8;$b(c);gb=b+16|0;break d}c=gb-32|0;gb=c;b=wb(e);b=DA(c+8|0,cs(e,of(e)+1|0),of(e),b);kR(v[b+8>>2]);v[b+8>>2]=v[b+8>>2]+8;CA(e,b);BA(b);gb=c+32|0}}e=yR(k,Um(f+16|0,f+38|0,f+32|0));e:{if(y[e+4>>2]<y[wb(e)>>2]){b=gb-16|0;gb=b;c=lR(b,e);wb(e);jR(v[c+4>>2],d);v[c+4>>2]=v[c+4>>2]+8;$b(c);gb=b+16|0;break e}c=gb-32|0;gb=c;b=wb(e);b=DA(c+8|0,cs(e,of(e)+1|0),of(e),b);jR(v[b+8>>2],d);v[b+8>>2]=v[b+8>>2]+8;CA(e,b);BA(b);gb=c+32|0}}oe(f+16|0,xd(a,x[f+38>>1]),v[f+32>>2]);Af(f+16|0,1);n=0}gb=f+48|0;return n|0}function D9(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=gb-80|0;gb=j;a:{b:{c:{k=Xp(1,32);d:{e:{if(!k){a=aa(4)|0;km(a);v[22640]=0;U(223,a|0,88880,1928);a=v[22640];v[22640]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1919;d=su(j- -64|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[22640]=0;c=Q(112,j+48|0,c|0)|0;f=v[22640];v[22640]=0;i:{if((f|0)!=1){v[22640]=0;f=Q(1929,d|0,c|0)|0;l=v[22640];v[22640]=0;if((l|0)==1){break i}v[22640]=0;Q(443,f|0,e|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}v[22640]=0;c=Q(112,j+48|0,c|0)|0;e=v[22640];v[22640]=0;j:{if((e|0)!=1){v[22640]=0;R(1930,d|0,c|0);e=v[22640];v[22640]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[22640]=0;a=T(1298,96)|0;i=v[22640];v[22640]=0;k:{l:{m:{if((i|0)!=1){v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;v[22640]=0;b=Q(1931,k|0,k+4|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break m}v[j+48>>2]=b;b=v[kq(j+24|0,j+48|0)>>2];c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;v[22640]=0;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;ca(2005,a|0,j+8|0,b|0,d|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break l}v[k+28>>2]=a;Aj(j+48|0);a=v[k+28>>2];v[k+24>>2]=a?a+8|0:0;Ll(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;Aj(j+48|0)}Zb(a)}Ll(d);Z(i|0)|0;v[22640]=0;Y(1911,8680,k|0,g|0,h|0);a=v[22640];v[22640]=0;if((a|0)!=1){v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){a=v[k+28>>2];if(a){kb[v[v[a>>2]+4>>2]](a)}v[k+24>>2]=0;v[k+28>>2]=0;a=v[k+20>>2];if(a){Zb(a);v[k+20>>2]=0}Zb(k);k=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)==1){break b}}Z(i|0)|0;k=0;v[22640]=0;Y(1911,8680,0,g|0,h|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}$()}gb=j+80|0;return k|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function kha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;v[h+24>>2]=d;k=Zf(a,c);se(h,v[a+28>>2]);d=v[h+12>>2];v[h+16>>2]=v[h+8>>2];v[h+20>>2]=d;a:{if(!k){if(id(a,5)){break a}}f=v[h+24>>2];d=gb-160|0;gb=d;i=wm(d+56|0,v[a+28>>2]);v[22640]=0;g=Q(640,d+40|0,34472)|0;e=v[22640];v[22640]=0;b:{c:{d:{e:{if((e|0)!=1){v[22640]=0;v[d+24>>2]=19923012;v[d+28>>2]=0;U(641,i|0,g|0,d+24|0);e=v[22640];v[22640]=0;if((e|0)==1){break e}Hb(g);if(!(v[i>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(g);break c}t[d+39|0]=0;v[22640]=0;g=Q(640,d+40|0,2597)|0;e=v[22640];v[22640]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){v[22640]=0;W(642,i|0,d+39|0,g|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break q}Hb(g);g=Kb(d+40|0);v[22640]=0;e=Q(640,d+24|0,7420)|0;j=v[22640];v[22640]=0;if((j|0)==1){break p}v[22640]=0;U(1102,i|0,g|0,e|0);j=v[22640];v[22640]=0;if((j|0)==1){break o}Hb(e);v[22640]=0;U(13,d+24|0,(w[d+39|0]?0:f)|0,g|0);e=v[22640];v[22640]=0;if((e|0)==1){break n}v[22640]=0;R(446,b|0,d+24|0);e=v[22640];v[22640]=0;if((e|0)==1){break m}vb(d+24|0);u[d+22>>1]=0;v[22640]=0;e=Q(640,d+24|0,8097)|0;f=v[22640];v[22640]=0;if((f|0)==1){break g}v[22640]=0;W(1103,i|0,d+22|0,e|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break l}Hb(e);sg(d+22|0,4e3);v[22640]=0;e=Q(640,d+24|0,10783)|0;f=v[22640];v[22640]=0;if((f|0)==1){break k}f=v[yc(d+16|0,x[d+22>>1])>>2];v[22640]=0;Y(1104,i|0,b|0,e|0,f|0);f=v[22640];v[22640]=0;if((f|0)==1){break j}Hb(e);u[d+14>>1]=65535;v[22640]=0;e=Q(640,d+24|0,6175)|0;f=v[22640];v[22640]=0;if((f|0)==1){break i}v[22640]=0;f=W(1103,i|0,d+14|0,e|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break h}j=x[d+22>>1];l=x[d+14>>1];Hb(e);if(!((f|0)==1|j>>>0<=l>>>0)){af(b,x[d+14>>1])}vb(g);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(g);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(d+24|0);break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Hb(e);break f}a=P()|0;O()|0}vb(g)}ch(i);S(a|0);L()}ch(i);gb=d+160|0}Sf(a,k,c,h+16|0);gb=h+32|0}function Lha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=gb-80|0;gb=e;r=v[a+16>>2];h=Sd(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];t=h,w=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;b=v[h+16>>2];if(b){t=h,w=gg(a+8|0,b),v[t>>2]=w;v[h+4>>2]=jb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;a:{if(d){while(1){m=0;f=m;j=g;v[e+72>>2]=g;v[e+76>>2]=f;i=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;b:{if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Id(v[h+8>>2],(u[(g<<1|2)+i>>1]+u[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Id(f,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=dg(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;q=v[i>>2];b=Lb(q,-16777216,16776704);p=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=mqa(l,s,f,f>>31);l=jb;p=mqa(p,p>>31,b,b>>31);f=p+f|0;b=jb+l|0;b=f>>>0<p>>>0?b+1|0:b;l=f;f=v[a+68>>2];f=mqa(f,f>>31,g,g>>31);g=l+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Ic(g,b,24);v[i+4>>2]=q;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function Ly(a){a=a|0;var b=0,c=0,d=C(0),e=0;Qb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[22640]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}ha(1838,e|0,67,5,c|0,b|0);b=v[22640];v[22640]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[22640]=0;ha(1838,a+4528|0,62,5,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[22640]=0;ha(1838,a+4552|0,53,5,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[22640]=0;ha(1838,a+4576|0,43,5,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[22640]=0;ha(1838,a+4600|0,32,5,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[22640]=0;ha(1838,a+4624|0,22,5,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[22640]=0;ha(1838,a+4648|0,75,5,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[22640]=0;ha(1838,a+4672|0,69,5,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[22640]=0;ha(1838,a+4696|0,60,5,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[22640]=0;ha(1838,a+4720|0,48,5,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[22640]=0;ha(1838,a+4744|0,36,5,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[22640]=0;ha(1838,a+4768|0,25,5,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}v[22640]=0;ha(1838,a+4792|0,0,0,0,0);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[22640]=0;ha(1838,a+4816|0,3,0,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[22640]=0;ha(1838,a+4840|0,3,0,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}v[22640]=0;ha(1838,a+4864|0,407,1,c|0,0);b=v[22640];v[22640]=0;if((b|0)==1){break a}v[22640]=0;ha(1838,a+4888|0,400,1,c|0,0);b=v[22640];v[22640]=0;if((b|0)==1){break a}v[22640]=0;ha(1838,a+4912|0,10,0,c|0,-1);b=v[22640];v[22640]=0;if((b|0)==1){break a}v[22640]=0;ha(1838,a+4936|0,10,0,c|0,-1);c=v[22640];v[22640]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(88880)|0;if((O()|0)==(ea(88880)|0)){Z(c|0)|0;t[a+5045|0]=0;$();return}S(c|0);L()}function loa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);c=gb-96|0;gb=c;e=gb-32|0;gb=e;g=b+16|0;DW(e+24|0,g);h=xb(e+24|0);d=v[e+28>>2];f=v[e+24>>2];v[e+8>>2]=f;v[e+12>>2]=d;v[e>>2]=f;v[e+4>>2]=d;d=a;fc(e+16|0,a,e);f=xb(e+16|0);if((f|0)==(h|0)){Yb(d,xb(e+24|0))}gb=e+32|0;if((f|0)!=(h|0)){Qb(g,0,128)}dX(b+48|0);t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;rd(c+72|0,a,og(a));v[22640]=0;d=T(492,c+72|0)|0;e=v[22640];v[22640]=0;a:{b:{if((e|0)==1){break b}v[22640]=0;e=b+4|0;R(467,e|0,d|0);d=v[22640];v[22640]=0;if((d|0)==1){break b}v[22640]=0;be(c- -64|0,e);d=v[22640];v[22640]=0;if((d|0)==1){break b}v[22640]=0;d=v[c+68>>2];v[c+8>>2]=v[c+64>>2];v[c+12>>2]=d;U(653,c+40|0,c+72|0,c+8|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;d=T(229,a|0)|0;e=v[22640];v[22640]=0;c:{if((e|0)==1){break c}v[22640]=0;U(320,c+40|0,a|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}v[22640]=0;a=T(307,c+40|0)|0;d=v[22640];v[22640]=0;d:{if((d|0)!=1){e:{f:{g:{if(!a){break g}while(1){v[22640]=0;a=Q(228,c+40|0,5)|0;d=v[22640];v[22640]=0;if((d|0)==1){break f}if(!a){break g}v[22640]=0;Q(654,c+40|0,c+36|0)|0;a=v[22640];v[22640]=0;h:{if((a|0)!=1){a=4;if((w[c+36|0]|w[c+37|0]<<8|(w[c+38|0]<<16|w[c+39|0]<<24))==1414682436|(w[c+36|0]|w[c+37|0]<<8|(w[c+38|0]<<16|w[c+39|0]<<24))==1196380752){break h}v[22640]=0;a=T(229,c+40|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[22640]=0;U(320,c+16|0,c+40|0,a|0);a=v[22640];v[22640]=0;i:{j:{if((a|0)!=1){if((w[c+36|0]|w[c+37|0]<<8|(w[c+38|0]<<16|w[c+39|0]<<24))!=1414682436){break j}v[22640]=0;i=C(Ba(655,c+16|0));a=v[22640];v[22640]=0;if((a|0)==1){break e}z[b+144>>2]=i;break i}a=P()|0;O()|0;break d}if((w[c+36|0]|w[c+37|0]<<8|(w[c+38|0]<<16|w[c+39|0]<<24))!=1196380752){break i}v[22640]=0;a=T(229,c+16|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break e}v[b+148>>2]=a}yb(c+16|0);continue}}yb(c+40|0);yb(c+72|0);gb=c+96|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0;yb(c+16|0);break d}a=P()|0;O()|0}yb(c+40|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}yb(c+72|0);S(a|0);L()}function GE(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=gb-128|0;gb=j;a:{b:{c:{if(!tn(f,g,h,i,0,0,0,0)){break c}m=f;n=g;l=h;o=i&65535;k=i>>>16&32767;d:{e:{if((k|0)!=32767){p=4;if(k){break e}m=l|m|(n|o)?3:2;break d}p=!(l|m|(n|o))}m=p}if(!m){break c}r=e>>>16|0;o=r&32767;if((o|0)!=32767){break b}}Dd(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];$E(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}l=o<<16;p=d;q=l|e&65535;m=q;n=h;q=i>>>16&32767;k=i&65535|q<<16;if((tn(b,c,p,m,f,g,h,k)|0)<=0){if(tn(b,c,p,m,f,g,n,k)){h=b;i=c;break a}Dd(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(o){i=c;h=b}else{Dd(j+96|0,b,c,p,m,0,0,0,1081540608);h=v[j+108>>2];m=h;p=v[j+104>>2];o=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){Dd(j+80|0,f,g,n,k,0,0,0,1081540608);f=v[j+92>>2];k=f;n=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;m=m&65535|65536;if((o|0)>(q|0)){while(1){k=p;l=n;t=k-l|0;l=m-((k>>>0<l>>>0)+s|0)|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;l=l-(k>>>0>t>>>0)|0;k=t-k|0;f:{if((l|0)>0?1:(l|0)>=0){m=h;h=h-f|0;i=i-((f>>>0>m>>>0)+g|0)|0;if(!(h|k|(i|l))){Dd(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}l=l<<1|k>>>31;p=k<<1|i>>>31;break f}l=m<<1|p>>>31;p=p<<1|i>>>31}m=l;l=i<<1|h>>>31;h=h<<1;i=l;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}l=p;q=l-n|0;n=m-((l>>>0<n>>>0)+s|0)|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=n-(l>>>0>q>>>0)|0;n=q-l|0;g:{if((k|0)<0){n=p;k=m;break g}p=h;h=h-f|0;i=i-((f>>>0>p>>>0)+g|0)|0;if(h|n|(i|k)){break g}Dd(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;m=i<<1|h>>>31;h=h<<1;i=m;c=b;b=n;k=k<<1|b>>>31;n=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){Dd(j- -64|0,h,i,n,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=n;e=k&65535|(b|o)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;gb=j+128|0}function Gm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-16|0;gb=h;a:{b:{if($c(a)|y[a+12>>2]<=y[b+4>>2]){break b}c=x[b+8>>1]>=Hi(a)>>>0;f=x[b+8>>1];if((f|0)!=65535?c:0){break b}g=f;if((g&65535)==65535){f=Hi(a)-1|0;g=0}e=Tc(a,v[b+4>>2],g&65535);i=w[b+12|0];k=i&4;c:{d:{if(i&2){break d}l=f&65535;if(l>>>0<(g&65535)>>>0){break d}j=w[b+10|0];c=g;d=e;while(1){e:{if(!k){if((j|0)!=w[d+3|0]){break e}break c}if((j|0)==w[d+2|0]){break c}}d=d+6|0;c=c+1|0;if((c&65535)>>>0<=l>>>0){continue}break}}j=f&65535;if(j>>>0>=(g&65535)>>>0){c=g;d=e;while(1){f:{if(!k){if(w[d+3|0]){break f}t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break c}if(w[d+2|0]){break f}t[d+2|0]=w[b+10|0];t[d+4|0]=w[b+11|0];break c}d=d+6|0;c=c+1|0;if(j>>>0>=(c&65535)>>>0){continue}break}}g:{if(!(i&1)){break g}i=v[ro(a)+480180>>2]&2;c=w[b+12|0];h:{if(c&4){break h}d=f&65535;if(d>>>0<(g&65535)>>>0){break h}while(1){i:{j:{switch(w[e+3|0]-9|0){case 4:if(!iz(v[ro(a)+8>>2],1)){break i}d=1;t[e+2|0]=1;t[e+4|0]=w[e+5|0];t[e+3|0]=w[b+10|0];t[e+5|0]=w[b+11|0];break a;case 0:break j;default:break i}}k:{if(i){c=w[e+5|0];if(c>>>0>128){break i}t[e+2|0]=2;t[e+3|0]=w[b+10|0];a=1;break k}t[e+2|0]=2;t[e+3|0]=w[b+10|0];c=w[e+5|0];a=2}t[e+4|0]=a+(c&255)>>>a;t[e+5|0]=w[b+11|0];break c}e=e+6|0;g=g+1|0;if(d>>>0>=(g&65535)>>>0){continue}break}c=w[b+12|0]}g=b;l:{m:{if(c&4){d=w[b+11|0];e=13;n:{switch(w[b+10|0]-1|0){case 1:d=dm(B(i?2:4,d));c=w[b+12|0];e=9;break;case 0:break n;default:break l}}t[b+11|0]=d;t[b+10|0]=e;c=c&254;break m}f=w[b+11|0];t[h+14|0]=f;e=b;d=w[b+10|0];o:{if(!(!i|(d|0)!=9)){if(f>>>0>128){break l}d=2;f=(f&254)>>>1|0;break o}t[h+15|0]=d;p:{if(ez(h+15|0,h+14|0,1)){d=w[h+15|0];if(d){break p}}c=w[b+12|0];break l}c=w[b+12|0];f=w[h+14|0]}t[e+11|0]=f;t[b+10|0]=d;c=c&254}t[g+12|0]=c}d=1;if(c&1){break g}t[b+12|0]=c^4;if(Gm(a,b)){break a}}q:{r:{c=v[b>>2];if((c|0)==1){if(y[a+12>>2]>v[b+4>>2]+1>>>0){break r}c=v[b>>2]}if((c|0)!=2){break b}d=0;c=v[b+4>>2];if(!c){break a}v[b+4>>2]=c-1;break q}v[b+4>>2]=v[b+4>>2]+1}t[b+12|0]=w[b+12|0]|1;d=Gm(a,b);break a}d=1;break a}d=0}gb=h+16|0;return d|0}function GL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=gb-80|0;gb=j;a:{b:{c:{d:{e:{f:{k=Xp(1,28);if(!k){a=aa(4)|0;km(a);v[22640]=0;U(223,a|0,88880,1928);a=v[22640];v[22640]=0;if((a|0)!=1){break a}break f}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1919;d=su(j- -64|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[22640]=0;c=Q(112,j+48|0,c|0)|0;f=v[22640];v[22640]=0;j:{if((f|0)!=1){v[22640]=0;f=Q(1929,d|0,c|0)|0;l=v[22640];v[22640]=0;if((l|0)==1){break j}v[22640]=0;Q(443,f|0,e|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}v[22640]=0;c=Q(112,j+48|0,c|0)|0;e=v[22640];v[22640]=0;k:{if((e|0)!=1){v[22640]=0;R(1930,d|0,c|0);e=v[22640];v[22640]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[22640]=0;a=T(1298,80)|0;i=v[22640];v[22640]=0;l:{m:{n:{if((i|0)!=1){v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;v[22640]=0;b=Q(1931,k|0,k+4|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break n}v[j+48>>2]=b;b=v[kq(j+24|0,j+48|0)>>2];c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;v[22640]=0;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;ca(1932,a|0,j+8|0,b|0,d|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break m}v[k+24>>2]=a;Aj(j+48|0);Ll(d);i=k;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;Aj(j+48|0)}Zb(a)}Ll(d);Z(i|0)|0;v[22640]=0;Y(1911,12338,k|0,g|0,h|0);a=v[22640];v[22640]=0;if((a|0)!=1){v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Zb(Ct(a))}i=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){Zb(a);v[k+20>>2]=0}Zb(k);break d}i=V(0)|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}Z(i|0)|0;i=0;v[22640]=0;Y(1911,12338,0,g|0,h|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}$()}gb=j+80|0;return i|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=gb-48|0;gb=g;a:{b:{c:{h=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?h>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?h>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?h>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?h>>>0>2147483648:0){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}s=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;m=v[a+48>>2];v[g+36>>2]=m;k=v[a+52>>2];v[g+40>>2]=k;l=v[a+56>>2];v[g+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[g+24>>2]=j;v[g+28>>2]=e;v[g+16>>2]=h;v[g+20>>2]=f;e:{if(d){while(1){m=1;b=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;e=(j>>>16&65520)+r|0;j=u[e+14>>1];h=u[e+12>>1];l=u[e+10>>1];q=u[e+8>>1];p=u[e+6>>1];t=u[e+4>>1];w=u[e+2>>1];x=u[e>>1];i=0;k=1;f=0;while(1){e=f<<1;v[(g+8|0)+(f<<2)>>2]=(((((((B(u[b+(e|-8)>>1],w)+B(u[b+(e|-12)>>1],x)|0)+B(u[b+(e|-4)>>1],t)|0)+B(u[b+e>>1],p)|0)+B(u[b+(e|4)>>1],q)|0)+B(u[b+(e|8)>>1],l)|0)+B(h,u[b+(e|12)>>1])|0)+B(j,u[b+(e|16)>>1])|0)/32768;e=k&1;k=0;f=1;if(e){continue}break}while(1){k=(g+8|0)+(i<<2)|0;j=v[k>>2];h=v[a+60>>2];l=h;e=(g+32|0)+(i<<3)|0;q=v[e>>2];b=Lb(q,-16777216,16776704);i=v[a+64>>2];f=Lb(v[e+4>>2],-16777216,16776704);p=h>>31;j=j<<8;h=j;h=mqa(l,p,h,h>>31);l=jb;p=h;h=mqa(i,i>>31,b,b>>31);i=p+h|0;b=jb+l|0;b=i>>>0<h>>>0?b+1|0:b;h=i;i=v[a+68>>2];i=mqa(i,i>>31,f,f>>31);f=h+i|0;b=jb+b|0;b=f>>>0<i>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=Ic(f,b,24);v[e+4>>2]=q;f=v[a+72>>2];v[k>>2]=(b|0)/256;v[e>>2]=b-(f&j);i=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;j=v[g+24>>2];e=v[g+28>>2];continue}break}j=v[g+24>>2];e=v[g+28>>2];l=v[g+44>>2];k=v[g+40>>2];m=v[g+36>>2];i=v[g+32>>2];break e}b=n>>12;f=o>>12}v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=i;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=e;gb=g+48|0}function Dl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Ab(c);v[22640]=0;R(102,a|0,d|0);d=v[22640];v[22640]=0;d:{if((d|0)!=1){e:{if(Ab(c)){while(1){d=v[kk(c,b)>>2];f:{if(d>>>0<=127){v[22640]=0;R(103,a|0,d<<24>>24);d=v[22640];v[22640]=0;if((d|0)!=1){break f}break e}v[22640]=0;R(103,a|0,63);d=v[22640];v[22640]=0;if((d|0)==1){break e}}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break d}}break a}return;case 2:b=0;a=Kb(a);d=Ab(c);v[22640]=0;R(102,a|0,d|0);d=v[22640];v[22640]=0;g:{if((d|0)!=1){h:{if(Ab(c)){while(1){d=v[kk(c,b)>>2];i:{if(d>>>0<=255){v[22640]=0;R(103,a|0,d<<24>>24);d=v[22640];v[22640]=0;if((d|0)!=1){break i}break h}v[22640]=0;R(103,a|0,63);d=v[22640];v[22640]=0;if((d|0)==1){break h}}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break g}}break a}return;case 3:oq(a,c,21392);return;case 5:oq(a,c,22416);return;case 4:oq(a,c,23440);return;case 6:oq(a,c,24464);return;default:a=aa(8)|0;v[22640]=0;Q(101,a|0,8367)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;da(a|0);S(b|0);L();case 0:break c}}e=gb-16|0;gb=e;f=Kb(a);j:{k:{if(Ab(c)){while(1){a=v[kk(c,g)>>2];l:{if(a>>>0>=2097152){v[22640]=0;R(103,f|0,63);a=v[22640];v[22640]=0;if((a|0)!=1){break l}break k}b=0;m:{n:{o:{while(1){d=a&63;t[(e+10|0)+b|0]=d;if(a>>>0<64){break o}a=a>>>6|0;b=b+1|0;if((b|0)!=6){continue}break}b=7;a=1;break n}if(!b){v[22640]=0;R(103,f|0,t[e+10|0]);a=v[22640];v[22640]=0;if((a|0)!=1){break l}break k}a=7-b|0;b=b+1|0;if((b|0)!=2){break n}if((d|0)==1){break m}b=2;a=6}i=(-1<<b^-1)<<a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){p:{if((a|0)==(b|0)){a=w[j|0];v[22640]=0;R(103,f|0,(a|i)<<24>>24);h=v[22640];v[22640]=0;a=d;if((h|0)!=1){break p}break k}v[22640]=0;a=a-1|0;R(103,f|0,t[a+(e+10|0)|0]|-128);h=v[22640];v[22640]=0;if((h|0)==1){break k}}if(a){continue}break}break l}v[22640]=0;R(103,f|0,t[e+10|0]|64);a=v[22640];v[22640]=0;if((a|0)==1){break k}}g=g+1|0;if(Ab(c)>>>0>g>>>0){continue}break}}gb=e+16|0;break j}a=P()|0;O()|0;vb(f);S(a|0);L()}return}ia(a|0,89e3,24);L()}b=P()|0;O()|0;vb(a);S(b|0);L()}function Mha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;e=gb-80|0;gb=e;r=v[a+16>>2];h=Sd(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];u=h,w=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;b=v[h+16>>2];if(b){u=h,w=gg(a+8|0,b),v[u>>2]=w;v[h+4>>2]=jb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;a:{if(d){while(1){m=0;f=m;j=g;v[e+72>>2]=g;v[e+76>>2]=f;i=(((i&2147483647)<<1|g>>>31)&-2)+r|0;b:{if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Id(v[h+8>>2],t[(g|1)+i|0]+t[i+(g&-2)|0]<<5);Hd(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Id(f,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);Hd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=dg(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;q=v[i>>2];b=Lb(q,-16777216,16776704);p=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=mqa(l,s,f,f>>31);l=jb;p=mqa(p,p>>31,b,b>>31);f=p+f|0;b=jb+l|0;b=f>>>0<p>>>0?b+1|0:b;l=f;f=v[a+68>>2];f=mqa(f,f>>31,g,g>>31);g=l+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Ic(g,b,24);v[i+4>>2]=q;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function Zh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;a:{if(!Ld(a)){break a}wk(a);if(c){c=b;n=gb-16|0;gb=n;f=a;if(Ld(a)){e=x[f+34>>1];o=v[f+4>>2];h=v[f+8>>2];m=v[f>>2];r=!(e&2)|(o>>>0>=h>>>0|h>>>0>m>>>0);p=v[f+12>>2];g=v[f+16>>2];s=!(e&8)|(p>>>0>=g>>>0|g>>>0>m>>>0);z=c+1298224|0;d=c+1074992|0;j=e&4;l=e&16;while(1){b:{if((f|0)!=v[d+104>>2]){break b}c=v[d+76>>2];if(!c){break b}c:{d:{i=d;e:{f:{if(s){break f}k=v[d+88>>2];if(k&2048){break f}v[d+84>>2]=g;v[d+80>>2]=p;e=l;c=g;break e}if(r){break d}v[d+84>>2]=h;v[d+80>>2]=o;k=v[d+88>>2];e=j;c=h}v[i+76>>2]=c;i=k|2;q=d+88|0;k=(e|0)!=0;e=1;break c}q=d+88|0;i=v[d+88>>2]&-3;k=0;e=0}i=i&-5|(e?k?4:0:0);v[d+88>>2]=i;if(y[d+4>>2]>c>>>0){i=i&-129;v[d+88>>2]=i;c=v[d+80>>2];v[d>>2]=0;v[d+4>>2]=c}if(!k){v[q>>2]=i&-129}if(e){break b}v[d+76>>2]=m}d=d+872|0;if((z|0)!=(d|0)){continue}break}}gb=n+16|0}if((ej(a)|0)==2){d=0;f=gb+-64|0;gb=f;e=bd(a);h=v[a+20>>2];g=h+(B(e,v[a>>2])<<1)|0;while(1){if(e){j=B(d,e);l=B(e,d^-1);c=0;while(1){u[g+(c+j<<1)>>1]=x[g+(c-e<<1)>>1];u[h+(c+l<<1)>>1]=x[h+(c<<1)>>1];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=g+(e<<5)|0;c=x[a+34>>1];if(c&2){j=v[a+8>>2];g=v[a+4>>2];Db(f+32|0,b+1074312|0,33);FS(f+40|0,d,h+(B(e,g)<<1)|0,j-g|0,e,(c&4)>>>2|0,Cb(f+32|0));c=x[a+34>>1]}if(c&8){g=v[a+16>>2];a=v[a+12>>2];Db(f+32|0,b+1074312|0,33);FS(f+8|0,d+(e<<7)|0,h+(B(a,e)<<1)|0,g-a|0,e,(c&16)>>>4|0,Cb(f+32|0))}gb=f- -64|0;return}if((ej(a)|0)!=1){break a}d=0;f=gb+-64|0;gb=f;e=bd(a);h=v[a+20>>2];g=h+B(e,v[a>>2])|0;while(1){if(e){j=B(d,e);l=B(e,d^-1);c=0;while(1){t[g+(c+j|0)|0]=w[g+(c-e|0)|0];t[h+(c+l|0)|0]=w[c+h|0];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=g+(e<<4)|0;c=x[a+34>>1];if(c&2){j=v[a+8>>2];g=v[a+4>>2];Db(f+32|0,b+1074312|0,33);ES(f+40|0,d,h+B(e,g)|0,j-g|0,e,(c&4)>>>2|0,Cb(f+32|0));c=x[a+34>>1]}if(c&8){g=v[a+16>>2];a=v[a+12>>2];Db(f+32|0,b+1074312|0,33);ES(f+8|0,d+(e<<6)|0,h+B(a,e)|0,g-a|0,e,(c&16)>>>4|0,Cb(f+32|0))}gb=f- -64|0}}function dha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;d=gb-48|0;gb=d;e=QR(d+32|0,1<<v[b+12>>2]);if(of(a)){while(1){f=A[ze(a,c)>>3];PR(Qc(e,c),f);c=c+1|0;if(of(a)>>>0>c>>>0){continue}break}}v[22640]=0;qz(b,e);c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}w=d,x=Sb(e),v[w>>2]=x;w=d,x=Wb(e),v[w+24>>2]=x;if(Gb(d,d+24|0)){while(1){c=v[d>>2];t=c;f=A[c+8>>3];i=gb-32|0;gb=i;o(+A[c>>3]);c=j(1)|0;g=j(0)|0;o(+f);k=j(1)|0;q=j(0)|0;p=c&2147483647;h=p;k=k&2147483647;r=(h|0)==(k|0)&g>>>0<q>>>0|h>>>0<k>>>0;c=r?g:q;h=r?h:k;r=h;l(0,c|0);l(1,h|0);f=+n();h=h>>>20|0;b:{if((h|0)==2047){break b}u=g;g=(k|0)==(p|0)&g>>>0>q>>>0|k>>>0<p>>>0;l(0,(g?u:q)|0);g=g?p:k;l(1,g|0);m=+n();p=!(c|r);c=g>>>20|0;if(!(p|(c|0)==2047)){if((c-h|0)>=65){f=m+f;break b}c:{if(c>>>0>=1534){f=f*1.90109156629516e-211;m=m*1.90109156629516e-211;s=5.260135901548374e210;break c}s=1;if(h>>>0>572){break c}f=f*5.260135901548374e210;m=m*5.260135901548374e210;s=1.90109156629516e-211}WI(i+24|0,i+16|0,m);WI(i+8|0,i,f);f=s*K(A[i>>3]+A[i+16>>3]+A[i+8>>3]+A[i+24>>3]);break b}f=m}gb=i+32|0;PR(t,Up(f));Wo(d);if(Gb(d,d+24|0)){continue}break}}v[22640]=0;oz(b,e);c=v[22640];v[22640]=0;if((c|0)==1){break a}v[22640]=0;nz(e);c=v[22640];v[22640]=0;if((c|0)==1){break a}if(qf(e)>>>0>3){c=1;while(1){HA(Qc(e,c),2);HA(Qc(e,(qf(e)>>>1|0)+c|0),0);c=c+1|0;if(c>>>0<qf(e)>>>1>>>0){continue}break}}v[22640]=0;qz(b,e);c=v[22640];v[22640]=0;if((c|0)==1){break a}w=d,x=Sb(e),v[w+24>>2]=x;w=d,x=Wb(e),v[w+16>>2]=x;d:{if(Gb(d+24|0,d+16|0)){while(1){c=v[d+24>>2];v[22640]=0;GA(d,c);g=v[22640];v[22640]=0;if((g|0)==1){break d}g=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=g;g=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=g;Wo(d+24|0);if(Gb(d+24|0,d+16|0)){continue}break}}v[22640]=0;oz(b,e);b=v[22640];v[22640]=0;if((b|0)==1){break a}v[22640]=0;nz(e);b=v[22640];v[22640]=0;if((b|0)==1){break a}if(of(a)){c=0;while(1){f=A[Qc(e,c)>>3];w=ze(a,c),y=f,A[w>>3]=y;c=c+1|0;if(of(a)>>>0>c>>>0){continue}break}}Sq(e);gb=d+48|0;return}}a=P()|0;O()|0;Sq(e);S(a|0);L()}function tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=gb-48|0;gb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}s=v[a+16>>2];h=v[a+44>>2];v[f+32>>2]=h;m=v[a+48>>2];v[f+36>>2]=m;k=v[a+52>>2];v[f+40>>2]=k;l=v[a+56>>2];v[f+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(d){while(1){i=(((i&2147483647)<<1|j>>>31)&-2)+s|0;b=(j>>>16&65520)+r|0;e=u[b+14>>1];j=u[b+12>>1];g=u[b+10>>1];l=u[b+8>>1];q=u[b+6>>1];p=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];h=0;m=1;k=1;b=0;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[i+(b|-4)|0],w)+B(t[i+(b|-6)|0],x)|0)+B(t[i+(b|-2)|0],p)|0)+B(t[b+i|0],q)|0)+B(t[i+(b|2)|0],l)|0)+B(t[i+(b|4)|0],g)|0)+B(j,t[i+(b|6)|0])|0)+B(e,t[i+(b|8)|0])<<8)/32768;y=k&1;k=0;b=1;if(y){continue}break}while(1){k=(f+8|0)+(h<<2)|0;j=v[k>>2];g=v[a+60>>2];l=g;i=(f+32|0)+(h<<3)|0;q=v[i>>2];b=Lb(q,-16777216,16776704);h=v[a+64>>2];e=Lb(v[i+4>>2],-16777216,16776704);p=g>>31;j=j<<8;g=j;g=mqa(l,p,g,g>>31);l=jb;p=g;g=mqa(h,h>>31,b,b>>31);h=p+g|0;b=jb+l|0;b=h>>>0<g>>>0?b+1|0:b;g=h;h=v[a+68>>2];h=mqa(h,h>>31,e,e>>31);e=g+h|0;b=jb+b|0;b=e>>>0<h>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}b=Ic(e,b,24);v[i+4>>2]=q;e=v[a+72>>2];v[k>>2]=(b|0)/256;v[i>>2]=b-(e&j);h=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;e=o>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];i=v[f+28>>2];continue}break}j=v[f+24>>2];i=v[f+28>>2];l=v[f+44>>2];k=v[f+40>>2];m=v[f+36>>2];h=v[f+32>>2];break e}b=n>>12;e=o>>12}v[a+40>>2]=n;v[a+20>>2]=e;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=i;gb=f+48|0}function oz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c=gb-208|0;gb=c;i=1;j=v[a+12>>2];k=1<<j;l=2;g=j;if(g>>>0>=2){f=k;while(1){h=f>>>2|0;if(f>>>0>=4){q=B(i,3);r=i<<1;s=h>>>0>1?h:1;g=0;while(1){eO(c+192|0,Qc(a,g<<1));eO(c+176|0,Qc(a,g));Ji(c+160|0,c+176|0,c+192|0);f=g<<l;p=i+f|0;if(f>>>0<p>>>0){while(1){d=Qc(b,f);e=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=e;e=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=e;m=f+i|0;d=Qc(b,m);e=v[d+12>>2];v[c+136>>2]=v[d+8>>2];v[c+140>>2]=e;e=v[d+4>>2];v[c+128>>2]=v[d>>2];v[c+132>>2]=e;n=f+r|0;d=Qc(b,n);e=v[d+12>>2];v[c+120>>2]=v[d+8>>2];v[c+124>>2]=e;e=v[d+4>>2];v[c+112>>2]=v[d>>2];v[c+116>>2]=e;o=f+q|0;d=Qc(b,o);e=v[d+12>>2];v[c+104>>2]=v[d+8>>2];v[c+108>>2]=e;e=v[d+4>>2];v[c+96>>2]=v[d>>2];v[c+100>>2]=e;Fl(c+80|0,c+144|0,c+128|0);Cj(c- -64|0,c+144|0,c+128|0);Fl(c+48|0,c+112|0,c+96|0);Cj(c+16|0,c+112|0,c+96|0);Ji(c+32|0,48576,c+16|0);Fl(c+16|0,c+80|0,c+48|0);d=Qc(b,f);e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;Fl(c,c- -64|0,c+32|0);Ji(c+16|0,c+192|0,c);m=Qc(b,m);d=m;e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;Cj(c,c+80|0,c+48|0);Ji(c+16|0,c+176|0,c);n=Qc(b,n);d=n;e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;Cj(c,c- -64|0,c+32|0);Ji(c+16|0,c+160|0,c);o=Qc(b,o);d=o;e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;f=f+1|0;if((p|0)!=(f|0)){continue}break}}g=g+1|0;if((s|0)!=(g|0)){continue}break}g=v[a+12>>2]}i=i<<2;f=h;l=l+2|0;if(l>>>0<=g>>>0){continue}break}}if(!(!(g&1)|!j)){g=k>>>1|0;j=g>>>0>1?g:1;f=0;while(1){k=f+g|0;h=Qc(b,k);a=v[h+12>>2];v[c+200>>2]=v[h+8>>2];v[c+204>>2]=a;a=v[h+4>>2];v[c+192>>2]=v[h>>2];v[c+196>>2]=a;Cj(c+176|0,Qc(b,f),c+192|0);h=Qc(b,k);a=v[c+188>>2];v[h+8>>2]=v[c+184>>2];v[h+12>>2]=a;a=v[c+180>>2];v[h>>2]=v[c+176>>2];v[h+4>>2]=a;pz(Qc(b,f),c+192|0);f=f+1|0;if((j|0)!=(f|0)){continue}break}}gb=c+208|0}function w2(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=gb-1072|0;gb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;v[a+956>>2]=a+960;j=Nx(a+960|0,100,8413,a+16|0);v[a+48>>2]=2434;o=ge(a+536|0,0,a+48|0);v[a+48>>2]=2434;m=ge(a+528|0,0,a+48|0);l=a+544|0;a:{b:{c:{if(j>>>0>=100){v[22640]=0;j=fa(2454)|0;l=v[22640];v[22640]=0;if((l|0)==1){break b}v[a>>2]=f;v[a+4>>2]=g;v[22640]=0;v[a+8>>2]=h;v[a+12>>2]=i;j=ca(2473,a+956|0,j|0,8413,a|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}if((j|0)==-1){v[22640]=0;X(2435);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break b}Ee(o,v[a+956>>2]);Ee(m,Ad(j<<2));if(vk(m)){v[22640]=0;X(2435);a=v[22640];v[22640]=0;if((a|0)==1){break b}break c}l=v[m>>2]}v[22640]=0;Ec(a+520|0,d);f=v[22640];v[22640]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){v[22640]=0;q=T(2458,a+520|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break j}v[22640]=0;f=v[a+956>>2];Y(2470,q|0,f|0,f+j|0,l|0);f=v[22640];v[22640]=0;if((f|0)==1){break j}p=(j|0)>=1?w[v[a+956>>2]]==45:p;h=Kb(a+488|0);f=Kb(a+472|0);g=Kb(a+456|0);v[22640]=0;na(2502,c|0,p|0,a+520|0,a+512|0,a+508|0,a+504|0,h|0,f|0,g|0,a+452|0);c=v[22640];v[22640]=0;if((c|0)==1){break i}v[a+36>>2]=2434;c=ge(a+40|0,0,a+36|0);i=a+48|0;n=v[a+452>>2];k:{if((n|0)<(j|0)){k=(Ab(g)+(j-n<<1|1)|0)+Ab(f)|0;break k}k=(Ab(g)+Ab(f)|0)+2|0}k=k+n|0;if(k>>>0<101){break h}Ee(c,Ad(k<<2));i=v[c>>2];if(i){break h}v[22640]=0;X(2435);b=v[22640];v[22640]=0;if((b|0)!=1){break c}break g}j=P()|0;O()|0;break a}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}k=v[d+4>>2];v[22640]=0;qa(2503,i|0,a+36|0,a+32|0,k|0,l|0,(j<<2)+l|0,q|0,p|0,a+512|0,v[a+508>>2],v[a+504>>2],h|0,f|0,g|0,n|0);j=v[22640];v[22640]=0;if((j|0)!=1){v[22640]=0;b=la(2483,b|0,i|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break d}}}j=P()|0;O()|0;Gc(c)}Hc(g);Hc(f);vb(h)}Vb(a+520|0);break a}Gc(c);Hc(g);Hc(f);vb(h);Vb(a+520|0);Gc(m);Gc(o);gb=a+1072|0;return b|0}L()}j=P()|0;O()|0}Gc(m);Gc(o);S(j|0);L()}function sx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=v[d>>2];if(!g){break l}if(!a){d=c;break j}v[d>>2]=0;d=c;break k}m:{if(!v[v[22545]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=t[e|0];if(d){v[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return Lf(e)|0}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=w[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}h=e+1|0;f=h;n:{if(!(g&33554432)){break n}if((w[h|0]&192)!=128){e=e-1|0;break d}h=e+2|0;f=h;if(!(g&524288)){break n}if((w[h|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=w[e|0];o:{if(e&3|g-1>>>0>126){break o}g=v[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=v[e+4>>2];f=e+4|0;e=f;if(!((g-16843009|g)&-2139062144)){continue}break}e=f}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+76576>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=w[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=v[e>>2];if((g|g-16843009)&-2139062144){break s}v[a>>2]=g&255;v[a+4>>2]=w[e+1|0];v[a+8>>2]=w[e+2|0];v[a+12>>2]=w[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=w[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}v[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+76576>>2];f=1;continue}h=w[e|0];f=h>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{i=e+1|0;f=h-128|g<<6;h=i;v:{if((f|0)>-1){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}i=e+2|0;f=h|f<<6;h=i;if((f|0)>-1){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;v[a>>2]=f;d=d-1|0;a=a+4|0;break t}v[115121]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=w[e|0]}if(g&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-d|0}v[115121]=25;if(!a){break b}}v[b>>2]=e}return-1}v[b>>2]=e;return c|0}function Pha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=gb-80|0;gb=e;p=v[a+16>>2];h=Sd(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];t=h,w=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;b=v[h+16>>2];if(b){t=h,w=gg(a+8|0,b),v[t>>2]=w;v[h+4>>2]=jb}j=v[a+44>>2];v[e+32>>2]=j;f=v[a+48>>2];v[e+36>>2]=f;l=v[a+52>>2];v[e+40>>2]=l;k=v[a+56>>2];v[e+44>>2]=k;q=v[a+24>>2];r=v[a+20>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;m=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=m;if(d){while(1){l=0;j=l;f=g;v[e+72>>2]=g;v[e+76>>2]=j;i=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+p|0;a:{if((b|0)<=0){break a}while(1){g=(j&2147483647)<<1|f>>>31;Id(v[h+8>>2],(u[(g<<1|2)+i>>1]+u[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break a}b=b-1|0;f=v[e+72>>2];j=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Id(f,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=dg(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;l=1;while(1){k=v[a+60>>2];m=k;i=(e+32|0)+(j<<3)|0;o=v[i>>2];b=Lb(o,-16777216,16776704);n=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=mqa(m,s,f,f>>31);m=jb;n=mqa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=mqa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Ic(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(l){j=1;l=0;f=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];k=v[e+44>>2];l=v[e+40>>2];f=v[e+36>>2];j=v[e+32>>2];i=v[e+28>>2]}v[a+56>>2]=k;v[a+52>>2]=l;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function A2(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=gb-464|0;gb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;v[a+348>>2]=a+352;j=Nx(a+352|0,100,8413,a+16|0);v[a+48>>2]=2434;o=ge(a+232|0,0,a+48|0);v[a+48>>2]=2434;m=ge(a+224|0,0,a+48|0);l=a+240|0;a:{b:{c:{if(j>>>0>=100){v[22640]=0;j=fa(2454)|0;l=v[22640];v[22640]=0;if((l|0)==1){break b}v[a>>2]=f;v[a+4>>2]=g;v[22640]=0;v[a+8>>2]=h;v[a+12>>2]=i;j=ca(2473,a+348|0,j|0,8413,a|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}if((j|0)==-1){v[22640]=0;X(2435);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break b}Ee(o,v[a+348>>2]);Ee(m,Ad(j));if(vk(m)){v[22640]=0;X(2435);a=v[22640];v[22640]=0;if((a|0)==1){break b}break c}l=v[m>>2]}v[22640]=0;Ec(a+216|0,d);f=v[22640];v[22640]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){v[22640]=0;q=T(21,a+216|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break j}v[22640]=0;f=v[a+348>>2];Y(2450,q|0,f|0,f+j|0,l|0);f=v[22640];v[22640]=0;if((f|0)==1){break j}p=(j|0)>=1?w[v[a+348>>2]]==45:p;h=Kb(a+192|0);f=Kb(a+176|0);g=Kb(a+160|0);v[22640]=0;na(2500,c|0,p|0,a+216|0,a+208|0,a+207|0,a+206|0,h|0,f|0,g|0,a+156|0);c=v[22640];v[22640]=0;if((c|0)==1){break i}v[a+36>>2]=2434;c=ge(a+40|0,0,a+36|0);i=a+48|0;n=v[a+156>>2];k:{if((n|0)<(j|0)){k=(Ab(g)+(j-n<<1|1)|0)+Ab(f)|0;break k}k=(Ab(g)+Ab(f)|0)+2|0}k=k+n|0;if(k>>>0<101){break h}Ee(c,Ad(k));i=v[c>>2];if(i){break h}v[22640]=0;X(2435);b=v[22640];v[22640]=0;if((b|0)!=1){break c}break g}j=P()|0;O()|0;break a}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}k=v[d+4>>2];v[22640]=0;qa(2501,i|0,a+36|0,a+32|0,k|0,l|0,j+l|0,q|0,p|0,a+208|0,t[a+207|0],t[a+206|0],h|0,f|0,g|0,n|0);j=v[22640];v[22640]=0;if((j|0)!=1){v[22640]=0;b=la(17,b|0,i|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break d}}}j=P()|0;O()|0;Gc(c)}vb(g);vb(f);vb(h)}Vb(a+216|0);break a}Gc(c);vb(g);vb(f);vb(h);Vb(a+216|0);Gc(m);Gc(o);gb=a+464|0;return b|0}L()}j=P()|0;O()|0}Gc(m);Gc(o);S(j|0);L()}function ima(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;t[a|0]=0;c=w[b|0];if(c){t[a|0]=c>>>0>96?-1:c+12|0}t[a+1|0]=w[b+1|0];c=a;d=w[b+2|0];e=d-16|0;a:{b:{if((e&255)>>>0<=128){t[a+2|0]=1;d=(e&254)>>>1|0;break b}c:{switch((d+96&240)>>>4|0){case 0:t[a+2|0]=4;d=d&15;break b;case 1:t[a+2|0]=3;d=d&15;break b;case 2:t[a+2|0]=6;d=d&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;d=d&15}t[c+4|0]=d}d=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{c=w[b+4|0];if(c>>>0<=28){switch(c|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(c-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((c|0)==128){break e}if((c|0)!=157){break d}t[a+2|0]=15;c=w[b+6|0];t[a+3|0]=20;t[a+4|0]=c>>>3;t[f+15|0]=15;g=a,h=w[ac(b+5|0,f+15|0)|0]|208,t[g+5|0]=h;break d}c=w[b+6|0];e=w[b+5|0];if(!(c|e)){break d}t[a+5|0]=e;t[a+3|0]=c;Mf(a);d=w[b+6|0]==15;break d}t[a+3|0]=2;g=a,h=di(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=3;g=a,h=di(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=4;g=a,h=di(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=5;t[a+5|0]=w[b+6|0]&240|w[b+5|0]>>>4;break d}c=w[b+5|0];if(c){t[a+5|0]=c;t[a+3|0]=9;break d}if((w[b+6|0]-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d}t[a+3|0]=13;t[a+5|0]=w[b+6|0]>>>1;break d}c=w[b+6|0];if(c){t[a+5|0]=c;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=w[b+5|0]&15;break d}t[a+3|0]=w[b+6|0];t[a+5|0]=w[b+5|0];Pu(a,1);d=(w[a+3|0]&254)==16;break d}t[a+3|0]=18;t[a+5|0]=w[b+5|0];break d}t[a+3|0]=31;t[a+5|0]=w[b+6|0]>>>1;break d}t[a+3|0]=31;t[a+5|0]=w[b+6|0]>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=w[b+6|0]>>>2}b=w[b+3|0];t:{if(!b){break t}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break t}if(w[a+2|0]){break t}t[a+2|0]=2;t[a+4|0]=b>>>2}gb=f+16|0;return d|0}function Oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb+-64|0;gb=d;u[d+62>>1]=c;sg(d+62|0,32);f=nc(a);v[22640]=0;R(730,f|0,x[d+62>>1]);a=v[22640];v[22640]=0;a:{if((a|0)!=1){b:{if(!x[d+62>>1]){break b}while(1){a=x[b+480190>>1]+1|0;u[d+60>>1]=a;c:{d:{if((a&65535)>>>0<4e3){break d}u[d+24>>1]=1;e:{if(!x[b+480190>>1]){break e}while(1){f:{if(Ld(Sl(b,x[d+24>>1]))){break f}i=d,j=PB(Sb(f),Wb(f),d+24|0),v[i+48>>2]=j;i=d,j=Wb(f),v[i+40>>2]=j;if(Gb(d+48|0,d+40|0)){break f}u[d+60>>1]=x[d+24>>1];c=1;if(!x[b+480192>>1]){break e}while(1){a=v[(((c&65535)<<2)+b|0)+900380>>2];g:{if(!a){break g}a=a+236|0;e=Cu(a);if((a|0)==(e|0)){break g}while(1){if(x[a>>1]==x[d+60>>1]){u[a>>1]=0}a=a+2|0;if((e|0)!=(a|0)){continue}break}}c=c+1|0;if(x[b+480192>>1]>=(c&65535)>>>0){continue}break}break e}a=x[d+24>>1]+1|0;u[d+24>>1]=a;if(x[b+480190>>1]>=(a&65535)>>>0){continue}break}}if(x[d+60>>1]<4e3){break d}c=Vu(d+48|0);v[22640]=0;a=Q(986,b|0,c|0)|0;e=v[22640];v[22640]=0;h:{i:{if((e|0)==1){break i}j:{if(a){v[22640]=0;Q(987,b|0,c|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break i}e=1;if(!x[b+480192>>1]){break j}while(1){a=v[(((e&65535)<<2)+b|0)+900380>>2];k:{if(!a){break k}a=a+236|0;g=Cu(a);if((a|0)==(g|0)){break k}while(1){l:{if(y[c+4>>2]<=x[a>>1]){break l}oe(d+40|0,c,x[a>>1]);if(Cb(d+40|0)){break l}u[a>>1]=0}a=a+2|0;if((g|0)!=(a|0)){continue}break}}e=e+1|0;if(x[b+480192>>1]>=(e&65535)>>>0){continue}break}break j}Ce(c);break b}yk(d+24|0,c);hB(d+32|0,d+24|0,1);Rl(d+16|0,c);v[22640]=0;t[d+15|0]=0;fT(d+40|0,d+32|0,d+16|0,d+15|0);a=v[22640];v[22640]=0;if((a|0)!=1){break h}}a=P()|0;O()|0;Ce(c);break a}yk(d,c);i=d,j=Mj(d+40|0,d),u[i+60>>1]=j;Ce(c);if(x[d+60>>1]>=4e3){break c}}v[22640]=0;R(421,f|0,d+60|0);a=v[22640];v[22640]=0;if((a|0)!=1){if(x[b+480190>>1]>=x[d+60>>1]){break c}u[b+480190>>1]=x[d+60>>1];break c}a=P()|0;O()|0;break a}h=h+1|0;if(x[d+62>>1]>(h&65535)>>>0){continue}break}}gb=d- -64|0;return}a=P()|0;O()|0}Ue(f);S(a|0);L()}function C9(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=gb-48|0;gb=k;a:{b:{c:{j=Xp(1,32);d:{e:{if(!j){a=aa(4)|0;km(a);v[22640]=0;U(223,a|0,88880,1928);a=v[22640];v[22640]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1919;d=su(k+32|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[22640]=0;c=Q(112,k+16|0,c|0)|0;f=v[22640];v[22640]=0;i:{if((f|0)!=1){v[22640]=0;f=Q(1929,d|0,c|0)|0;l=v[22640];v[22640]=0;if((l|0)==1){break i}v[22640]=0;Q(443,f|0,e|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}v[22640]=0;c=Q(112,k+16|0,c|0)|0;e=v[22640];v[22640]=0;j:{if((e|0)!=1){v[22640]=0;R(1930,d|0,c|0);e=v[22640];v[22640]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;vb(c);break f}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[22640]=0;c=T(1298,96)|0;e=v[22640];v[22640]=0;k:{l:{m:{if((e|0)!=1){v[22640]=0;e=Q(1931,j|0,j+4|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break m}v[k+16>>2]=e;e=v[kq(k+8|0,k+16|0)>>2];v[22640]=0;ga(2006,c|0,a|0,b|0,e|0,d|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break l}v[j+28>>2]=c;Aj(k+16|0);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;Ll(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;Aj(k+16|0)}Zb(c)}Ll(d);Z(i|0)|0;v[22640]=0;Y(1911,2069,j|0,g|0,h|0);a=v[22640];v[22640]=0;if((a|0)!=1){v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){a=v[j+28>>2];if(a){kb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Zb(a);v[j+20>>2]=0}Zb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)==1){break b}}Z(i|0)|0;j=0;v[22640]=0;Y(1911,2069,0,g|0,h|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}$()}gb=k+48|0;return j|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function r8(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=C(0),g=C(0),h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=0;e=gb-16|0;gb=e;a:{b:{c:{d:{switch(b-1|0){case 0:c=z[a+48>>2];a=v[a+48>>2];e:{f:{g:{if(!((a|0)>-1?a>>>0>=8388608:0)){g=C(C(-1)/C(c*c));if(!(a&2147483647)){break e}g=C(C(c-c)/C(0));if((a|0)<=-1){break e}a=(p(C(c*C(33554432))),j(2));b=-152;break g}if(a>>>0>2139095039){break f}b=-127;c=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;n=C((a>>>23|0)+b|0);c=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));i=C(c*C(c*C(.5)));k=C(c/C(c+C(2)));f=C(k*k);m=C(f*f);g=c;c=(l(2,(p(C(c-i)),j(2))&-4096),q());f=C(C(C(g-c)-i)+C(k*C(i+C(C(f*C(C(m*C(.2849878668785095))+C(.6666666269302368)))+C(m*C(C(m*C(.24279078841209412))+C(.40000972151756287)))))));c=C(C(n*C(.3010292053222656))+C(C(c*C(.434326171875))+C(C(f*C(.434326171875))+C(C(n*C(7.903415166765626e-7))+C(C(f+c)*C(-3168997136526741e-20))))))}g=c}f=C(g*C(2e3));if(!(C(D(f))<C(2147483648))){break c}a=~~f;break b;case 1:a=(B(v[v[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:b=gb-16|0;gb=b;h:{i:{j:{k:{a=w[v[a+24>>2]+24648|0];if(a>>>0>=6){e=aa(8)|0;v[22640]=0;b=Q(112,b|0,2219)|0;a=v[22640];v[22640]=0;if((a|0)==1){break k}qc(e,b);v[22640]=0;U(223,e|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break i}a=P()|0;O()|0;vb(b);break j}gb=b+16|0;a=v[(a<<24>>24<<2)+59440>>2];break h}a=P()|0;O()|0;da(e|0)}S(a|0)}L()}break b;case 3:v[e>>2]=0;d=gb-80|0;gb=d;a=v[a+24>>2]+24604|0;v[d+40>>2]=v[a+32>>2];v[d>>2]=v[a+36>>2];b=v[Nf(d+40|0,d)>>2];o=e;l:{if(v[a+32>>2]==v[_q(d+40|0)+32>>2]){h=-1;if(v[a+36>>2]==v[_q(d)+36>>2]){break l}}h=0;if((b|0)<1){break l}h=(b+500>>>0)/1e3|0}v[o>>2]=h;gb=d+80|0;a=v[e>>2];break b;default:break d}}d=aa(8)|0;v[22640]=0;b=Q(112,e|0,7711)|0;a=v[22640];v[22640]=0;m:{if((a|0)!=1){qc(d,b);v[22640]=0;U(223,d|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);break m}a=P()|0;O()|0;da(d|0)}S(a|0);L()}a=-2147483648}gb=e+16|0;return a|0}L()}function wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=gb-48|0;gb=f;a:{b:{c:{i=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?i>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?i>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?i>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?i>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;g=v[a+48>>2];v[f+36>>2]=g;k=v[a+52>>2];v[f+40>>2]=k;m=v[a+56>>2];v[f+44>>2]=m;r=v[a+24>>2];s=v[a+20>>2];h=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=h;v[f+16>>2]=i;v[f+20>>2]=e;if(d){while(1){m=1;e=((((h&2147483647)<<1|j>>>31)&2147483646)<<1)+q|0;b=(j>>>16&65520)+p|0;j=u[b+14>>1];i=u[b+12>>1];n=u[b+10>>1];l=u[b+8>>1];o=u[b+6>>1];t=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];k=0;b=1;g=0;while(1){h=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((((B(u[e+(h|-8)>>1],w)+B(u[e+(h|-12)>>1],x)|0)+B(u[e+(h|-4)>>1],t)|0)+B(u[e+h>>1],o)|0)+B(u[e+(h|4)>>1],l)|0)+B(u[e+(h|8)>>1],n)|0)+B(u[e+(h|12)>>1],i)|0)+B(j,u[e+(h|16)>>1])|0)/32768;h=b;b=0;g=1;if(h){continue}break}while(1){j=(f+8|0)+(k<<2)|0;g=v[j>>2];i=v[a+60>>2];n=i;h=(f+32|0)+(k<<3)|0;k=v[h>>2];b=Lb(k,-16777216,16776704);l=v[a+64>>2];e=Lb(v[h+4>>2],-16777216,16776704);o=i>>31;i=g<<8;g=i;g=mqa(n,o,g,g>>31);n=jb;l=mqa(l,l>>31,b,b>>31);g=l+g|0;b=jb+n|0;b=g>>>0<l>>>0?b+1|0:b;o=g;g=v[a+68>>2];g=mqa(g,g>>31,e,e>>31);e=o+g|0;b=jb+b|0;b=e>>>0<g>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}b=Ic(e,b,24);v[h+4>>2]=k;e=v[a+72>>2];v[j>>2]=(b|0)/256;v[h>>2]=b-(e&i);k=1;b=m&1;m=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];h=v[f+28>>2];continue}break}j=v[f+24>>2];h=v[f+28>>2];m=v[f+44>>2];k=v[f+40>>2];g=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function Qha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;e=gb-80|0;gb=e;p=v[a+16>>2];h=Sd(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];u=h,w=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;b=v[h+16>>2];if(b){u=h,w=gg(a+8|0,b),v[u>>2]=w;v[h+4>>2]=jb}j=v[a+44>>2];v[e+32>>2]=j;f=v[a+48>>2];v[e+36>>2]=f;l=v[a+52>>2];v[e+40>>2]=l;k=v[a+56>>2];v[e+44>>2]=k;q=v[a+24>>2];r=v[a+20>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;m=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=m;if(d){while(1){l=0;j=l;f=g;v[e+72>>2]=g;v[e+76>>2]=j;i=(((i&2147483647)<<1|g>>>31)&-2)+p|0;a:{if((b|0)<=0){break a}while(1){g=(j&2147483647)<<1|f>>>31;Id(v[h+8>>2],t[(g|1)+i|0]+t[i+(g&-2)|0]<<5);Hd(v[h+8>>2],4);Ub(e+72|0,h);if((b|0)<2){break a}b=b-1|0;f=v[e+72>>2];j=v[e+76>>2];continue}}b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Id(f,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);Hd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=dg(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;l=1;while(1){k=v[a+60>>2];m=k;i=(e+32|0)+(j<<3)|0;o=v[i>>2];b=Lb(o,-16777216,16776704);n=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);s=k>>31;k=f<<8;f=k;f=mqa(m,s,f,f>>31);m=jb;n=mqa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=mqa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Ic(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[(e+8|0)+(j<<2)>>2]=(b|0)/256;v[i>>2]=b-(g&k);if(l){j=1;l=0;f=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Ub(e+24|0,e+16|0);if(d){c=c+8|0;b=v[h+16>>2];g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];k=v[e+44>>2];l=v[e+40>>2];f=v[e+36>>2];j=v[e+32>>2];i=v[e+28>>2]}v[a+56>>2]=k;v[a+52>>2]=l;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=g;v[a+4>>2]=i;gb=e+80|0}function Ci(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=C(0),n=0,o=C(0),p=0;if(!(kb[v[v[a>>2]+136>>2]](a)|0)){g=w[v[a+20>>2]+25|0]}j=z[v[a+20>>2]+144>>2];k=C(1);if(!(kb[v[v[a>>2]+136>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((kb[v[v[a>>2]+152>>2]](a)|0)<1){break a}if(!HM(v[a+20>>2])){break a}j=C(C(j+j)+C(-1));k=C(-j)}m=z[a+4196>>2];k=C(m*k);j=C(m*j);l=a+44|0;n=Md(l,0);l=Md(l,1);b:{c:{switch(g|0){case 4:if(!f){break b}while(1){g=i<<2;k=z[g+n>>2];h=b+g|0;m=z[h>>2];p=h;h=c+g|0;z[p>>2]=C(z[d+g>>2]*j)-C(z[h>>2]+z[g+l>>2]);z[h>>2]=C(z[e+g>>2]*j)-C(k+m);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 3:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(C(z[g+n>>2]*j)-z[d+g>>2])+z[h>>2];h=c+g|0;z[h>>2]=C(C(z[g+l>>2]*j)-z[e+g>>2])+z[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 2:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(z[h>>2]+z[d+g>>2])-C(z[g+n>>2]*k);h=c+g|0;z[h>>2]=C(z[h>>2]+z[e+g>>2])-C(z[g+l>>2]*k);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 1:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(z[h>>2]+z[g+n>>2])-C(z[d+g>>2]*j);h=c+g|0;z[h>>2]=C(z[h>>2]+z[g+l>>2])-C(z[e+g>>2]*j);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 0:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(C(z[g+n>>2]*k)+C(z[d+g>>2]*j))+z[h>>2];h=c+g|0;z[h>>2]=C(C(z[g+l>>2]*k)+C(z[e+g>>2]*j))+z[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 5:break c;default:break b}}g=HM(v[a+20>>2]);if(!f){break b}j=g?C(j*C(.5)):j;k=g?C(k*C(.5)):k;while(1){g=i<<2;h=g+b|0;m=C(z[d+g>>2]-z[g+n>>2]);o=C(z[g+l>>2]-z[e+g>>2]);z[h>>2]=C(z[h>>2]+C(m*j))+C(o*k);g=c+g|0;z[g>>2]=C(C(o*j)+C(m*k))+z[g>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break}}d:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break d}if(kb[v[v[a>>2]+136>>2]](a)|!f){break d}e=0;while(1){a=e<<2;d=a+b|0;z[d>>2]=z[d>>2]+z[a+n>>2];d=a+c|0;z[d>>2]=z[d>>2]+z[a+l>>2];e=e+1|0;if((f|0)!=(e|0)){continue}break}}}function sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=C(0),u=0,w=0,x=0,y=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0);m=a+44|0;if(ki(m)){A=Md(m,0);B=Md(m,1);D=kd(m,0);E=kd(m,1);q=v[a+4296>>2];o=v[a+4300>>2];if(d){j=a+4304|0;i=q+1|0;u=i+v[a+4272>>2]&4095;l=j+(u<<4)|0;w=i+v[a+4276>>2]&4095;g=((w<<4)+j|0)+4|0;x=i+v[a+4280>>2]&4095;n=((x<<4)+j|0)+8|0;y=i+v[a+4284>>2]&4095;h=((y<<4)+j|0)+12|0;r=v[a+4288>>2]+o|0;s=v[a+4292>>2]+o|0;G=a+69840|0;H=a+78032|0;F=d;while(1){u=u-1&4095;i=(u<<4)+j|0;e=z[i>>2];r=r&1023;I=(r<<3)+G|0;p=z[I+4>>2];J=z[h>>2];K=z[n>>2];L=z[g>>2];M=z[l>>2];N=z[B>>2];O=z[A>>2];t=z[a+4232>>2];w=w-1&4095;l=(w<<4)+j|0;k=z[l+4>>2];f=C(C(t*z[I>>2])+C(k*C(.6180340051651001)));h=o<<3;g=h+G|0;z[g+4>>2]=k-C(f*C(.6180340051651001));k=e;e=C(C(p*t)-C(e*C(.6180340051651001)));z[g>>2]=k+C(e*C(.6180340051651001));z[i>>2]=f;z[l+4>>2]=e;s=s&1023;g=(s<<3)+H|0;p=z[g+4>>2];x=x-1&4095;n=(x<<4)+j|0;f=z[n+8>>2];t=z[a+4236>>2];e=C(t*z[g>>2]);y=y-1&4095;g=(y<<4)+j|0;k=z[g+12>>2];e=C(e+C(k*C(.6180340051651001)));h=h+H|0;z[h+4>>2]=k-C(e*C(.6180340051651001));k=f;f=C(C(p*t)-C(f*C(.6180340051651001)));z[h>>2]=k+C(f*C(.6180340051651001));z[n+8>>2]=e;z[g+12>>2]=f;f=C(z[i>>2]+e);e=C(O+C(1.0000000031710769e-30));z[D>>2]=f+C(z[a+4224>>2]*e);f=C(N+C(1.0000000031710769e-30));z[E>>2]=C(C(z[a+4224>>2]*f)+z[l+4>>2])+z[g+12>>2];h=(q<<4)+j|0;p=z[a+4228>>2];e=C(p*e);z[h>>2]=C(C(z[a+4240>>2]*z[i>>2])+e)+C(M*z[a+4244>>2]);f=C(p*f);z[h+4>>2]=C(C(z[a+4248>>2]*z[l+4>>2])+f)+C(L*z[a+4252>>2]);z[h+8>>2]=C(C(z[a+4256>>2]*z[n+8>>2])-f)+C(K*z[a+4260>>2]);z[h+12>>2]=C(C(z[a+4264>>2]*z[g+12>>2])+e)+C(J*z[a+4268>>2]);h=g+12|0;n=n+8|0;g=l+4|0;E=E+4|0;D=D+4|0;B=B+4|0;A=A+4|0;s=s-1|0;r=r-1|0;o=o-1&1023;q=q-1&4095;l=i;F=F-1|0;if(F){continue}break}}v[a+4300>>2]=o;v[a+4296>>2]=q;Ci(a,b,c,kd(m,0),kd(m,1),d)}}function xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=gb-48|0;gb=f;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;i=v[a+48>>2];v[f+36>>2]=i;k=v[a+52>>2];v[f+40>>2]=k;m=v[a+56>>2];v[f+44>>2]=m;r=v[a+24>>2];s=v[a+20>>2];g=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=g;v[f+16>>2]=h;v[f+20>>2]=e;if(d){while(1){e=(((g&2147483647)<<1|j>>>31)&-2)+q|0;b=(j>>>16&65520)+p|0;j=u[b+14>>1];h=u[b+12>>1];n=u[b+10>>1];l=u[b+8>>1];o=u[b+6>>1];w=u[b+4>>1];x=u[b+2>>1];y=u[b>>1];k=0;m=1;i=1;b=0;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[e+(b|-4)|0],x)+B(t[e+(b|-6)|0],y)|0)+B(t[e+(b|-2)|0],w)|0)+B(t[b+e|0],o)|0)+B(t[e+(b|2)|0],l)|0)+B(t[e+(b|4)|0],n)|0)+B(t[e+(b|6)|0],h)|0)+B(j,t[e+(b|8)|0])<<8)/32768;g=i;i=0;b=1;if(g){continue}break}while(1){j=(f+8|0)+(k<<2)|0;e=v[j>>2];h=v[a+60>>2];n=h;i=(f+32|0)+(k<<3)|0;k=v[i>>2];b=Lb(k,-16777216,16776704);l=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);o=h>>31;h=e<<8;e=h;e=mqa(n,o,e,e>>31);n=jb;l=mqa(l,l>>31,b,b>>31);e=l+e|0;b=jb+n|0;b=e>>>0<l>>>0?b+1|0:b;o=e;e=v[a+68>>2];e=mqa(e,e>>31,g,g>>31);g=o+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Ic(g,b,24);v[i+4>>2]=k;g=v[a+72>>2];v[j>>2]=(b|0)/256;v[i>>2]=b-(g&h);k=1;b=m&1;m=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];g=v[f+28>>2];continue}break}j=v[f+24>>2];g=v[f+28>>2];m=v[f+44>>2];k=v[f+40>>2];i=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=i;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function Wp(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Ad(b)}if(b>>>0>=4294967232){v[115121]=48;return 0}e=b>>>0<11?16:b+11&-8;h=a-4|0;i=v[h>>2];c=i&-8;a:{b:{if(!(i&3)){if(e>>>0<256|c>>>0<(e|4)>>>0){break b}if(c-e>>>0<=v[116569]<<1>>>0){break a}break b}g=a-8|0;f=c+g|0;if(c>>>0>=e>>>0){b=c-e|0;if(b>>>0<16){break a}v[h>>2]=i&1|e|2;c=e+g|0;v[c+4>>2]=b|3;v[f+4>>2]=v[f+4>>2]|1;zs(c,b);return a}if(v[116455]==(f|0)){c=c+v[116452]|0;if(c>>>0<=e>>>0){break b}v[h>>2]=i&1|e|2;b=e+g|0;c=c-e|0;v[b+4>>2]=c|1;v[116452]=c;v[116455]=b;return a}if(v[116454]==(f|0)){c=c+v[116451]|0;if(c>>>0<e>>>0){break b}b=c-e|0;c:{if(b>>>0>=16){v[h>>2]=i&1|e|2;d=e+g|0;v[d+4>>2]=b|1;c=c+g|0;v[c>>2]=b;v[c+4>>2]=v[c+4>>2]&-2;break c}v[h>>2]=c|i&1|2;b=c+g|0;v[b+4>>2]=v[b+4>>2]|1;b=0}v[116454]=d;v[116451]=b;return a}d=v[f+4>>2];if(d&2){break b}j=c+(d&-8)|0;if(j>>>0<e>>>0){break b}l=j-e|0;d:{if(d>>>0<=255){b=v[f+8>>2];d=d>>>3|0;c=v[f+12>>2];if((c|0)==(b|0)){n=465796,o=v[116449]&qqa(-2,d),v[n>>2]=o;break d}v[b+12>>2]=c;v[c+8>>2]=b;break d}k=v[f+24>>2];c=v[f+12>>2];e:{if((f|0)!=(c|0)){b=v[f+8>>2];v[b+12>>2]=c;v[c+8>>2]=b;break e}f:{b=f+20|0;d=v[b>>2];if(d){break f}b=f+16|0;d=v[b>>2];if(d){break f}c=0;break e}while(1){m=b;c=d;b=c+20|0;d=v[b>>2];if(d){continue}b=c+16|0;d=v[c+16>>2];if(d){continue}break}v[m>>2]=0}if(!k){break d}b=v[f+28>>2];d=(b<<2)+466100|0;g:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break g}n=465800,o=v[116450]&qqa(-2,b),v[n>>2]=o;break d}v[(v[k+16>>2]==(f|0)?16:20)+k>>2]=c;if(!c){break d}}v[c+24>>2]=k;b=v[f+16>>2];if(b){v[c+16>>2]=b;v[b+24>>2]=c}b=v[f+20>>2];if(!b){break d}v[c+20>>2]=b;v[b+24>>2]=c}if(l>>>0<=15){v[h>>2]=i&1|j|2;b=g+j|0;v[b+4>>2]=v[b+4>>2]|1;return a}v[h>>2]=i&1|e|2;b=e+g|0;v[b+4>>2]=l|3;c=g+j|0;v[c+4>>2]=v[c+4>>2]|1;zs(b,l);return a}c=Ad(b);if(!c){return 0}d=v[h>>2];d=(d&3?-4:-8)+(d&-8)|0;hc(c,a,b>>>0>d>>>0?d:b);Zb(a);a=c}return a}function qz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=gb-208|0;gb=c;f=1;e=v[a+12>>2];h=1<<e;if(e&1){i=h>>>1|0;k=i>>>0>1?i:1;e=0;while(1){d=e+i|0;f=Qc(b,d);j=v[f+12>>2];v[c+200>>2]=v[f+8>>2];v[c+204>>2]=j;j=v[f+4>>2];v[c+192>>2]=v[f>>2];v[c+196>>2]=j;Cj(c+176|0,Qc(b,e),c+192|0);f=Qc(b,d);d=f;j=v[c+188>>2];v[d+8>>2]=v[c+184>>2];v[d+12>>2]=j;d=v[c+180>>2];v[f>>2]=v[c+176>>2];v[f+4>>2]=d;pz(Qc(b,e),c+192|0);e=e+1|0;if((k|0)!=(e|0)){continue}break}e=v[a+12>>2];f=2;h=h>>>3|0}else{h=h>>>2|0}k=e&-2;if(k){while(1){if(f){o=B(h,3);p=h<<1;i=0;while(1){e=Qc(a,i<<1);d=v[e+12>>2];v[c+200>>2]=v[e+8>>2];v[c+204>>2]=d;d=v[e+4>>2];v[c+192>>2]=v[e>>2];v[c+196>>2]=d;e=Qc(a,i);d=v[e+12>>2];v[c+184>>2]=v[e+8>>2];v[c+188>>2]=d;d=v[e+4>>2];v[c+176>>2]=v[e>>2];v[c+180>>2]=d;Ji(c+160|0,c+176|0,c+192|0);e=i<<k;j=h+e|0;if(e>>>0<j>>>0){while(1){d=Qc(b,e);g=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=g;g=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=g;g=e+h|0;Ji(c+128|0,c+192|0,Qc(b,g));l=e+p|0;Ji(c+112|0,c+176|0,Qc(b,l));n=e+o|0;Ji(c+96|0,c+160|0,Qc(b,n));Fl(c+80|0,c+144|0,c+112|0);Cj(c- -64|0,c+144|0,c+112|0);Fl(c+48|0,c+128|0,c+96|0);Vm(c+16|0,-A[6072],-A[6073]);Cj(c,c+128|0,c+96|0);Ji(c+32|0,c+16|0,c);Fl(c+16|0,c+80|0,c+48|0);d=Qc(b,e);m=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=m;m=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=m;Cj(c+16|0,c+80|0,c+48|0);d=Qc(b,g);m=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=m;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;Fl(c+16|0,c- -64|0,c+32|0);d=Qc(b,l);l=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=l;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;Cj(c+16|0,c- -64|0,c+32|0);d=Qc(b,n);l=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=l;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;e=e+1|0;if((j|0)!=(e|0)){continue}break}}i=i+1|0;if((i|0)!=(f|0)){continue}break}}h=h>>>2|0;f=f<<2;k=k-2|0;if(k){continue}break}}gb=c+208|0}function FL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=gb-48|0;gb=k;a:{b:{c:{d:{e:{f:{j=Xp(1,28);if(!j){a=aa(4)|0;km(a);v[22640]=0;U(223,a|0,88880,1928);a=v[22640];v[22640]=0;if((a|0)!=1){break a}break f}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1919;d=su(k+32|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[22640]=0;c=Q(112,k+16|0,c|0)|0;f=v[22640];v[22640]=0;j:{if((f|0)!=1){v[22640]=0;f=Q(1929,d|0,c|0)|0;l=v[22640];v[22640]=0;if((l|0)==1){break j}v[22640]=0;Q(443,f|0,e|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}v[22640]=0;c=Q(112,k+16|0,c|0)|0;e=v[22640];v[22640]=0;k:{if((e|0)!=1){v[22640]=0;R(1930,d|0,c|0);e=v[22640];v[22640]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;vb(c);break g}vb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[22640]=0;c=T(1298,80)|0;e=v[22640];v[22640]=0;l:{m:{n:{if((e|0)!=1){v[22640]=0;e=Q(1931,j|0,j+4|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break n}v[k+16>>2]=e;e=v[kq(k+8|0,k+16|0)>>2];v[22640]=0;ga(1933,c|0,a|0,b|0,e|0,d|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break m}v[j+24>>2]=c;Aj(k+16|0);Ll(d);i=j;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;Aj(k+16|0)}Zb(c)}Ll(d);Z(i|0)|0;v[22640]=0;Y(1911,12294,j|0,g|0,h|0);a=v[22640];v[22640]=0;if((a|0)!=1){v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Zb(Ct(a))}i=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){Zb(a);v[j+20>>2]=0}Zb(j);break d}i=V(0)|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}Z(i|0)|0;i=0;v[22640]=0;Y(1911,12294,0,g|0,h|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}$()}gb=k+48|0;return i|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Bb()}L()}function ZS(a){a=a|0;var b=0,c=0,d=0,e=0;Qb(a,0,288);eB(a+288|0);Uo(a+800|0);t[a+2|0]=w[11492];b=w[11490]|w[11491]<<8;t[a|0]=b;t[a+1|0]=b>>>8;t[a+34|0]=w[11551];b=w[11549]|w[11550]<<8;t[a+32|0]=b;t[a+33|0]=b>>>8;b=w[2591]|w[2592]<<8|(w[2593]<<16|w[2594]<<24);t[a+99|0]=b;t[a+100|0]=b>>>8;t[a+101|0]=b>>>16;t[a+102|0]=b>>>24;b=w[2588]|w[2589]<<8|(w[2590]<<16|w[2591]<<24);t[a+96|0]=b;t[a+97|0]=b>>>8;t[a+98|0]=b>>>16;t[a+99|0]=b>>>24;b=w[12834]|w[12835]<<8|(w[12836]<<16|w[12837]<<24);t[a+128|0]=b;t[a+129|0]=b>>>8;t[a+130|0]=b>>>16;t[a+131|0]=b>>>24;b=w[12837]|w[12838]<<8|(w[12839]<<16|w[12840]<<24);t[a+131|0]=b;t[a+132|0]=b>>>8;t[a+133|0]=b>>>16;t[a+134|0]=b>>>24;t[a+260|0]=w[6444];b=w[6440]|w[6441]<<8|(w[6442]<<16|w[6443]<<24);t[a+256|0]=b;t[a+257|0]=b>>>8;t[a+258|0]=b>>>16;t[a+259|0]=b>>>24;b=gb-32|0;gb=b;c=Tb(b+16|0,2028);v[22640]=0;R(471,b+8|0,a+288|0);d=v[22640];v[22640]=0;a:{b:{if((d|0)==1){break b}v[22640]=0;Q(429,b+8|0,c|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}vb(c);gb=b+32|0;break a}a=P()|0;O()|0;vb(c);S(a|0);L()}d=a+800|0;b=0;a=gb+-64|0;gb=a;c:{d:{e:{while(1){v[a+60>>2]=b<<3;f:{if(b>>>0<=15){Df(a+32|0,1193);v[22640]=0;R(469,a+16|0,a+60|0);c=v[22640];v[22640]=0;g:{h:{i:{j:{if((c|0)!=1){v[22640]=0;U(470,a+48|0,a+32|0,a+16|0);c=v[22640];v[22640]=0;if((c|0)==1){break j}v[22640]=0;R(471,a+8|0,d+(b<<5)|0);c=v[22640];v[22640]=0;if((c|0)==1){break i}v[22640]=0;Q(429,a+8|0,a+48|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break i}vb(a+48|0);vb(a+16|0);Hb(a+32|0);break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;vb(a+48|0)}vb(a+16|0)}Hb(a+32|0);break d}c=Tb(a+48|0,18693);v[22640]=0;R(471,a+32|0,d+(b<<5)|0);e=v[22640];v[22640]=0;if((e|0)==1){break e}v[22640]=0;Q(429,a+32|0,c|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break e}vb(c)}b=b+1|0;if((b|0)!=128){continue}break}gb=a- -64|0;break c}b=P()|0;O()|0;vb(c)}S(b|0);L()}}function lk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Ab(c);v[22640]=0;R(104,a|0,d|0);d=v[22640];v[22640]=0;d:{if((d|0)!=1){e:{if(Ab(c)){while(1){d=t[mc(c,b)|0];f:{if((d|0)>=0){v[22640]=0;R(105,a|0,d&255);d=v[22640];v[22640]=0;if((d|0)!=1){break f}break e}v[22640]=0;R(105,a|0,65533);d=v[22640];v[22640]=0;if((d|0)==1){break e}}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break d}}break a}return;case 2:b=0;a=Kb(a);d=Ab(c);v[22640]=0;R(104,a|0,d|0);d=v[22640];v[22640]=0;g:{if((d|0)!=1){h:{if(Ab(c)){while(1){d=w[mc(c,b)|0];v[22640]=0;R(105,a|0,d|0);d=v[22640];v[22640]=0;if((d|0)==1){break h}b=b+1|0;if(Ab(c)>>>0>b>>>0){continue}break}}break g}}break a}return;case 3:nq(a,c,21392);return;case 5:nq(a,c,22416);return;case 4:nq(a,c,23440);return;case 6:nq(a,c,24464);return;default:a=aa(8)|0;v[22640]=0;Q(101,a|0,8367)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=P()|0;O()|0;da(a|0);S(b|0);L();case 0:break c}}d=gb-16|0;gb=d;e=Kb(a);f=d,g=wd(c),v[f+8>>2]=g;f=d,g=df(c),v[f>>2]=g;i:{j:{k:{if(!Gb(d+8|0,d)){break k}c=0;a=0;while(1){b=w[v[d+8>>2]];l:{if(!c){if(!(b&128)){c=0;v[22640]=0;R(105,e|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break l}break j}if((b&224)==192){a=b&31;c=1;break l}if((b&240)==224){a=b&15;c=2;break l}if((b&248)==240){a=b&7;c=3;break l}a=0;v[22640]=0;R(105,e|0,65533);b=v[22640];v[22640]=0;c=0;if((b|0)==1){break j}break l}if((b&192)!=128){v[22640]=0;R(105,e|0,65533);a=v[22640];v[22640]=0;if((a|0)==1){break j}a=b&63;c=-1;break l}b=b&63|a<<6;c=c-1|0;if(c){a=b;break l}a=0;v[22640]=0;R(105,e|0,b|0);b=v[22640];v[22640]=0;c=0;if((b|0)==1){break j}}Me(d+8|0);if(Gb(d+8|0,d)){continue}break}if(!c){break k}v[22640]=0;R(105,e|0,65533);a=v[22640];v[22640]=0;if((a|0)!=1){break k}break j}gb=d+16|0;break i}a=P()|0;O()|0;Hc(e);S(a|0);L()}return}ia(a|0,89e3,24);L()}b=P()|0;O()|0;Hc(a);S(b|0);L()}function Vz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-160|0;gb=g;a:{b:{c:{d:{e:{if(!c){break e}d=v[c+4>>2];if(!d&y[c>>2]>=xb(b)>>>0|d){break e}b=aa(8)|0;v[22640]=0;Q(167,b|0,18693)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break d}a=P()|0;O()|0;da(b|0);break a}if(!v[b>>2]){b=aa(8)|0;v[22640]=0;T(1300,b|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break c}a=P()|0;O()|0;da(b|0);break a}d=v[b+4>>2];e=v[b>>2];v[g>>2]=e;v[g+4>>2]=d;v[g+128>>2]=e;v[g+132>>2]=d;d=gb-32|0;gb=d;e=v[g+4>>2];f=v[g>>2];v[d+8>>2]=f;v[d+12>>2]=e;v[d+16>>2]=f;v[d+20>>2]=e;Lh(d+24|0,d+8|0);e=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=e;e=gb-16|0;gb=e;f=v[d+4>>2];h=v[d>>2];v[e>>2]=h;v[e+4>>2]=f;v[e+8>>2]=h;v[e+12>>2]=f;f=gb-16|0;gb=f;h=v[e+4>>2];j=v[e>>2];v[f>>2]=j;v[f+4>>2]=h;v[f+8>>2]=j;v[f+12>>2]=h;h=g+136|0;NF(h,f);gb=f+16|0;gb=e+16|0;v[h+12>>2]=0;gb=d+32|0;f:{g:{if(a&2){d=In(g+104|0,h);v[22640]=0;e=Q(1301,d|0,c|0)|0;f=v[22640];v[22640]=0;d=1;if((f|0)==1){break f}if((e|0)==1){break g}f=In(g+80|0,h);v[22640]=0;f=Q(1302,f|0,c|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break b}k=(f|0)==1;if(k){break g}i=In(g+56|0,h);v[22640]=0;i=Q(1303,i|0,c|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break b}l=(i|0)==1;if(l){break g}j=In(g+32|0,h);v[22640]=0;j=Q(1304,j|0,c|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break b}if((j|0)==1){break g}d=(e|0)==-1?-1:0;d=k?d:(f|0)==-1?-1:d;i=(j|0)==-1?-1:l?d:(i|0)==-1?-1:d}if(a&1){a=38192;while(1){d=v[a>>2];if(d){e=In(g+8|0,h);v[22640]=0;e=Q(d|0,e|0,c|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}d=1;if((e|0)==1){break g}i=(e|0)==-1?-1:i}a=a+12|0;if((a|0)!=38696){continue}break}}if(c){d=0;if((i|0)!=-1){break g}d=Uc(v[c>>2],v[c+4>>2])>>>0>xb(b)>>>0?-1:0;break g}d=0;if((i|0)!=-1){break g}d=xb(b)>>>0>2047?1:-1}gb=g+160|0;return d}break b}ia(b|0,89160,24);L()}ia(b|0,89056,24);L()}a=P()|0;O()|0}S(a|0);L()}function F7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-96|0;gb=e;a:{if(dd(c)){break a}f=w[oL(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}vs(e+80|0,c,0,Ab(c)-1|0);Eb(c,e+80|0);vb(e+80|0)}Kd(e+80|0);f=v[e+80>>2];Kd(e+72|0);g=nL(f,v[e+76>>2],c);Kd(e+80|0);b:{c:{d:{e:{f:{if(v[e+84>>2]==(g|0)){if(ne(c,18693)){a=aa(8)|0;v[22640]=0;b=Q(112,e+80|0,7808)|0;c=v[22640];v[22640]=0;if((c|0)==1){break d}qc(a,b);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(b);break c}if(!d){break f}a=aa(8)|0;v[22640]=0;U(2053,e+80|0,14731,c|0);b=v[22640];v[22640]=0;if((b|0)!=1){qc(a,e+80|0);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break b}c=P()|0;O()|0;vb(e+80|0);break c}c=P()|0;O()|0;da(a|0);break c}f=Kb(e+80|0);g:{h:{i:{j:{switch(v[g+4>>2]){case 0:ug(e- -64|0,c);v[22640]=0;c=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=c;b=W(1996,b|0,e+8|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;t[e+72|0]=b;R(2056,a|0,e+72|0);a=v[22640];v[22640]=0;if((a|0)!=1){break g}}break i;case 1:ug(e+56|0,c);v[22640]=0;c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;b=oG(b,e+16|0,d);c=jb;d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;v[e+72>>2]=b;v[e+76>>2]=c;R(2059,a|0,e+72|0);a=v[22640];v[22640]=0;if((a|0)!=1){break g}}break i;case 2:ug(e+48|0,c);v[22640]=0;c=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=c;h=+oa(1998,b|0,e+24|0,d|0);b=v[22640];v[22640]=0;if((b|0)!=1){v[22640]=0;A[e+72>>3]=h;R(2060,a|0,e+72|0);a=v[22640];v[22640]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}ug(e+40|0,c);v[22640]=0;c=v[e+44>>2];v[e+32>>2]=v[e+40>>2];v[e+36>>2]=c;Y(1999,a|0,b|0,e+32|0,d|0);a=v[22640];v[22640]=0;if((a|0)!=1){break g}}c=P()|0;O()|0;vb(f);break c}Dc(a,f)}vb(f);break e}Kb(a)}gb=e+96|0;return}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=gb-48|0;gb=g;t=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;n=v[a+48>>2];v[g+36>>2]=n;h=v[a+52>>2];v[g+40>>2]=h;j=v[a+56>>2];v[g+44>>2]=j;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){n=1;e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+t|0;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];q=u[f+32>>1];m=u[f+30>>1];r=u[f+28>>1];w=u[f+26>>1];x=u[f+24>>1];i=0;h=1;f=0;while(1){s=(g+8|0)+(f<<2)|0;f=f<<1;v[s>>2]=(((((B(u[e+(f|8)>>1],l)+B(u[e+(f|4)>>1],q)|0)+B(j,u[e+(f|12)>>1])|0)+B(k,u[e+(f|16)>>1])|0)/2|0)+((((B(u[e+(f|-8)>>1],w)+B(u[e+(f|-12)>>1],x)|0)+B(u[e+(f|-4)>>1],r)|0)+B(u[e+f>>1],m)|0)/2|0)|0)/16384;s=h&1;h=0;f=1;if(s){continue}break}while(1){k=(g+8|0)+(i<<2)|0;h=v[k>>2];j=v[a+60>>2];l=j;f=(g+32|0)+(i<<3)|0;q=v[f>>2];e=Lb(q,-16777216,16776704);m=v[a+64>>2];i=Lb(v[f+4>>2],-16777216,16776704);r=j>>31;j=h<<8;h=j;h=mqa(l,r,h,h>>31);l=jb;m=mqa(m,m>>31,e,e>>31);h=m+h|0;e=jb+l|0;e=h>>>0<m>>>0?e+1|0:e;l=h;h=v[a+68>>2];h=mqa(h,h>>31,i,i>>31);i=l+h|0;e=jb+e|0;e=h>>>0>i>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=Ic(i,e,24);v[f+4>>2]=q;i=v[a+72>>2];v[k>>2]=(e|0)/256;v[f>>2]=e-(i&j);i=1;e=n&1;n=0;if(e){continue}break}e=v[a+32>>2];p=v[a+28>>2]+p|0;f=p>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);o=e+o|0;l=o>>12;v[c+4>>2]=v[c+4>>2]+B(l,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];j=v[g+44>>2];h=v[g+40>>2];n=v[g+36>>2];i=v[g+32>>2];break a}l=o>>12;f=p>>12}v[a+40>>2]=o;v[a+20>>2]=f;v[a+36>>2]=p;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=n;v[a+44>>2]=i;v[a+24>>2]=l;v[a>>2]=k;v[a+4>>2]=e;gb=g+48|0}function Bha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb+-64|0;gb=c;u[c+62>>1]=b;e=Qi(a);b=e;f=c+48|0;g=Gg(f);a:{if(!b){break a}v[22640]=0;R(830,f|0,b|0);h=v[22640];v[22640]=0;if((h|0)!=1){v[22640]=0;R(1096,f|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Zr(g);S(a|0);L()}b:{c:{if(!e){break c}b=0;while(1){i=rc(f,b),j=b-d|0,u[i>>1]=j;v[22640]=0;g=Q(1095,a|0,b|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break b}d=(x[g>>1]==x[c+62>>1])+d|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}if(!(d&65535)){break c}e=Sb(a);d=Wb(a);b=gb-32|0;gb=b;v[b+16>>2]=d;i=b,j=PB(e,d,c+62|0),v[i+24>>2]=j;d:{if(!Gb(b+24|0,b+16|0)){break d}v[b+8>>2]=v[b+24>>2];if(!Gb(mf(b+8|0),b+16|0)){break d}while(1){if(x[v[b+8>>2]>>1]!=x[c+62>>1]){u[v[b+24>>2]>>1]=x[v[b+8>>2]>>1];mf(b+24|0)}if(Gb(mf(b+8|0),b+16|0)){continue}break}}gb=b+32|0;v[c+32>>2]=v[b+24>>2];b=Fd(c+40|0,c+32|0);i=c,j=Wb(a),v[i+16>>2]=j;e=Fd(c+24|0,c+16|0);b=v[b>>2];d=gb-32|0;gb=d;v[d+16>>2]=v[e>>2];v[d+24>>2]=b;b=a;e=v[b>>2];i=d,j=Sb(b),v[i+8>>2]=j;e=e+(tp(d+24|0,d+8|0)<<1)|0;if(Gb(d+24|0,d+16|0)){zn(b,Bg(e+(tp(d+16|0,d+24|0)<<1)|0,v[b+4>>2],e))}bh(e);gb=d+32|0;i=c,j=Sb(a),v[i+32>>2]=j;i=c,j=Wb(a),v[i+16>>2]=j;if(Gb(c+32|0,c+16|0)){while(1){b=x[v[c+32>>2]>>1];d=v[a+24>>2];v[22640]=0;d=ke(d+484344|0,b);e=v[22640];v[22640]=0;if((e|0)==1){break b}e:{if(!d){break e}b=_b(v[a+24>>2]+484344|0,b);i=c,j=Sb(b),v[i+8>>2]=j;i=c,j=Wb(b),v[i>>2]=j;if(!Gb(c+8|0,c)){break e}while(1){b=v[c+8>>2];f:{if(w[b+3|0]!=12){break f}d=w[b+5|0];if(sc(f)>>>0<=d>>>0){break f}i=b,j=w[rc(f,w[b+5|0])|0],t[i+5|0]=j}Wj(c+8|0);if(Gb(c+8|0,c)){continue}break}}mf(c+32|0);if(Gb(c+32|0,c+16|0)){continue}break}}b=x[a+28>>1];if(sc(f)>>>0<=b>>>0){break c}i=a,j=x[rc(f,x[a+28>>1])>>1],u[i+28>>1]=j}Ue(f);gb=c- -64|0;return}a=P()|0;O()|0;Ue(f);S(a|0);L()}function Ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=0,h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=C(0),y=0,A=C(0),B=0,E=0,F=0,G=0,H=C(0);a:{if(!v[a+4276>>2]){break a}i=a+44|0;if(!ki(i)){break a}p=Md(i,0);q=Md(i,1);r=kd(i,0);s=kd(i,1);y=kb[v[v[a>>2]+192>>2]](a)|0;e=C(kb[v[v[a>>2]+200>>2]](a));x=C(kb[v[v[a>>2]+188>>2]](a));t=kb[v[v[a>>2]+212>>2]](a)|0;if(d){j=a+4260|0;A=C(e*C(.009999999776482582));B=t&1;k=v[a+4256>>2];n=v[a+4272>>2];E=t>>>0>1;u=d;while(1){h=z[p>>2];l=z[q>>2];g=oo(a,k+n|0);k=oo(a,n);e=z[Mb(j,g)>>2];G=Mb(j,k),H=C(C(A*e)+C(C(l+h)*C(.5))),z[G>>2]=H;b:{if(y){f=z[a+4244>>2];e=C(z[a+4236>>2]+f);z[a+4236>>2]=e;f=C(f+z[a+4240>>2]);z[a+4240>>2]=f;if(!(e<=C(1))){e=C(e+C(-2));z[a+4236>>2]=e}if(!(f<=C(1))){z[a+4240>>2]=f+C(-2)}e=C(D(e));e=C(C(e+e)+C(-1));f=C(D(z[a+4240>>2]));f=C(C(f+f)+C(-1));break b}f=z[a+4244>>2];m=z[a+4240>>2];e=C(C(f*m)+z[a+4236>>2]);z[a+4236>>2]=e;f=C(m-C(e*f));z[a+4240>>2]=f}m=z[Mb(j,oo(a,v[a+4280>>2]+v[a+4272>>2]|0))>>2];G=r,H=C(C(C(C(m-h)+C(C(C(z[Mb(j,oo(a,v[a+4284>>2]+v[a+4272>>2]|0))>>2]-m)*C(.000244140625))*C(v[a+4280>>2]&4095)))*x)+h),z[G>>2]=H;h=z[Mb(j,oo(a,v[a+4288>>2]+v[a+4272>>2]|0))>>2];G=s,H=C(C(C(C(h-l)+C(C(C(z[Mb(j,oo(a,v[a+4292>>2]+v[a+4272>>2]|0))>>2]-h)*C(.000244140625))*C(v[a+4288>>2]&4095)))*x)+l),z[G>>2]=H;g=v[a+4272>>2];n=(((g|0)>0?0:v[a+4276>>2]<<12)+g|0)-4096|0;v[a+4272>>2]=n;w=a;k=v[a+4256>>2];o=k;h=z[a+4248>>2];l=C(h*(B?f:e));c:{if(C(D(l))<C(2147483648)){g=~~l;break c}g=-2147483648}o=o+(E?g:0-g|0)|0;v[w+4288>>2]=o;F=t>>>0<4;q=q+4|0;p=p+4|0;w=a;e=C(h*e);d:{if(C(D(e))<C(2147483648)){g=~~e;break d}g=-2147483648}g=(F?g:0-g|0)+k|0;v[w+4280>>2]=g;v[a+4292>>2]=o+4096;v[a+4284>>2]=g+4096;s=s+4|0;r=r+4|0;u=u-1|0;if(u){continue}break}}Ci(a,b,c,kd(i,0),kd(i,1),d)}}function cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=gb-48|0;gb=g;s=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;n=v[a+48>>2];v[g+36>>2]=n;h=v[a+52>>2];v[g+40>>2]=h;j=v[a+56>>2];v[g+44>>2]=j;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){e=(((e&2147483647)<<1|k>>>31)&-2)+s|0;n=1;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];q=u[f+32>>1];m=u[f+30>>1];r=u[f+28>>1];w=u[f+26>>1];x=u[f+24>>1];i=0;h=1;f=0;while(1){v[(g+8|0)+(f<<2)>>2]=(((((B(t[e+(f|4)|0],l)+B(t[e+(f|2)|0],q)|0)+B(j,t[e+(f|6)|0])|0)+B(k,t[e+(f|8)|0])<<8)/2|0)+((((B(t[e+(f|-4)|0],w)+B(t[e+(f|-6)|0],x)|0)+B(t[e+(f|-2)|0],r)|0)+B(t[e+f|0],m)<<8)/2|0)|0)/16384;y=h&1;h=0;f=1;if(y){continue}break}while(1){k=(g+8|0)+(i<<2)|0;h=v[k>>2];j=v[a+60>>2];l=j;f=(g+32|0)+(i<<3)|0;q=v[f>>2];e=Lb(q,-16777216,16776704);m=v[a+64>>2];i=Lb(v[f+4>>2],-16777216,16776704);r=j>>31;j=h<<8;h=j;h=mqa(l,r,h,h>>31);l=jb;m=mqa(m,m>>31,e,e>>31);h=m+h|0;e=jb+l|0;e=h>>>0<m>>>0?e+1|0:e;l=h;h=v[a+68>>2];h=mqa(h,h>>31,i,i>>31);i=l+h|0;e=jb+e|0;e=h>>>0>i>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=Ic(i,e,24);v[f+4>>2]=q;i=v[a+72>>2];v[k>>2]=(e|0)/256;v[f>>2]=e-(i&j);i=1;e=n&1;n=0;if(e){continue}break}e=v[a+32>>2];p=v[a+28>>2]+p|0;l=p>>12;v[c>>2]=v[c>>2]+B(l,v[g+8>>2]);o=e+o|0;f=o>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];j=v[g+44>>2];h=v[g+40>>2];n=v[g+36>>2];i=v[g+32>>2];break a}f=o>>12;l=p>>12}v[a+40>>2]=o;v[a+20>>2]=l;v[a+36>>2]=p;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=n;v[a+44>>2]=i;v[a+24>>2]=f;v[a>>2]=k;v[a+4>>2]=e;gb=g+48|0}function fg(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;j=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=j;f=x[a+20>>1];b=x[a+70>>1]+(f+x[a+22>>1]|0)|0;b=w[a+79|0]?x[v[a>>2]+3836>>1]+b|0:b;a:{b:{c:{d:{switch(v[a+16>>2]){case 1:h=f;c=x[v[a>>2]+3832>>1];f=x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((c>>>x[a+44>>1]&7)<<1)>>1]|0:0;g=c;c=x[a+46>>1];f=h+(c?g&c?0:f:f)|0;u[a+20>>1]=f;c=2;i=x[a+28>>1];if((i|0)<=f<<16>>16){break c}break b;case 2:if(w[a+78|0]){break b}case 3:c=0;h=f;f=x[v[a>>2]+3832>>1];i=x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((f>>>x[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=x[a+58>>1];f=h+(f?g&f?0:i:i)|0;u[a+20>>1]=f;if(f<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:c=0;v[a+72>>2]=0;break a;case 0:break d}}c=1;h=f;g=(f^-1)<<16>>16;f=x[v[a>>2]+3832>>1];k=x[a+24>>1]?B(g,x[a+36>>1]>>>x[v[a+40>>2]+((f>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=x[a+34>>1];f=h+(f?g&f?0:k:k)|0;u[a+20>>1]=f;if(f<<16>>16>=1){break b}}v[a+16>>2]=c;u[a+20>>1]=i}f=b<<3;if(e){d=(u[a+74>>1]+u[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(x[a+12>>1]){case 0:e=(b&512)>>>9|0;b=x[((b&256?c^255:c)<<1)+35072>>1];break e;case 1:e=0;b=x[((b&512?0:b&256?c^255:c)<<1)+35072>>1];break e;case 2:e=0;b=x[((b&256?c^255:c)<<1)+35072>>1];break e;case 3:e=0;b=x[((b&256?0:c)<<1)+35072>>1];break e;case 4:g:{if(b&512){e=0;b=35072;break g}e=(b&256)>>>8|0;b=(((c<<1^b<<24>>31)&254)<<1)+35072|0}b=x[b>>1];break e;case 5:e=0;if(b&512){b=35072}else{c=c<<1&254;b=((b&128?c^255:c)<<1)+35072|0}b=x[b>>1];break e;case 6:e=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;e=(b&512)>>>9|0;b=e?c^4088:c}u[a+74>>1]=x[a+72>>1];d=a;a=b+f|0;a=(a&65535)>>>0<8191?a:8191;c=0-e^x[((a&255)<<1)+34560>>1]+1024>>>((a&65280)>>>8)<<1;u[d+72>>1]=c}return c<<16>>16}function f3(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=gb-432|0;gb=i;v[i+424>>2]=37;v[i+428>>2]=0;m=Is(i+424|1,11230,v[c+4>>2]);v[i+380>>2]=i+384;a=xe();a:{if(m){k=v[c+8>>2];v[i+72>>2]=g;v[i+76>>2]=h;j=i- -64|0;v[j>>2]=e;v[j+4>>2]=f;v[i+48>>2]=k;a=Ff(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=Ff(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=2434;k=ge(i+368|0,0,i+128|0);l=i+384|0;j=l;b:{c:{d:{if((a|0)>=30){e:{if(m){v[22640]=0;a=fa(2454)|0;j=v[22640];v[22640]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=e;v[i+20>>2]=f;v[i+24>>2]=g;v[i+28>>2]=h;v[i>>2]=j;v[22640]=0;a=ca(2473,i+380|0,a|0,i+424|0,i|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){break e}break c}v[22640]=0;a=fa(2454)|0;j=v[22640];v[22640]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[22640]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=ca(2473,i+380|0,a|0,i+424|0,i+32|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break c}}if((a|0)==-1){v[22640]=0;X(2435);a=v[22640];v[22640]=0;if((a|0)==1){break c}break d}Ee(k,v[i+380>>2]);j=v[i+380>>2]}f=a+j|0;g=Pg(j,f,c);v[i+116>>2]=2434;e=ge(i+120|0,0,i+116|0);f:{g:{if(v[i+380>>2]==(i+384|0)){a=i+128|0;break g}a=Ad(a<<3);if(!a){v[22640]=0;X(2435);a=v[22640];v[22640]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(e,a);l=v[i+380>>2]}v[22640]=0;Ec(i+104|0,c);h=v[22640];v[22640]=0;h:{i:{if((h|0)!=1){v[22640]=0;ja(2482,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=v[22640];v[22640]=0;if((f|0)==1){break i}Vb(i+104|0);v[22640]=0;a=la(2483,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break h}Gc(e);Gc(k);gb=i+432|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Vb(i+104|0);break f}c=P()|0;O()|0}Gc(e);break b}L()}c=P()|0;O()|0}Gc(k);S(c|0);L()}function p3(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=gb-256|0;gb=i;v[i+248>>2]=37;v[i+252>>2]=0;m=Is(i+248|1,11230,v[c+4>>2]);v[i+204>>2]=i+208;a=xe();a:{if(m){k=v[c+8>>2];v[i+72>>2]=g;v[i+76>>2]=h;j=i- -64|0;v[j>>2]=e;v[j+4>>2]=f;v[i+48>>2]=k;a=Ff(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=Ff(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=2434;k=ge(i+192|0,0,i+128|0);l=i+208|0;j=l;b:{c:{d:{if((a|0)>=30){e:{if(m){v[22640]=0;a=fa(2454)|0;j=v[22640];v[22640]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=e;v[i+20>>2]=f;v[i+24>>2]=g;v[i+28>>2]=h;v[i>>2]=j;v[22640]=0;a=ca(2473,i+204|0,a|0,i+248|0,i|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){break e}break c}v[22640]=0;a=fa(2454)|0;j=v[22640];v[22640]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[22640]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=ca(2473,i+204|0,a|0,i+248|0,i+32|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break c}}if((a|0)==-1){v[22640]=0;X(2435);a=v[22640];v[22640]=0;if((a|0)==1){break c}break d}Ee(k,v[i+204>>2]);j=v[i+204>>2]}f=a+j|0;g=Pg(j,f,c);v[i+116>>2]=2434;e=ge(i+120|0,0,i+116|0);f:{g:{if(v[i+204>>2]==(i+208|0)){a=i+128|0;break g}a=Ad(a<<1);if(!a){v[22640]=0;X(2435);a=v[22640];v[22640]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(e,a);l=v[i+204>>2]}v[22640]=0;Ec(i+104|0,c);h=v[22640];v[22640]=0;h:{i:{if((h|0)!=1){v[22640]=0;ja(2474,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=v[22640];v[22640]=0;if((f|0)==1){break i}Vb(i+104|0);v[22640]=0;a=la(17,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break h}Gc(e);Gc(k);gb=i+256|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Vb(i+104|0);break f}c=P()|0;O()|0}Gc(e);break b}L()}c=P()|0;O()|0}Gc(k);S(c|0);L()}function o6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;g=-2;a:{if(!a){break a}c=v[a+28>>2];if(!c){break a}f=(b|0)==1?2:b;if(f>>>0>4|!(1<<f&21)){break a}h=v[c+11e3>>2];k=v[a+4>>2];v[c+11e3>>2]=0;b:{if(v[c+43780>>2]<0){break b}b=v[c+11004>>2];if((f|0)!=4?b:0){break a}i=v[c+11008>>2]>0?9:8;v[c+11004>>2]=b|(f|0)==4;b=(f|0)!=4;if(!(b|!h)){v[e+12>>2]=v[a+4>>2];v[e+8>>2]=v[a+16>>2];b=v[a+12>>2];h=wJ(c,v[a>>2],e+12|0,b,b,e+8|0,i|4);v[c+43780>>2]=h;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];b=v[e+8>>2];v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];g=-3;if((h|0)<0){break a}if(!h){g=1;break a}v[c+43780>>2]=-1;g=-5;break a}h=v[c+10996>>2];if(!h){i=b?i|2:i;j=c+11012|0;d=v[c+10992>>2];h=(f|0)!=4;while(1){b=v[a+4>>2];v[e+8>>2]=32768-d;v[e+12>>2]=b;f=wJ(c,v[a>>2],e+12|0,j,d+j|0,e+8|0,i);v[c+43780>>2]=f;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];d=v[e+8>>2];v[c+10996>>2]=d;b=v[a+16>>2];d=b>>>0>d>>>0?d:b;hc(v[a+12>>2],v[c+10992>>2]+j|0,d);v[a+12>>2]=d+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-d;v[a+20>>2]=d+v[a+20>>2];b=v[c+10996>>2]-d|0;v[c+10996>>2]=b;d=d+v[c+10992>>2]&32767;v[c+10992>>2]=d;if((f|0)<0){break b}g=-5;if(k?0:(f|0)==1){break a}if(!h){if(!f){g=b?-5:1;break a}if(v[a+16>>2]){continue}break a}if(f){g=0;if(!v[a+4>>2]|!v[a+16>>2]){break a}if(!b){continue}break a}break}g=!b;break a}b=v[a+16>>2];b=b>>>0>h>>>0?h:b;hc(v[a+12>>2],(v[c+10992>>2]+c|0)+11012|0,b);v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];a=v[c+10996>>2]-b|0;v[c+10996>>2]=a;v[c+10992>>2]=b+v[c+10992>>2]&32767;g=0;if(v[c+43780>>2]){break a}g=!a;break a}g=-3}gb=e+16|0;return g|0}function nka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-32|0;gb=h;l=h,m=br(b),v[l+16>>2]=m;e=gb-32|0;gb=e;c=b;d=a;b=Vd(d);g=ec(d);a:{b:{if(b){wb(d);c:{while(1){d:{d=b+14|0;e:{if(Eu(c,d)){if(!v[b>>2]){break b}g=b;break e}if(!Eu(d,c)){break c}g=b+4|0;if(!v[b+4>>2]){break d}b=g;g=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=g;break a}v[e+28>>2]=b;b=g;break a}b=ec(d)}v[e+28>>2]=b}g=b;b=v[b>>2];t[e+27|0]=0;if(!b){j=gb-16|0;gb=j;b=ec(a);k=Pj(e+8|0,Mc(48,4),Qj(j+8|0,b));b=v[k>>2];i=gb-16|0;gb=i;v[i+8>>2]=v[h+16>>2];c=v[i+8>>2];d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b+14|0]=f;t[b+15|0]=f>>>8;t[b+16|0]=f>>>16;t[b+17|0]=f>>>24;t[b+18|0]=d;t[b+19|0]=d>>>8;t[b+20|0]=d>>>16;t[b+21|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);f=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+38|0]=f;t[b+39|0]=f>>>8;t[b+40|0]=f>>>16;t[b+41|0]=f>>>24;t[b+42|0]=d;t[b+43|0]=d>>>8;t[b+44|0]=d>>>16;t[b+45|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);f=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b+30|0]=f;t[b+31|0]=f>>>8;t[b+32|0]=f>>>16;t[b+33|0]=f>>>24;t[b+34|0]=d;t[b+35|0]=d>>>8;t[b+36|0]=d>>>16;t[b+37|0]=d>>>24;d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);c=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[b+22|0]=c;t[b+23|0]=c>>>8;t[b+24|0]=c>>>16;t[b+25|0]=c>>>24;t[b+26|0]=d;t[b+27|0]=d>>>8;t[b+28|0]=d>>>16;t[b+29|0]=d>>>24;u[b+46>>1]=0;gb=i+16|0;l=ec(k),m=1,t[l+4|0]=m;gb=j+16|0;Ak(a,v[e+28>>2],g,v[e+8>>2]);b=$d(e+8|0);t[e+27|0]=1;g=e+8|0;c=g;a=v[c>>2];v[c>>2]=0;if(a){ec(g);if(a){vT(a)}}}Rj(h+24|0,yc(e+8|0,b),e+27|0);gb=e+32|0;a=Vl(h+24|0);gb=h+32|0;return a+32|0}function Qja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;j=c+484344|0;vg(j,w[b+70|0]|w[b+71|0]<<8);a:{if(w[b+70|0]|w[b+71|0]<<8){while(1){f=v[a+8>>2];g=og(a);Yb(a,1);b:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=de(a)+1|0;break b}c=Kg(a)}d=Kg(a);Xc(a,f+g|0);rd(e+24|0,a,d);v[22640]=0;c=W(365,j|0,i&65535,(c?c>>>0<1024?c:1024:64)|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break a}c:{if(!c|!d){break c}c=_b(j,i);k=e,l=Sb(c),v[k+16>>2]=l;k=e,l=Wb(c),v[k+8>>2]=l;if(!Gb(e+16|0,e+8|0)){break c}while(1){d=v[e+16>>2];v[22640]=0;c=T(353,e+24|0)|0;f=v[22640];v[22640]=0;d:{e:{f:{if((f|0)!=1){if(!(c&128)){break f}if(c&1){v[22640]=0;f=T(353,e+24|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break a}t[d|0]=f}if(c&2){break e}break d}break a}t[d|0]=c;c=255}v[22640]=0;f=T(353,e+24|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break a}t[d+1|0]=f}f=0;if(c&4){v[22640]=0;f=T(353,e+24|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break a}}if(c&8){v[22640]=0;g=T(353,e+24|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break a}t[d+3|0]=g}if(c&16){v[22640]=0;c=T(353,e+24|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break a}t[d+5|0]=c}c=d;g:{h:{g=w[d|0];if(!g){break h}h=255;if((g|0)==97){break g}if(g>>>0>96){break h}h=g+12|0;break g}h=0}t[c|0]=h;i:{if(w[d+5|0]|w[d+3|0]){v[22640]=0;Mf(d);c=v[22640];v[22640]=0;if((c|0)!=1){break i}break a}t[d+3|0]=0}if(w[d+1|0]==255){t[d+1|0]=0}c=f-16|0;j:{if((c&255)>>>0<=64){t[d+4|0]=c;t[d+2|0]=1;break j}if(f>>>0<96){break j}c=f&15;t[d+4|0]=c;f=f-96>>4;t[d+2|0]=w[f+33807|0];if((f|0)!=6){break j}t[d+4|0]=c<<2}Wj(e+16|0);if(Gb(e+16|0,e+8|0)){continue}break}}yb(e+24|0);i=i+1|0;if(i>>>0<(w[b+70|0]|w[b+71|0]<<8)>>>0){continue}break}}gb=e+48|0;return}a=P()|0;O()|0;yb(e+24|0);S(a|0);L()}function ok(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=gb-16|0;gb=i;a:{if(!v[c>>2]|!d){break a}j=c;f=v[c>>2]+B(d,20)|0;b:{c:{if(v[a+480180>>2]==64){break c}f=v[c>>2]+((B(d,36318)|0)/1024|0)|0;if(v[a+480180>>2]==512){break c}d:{e:{f:{f=v[a+480208>>2];if(f&16){if(v[a+480180>>2]!=4){break f}f=v[a+480208>>2]}if(f&16){break d}Db(i,a+1074312|0,7);if(!Cb(i)){break d}f=v[c>>2];if((d|0)>-1){break e}g=mqa(f,0,14317456,0);h=jb;f=mqa(f,0,0-d|0,0)+14317456|0;d=jb;f=yP(pqa(g,h,f,f>>>0<14317456?d+1|0:d),jb);break c}k=v[c>>2];f=d>>31;v[i+12>>2]=f+d^f;tc(i+12|0,1020);h=v[i+12>>2];f=c;l=f;g=v[f>>2];m=g;n=g>>31;g:{if((d|0)>=1){if(h>>>0<=15){g=gb-16|0;gb=g;Db(g+8|0,a+1074312|0,7);f=Cb(g+8|0);gb=g+16|0;h=v[(h<<2)+(f?43824:43888)>>2];break g}g=gb-16|0;gb=g;Db(g+8|0,a+1074312|0,7);f=Cb(g+8|0);gb=g+16|0;h=v[(h>>>2<<2)+(f?43952:44976)>>2];break g}if(h>>>0<=15){g=gb-16|0;gb=g;Db(g+8|0,a+1074312|0,7);f=Cb(g+8|0);gb=g+16|0;h=v[(h<<2)+(f?43888:43824)>>2];break g}g=gb-16|0;gb=g;Db(g+8|0,a+1074312|0,7);f=Cb(g+8|0);gb=g+16|0;h=v[(h>>>2<<2)+(f?44976:43952)>>2]}h=mqa(m,n,h,h>>31)+32768|0;f=jb;f=zc(nqa(h,h>>>0<32768?f+1|0:f,65536,0),jb);v[l>>2]=f;if((f|0)!=(k|0)){break b}Db(i,a+1074312|0,7);h=Cb(i);f=v[c>>2];if(!(h^(d|0)>0)){d=(f|0)==2147483647;f=v[c>>2];if(d){break b}f=f+1|0;break c}if((f|0)<2){break b}f=f-1|0;break c}d=mqa(f,f>>31,d,0);h=jb;g=h;if((g|0)>0?1:(g|0)>=0?d>>>0>=14317456:0){if(e){v[c>>2]=2147483647;break a}v[c>>2]=0;v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248;break a}f=yP(pqa(mqa(f,0,14317456,0),jb,14317456-d|0,0-(g+(d>>>0>14317456)|0)|0),jb);break c}f=v[c>>2]-d|0}v[j>>2]=f}if((f|0)>0){break a}v[c>>2]=1;if(v[a+480180>>2]!=2|e){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}gb=i+16|0}function Vga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;m=gb-16|0;gb=m;n=c;k=d;f=gb-32|0;gb=f;l=f+28|0;g=f+24|0;i=c;e=gb-32|0;gb=e;v[e+24>>2]=b;a:{b:{c:{d:{h=a;if(!Jk(e+24|0,yc(e+16|0,yh(h)))){j=wb(h);if(!Ml(j,i,ue(e+24|0))){break d}}v[e+16>>2]=b;if(!Jk(e+16|0,yc(e+8|0,gC(h)))){o=wb(h);j=e+16|0;p=j;c=v[j>>2];g=v[c>>2];e:{if(g){c=g;while(1){g=c;c=v[c+4>>2];if(c){continue}break}break e}if(jg(c)){while(1){c=v[c+8>>2];if(jg(c)){continue}break}}g=v[c+8>>2]}v[p>>2]=g;if(!Ml(o,ue(j),i)){break c}}if(!v[b>>2]){v[l>>2]=b;break a}b=v[e+16>>2];v[l>>2]=b;b=b+4|0;break a}if(!Ml(j,ue(e+24|0),i)){break b}c=gb-16|0;gb=c;v[c+8>>2]=b;Oj(c+8|0);gb=c+16|0;c=v[c+8>>2];v[e+16>>2]=c;if(!Jk(e+16|0,yc(e+8|0,yh(h)))){if(!Ml(j,i,ue(e+16|0))){break c}}if(!v[v[e+24>>2]+4>>2]){v[l>>2]=b;b=b+4|0;break a}v[l>>2]=c;b=c;break a}b=nR(h,l,i);break a}v[l>>2]=b;v[g>>2]=b;b=g}gb=e+32|0;c=b;b=v[b>>2];t[f+23|0]=0;if(!b){i=gb-16|0;gb=i;b=ec(a);h=Pj(f+8|0,mR(),Qj(i+8|0,b));b=v[h>>2];v[22640]=0;b=b+16|0;g=v[22640];v[22640]=0;f:{if((g|0)!=1){g=v[n+4>>2];v[b>>2]=v[n>>2];v[b+4>>2]=g;wb(k);n=mh(b+8|0);v[b+8>>2]=v[k>>2];v[b+12>>2]=v[k+4>>2];b=wb(k);q=wb(n),r=v[b>>2],v[q>>2]=r;v[b>>2]=0;v[k>>2]=0;v[k+4>>2]=0;q=ec(h),r=1,t[q+4|0]=r;gb=i+16|0;break f}a=P()|0;O()|0;zA(h);S(a|0);L()}Ak(a,v[f+28>>2],c,v[f+8>>2]);b=$d(f+8|0);t[f+23|0]=1;zA(f+8|0)}Rj(m,yc(f+8|0,b),f+23|0);gb=f+32|0;a=m;if(!w[ec(a)|0]){c=ue(a)+8|0;b=c;if(v[b>>2]){of(b);oR(b);pg(b);of(b);AA(wb(b),v[b>>2],pg(b));q=wb(b),r=0,v[q>>2]=r;v[b>>2]=0;v[b+4>>2]=0}ip(c,d);v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];b=wb(d);q=wb(c),r=v[b>>2],v[q>>2]=r;v[b>>2]=0;v[d>>2]=0;v[d+4>>2]=0}a=v[yc(m+8|0,v[a>>2])>>2];gb=m+16|0;return a|0}function zea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=gb-144|0;gb=c;e=wm(c+40|0,a);v[22640]=0;d=Q(640,c+24|0,49997)|0;a=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[22640]=0;v[c>>2]=19923012;v[c+4>>2]=0;U(641,e|0,d|0,c|0);a=v[22640];v[22640]=0;if((a|0)==1){break n}Hb(d);if(v[e>>2]&1073741824){break e}v[22640]=0;d=Q(640,c+24|0,10717)|0;a=v[22640];v[22640]=0;if((a|0)==1){break m}v[22640]=0;ca(1481,e|0,b|0,d|0,1482)|0;a=v[22640];v[22640]=0;if((a|0)==1){break l}Hb(d);v[c+20>>2]=0;v[c+16>>2]=0;v[22640]=0;d=Q(640,c+24|0,13859)|0;a=v[22640];v[22640]=0;if((a|0)==1){break k}v[22640]=0;W(1483,e|0,c+20|0,d|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break j}Hb(d);v[22640]=0;d=Q(640,c+24|0,13849)|0;a=v[22640];v[22640]=0;if((a|0)==1){break i}v[22640]=0;W(1483,e|0,c+16|0,d|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break h}Hb(d);a=b;d=v[c+16>>2];f=v[c+20>>2];o:{if(!f){break o}if(d>>>0<f>>>0|f>>>0>y[v[ro(a)+8>>2]+40>>2]){break o}if(d>>>0>y[v[ro(a)+8>>2]+40>>2]){break o}v[a+20>>2]=d;v[a+16>>2]=f}d=Ho(c+24|0);v[22640]=0;f=Q(640,c|0,11449)|0;a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;U(1484,e|0,d|0,f|0);a=v[22640];v[22640]=0;if((a|0)==1){break g}Hb(f);if($c(d)){break f}v[22640]=0;U(1485,d|0,v[c+20>>2],16777216);a=v[22640];v[22640]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hb(d);break a}a=P()|0;O()|0;Hb(f);break b}v[22640]=0;R(1486,b|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}Lc(d)}ch(e);gb=c+144|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}Lc(d)}ch(e);S(a|0);L()}function H2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=gb-624|0;gb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=2485;b=ge(a+200|0,a+208|0,a+16|0);v[22640]=0;Ec(a+192|0,e);h=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)!=1){v[22640]=0;h=T(2458,a+192|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break k}t[a+191|0]=0;e=v[e+4>>2];v[22640]=0;c=ra(2493,a+616|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,h|0,b|0,a+196|0,a+608|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}if(!c){break e}c=w[11896]|w[11897]<<8|(w[11898]<<16|w[11899]<<24);t[a+183|0]=c;t[a+184|0]=c>>>8;t[a+185|0]=c>>>16;t[a+186|0]=c>>>24;c=w[11893]|w[11894]<<8|(w[11895]<<16|w[11896]<<24);v[a+176>>2]=w[11889]|w[11890]<<8|(w[11891]<<16|w[11892]<<24);v[a+180>>2]=c;v[22640]=0;Y(2470,h|0,a+176|0,a+186|0,a+128|0);c=v[22640];v[22640]=0;if((c|0)==1){break j}v[a+4>>2]=2434;d=ge(a+8|0,0,a+4|0);h=v[a+196>>2];c=h-v[b>>2]|0;e=a+16|0;if((c|0)<393){break h}Ee(d,Ad((c>>>2|0)+2|0));if(v[d>>2]){break i}v[22640]=0;X(2435);c=v[22640];v[22640]=0;if((c|0)==1){break g}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=v[d>>2]}if(w[a+191|0]){t[e|0]=45;e=e+1|0}c=v[b>>2];if(h>>>0>c>>>0){h=a+168|0;while(1){j=e,k=w[(a+176|0)+(gx(a+128|0,h,c)-(a+128|0)>>2)|0],t[j|0]=k;e=e+1|0;c=c+4|0;if(c>>>0<y[a+196>>2]){continue}break}}t[e|0]=0;v[a>>2]=g;if((zH(a+16|0,a)|0)==1){break f}v[22640]=0;_(2487,5213);c=v[22640];v[22640]=0;if((c|0)!=1){break a}}e=P()|0;O()|0;Gc(d);break c}Gc(d)}v[22640]=0;c=Q(2464,a+616|0,a+608|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}if(c){v[f>>2]=v[f>>2]|2}c=v[a+616>>2];Vb(a+192|0);Gc(b);gb=a+624|0;return c|0}e=P()|0;O()|0}Vb(a+192|0)}Gc(b);S(e|0);L()}L()}function $na(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-32|0;gb=g;v[g+24>>2]=d;k=Zf(a,c);se(g,v[a+28>>2]);d=v[g+12>>2];v[g+16>>2]=v[g+8>>2];v[g+20>>2]=d;a:{if(!k){if(id(a,5)){break a}}j=v[g+24>>2];d=gb-160|0;gb=d;h=wm(d+56|0,v[a+28>>2]);v[22640]=0;e=Q(640,d+8|0,34479)|0;f=v[22640];v[22640]=0;b:{c:{d:{e:{if((f|0)!=1){v[22640]=0;v[d+48>>2]=19923012;v[d+52>>2]=0;U(641,h|0,e|0,d+48|0);f=v[22640];v[22640]=0;if((f|0)==1){break e}Hb(e);if(!(v[h>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e);break c}t[d+48|0]=0;t[d+47|0]=0;v[22640]=0;e=Q(640,d+8|0,7420)|0;f=v[22640];v[22640]=0;f:{if((f|0)!=1){v[22640]=0;U(1106,h|0,d+48|0,e|0);f=v[22640];v[22640]=0;if((f|0)==1){break f}Hb(e);if(!w[d+48|0]){break b}vf(d+48|0,50);v[22640]=0;e=Q(640,d+8|0,10598)|0;f=v[22640];v[22640]=0;g:{h:{i:{j:{if((f|0)!=1){v[22640]=0;U(1106,h|0,d+47|0,e|0);f=v[22640];v[22640]=0;if((f|0)==1){break j}Hb(e);e=Oi(b);f=w[d+48|0];if(e>>>0<f>>>0){e=UA(d+8|0,v[b+12>>2]);v[22640]=0;U(1107,b|0,f|0,e|0);f=v[22640];v[22640]=0;if((f|0)==1){break i}Xm(e)}e=0;f=x[Nj(b,0)+28>>1];t[d+7|0]=0;if(w[d+48|0]){while(1){i=e&255;af(Nj(b,i),f);i=Nj(b,i);v[22640]=0;R(1108,d+8|0,d+7|0);l=v[22640];v[22640]=0;if((l|0)==1){break h}v[22640]=0;Y(1109,h|0,i|0,d+8|0,j|0);i=v[22640];v[22640]=0;if((i|0)==1){break g}Hb(d+8|0);e=e+1|0;t[d+7|0]=e;if(w[d+48|0]>(e&255)>>>0){continue}break}}e=w[d+47|0];j=Oi(b);t[b+16|0]=e>>>0<j>>>0?w[d+47|0]:0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e);break c}a=P()|0;O()|0;Xm(e);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(d+8|0);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Hb(e)}ch(h);S(a|0);L()}ch(h);gb=d+160|0}Sf(a,k,c,g+16|0);gb=g+32|0}function Oq(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;v[e+12>>2]=u[b+780>>1]+w[b+837|0];v[e+8>>2]=u[b+782>>1]+(w[b+838|0]&127);Qd(e+12|0,0,127);Qd(e+8|0,0,127);m=a+1074312|0;Db(e,m,1);j=Cb(e);i=v[e+12>>2];if(!j){u[b+780>>1]=0;t[b+837|0]=i;j=v[e+8>>2];u[b+782>>1]=0;t[b+838|0]=j}Db(e,m,36);i=B(i,d+256|0);n=(i|0)/256|0;j=Cb(e);l=v[e+8>>2];a:{if(!(l|!j|(i|0)<65024)){n=-1;a=b+788|0;if(!ce(a)){break a}if(nu(a)|x[b+786>>1]|(v[b>>2]|v[b+4>>2])){break a}a=v[b+88>>2];if(a&8192){break a}v[b+88>>2]=a&-32769;break a}v[b+88>>2]=v[b+88>>2]|32768;f=me(C(10),C(C(0-l|0)*C(.00937500037252903)));i=gb-16|0;gb=i;h=C(B(v[e+12>>2],d+256|0)>>>0);l=i;d=a;b:{if(v[a+480180>>2]!=33554432){g=C(110);k=C(C(h/(w[d+480209|0]&128?C(10240):C(12288)))+C(.25));break b}g=C(125);k=C(h*C(9227362170349807e-20))}o=l,p=Xh(C(me(C(2),k)*g)),v[o+12>>2]=p;Qd(i+12|0,120,2e4);j=v[i+12>>2];d=v[d+24620>>2];gb=i+16|0;Db(e,m,36);h=C(C(((d|0)<j<<1?d>>>1|0:j)>>>0)*C(6.2831854820251465));c:{if(!(!Cb(e)|v[a+480208>>2]&32768)){g=C(C(y[a+24620>>2])/h);h=C(C(f+C(-1))+C(g*f));z[e>>2]=h;f=C(g*g);break c}g=C(h/C(y[a+24620>>2]));f=C(f+f);z[e>>2]=g*C(C(1)-f);cQ(e,C(2));h=C(C(f-z[e>>2])/g);z[e>>2]=h;f=C(C(1)/C(g*g))}g=C(C(h+C(1))+f);h=C(C(C(f+f)+h)/g);k=C(C(16777216)/g);f=C(C(-f)/g);d:{if(w[b+845|0]==1){o=b,p=Xh(C(C(16777216)-k)),v[o+60>>2]=p;o=b,p=Xh(C(h*C(16777216))),v[o+64>>2]=p;o=b,p=Xh(C(f*C(16777216))),v[o+68>>2]=p;a=-1;break d}o=b,p=Xh(k),v[o+60>>2]=p;o=b,p=Xh(C(h*C(16777216))),v[o+64>>2]=p;o=b,p=Xh(C(f*C(16777216))),v[o+68>>2]=p;a=0;if(v[b+60>>2]){break d}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break a}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}gb=e+16|0;return n}function zo(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;v[b+88>>2]=v[b+88>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){Db(f+8|0,a+1074312|0,15);if(Cb(f+8|0)){break b}}if(v[a+480180>>2]!=268435456){break a}}c=c?c:w[b+811|0];t[b+812|0]=c;t[b+811|0]=c}if(c){u[b+768>>1]=c}c:{if(Hj(b)){d=x[b+768>>1];if(!d){break c}e=v[b+856>>2];c=b;g=v[a+1074392>>2];i=0-d|0;j=d;d=v[b+708>>2];h=(+(g>>>0)+1)*+(((d|0)<0?i:j)|0)/+y[a+1074416>>2];d:{if(D(h)<2147483648){a=~~h;break d}a=-2147483648}v[c+856>>2]=a;if(w[b+90|0]&16){a=B(v[v[v[b+656>>2]+44>>2]+36>>2]+1|0,a);v[b+856>>2]=a}a=a-(g?e:0)|0;c=a>>31;e=d>>31;if((e+d^e)>>>0<=(c^a+c)>>>0){if(!d){break c}v[b+708>>2]=0;v[b+852>>2]=d+v[b+852>>2];t[b+851|0]=w[b+851|0]|32;break c}v[b+708>>2]=d-a;v[b+852>>2]=a+v[b+852>>2];t[b+851|0]=w[b+851|0]|32;break c}c=1;e:{if(!(t[b+851|0]&1)|v[a+480180>>2]&524352){break e}if(v[a+1074416>>2]==1){Db(f+8|0,a+1074312|0,6);if(Cb(f+8|0)){break e}}c=0;if(v[a+480180>>2]!=8){break e}c=(w[a+480208|0]&2)>>>1|0}d=x[b+768>>1];e=v[a+480180>>2];f:{if(!v[b+700>>2]|!v[b+708>>2]){break f}e=(e|0)==268435456&d>>>0>239;if(!(e?t[b+851|0]&1:c)){break f}c=b+700|0;d=B(v[a+480180>>2]==64?2:4,e?d-240|0:d);d=qk(a)?d:0-d|0;e=v[b+700>>2];g=v[b+708>>2];if(!(w[b+851|0]&8?0:(e|0)>=(g|0))){ok(a,b,c,d,1);d=v[b+708>>2];if((d|0)>=v[b+700>>2]){break f}v[c>>2]=d;break f}if((e|0)<=(g|0)){break f}ok(a,b,c,0-d|0,1);e=v[b+700>>2];d=v[b+708>>2];g:{if((e|0)<(d|0)){v[c>>2]=d;break g}if((d|0)!=(e|0)){break f}}Db(f+8|0,a+1074312|0,112);if(!Cb(f+8|0)){break f}t[b+851|0]=w[b+851|0]|8}if(v[b+700>>2]!=v[b+708>>2]){break c}Db(f+8|0,a+1074312|0,25);if(!(k=Cb(f+8|0),l=1,m=v[a+480180>>2]!=1,m?k:l)){break c}v[b+708>>2]=0}gb=f+16|0}function P2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=gb-288|0;gb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=2485;b=ge(a+152|0,a+160|0,a+16|0);v[22640]=0;Ec(a+144|0,e);h=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)!=1){v[22640]=0;h=T(21,a+144|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break k}t[a+143|0]=0;e=v[e+4>>2];v[22640]=0;c=ra(2486,a+280|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,h|0,b|0,a+148|0,a+260|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}if(!c){break e}c=w[11896]|w[11897]<<8|(w[11898]<<16|w[11899]<<24);t[a+135|0]=c;t[a+136|0]=c>>>8;t[a+137|0]=c>>>16;t[a+138|0]=c>>>24;c=w[11893]|w[11894]<<8|(w[11895]<<16|w[11896]<<24);v[a+128>>2]=w[11889]|w[11890]<<8|(w[11891]<<16|w[11892]<<24);v[a+132>>2]=c;v[22640]=0;Y(2450,h|0,a+128|0,a+138|0,a+118|0);c=v[22640];v[22640]=0;if((c|0)==1){break j}v[a+4>>2]=2434;d=ge(a+8|0,0,a+4|0);h=v[a+148>>2];e=a+16|0;if((h-v[b>>2]|0)<99){break h}Ee(d,Ad((h-v[b>>2]|0)+2|0));if(v[d>>2]){break i}v[22640]=0;X(2435);c=v[22640];v[22640]=0;if((c|0)==1){break g}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=v[d>>2]}if(w[a+143|0]){t[e|0]=45;e=e+1|0}c=v[b>>2];if(h>>>0>c>>>0){h=a+128|0;while(1){j=e,k=w[((Dm(a+118|0,h,c)-a|0)+a|0)+10|0],t[j|0]=k;e=e+1|0;c=c+1|0;if(c>>>0<y[a+148>>2]){continue}break}}t[e|0]=0;v[a>>2]=g;if((zH(a+16|0,a)|0)==1){break f}v[22640]=0;_(2487,5213);c=v[22640];v[22640]=0;if((c|0)!=1){break a}}e=P()|0;O()|0;Gc(d);break c}Gc(d)}v[22640]=0;c=Q(2437,a+280|0,a+272|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}if(c){v[f>>2]=v[f>>2]|2}c=v[a+280>>2];Vb(a+144|0);Gc(b);gb=a+288|0;return c|0}e=P()|0;O()|0}Vb(a+144|0)}Gc(b);S(e|0);L()}L()}function q_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb-80|0;gb=d;vc(b);ls(a);a:{if(!Hh(b,d+72|0)){break a}if(!mF(d+72|0)){break a}if(!c){j=1;break a}if(!Pb(b,4)){break a}Jw(a);o=d,p=Iw(),v[o+48>>2]=p;Hw(hj(a)+32|0,d+48|0);js(d+48|0);k=v[hj(a)+32>>2];c=hm(b);if(c&1){break a}e=c-4|0;Xc(b,e);c=gb-16|0;gb=c;vw(c+8|0,b);g=w[lc(c+8|0,0)|0];f=w[lc(c+8|0,1)|0];i=w[lc(c+8|0,2)|0];gb=c+16|0;g=i|(f<<8|g<<16);if(!g){break a}v[22640]=0;R(303,k|0,g|0);c=v[22640];v[22640]=0;j=1;if((c|0)==1){a=V(88880)|0;if((O()|0)==(ea(88880)|0)){Z(a|0)|0;$();j=0;break a}S(a|0);L()}Xc(b,4);lF(d+48|0,b);i=v[k>>2];f=gb-32|0;gb=f;b=v[d+48>>2];t[f+24|0]=w[b|0];t[f+25|0]=w[b+1|0];t[f+26|0]=w[b+2|0];t[f+27|0]=w[b+3|0];c=kF(f+8|0);e=b+e|0;v[c+12>>2]=e-4;v[c+8>>2]=b;$j(c,w[e-1|0]);b=g;while(1){b:{if(!$j(c,1)){v[f+4>>2]=1;while(1){e=$j(c,2);v[f+4>>2]=e+v[f+4>>2];if((e|0)==3){continue}break}tc(f+4|0,b);c:{if(!v[f+4>>2]){break c}e=1;while(1){b=b-1|0;o=i+b|0,p=$j(c,8),t[o|0]=p;if(y[f+4>>2]<=e>>>0){break c}e=e+1|0;continue}}if(!b){break b}}e=$j(c,2);v[f+4>>2]=e+2;d:{if((e|0)==3){e=c;if($j(c,1)){h=w[lc(f+24|0,3)|0]}else{h=7}l=$j(e,h);while(1){e=$j(c,3);v[f+4>>2]=e+v[f+4>>2];if((e|0)==7){continue}break}break d}l=$j(c,w[lc(f+24|0,e)|0])}tc(f+4|0,b);h=0;m=v[f+4>>2];if(m){while(1){e=0;n=b+l|0;if(g>>>0>n>>>0){e=w[i+n|0]}b=b-1|0;t[i+b|0]=e;h=h+1|0;if((m|0)!=(h|0)){continue}break}}if(b){continue}}break}gb=f+32|0;be(d+32|0,k);b=v[d+36>>2];v[d+16>>2]=v[d+32>>2];v[d+20>>2]=b;Lh(d+40|0,d+16|0);b=Sd(d+24|0);c=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;b=gm(d+48|0,d+8|0,d);od(hj(a)+12|0,b);yb(b)}gb=d+80|0;return j|0}function fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=gb-48|0;gb=f;q=v[a+16>>2];e=v[a+44>>2];v[f+32>>2]=e;g=v[a+48>>2];v[f+36>>2]=g;k=v[a+52>>2];v[f+40>>2]=k;n=v[a+56>>2];v[f+44>>2]=n;r=v[a+24>>2];s=v[a+20>>2];h=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=h;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;if(d){while(1){n=1;i=((((h&2147483647)<<1|j>>>31)&2147483646)<<1)+q|0;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];m=u[e+36>>1];o=u[e+34>>1];l=u[e+32>>1];p=u[e+30>>1];t=u[e+28>>1];w=u[e+26>>1];x=u[e+24>>1];k=0;e=1;g=0;while(1){h=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[i+(h|8)>>1],o)+B(u[i+(h|4)>>1],l)|0)+B(u[i+(h|12)>>1],m)|0)+B(j,u[i+(h|16)>>1])|0)/2|0)+((((B(u[i+(h|-8)>>1],w)+B(u[i+(h|-12)>>1],x)|0)+B(u[i+(h|-4)>>1],t)|0)+B(u[i+h>>1],p)|0)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}while(1){j=(f+8|0)+(k<<2)|0;g=v[j>>2];m=v[a+60>>2];o=m;h=(f+32|0)+(k<<3)|0;k=v[h>>2];e=Lb(k,-16777216,16776704);l=v[a+64>>2];i=Lb(v[h+4>>2],-16777216,16776704);p=m>>31;m=g<<8;g=m;g=mqa(o,p,g,g>>31);o=jb;l=mqa(l,l>>31,e,e>>31);g=l+g|0;e=jb+o|0;e=g>>>0<l>>>0?e+1|0:e;p=g;g=v[a+68>>2];g=mqa(g,g>>31,i,i>>31);i=p+g|0;e=jb+e|0;e=i>>>0<g>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=Ic(i,e,24);v[h+4>>2]=k;i=v[a+72>>2];v[j>>2]=(e|0)/256;v[h>>2]=e-(i&m);k=1;e=n&1;n=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],r);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];h=v[f+28>>2];continue}break}j=v[f+24>>2];h=v[f+28>>2];n=v[f+44>>2];k=v[f+40>>2];g=v[f+36>>2];e=v[f+32>>2]}v[a+56>>2]=n;v[a+52>>2]=k;v[a+48>>2]=g;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}
function gN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{b:{d=b;e=v[b>>2];if(e){if(!v[b+4>>2]){break b}g=v[b+4>>2];c:{if(!g){if(!jg(d)){while(1){d=v[d+8>>2];if(!jg(d)){continue}break}}d=v[d+8>>2];break c}d=UV(g)}e=v[d>>2];if(e){break b}}e=v[d+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[d+8>>2];g=0}d:{e:{if(jg(d)){v[v[d+8>>2]>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=v[d+8>>2]+4|0;break e}v[v[d+8>>2]+4>>2]=e;c=v[d+8>>2]}c=v[c>>2]}h=!w[d+12|0];if((b|0)!=(d|0)){v[d+8>>2]=v[b+8>>2];f:{if(jg(b)){f=v[d+8>>2];break f}f=v[d+8>>2]+4|0}v[f>>2]=d;f=v[b>>2];v[d>>2]=f;cp(f,d);f=v[b+4>>2];v[d+4>>2]=f;if(f){cp(f,d)}t[d+12|0]=w[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=jg(c);d=w[c+12|0];g:{h:{if(!b){if(!d){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;ur(v[c+8>>2]);b=v[c>>2];a=(b|0)==(a|0)?c:a;c=v[b+4>>2]}b=v[c>>2];i:{if(!(w[b+12|0]?0:b)){b=v[c+4>>2];if(w[b+12|0]?0:b){break i}t[c+12|0]=0;j:{b=v[c+8>>2];if((b|0)!=(a|0)){if(w[b+12|0]){break j}a=b}t[a+12|0]=1;return}if(!jg(b)){break h}b=v[b+8>>2]+4|0;break g}a=v[c+4>>2];if(w[a+12|0]?0:a){break i}t[b+12|0]=1;t[c+12|0]=0;tr(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c+4>>2]+12|0]=1;ur(v[c+8>>2]);return}if(!d){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;tr(v[c+8>>2]);b=v[c+4>>2];a=(b|0)==(a|0)?c:a;c=v[b>>2]}d=v[c>>2];k:{if(w[d+12|0]?0:d){break k}b=v[c+4>>2];if(!(w[b+12|0]?0:b)){t[c+12|0]=0;b=v[c+8>>2];if(!((a|0)!=(b|0)?w[b+12|0]:0)){t[b+12|0]=1;return}if(jg(b)){b=v[b+8>>2]+4|0;break g}b=v[b+8>>2];break g}if(w[d+12|0]?0:d){break k}t[b+12|0]=1;t[c+12|0]=0;ur(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c>>2]+12|0]=1;tr(v[c+8>>2]);return}b=v[b+8>>2]}c=v[b>>2];continue}}t[e+12|0]=1}}function P7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;g=nc(a);a=b+24|0;f=Rb(v[a>>2]+484360|0);v[22640]=0;h=Qi(f);f=v[22640];v[22640]=0;a:{b:{c:{if((f|0)==1){break c}v[22640]=0;R(1427,g|0,h|0);f=v[22640];v[22640]=0;if((f|0)==1){break c}d:{e:{if(h){f=0;while(1){c=x[rc(Rb(v[a>>2]+484360|0),f)>>1];d=v[a>>2];v[22640]=0;d=$l(d+484344|0,c);i=v[22640];v[22640]=0;if((i|0)==1){break b}f:{if(d){c=_b(v[a>>2]+484344|0,x[rc(Rb(v[a>>2]+484360|0),f)>>1]);v[22640]=0;R(2098,e|0,c|0);c=v[22640];v[22640]=0;g:{h:{i:{if((c|0)!=1){v[22640]=0;U(2092,e+16|0,b|0,e|0);c=v[22640];v[22640]=0;if((c|0)==1){break i}v[22640]=0;R(1429,g|0,e+16|0);c=v[22640];v[22640]=0;if((c|0)==1){break h}vb(e+16|0);vb(e);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(e+16|0)}vb(e);break a}v[22640]=0;d=v[22640];v[22640]=0;if((d|0)==1){break b}if((c|0)==65534){v[22640]=0;c=Q(112,e+16|0,6415)|0;d=v[22640];v[22640]=0;j:{if((d|0)!=1){v[22640]=0;R(1429,g|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break j}vb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}v[22640]=0;d=v[22640];v[22640]=0;if((d|0)==1){break b}if((c|0)==65535){v[22640]=0;c=Q(112,e+16|0,6377)|0;d=v[22640];v[22640]=0;k:{if((d|0)!=1){v[22640]=0;R(1429,g|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break k}vb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}v[22640]=0;c=Q(112,e+16|0,11858)|0;d=v[22640];v[22640]=0;if((d|0)==1){break e}v[22640]=0;R(1429,g|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break d}vb(c)}f=f+1|0;if((h|0)!=(f|0)){continue}break}}gb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}vd(g);S(a|0);L()}function ifa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=gb-48|0;gb=g;h=Ii(b)^-1;a:{if(Nb(d)>>>0<=h>>>0){Wt(a);break a}Ii(b);if((w[c+4|0]|w[c+5|0]<<8)>>>0>=60){Yb(b,4)}k=g,l=Ii(b),v[k+44>>2]=l;Yb(b,4);i=Ii(b);j=Ii(b);if(!((j|0)>36?(i|0)>=1:0)){Wt(a);break a}b:{if(!f){break b}if(!xr(xd(e,v[Mb(d,h)>>2]),f)){break b}Wt(a);break a}Ew(g+24|0,b,j,i);v[22640]=0;b=T(307,g+24|0)|0;d=v[22640];v[22640]=0;c:{if((d|0)==1){break c}d:{e:{if(!b){v[22640]=0;T(1433,a|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break e}break c}if((w[c+4|0]|w[c+5|0]<<8)>>>0<=39){v[22640]=0;Q(350,g+24|0,8)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}}if((w[c+4|0]|w[c+5|0]<<8)>>>0<=59){v[22640]=0;Q(350,g+24|0,16)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}}v[22640]=0;T(1425,g+24|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}f:{if((w[c+4|0]|w[c+5|0]<<8)>>>0>=120){v[22640]=0;T(1425,g+24|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;Q(350,g+24|0,8)|0;break f}if((w[c+4|0]|w[c+5|0]<<8)>>>0>=100){v[22640]=0;Q(350,g+24|0,4)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;T(1425,g+24|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;Q(350,g+24|0,4)|0;break f}if((w[c+4|0]|w[c+5|0]<<8)>>>0>=62){v[22640]=0;T(1425,g+24|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;Q(350,g+24|0,4)|0;break f}v[22640]=0;T(1425,g+24|0)|0}b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;b=T(1425,g+24|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break d}v[22640]=0;U(320,g|0,g+24|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break d}Wk(a,g);v[a+20>>2]=v[g+44>>2];yb(g)}yb(g+24|0);break a}}a=P()|0;O()|0;yb(g+24|0);S(a|0);L()}gb=g+48|0}function u2(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;x=gb-16|0;gb=x;v[c>>2]=a;B=d&512;while(1){a:{b:{switch(t[i+z|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];q=Qs(g,32);p=v[c>>2];v[c>>2]=p+4;v[p>>2]=q;break a;case 3:if(dd(n)){break a}q=v[kk(n,0)>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=q;break a;case 2:if(dd(m)|!B){break a}D=c,E=Ti(wd(m),ui(m),v[c>>2]),v[D>>2]=E;break a;case 4:break b;default:break a}}C=v[c>>2];e=h?e+4|0:e;s=e;c:{if(e>>>0>=f>>>0){break c}while(1){if(!ml(g,2048,v[s>>2])){break c}s=s+4|0;if(s>>>0<f>>>0){continue}break}}if((o|0)>=1){d:{e:{if(e>>>0>=s>>>0){p=o;break e}r=v[c>>2];p=o;while(1){f:{s=s-4|0;v[r>>2]=v[s>>2];q=p;p=p-1|0;r=r+4|0;if(e>>>0>=s>>>0){break f}if((q|0)>1){continue}}break}v[c>>2]=r;if((q|0)>1){break e}q=v[c>>2];r=q+4|0;break d}A=Qs(g,48);u=v[c>>2];r=u+4|0;while(1){v[u>>2]=A;q=r;r=q+4|0;y=(p|0)>1;p=p-1|0;u=q;if(y){continue}break}}v[c>>2]=r;v[q>>2]=j}g:{if((e|0)==(s|0)){q=Qs(g,48);p=v[c>>2];r=p+4|0;v[c>>2]=r;v[p>>2]=q;break g}if(dd(l)){q=-1}else{q=t[mc(l,0)|0]}u=0;p=0;while(1){r=p+1|0;h:{if((p|0)!=(q|0)){break h}p=v[c>>2];v[c>>2]=p+4;v[p>>2]=k;u=u+1|0;if(Ab(l)>>>0>u>>>0){if(w[mc(l,u)|0]==127){q=-1;r=1;break h}q=t[mc(l,u)|0]}r=1}p=r;s=s-4|0;A=v[s>>2];y=v[c>>2];r=y+4|0;v[c>>2]=r;v[y>>2]=A;if((e|0)!=(s|0)){continue}break}}Hs(C,r)}z=z+1|0;if((z|0)!=4){continue}break}if(Ab(n)>>>0>1){D=x,E=wd(n),v[D+8>>2]=E;e=gb-16|0;gb=e;v[e+8>>2]=v[x+8>>2];Fg(e+8|0);gb=e+16|0;D=c,E=Ti(v[e+8>>2],ui(n),v[c>>2]),v[D>>2]=E}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}gb=x+16|0}function Eha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;d=b&5;a:{if(!(c&5)){if(!d){break a}i=a,j=Au(t[a+36|0],t[a+37|0]),v[i+24>>2]=j;u[a+36>>1]=0;if((b|0)!=1){break a}e=mqa(v[a+24>>2],0,8272,0)+4181|0;d=jb;i=a,j=Uc(pqa(e,e>>>0<4181?d+1|0:d,8363,0),jb),v[i+24>>2]=j;break a}if(d){break a}if((c|0)==1){e=mqa(v[a+24>>2],0,8363,0)+4136|0;d=jb;i=a,j=Uc(pqa(e,e>>>0<4136?d+1|0:d,8272,0),jb),v[i+24>>2]=j}e=gb-16|0;gb=e;g=e+8|0;d=gb-16|0;gb=d;h=v[a+24>>2];b:{if(!h){t[g|0]=0;t[g+1|0]=0;break b}gt(d+8|0,Lb(Oo(Up(+(h>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);t[d+7|0]=v[d+8>>2];t[d+6|0]=v[d+12>>2];VA(g,d+7|0,d+6|0)}gb=d+16|0;yc(e,a+36|0);yc(e+4|0,a+37|0);d=e+8|0;BS(e,d);BS(e+4|0,d+1|0);gb=e+16|0}if(c&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(c&7){u[a+32>>1]=64;d=x[a+34>>1];if(d&8){e=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=e;d=d&16?d|6:d&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=d&65511}d=c&4;if(d){e=x[a+34>>1];if(!(e&32)){u[a+28>>1]=128;u[a+34>>1]=e|32}vf(a+40|0,15);vf(a+41|0,63)}c:{if(!(!d|!(b&16777248)?c&16777248?b&4:0:1)|!w[a+41|0]){break c}e=w[a+40|0];if(!e){break c}b=a;d=w[a+39|0];if(d){d=dm(Uc(((e<<8|d>>>1)>>>0)/(d>>>0)|0,0))}else{d=255}t[b+39|0]=d}d:{e:{if((c|0)!=4){if((c|0)==16777216){break d}if((c|0)!=32|w[a+38|0]!=2){break e}t[a+38|0]=3;break e}if(w[a+38|0]!=4){break e}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}f:{if(!(!(w[a+35|0]&2)|c&16777218)){v[f+24>>2]=0;v[f+8>>2]=0;v[f+16>>2]=0;v[f+20>>2]=0;v[f>>2]=0;v[f+4>>2]=0;Po(a,0,f);break f}if(!(w[a+35|0]&2)|(c|0)!=2){break f}a=a+68|0;b=lc(a,8);t[b|0]=w[b|0]&3;a=lc(a,9);t[a|0]=w[a|0]&3}gb=f+32|0}function ez(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;e=1;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=w[a|0];switch(d|0){case 0:break a;case 3:break j;case 2:break k;case 13:break l;case 5:break b;case 9:break d;case 11:break e;case 20:break f;case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break g;case 4:break i;default:break h}}t[a|0]=1;t[f+15|0]=64;i=b,j=w[ac(b,f+15|0)|0],t[i|0]=j;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=12;e=1;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=13;e=1;break a}g=w[b|0];if(g>>>0<240){d=0;while(1){h=w[d+39472|0];m:{n:{if(c){if(g>>>0<=h>>>0){break n}break m}if((g|0)!=(h|0)){break m}}t[a|0]=11;t[b|0]=d;break a}e=d>>>0<9;d=d+1|0;if((d|0)!=10){continue}break}break a}t[a|0]=11;t[b|0]=9;break a}if((d|0)==26){break c}}e=0;break a}e=0;o:{p:{q:{d=w[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}t[b|0]=0;t[a|0]=0;e=1;break a}t[a|0]=2;t[b|0]=w[b|0]<<2&60|2;e=1;break a}e=0;c=w[b|0];if(!c){break a}d=c&15;if(!d){t[b|0]=c>>>4;t[a|0]=3;e=1;break a}g=c&240;if(!g){t[a|0]=4;e=1;break a}if((d|0)==15){t[b|0]=c>>>4;t[a|0]=5;e=1;break a}if((g|0)!=240){break a}t[b|0]=d;t[a|0]=6;e=1;break a}c=b;b=w[b|0];t[c|0]=(b|0)==255?64:b>>>2|0;t[a|0]=2;break a}r:{if(c){t[b|0]=0;break r}e=0;if(w[b|0]){break a}}t[a|0]=8;e=1;break a}s:{if(c){t[f+14|0]=w[b|0]&15;t[f+13|0]=9;d=w[ac(f+14|0,f+13|0)|0];break s}e=0;d=w[b|0];if((d&14)>>>0>9|d&240){break a}}t[b|0]=d&15;t[a|0]=8;e=1}gb=f+16|0;return e}function Tx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:while(1){g=b-4|0;b:while(1){d=a;c:while(1){d:{e:{f:{g:{h:{i:{j:{k:{a=b-d|0;e=a>>2;switch(e|0){case 4:break j;case 2:break k;case 0:case 1:break d;case 3:break g;case 5:break i;default:break h}}if(!Ed(g,d)){break d}jc(d,g);return}Sx(d,d+4|0,d+8|0,g);return}Rx(d,d+4|0,d+8|0,d+12|0,g);return}if((a|0)<=123){f=gb-16|0;gb=f;e=d;c=d+8|0;ao(d,d+4|0,c);a=d+12|0;g=b;if((a|0)!=(g|0)){while(1){b=a;if(Ed(a,c)){v[f+12>>2]=v[b>>2];d=b;while(1){l:{a=c;v[d>>2]=v[a>>2];if((a|0)==(e|0)){a=e;break l}d=a;c=d-4|0;if(Ed(f+12|0,c)){continue}}break}v[a>>2]=v[f+12>>2]}c=b;a=b+4|0;if((g|0)!=(a|0)){continue}break}}gb=f+16|0;return}h=((e|0)/2<<2)+d|0;m:{if((a|0)>=3997){a=(e|0)/4<<2;i=Rx(d,a+d|0,h,a+h|0,g);break m}i=ao(d,h,g)}a=g;if(!Ed(d,h)){while(1){a=a-4|0;if((d|0)==(a|0)){f=d+4|0;if(Ed(d,g)){break e}if((f|0)==(g|0)){break d}while(1){if(Ed(d,f)){jc(f,g);f=f+4|0;break e}f=f+4|0;if((g|0)!=(f|0)){continue}break}break d}if(!Ed(a,h)){continue}break}jc(d,a);i=i+1|0}e=d+4|0;if(e>>>0>=a>>>0){break f}while(1){f=e;e=e+4|0;if(Ed(f,h)){continue}while(1){a=a-4|0;if(!Ed(a,h)){continue}break}if(a>>>0<f>>>0){e=f;break f}else{jc(f,a);h=(f|0)==(h|0)?a:h;i=i+1|0;continue}}}ao(d,d+4|0,g);break d}n:{if((e|0)==(h|0)){break n}if(!Ed(h,e)){break n}jc(e,h);i=i+1|0}if(!i){f=MI(d,e);a=e+4|0;if(MI(a,b)){b=e;a=d;if(!f){continue a}break d}if(f){continue b}}if((e-d|0)<(b-e|0)){Tx(d,e,c);a=e+4|0;continue b}Tx(e+4|0,b,c);b=e;a=d;continue a}a=g;if((f|0)==(a|0)){break d}while(1){e=f;f=e+4|0;if(!Ed(d,e)){continue}while(1){a=a-4|0;if(Ed(d,a)){continue}break}if(a>>>0<=e>>>0){d=e;continue c}else{jc(e,a);continue}}}break}break}break}}function uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;h=gb-16|0;gb=h;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}s=v[a+16>>2];g=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(d){while(1){b=(j>>>16&65520)+p|0;f=u[b>>1];e=(e<<1)+s|0;j=u[e-6>>1];i=u[b+2>>1];n=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];r=v[a+60>>2];b=Lb(m,-16777216,16776704);o=v[a+64>>2];g=Lb(g,-16777216,16776704);b=mqa(o,o>>31,b,b>>31);o=jb;q=b;j=(((((((B(i,n)+B(f,j)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=j;f=mqa(r,r>>31,b,b>>31);e=q+f|0;b=jb+o|0;b=e>>>0<f>>>0?b+1|0:b;q=e;e=v[a+68>>2];e=mqa(e,e>>31,g,g>>31);g=q+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Ic(g,b,24);g=v[a+72>>2];e=v[a+32>>2];l=v[a+28>>2]+l|0;f=l>>12;n=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,n);k=e+k|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(n,i);b=b-(g&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=m;m=b;continue}break}j=v[h+8>>2];e=v[h+12>>2];g=m;break e}i=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=g;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}r=v[a+16>>2];g=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(d){while(1){b=e+r|0;f=t[b+4|0];e=(j>>>16&65520)+p|0;j=u[e+14>>1];i=t[b+3|0];o=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=Lb(m,-16777216,16776704);n=v[a+64>>2];g=Lb(g,-16777216,16776704);b=mqa(n,n>>31,b,b>>31);n=jb;J=b;b=v[a+68>>2];q=mqa(b,b>>31,g,g>>31);g=J+q|0;b=jb+n|0;b=g>>>0<q>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,o)|0)+B(f,j)<<8)/32768<<8;f=mqa(H,I,e,e>>31);g=g+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Ic(g,b,24);g=v[a+72>>2];j=v[a+32>>2];l=v[a+28>>2]+l|0;f=l>>12;o=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,o);k=j+k|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,i);b=b-(g&e)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=m;m=b;continue}break}j=v[h+8>>2];e=v[h+12>>2];g=m;break e}i=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=g;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=gb-48|0;gb=g;q=v[a+16>>2];h=v[a+44>>2];v[g+32>>2]=h;e=v[a+48>>2];v[g+36>>2]=e;k=v[a+52>>2];v[g+40>>2]=k;n=v[a+56>>2];v[g+44>>2]=n;r=v[a+24>>2];s=v[a+20>>2];i=v[a+4>>2];j=v[a>>2];v[g+24>>2]=j;v[g+28>>2]=i;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;if(d){while(1){f=(((i&2147483647)<<1|j>>>31)&-2)+q|0;n=1;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];m=u[e+36>>1];o=u[e+34>>1];l=u[e+32>>1];p=u[e+30>>1];w=u[e+28>>1];x=u[e+26>>1];y=u[e+24>>1];k=0;e=1;h=0;while(1){v[(g+8|0)+(h<<2)>>2]=(((((B(t[f+(h|4)|0],o)+B(t[f+(h|2)|0],l)|0)+B(t[f+(h|6)|0],m)|0)+B(j,t[f+(h|8)|0])<<8)/2|0)+((((B(t[f+(h|-4)|0],x)+B(t[f+(h|-6)|0],y)|0)+B(t[f+(h|-2)|0],w)|0)+B(t[h+f|0],p)<<8)/2|0)|0)/16384;i=e;e=0;h=1;if(i){continue}break}while(1){j=(g+8|0)+(k<<2)|0;f=v[j>>2];m=v[a+60>>2];o=m;i=(g+32|0)+(k<<3)|0;k=v[i>>2];e=Lb(k,-16777216,16776704);l=v[a+64>>2];h=Lb(v[i+4>>2],-16777216,16776704);p=m>>31;m=f<<8;f=m;f=mqa(o,p,f,f>>31);o=jb;l=mqa(l,l>>31,e,e>>31);f=l+f|0;e=jb+o|0;e=f>>>0<l>>>0?e+1|0:e;l=f;f=v[a+68>>2];f=mqa(f,f>>31,h,h>>31);h=l+f|0;e=jb+e|0;e=h>>>0<f>>>0?e+1|0:e;h=h+8388608|0;if(h>>>0<8388608){e=e+1|0}e=Ic(h,e,24);v[i+4>>2]=k;h=v[a+72>>2];v[j>>2]=(e|0)/256;v[i>>2]=e-(h&m);k=1;e=n&1;n=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],r);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;j=v[g+24>>2];i=v[g+28>>2];continue}break}j=v[g+24>>2];i=v[g+28>>2];n=v[g+44>>2];k=v[g+40>>2];h=v[g+32>>2];e=v[g+36>>2]}v[a+56>>2]=n;v[a+52>>2]=k;v[a+48>>2]=e;v[a+44>>2]=h;v[a>>2]=j;v[a+4>>2]=i;gb=g+48|0}function HZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;vc(c);a:{if(!Pb(c,3)){break a}while(1){Pr(f+8|0,c);i=md(f+8|0);d=Re(f+8|0);g=f+8|0;if(y[a+12>>2]<=w[g|0]){break a}e=Tc(a,w[g|0],b);h=w[i|0];b:{if(h>>>0<=126){if(!(h|w[d|0])){t[e|0]=254;break b}t[e|0]=h+1;if(w[d|0]==255){break b}if(!w[e+1|0]){t[e+1|0]=j}t[e+2|0]=1;t[e+4|0]=w[d|0];break b}c:{switch(h-127|0){case 0:d=w[g|0]+t[d|0]|0;if((d|0)<0|(d|0)>=v[a+12>>2]<<16>>16){break b}d=Tc(a,d,b);g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[e|0]=g;t[e+1|0]=g>>>8;t[e+2|0]=g>>>16;t[e+3|0]=g>>>24;d=w[d+4|0]|w[d+5|0]<<8;t[e+4|0]=d;t[e+5|0]=d>>>8;break b;case 1:j=w[d|0]+1|0;t[e+1|0]=j;break b;default:break c}}d=t[d|0];t[f+7|0]=d;g=0;h=h&127;if(h>>>0<=23){g=w[h+28800|0]}d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{h=w[i|0];switch((h&127)-2|0){case 21:break g;case 18:break h;case 17:break i;case 16:case 20:break j;case 15:break k;case 2:break l;case 1:break m;case 0:case 8:case 9:break n;default:break e}}if((d|0)>-1){break f}d=0-d&15;break e}t[f+6|0]=64;d=w[ac(f+7|0,f+6|0)|0];if(w[e+2|0]>1){break e}t[e+4|0]=d;t[e+2|0]=1;break b}if((d|0)>-1){g=3;break d}d=0-d&127;t[f+7|0]=d;break e}if(!d){break b}if((d|0)<=-1){d=0-d|-16;t[f+7|0]=d;break e}d=d<<4|15;t[f+7|0]=d;break e}if(!d){break b}g=(d|0)>-1;if(!g){d=0-d&15;t[f+7|0]=d;h=w[i|0]}g=g?3:2;d=((h|0)==22?-32:-16)|d;t[f+7|0]=d;break d}d=d&15|-48;t[f+7|0]=d;break e}d=d&15|-64;t[f+7|0]=d;break e}d=d- -64&127;if(!w[e+3|0]){break e}o:{switch(w[e+2|0]){case 0:case 2:break o;default:break b}}t[e+2|0]=2;t[e+4|0]=d>>>1;break b}d=d<<4}if(!(g&255)){break b}}t[e+5|0]=d;t[e+3|0]=g}if(Pb(c,3)){continue}break}}gb=f+16|0}function y2(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=gb-16|0;gb=x;v[c>>2]=a;A=d&512;while(1){a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];q=rn(g,32);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 3:if(dd(n)){break a}q=w[mc(n,0)|0];p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 2:if(dd(m)|!A){break a}C=c,D=Ti(wd(m),df(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=h?e+1|0:e;r=e;c:{if(e>>>0>=f>>>0){break c}while(1){if(!jh(g,2048,t[r|0])){break c}r=r+1|0;if((r|0)!=(f|0)){continue}break}r=f}if((o|0)>=1){q=o;d:{if(e>>>0<r>>>0){while(1){e:{r=r-1|0;p=w[r|0];s=v[c>>2];v[c>>2]=s+1;t[s|0]=p;s=q;q=q-1|0;if(e>>>0>=r>>>0){break e}if((s|0)>1){continue}}break}u=0;p=0;if((s|0)<2){break d}}u=rn(g,48);p=q}q=v[c>>2];v[c>>2]=q+1;if((p|0)>=1){while(1){t[q|0]=u;q=v[c>>2];v[c>>2]=q+1;s=(p|0)>1;p=p-1|0;if(s){continue}break}}t[q|0]=j}f:{if((e|0)==(r|0)){q=rn(g,48);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break f}if(dd(l)){q=-1}else{q=t[mc(l,0)|0]}u=0;p=0;while(1){s=p+1|0;g:{if((q|0)!=(p|0)){break g}p=v[c>>2];v[c>>2]=p+1;t[p|0]=k;u=u+1|0;if(Ab(l)>>>0>u>>>0){if(w[mc(l,u)|0]==127){q=-1;s=1;break g}q=t[mc(l,u)|0]}s=1}p=s;r=r-1|0;s=w[r|0];z=v[c>>2];v[c>>2]=z+1;t[z|0]=s;if((e|0)!=(r|0)){continue}break}}mm(B,v[c>>2])}y=y+1|0;if((y|0)!=4){continue}break}if(Ab(n)>>>0>1){C=x,D=wd(n),v[C+8>>2]=D;e=gb-16|0;gb=e;v[e+8>>2]=v[x+8>>2];v[e+8>>2]=v[e+8>>2]+1;gb=e+16|0;C=c,D=Ti(v[e+8>>2],df(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}gb=x+16|0}function Ks(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;i=gb-128|0;gb=i;v[i+120>>2]=b;k=Op(c,d);v[i+4>>2]=2434;n=pH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Ad(k);if(!j){v[22640]=0;X(2435);a=v[22640];v[22640]=0;if((a|0)!=1){break a}break b}Ee(n,j)}m=(c|0)==(d|0);if(!m){b=c;h=j;while(1){c:{if(!dd(b)){t[h|0]=1;break c}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;if((d|0)!=(b|0)){continue}break}}while(1){r=o;v[22640]=0;h=Q(2436,a|0,i+120|0)|0;b=v[22640];v[22640]=0;d:{if((b|0)!=1){if(h&(k|0)!=0){break d}v[22640]=0;b=Q(2437,a|0,i+120|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}e:{if(!m){while(1){if(w[j|0]==2){d=c;break e}j=j+1|0;c=c+12|0;if((d|0)!=(c|0)){continue}break}}v[f>>2]=v[f>>2]|4}Gc(n);gb=i+128|0;return d|0}break b}v[22640]=0;p=T(2438,a|0)|0;b=v[22640];v[22640]=0;f:{if((b|0)!=1){if(g){break f}v[22640]=0;p=Q(2439,e|0,p|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break f}}break b}o=r+1|0;if(m){continue}s=0;h=c;b=j;while(1){g:{if(w[b|0]!=1){break g}q=t[mc(h,r)|0];h:{if(g){break h}v[22640]=0;q=Q(2439,e|0,q<<24>>24)|0;u=v[22640];v[22640]=0;if((u|0)!=1){break h}break b}i:{if((p&255)==(q&255)){s=1;if((Ab(h)|0)!=(o|0)){break g}t[b|0]=2;l=l+1|0;break i}t[b|0]=0}k=k-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}if(!s){continue}v[22640]=0;T(2440,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){if(k+l>>>0<2){continue}h=c;b=j;if(m){continue}while(1){j:{if(w[b|0]!=2){break j}if((Ab(h)|0)==(o|0)){break j}t[b|0]=0;l=l-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}continue}break}}a=P()|0;O()|0;Gc(n);S(a|0)}L()}function Iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;r=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;m=v[a+48>>2];v[b+36>>2]=m;g=v[a+52>>2];v[b+40>>2]=g;i=v[a+56>>2];v[b+44>>2]=i;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){m=1;e=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+r|0;h=j>>>21&2040;j=u[h+46534>>1];i=u[h+46532>>1];k=u[h+46530>>1];p=u[h+46528>>1];h=0;g=1;f=0;while(1){q=(b+8|0)+(f<<2)|0;f=f<<1;v[q>>2]=(((B(u[f+e>>1],k)+B(u[e+(f|-4)>>1],p)|0)+B(i,u[e+(f|4)>>1])|0)+B(j,u[e+(f|8)>>1])|0)/16384;l=g&1;g=0;f=1;if(l){continue}break}while(1){j=(b+8|0)+(h<<2)|0;g=v[j>>2];i=v[a+60>>2];k=i;h=(b+32|0)+(h<<3)|0;p=v[h>>2];e=Lb(p,-16777216,16776704);l=v[a+64>>2];f=Lb(v[h+4>>2],-16777216,16776704);q=i>>31;i=g<<8;g=i;g=mqa(k,q,g,g>>31);k=jb;l=mqa(l,l>>31,e,e>>31);g=l+g|0;e=jb+k|0;e=g>>>0<l>>>0?e+1|0:e;k=g;g=v[a+68>>2];g=mqa(g,g>>31,f,f>>31);f=k+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Ic(f,e,24);v[h+4>>2]=p;f=v[a+72>>2];v[j>>2]=(e|0)/256;v[h>>2]=e-(f&i);h=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);n=e+n|0;k=n>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];g=v[b+40>>2];m=v[b+36>>2];h=v[b+32>>2];break a}k=n>>12;f=o>>12}v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=i;v[a+52>>2]=g;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=e;gb=b+48|0}function NS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-32|0;gb=f;d=c&4;a:{if(!(b&4)){if(!d){break a}t[a+15|0]=w[a+16|0];b=w[a+12|0];t[a+12|0]=b&247;d=!(b&2);b=w[a+14|0];if(d|b>>>0<=w[a+13|0]){break a}if(Nb(a)>>>0<=b>>>0){break a}while(1){d=Ac(a,b);u[d>>1]=x[d>>1]+1;b=b+1|0;if(Nb(a)>>>0>b>>>0){continue}break}break a}if(d){break a}b=w[a+14|0];b:{if(b>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|b>>>0<=w[a+13|0]){break a}if(Nb(a)>>>0<=b>>>0){break a}d=x[Ac(a,w[a+14|0])>>1];e=Ac(a,w[a+14|0]-1|0);b=w[a+14|0];if(x[e>>1]<(d-1|0)){b=x[Ac(a,b)>>1]-1&65535;d=Zq(a,b,64,64);q=f,r=Sb(a),v[q+8>>2]=r;q=f,r=Xo(f+8|0,w[a+14|0]),v[q+16>>2]=r;e=Fd(f+24|0,f+16|0);h=qr(f,b,d&255);g=gb-32|0;gb=g;v[g+24>>2]=v[e>>2];b=a;d=v[a>>2];q=g,r=Sb(a),v[q>>2]=r;d=d+(gv(g+24|0,g)<<2)|0;c:{d:{if(y[a+4>>2]<y[wb(a)>>2]){i=v[b+4>>2];if((i|0)!=(d|0)){break d}sW(b,h);break c}e=wb(b);e=zp(g,_g(b,Nb(b)+1|0),d-v[b>>2]>>2,e);v[22640]=0;R(1089,e|0,h|0);l=v[22640];v[22640]=0;e:{if((l|0)==1){break e}v[22640]=0;d=W(1090,b|0,e|0,d|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}cj(e);break c}a=P()|0;O()|0;cj(e);S(a|0);L()}m=gb-16|0;gb=m;l=d;o=b;p=v[b+4>>2];b=(p-(d+4|0)|0)+d|0;j=yg(m,o,i-b>>2);f:{g:{if(b>>>0<i>>>0){k=v[j+4>>2];e=b;while(1){n=wb(o);v[22640]=0;gn(n,k,e);n=v[22640];v[22640]=0;if((n|0)==1){break g}k=k+4|0;v[j+4>>2]=k;e=e+4|0;if(i>>>0>e>>>0){continue}break}}$b(j);hn(l,b,p);gb=m+16|0;break f}a=P()|0;O()|0;$b(j);S(a|0);L()}u[d>>1]=x[h>>1];t[d+2|0]=w[h+2|0]}bh(d);gb=g+32|0;break a}t[a+14|0]=b-1}if((c|0)!=16777216){t[a+17|0]=255}gb=f+32|0}function Js(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;i=gb-128|0;gb=i;v[i+120>>2]=b;k=Op(c,d);v[i+4>>2]=2434;n=pH(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Ad(k);if(!j){v[22640]=0;X(2435);a=v[22640];v[22640]=0;if((a|0)!=1){break a}break b}Ee(n,j)}m=(c|0)==(d|0);if(!m){b=c;h=j;while(1){c:{if(!dd(b)){t[h|0]=1;break c}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;if((d|0)!=(b|0)){continue}break}}while(1){r=o;v[22640]=0;h=Q(2463,a|0,i+120|0)|0;b=v[22640];v[22640]=0;d:{if((b|0)!=1){if(h&(k|0)!=0){break d}v[22640]=0;b=Q(2464,a|0,i+120|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}e:{if(!m){while(1){if(w[j|0]==2){d=c;break e}j=j+1|0;c=c+12|0;if((d|0)!=(c|0)){continue}break}}v[f>>2]=v[f>>2]|4}Gc(n);gb=i+128|0;return d|0}break b}v[22640]=0;p=T(2465,a|0)|0;b=v[22640];v[22640]=0;f:{if((b|0)!=1){if(g){break f}v[22640]=0;p=Q(2466,e|0,p|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break f}}break b}o=r+1|0;if(m){continue}s=0;h=c;b=j;while(1){g:{if(w[b|0]!=1){break g}q=v[kk(h,r)>>2];h:{if(g){break h}v[22640]=0;q=Q(2466,e|0,q|0)|0;u=v[22640];v[22640]=0;if((u|0)!=1){break h}break b}i:{if((p|0)==(q|0)){s=1;if((Ab(h)|0)!=(o|0)){break g}t[b|0]=2;l=l+1|0;break i}t[b|0]=0}k=k-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}if(!s){continue}v[22640]=0;T(2467,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){if(k+l>>>0<2){continue}h=c;b=j;if(m){continue}while(1){j:{if(w[b|0]!=2){break j}if((Ab(h)|0)==(o|0)){break j}t[b|0]=0;l=l-1|0}b=b+1|0;h=h+12|0;if((h|0)!=(d|0)){continue}break}continue}break}}a=P()|0;O()|0;Gc(n);S(a|0)}L()}function S7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb+-64|0;gb=c;f=nc(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(yj(b)){th(c+56|0);break n}v[22640]=0;R(2096,c+40|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break m}v[22640]=0;a=T(2084,c+40|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break l}v[c+56>>2]=a;Uf(c+40|0)}if(yj(b)){a=b+36|0}else{a=v[c+56>>2]}e=jo(a);v[22640]=0;R(1427,f|0,e|0);e=v[22640];v[22640]=0;if((e|0)==1){break k}h=c,i=Sb(a),v[h+32>>2]=i;h=c,i=Wb(a),v[h+24>>2]=i;if(Gb(c+32|0,c+24|0)){a=b+24|0;while(1){e=v[c+32>>2];b=Nj(v[a>>2]+484360|0,w[e+16|0]);v[22640]=0;R(2097,c+8|0,b|0);d=v[22640];v[22640]=0;if((d|0)==1){break j}v[22640]=0;R(2039,c+40|0,c+8|0);d=v[22640];v[22640]=0;if((d|0)==1){break i}v[22640]=0;R(1429,f|0,c+40|0);d=v[22640];v[22640]=0;if((d|0)==1){break h}vb(c+40|0);vb(c+8|0);o:{if(!dd(HK(f))){break o}d=w[e+12|0];v[22640]=0;d=Q(497,b|0,d|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}if(!d){break o}d=v[a>>2];v[22640]=0;d=Dk(d);g=v[22640];v[22640]=0;if((g|0)==1){break f}b=_b(v[a>>2]+484344|0,x[rc(b,v[e+12>>2])>>1]);v[22640]=0;R(2098,c+8|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;Y(400,c+40|0,0,d|0,c+8|0);b=v[22640];v[22640]=0;if((b|0)==1){break d}Eb(HK(f),c+40|0);vb(c+40|0);vb(c+8|0)}aL(c+32|0);if(Gb(c+32|0,c+24|0)){continue}break}}yl(c+56|0);gb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Uf(c+40|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(c+40|0)}vb(c+8|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;vb(c+8|0);break b}b=P()|0;O()|0}yl(c+56|0)}vd(f);S(b|0);L()}function zha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=gb-32|0;gb=e;u[e+28>>1]=c;u[e+30>>1]=b;u[e+26>>1]=d;d=0;m=x[v[v[a+24>>2]+8>>2]+12>>1];a:{if(m>>>0<=b>>>0){break a}if(!c|Qi(a)>>>0>=m>>>0){break a}sg(e+28|0,m-b&65535);s=e,t=Yl(a),u[s+8>>1]=t;b=Ie(e+30|0,e+8|0);hW(a,x[e+28>>1]+x[b>>1]|0);b=x[e+30>>1];if(sc(a)>>>0<b>>>0){yf(a,x[e+30>>1])}s=e,t=Sb(a),v[s>>2]=t;c=x[e+30>>1];b=gb-16|0;gb=b;v[b+8>>2]=v[e>>2];v[b+8>>2]=v[b+8>>2]+(c<<1);gb=b+16|0;v[e+8>>2]=v[b+8>>2];b=v[Fd(e+16|0,e+8|0)>>2];f=x[e+28>>1];i=e+26|0;j=gb-32|0;gb=j;v[j+24>>2]=b;c=a;b=v[c>>2];s=j,t=Sb(c),v[s>>2]=t;d=b+(tp(j+24|0,j)<<1)|0;b:{c:{d:{if(!f){break d}b=v[wb(c)>>2];g=v[c+4>>2];if(f>>>0<=b-g>>1>>>0){b=f;k=g-d|0;h=k>>1;if(b>>>0>h>>>0){up(c,f-h|0,i);b=h;if(!k){break d}}p=gb-16|0;gb=p;h=c;k=g;n=d;q=v[c+4>>2];r=f<<1;f=(q-(r+d|0)|0)+d|0;l=ji(p,c,g-f>>1);if(f>>>0<g>>>0){o=v[l+4>>2];g=f;while(1){wb(h);Qo(o,g);o=o+2|0;v[l+4>>2]=o;g=g+2|0;if(k>>>0>g>>>0){continue}break}}$b(l);hn(n,f,q);gb=p+16|0;fv(d,b,d>>>0<=i>>>0?i>>>0<y[c+4>>2]?i+r|0:i:i);break d}b=wb(c);g=En(j,Rk(c,sc(c)+f|0),d-v[c>>2]>>1,b);v[22640]=0;U(344,g|0,f|0,i|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}b=c;Fp(c);f=g;k=v[f+4>>2];h=d;i=f+4|0;xk(wb(c),v[c>>2],d,i);wb(c);l=f+8|0;n=l;d=v[c+4>>2];if((h|0)!=(d|0)){c=v[n>>2];while(1){Qo(c,h);c=v[n>>2]+2|0;v[n>>2]=c;h=h+2|0;if((d|0)!=(h|0)){continue}break}}jc(b,i);jc(b+4|0,l);jc(wb(b),cc(f));v[f>>2]=v[f+4>>2];Wr(b,sc(b));d=k;Gh(g)}bh(d);gb=j+32|0;break b}a=P()|0;O()|0;Gh(g);S(a|0);L()}if(sc(a)>>>0>m>>>0){yf(a,m)}d=x[e+28>>1]}gb=e+32|0;return d&65535}function Gla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=gb-16|0;gb=d;a:{if(!Pb(a,2)){qh(c+484344|0,b,64);break a}j=c+484344|0;h=Jd(Lv(a),1,1024);if(!qh(j,b,h)|!h){break a}k=x[c+480188>>1];while(1){n=Pf(_b(j,b),i);g=0;if(k){while(1){xn(d+8|0,a);e=md(d+8|0);o=Re(d+8|0);c=B(g,6)+n|0;f=w[aj(d+8|0)|0];t[c+5|0]=f;l=0;m=w[d+8|0];if((m-1&255)>>>0<=35){t[c|0]=m+48;l=w[e|0]+1|0}e=c+5|0;t[c+1|0]=l;b:{c:{d:{switch(w[o|0]){case 1:t[c+3|0]=2;t[e|0]=f&15;break b;case 2:t[c+3|0]=3;t[e|0]=f&15;break b;case 12:if(!f){break b}t[c+3|0]=1;break b;case 13:if(!f){break b}t[c+3|0]=39;t[d+7|0]=15;p=e,q=w[ac(d+7|0,e)|0]|16,t[p|0]=q;break b;case 30:if(!f){break b}t[c+3|0]=38;t[d+6|0]=15;p=e,q=w[ac(d+6|0,e)|0]|16,t[p|0]=q;break b;case 21:if(!f){break b}t[c+3|0]=39;t[d+5|0]=15;p=e,q=w[ac(d+5|0,e)|0]|80,t[p|0]=q;break b;case 17:if(!f){break b}t[c+3|0]=38;t[d+4|0]=15;p=e,q=w[ac(d+4|0,e)|0]|80,t[p|0]=q;break b;case 15:t[c+3|0]=19;t[e|0]=(f|0)!=0;break b;case 25:t[c+3|0]=12;break b;case 27:Yo(c);t[c|0]=255;break b;case 28:t[c+3|0]=16;break b;case 31:t[c+3|0]=11;e:{f:{g:{switch(f>>>4|0){case 4:if((f|0)==64){break f}t[e|0]=f&15;break b;case 5:t[e|0]=f<<4;break b;case 6:t[d+3|0]=f&15;t[d+2|0]=14;p=e,q=w[ac(d+3|0,d+2|0)|0]|240,t[p|0]=q;break b;case 0:case 1:case 2:case 3:break f;case 7:break g;default:break e}}t[d+1|0]=f&15;t[d|0]=14;p=e,q=w[ac(d+1|0,d)|0]<<4|15,t[p|0]=q;break b}t[c+4|0]=f;t[c+2|0]=1}t[c+3|0]=0;break c;case 0:break c;default:break d}}t[c+3|0]=0}t[e|0]=0}g=g+1|0;if((k|0)!=(g|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}gb=d+16|0}function Jia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;m=v[a+48>>2];v[b+36>>2]=m;f=v[a+52>>2];v[b+40>>2]=f;i=v[a+56>>2];v[b+44>>2]=i;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){e=(((e&2147483647)<<1|j>>>31)&-2)+q|0;g=j>>>21&2040;j=u[g+46534>>1];i=u[g+46532>>1];k=u[g+46530>>1];p=u[g+46528>>1];h=0;m=1;f=1;g=0;while(1){v[(b+8|0)+(g<<2)>>2]=(((B(t[e+g|0],k)+B(t[e+(g|-2)|0],p)|0)+B(i,t[e+(g|2)|0])|0)+B(j,t[e+(g|4)|0])<<8)/16384;l=f&1;f=0;g=1;if(l){continue}break}while(1){j=(b+8|0)+(h<<2)|0;f=v[j>>2];i=v[a+60>>2];k=i;g=(b+32|0)+(h<<3)|0;p=v[g>>2];e=Lb(p,-16777216,16776704);l=v[a+64>>2];h=Lb(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=mqa(k,r,f,f>>31);k=jb;l=mqa(l,l>>31,e,e>>31);f=l+f|0;e=jb+k|0;e=f>>>0<l>>>0?e+1|0:e;k=f;f=v[a+68>>2];f=mqa(f,f>>31,h,h>>31);h=k+f|0;e=jb+e|0;e=f>>>0>h>>>0?e+1|0:e;h=h+8388608|0;if(h>>>0<8388608){e=e+1|0}e=Ic(h,e,24);v[g+4>>2]=p;h=v[a+72>>2];v[j>>2]=(e|0)/256;v[g>>2]=e-(h&i);h=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;k=o>>12;v[c>>2]=v[c>>2]+B(k,v[b+8>>2]);n=e+n|0;g=n>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];f=v[b+40>>2];m=v[b+36>>2];h=v[b+32>>2];break a}g=n>>12;k=o>>12}v[a+40>>2]=n;v[a+20>>2]=k;v[a+36>>2]=o;v[a+56>>2]=i;v[a+52>>2]=f;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=g;v[a>>2]=j;v[a+4>>2]=e;gb=b+48|0}function z3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Kb(a+208|0);v[22640]=0;Ec(a+16|0,d);b=v[22640];v[22640]=0;a:{b:{c:{d:{if((b|0)!=1){v[22640]=0;b=T(2458,a+16|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break d}v[22640]=0;Y(2470,b|0,83184,83210,a+224|0);b=v[22640];v[22640]=0;if((b|0)==1){break d}Vb(a+16|0);c=Kb(a+192|0);b=Kc(c);v[22640]=0;R(118,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}b=mc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[22640]=0;d=Q(2463,a+344|0,a+336|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Ab(c)+b|0)){d=Ab(c);b=Ab(c);v[22640]=0;R(118,c|0,b<<1);b=v[22640];v[22640]=0;if((b|0)==1){break b}b=Kc(c);v[22640]=0;R(118,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}b=mc(c,0);v[a+188>>2]=d+b}v[22640]=0;d=T(2465,a+344|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break e}if(nm(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[22640]=0;T(2467,a+344|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Vb(a+16|0);break a}v[22640]=0;R(118,c|0,v[a+188>>2]-b|0);b=v[22640];v[22640]=0;f:{if((b|0)==1){break f}b=Jb(c);v[22640]=0;d=fa(2454)|0;g=v[22640];v[22640]=0;if((g|0)==1){break f}v[a>>2]=f;v[22640]=0;b=ca(2455,b|0,d|0,a|0,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[22640]=0;b=Q(2464,a+344|0,a+336|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(c);vb(h);gb=a+352|0;return b|0}}b=P()|0;O()|0;vb(c)}vb(h);S(b|0);L()}function yO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;f=B(b,872)+a|0;a:{if(w[f+1075082|0]&2){h=1;b:{if(!(w[a+480209|0]&16)){break b}h=0;if(!(v[a+480180>>2]&16777248)){break b}h=!(w[a+480208|0]&4)}if(v[a+480180>>2]==64){a=B(b,872)+a|0;b=a+1075811|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075816|0],167)}t[b|0]=d+1;break a}k=f+1074992|0;c:{if(!h){break c}Db(g+8|0,a+1074312|0,21);if(!Cb(g+8|0)){break c}f=B(b,872)+a|0;e=f+1075811|0;t[e|0]=w[e|0]+(w[f+1075815|0]<<2)}e=B(b,872)+a|0;i=e+1075814|0;j=e+1075811|0;f=Cz(a,w[i|0],w[j|0]);d:{if(Hj(k)){z[d>>2]=C(C(B(w[e+1075816|0],f)|0)*C(6510417279059766e-21))+z[d>>2];c=e+1075843|0;d=w[c|0];t[c|0]=d&207|32;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break d}t[c|0]=d|48;break d}if((v[a+480208>>2]&2101248)==2101248|(w[a+480209|0]&16?v[a+480180>>2]&67633152:0)){break a}f=v[a+480180>>2]&5?(w[i|0]&3)==1?0-f|0:f:f;i=a+1074312|0;Db(g+8|0,i,21);d=Cb(g+8|0);e=v[a+480208>>2];e:{if(d){d=e&4;f=d?f:0-f|0;d=d?5:6;break e}d=5;f:{if(e&131072){break f}d=8;if(v[a+480180>>2]==1024){break f}d=7;if(v[a+480180>>2]&524304|(w[a+480208|0]&4?0:v[a+480180>>2]&16777248)){break f}d=6}Db(g+8|0,i,80);if(!Cb(g+8|0)){break e}d=w[(B(b,872)+a|0)+1075783|0]==26?d+2|0:d}e=B(b,872)+a|0;d=(0-B(w[e+1075816|0],f)|0)/(1<<d)|0;ok(a,k,c,d,0);c=gu(a,b);if(!c){break d}f=c;e=v[e+1075648>>2];if(e){e=w[e+33|0]}else{e=2}kb[v[v[c>>2]+88>>2]](f,d,e<<24>>24,b)}if(!h){break a}Db(g+8|0,a+1074312|0,21);if(Cb(g+8|0)){break a}t[j|0]=w[j|0]+w[(B(b,872)+a|0)+1075815|0];break a}if(!(w[f+1075662|0]&2)){break a}a=gu(a,b);if(!a){break a}kb[v[v[a>>2]+88>>2]](a,0,0,b)}gb=g+16|0}function Kna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0;g=gb-48|0;gb=g;a:{if(w[b+8|0]){b=b+12|0;z=g,A=pc(b)-c|0,v[z+40>>2]=A;z=g,A=xb(d),v[z+32>>2]=A;e=v[Fb(g+40|0,g+32|0)>>2];z=g,A=Sb(b),v[z+40>>2]=A;l=we(g+40|0,c);z=g,A=Sb(b),v[z+24>>2]=A;z=g,A=we(g+24|0,c),v[z+32>>2]=A;Ti(l,we(g+32|0,e),v[d>>2]);Uj(a,d,e);break a}e=v[d+4>>2];d=v[d>>2];v[g+8>>2]=d;v[g+12>>2]=e;v[g+16>>2]=d;v[g+20>>2]=e;n=g+8|0;d=gb-48|0;gb=d;b:{if(!w[b+24|0]){e=v[n+4>>2];l=v[n>>2];v[d+40>>2]=l;v[d+44>>2]=e;i=v[v[b>>2]+40>>2];v[d>>2]=l;v[d+4>>2]=e;kb[i|0](a,b,c,d);break b}p=v[n>>2];e=xb(n);v[d+36>>2]=e;c:{if(!e){break c}l=b+40|0;while(1){i=d;m=c;x=l;j=0;h=gb-32|0;gb=h;e=b;o=e+40|0;f=e+232|0;q=c&-4096;d:{while(1){r=ci(f,j);k=v[r>>2];s=ln(o,k);if(!(!w[s+8|0]|v[s>>2]!=(q|0))){v[h+24>>2]=v[r>>2];e=f+(j<<2)|0;hn(f,e,e+4|0);z=ci(f,0),A=v[h+24>>2],v[z>>2]=A;break d}j=j+1|0;if((j|0)!=16){continue}break}z=h,A=v[ci(f,15)>>2],v[z+24>>2]=A;hn(f,f+60|0,f- -64|0);f=ci(f,0);v[f>>2]=v[h+24>>2];k=v[f>>2];f=ln(o,k);v[f>>2]=q;zC(h+16|0,e,k);j=v[v[e>>2]+40>>2];o=v[h+20>>2];v[h+8>>2]=v[h+16>>2];v[h+12>>2]=o;kb[j|0](h+24|0,e,q,h+8|0);z=f,A=xb(h+24|0),v[z+4>>2]=A;t[f+8|0]=1}gb=h+32|0;f=i;e=ln(x,k);i=m-v[e>>2]|0;v[f+16>>2]=4096-i;z=d,A=v[Fb(d+16|0,d+36|0)>>2],v[z+32>>2]=A;e=v[e+4>>2];m=e-i|0;v[d+28>>2]=e>>>0<m>>>0?0:m;e=v[Fb(d+32|0,d+28|0)>>2];zC(d+16|0,b,k);m=v[d+16>>2];zC(d+8|0,b,k);Bg(i+m|0,e+(i+v[d+8>>2]|0)|0,p);i=v[d+36>>2]-e|0;v[d+36>>2]=i;u=e+u|0;if(e>>>0<y[d+32>>2]){break c}c=c+e|0;p=e+p|0;if(i){continue}break}}Uj(a,n,u)}gb=d+48|0}gb=g+48|0}function L3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Kb(a+208|0);v[22640]=0;Ec(a+16|0,d);b=v[22640];v[22640]=0;a:{b:{c:{d:{if((b|0)!=1){v[22640]=0;b=T(21,a+16|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break d}v[22640]=0;Y(2450,b|0,83184,83210,a+224|0);b=v[22640];v[22640]=0;if((b|0)==1){break d}Vb(a+16|0);c=Kb(a+192|0);b=Kc(c);v[22640]=0;R(118,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}b=mc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[22640]=0;d=Q(2436,a+264|0,a+256|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Ab(c)+b|0)){d=Ab(c);b=Ab(c);v[22640]=0;R(118,c|0,b<<1);b=v[22640];v[22640]=0;if((b|0)==1){break b}b=Kc(c);v[22640]=0;R(118,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}b=mc(c,0);v[a+188>>2]=d+b}v[22640]=0;d=T(2438,a+264|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break e}if(om(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[22640]=0;T(2440,a+264|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Vb(a+16|0);break a}v[22640]=0;R(118,c|0,v[a+188>>2]-b|0);b=v[22640];v[22640]=0;f:{if((b|0)==1){break f}b=Jb(c);v[22640]=0;d=fa(2454)|0;g=v[22640];v[22640]=0;if((g|0)==1){break f}v[a>>2]=f;v[22640]=0;b=ca(2455,b|0,d|0,a|0,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[22640]=0;b=Q(2437,a+264|0,a+256|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(c);vb(h);gb=a+272|0;return b|0}}b=P()|0;O()|0;vb(c)}vb(h);S(b|0);L()}function nM(a){var b=C(0),c=0,d=0,e=0,f=0,g=0,h=C(0),i=C(0),k=0,l=C(0);d=gb-16|0;gb=d;k=d,l=C(My(z[a+4216>>2])/C(uf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(K(C(C(Rp(C(z[Cm(d+12|0,d+8|0)>>2]*C(6.2831854820251465)))*C(.4000000059604645))+C(.6000000238418579))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));f=a;b=C(C(z[a+4212>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}t[f+4272|0]=c;f=a;e=2;b:{if(c>>>0<4){break b}e=3;if(c>>>0<8){break b}e=c>>>0<16?4:5}t[f+4273|0]=e;h=me(C(10),C(C(C(z[a+4208>>2]*C(60))+C(-60))*C(.05000000074505806)));k=d,l=C(My(z[a+4220>>2])/C(uf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;i=z[Cm(d+12|0,d+8|0)>>2];k=d,l=C(My(z[a+4224>>2])/C(uf(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(z[Cm(d+12|0,d+8|0)>>2]*C(3.1415927410125732));e=gb-16|0;gb=e;f=(p(b),j(2));c=f&2147483647;c:{if(c>>>0<=1061752794){if(c>>>0<964689920){break c}b=bo(+b,0);break c}if(c>>>0<=1081824209){g=+b;if(c>>>0<=1075235811){b=bo(((f|0)>-1?-1.5707963267948966:1.5707963267948966)+g,1);break c}b=bo(((f|0)>-1?-3.141592653589793:3.141592653589793)+g,0);break c}if(c>>>0<=1088565717){g=+b;if(c>>>0<=1085271519){b=bo(((f|0)>-1?-4.71238898038469:4.71238898038469)+g,1);break c}b=bo(((f|0)>-1?-6.283185307179586:6.283185307179586)+g,0);break c}if(c>>>0>=2139095040){b=C(b-b);break c}c=Vx(b,e+8|0);b=bo(A[e+8>>3],c&1)}gb=e+16|0;z[a+4268>>2]=C(C(1)-b)/C(b+C(1));b=Rp(C(i*C(6.2831854820251465)));z[a+4264>>2]=-b;h=C(h*C(K(C(C(1)-C(b*b)))));b=z[a+4268>>2];z[a+4260>>2]=C(h*C(K(C(C(1)-C(b*b)))))*z[(w[a+4272|0]<<2)+51968>>2];gb=d+16|0}function Nha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;p=v[a+16>>2];i=Sd(f+16|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];q=i,r=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[i+16>>2];if(b){q=i,r=gg(a+8|0,b),v[q>>2]=r;v[i+4>>2]=jb}g=v[a+48>>2];m=v[a+40>>2];n=v[a+36>>2];o=v[a+44>>2];h=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=h;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(d){while(1){l=0;e=l;v[f+40>>2]=j;v[f+44>>2]=e;h=(h<<1)+p|0;b:{if((b|0)<=0){break b}while(1){Id(v[i+8>>2],u[(e<<1)+h>>1]/4<<16>>16);Hd(v[i+8>>2],4);Ub(f+40|0,i);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[i+8>>2];Ub(b,b+8|0);b=v[i+8>>2];e=v[b+4>>2];if(e){Id(b,u[h+(v[f+44>>2]<<1)>>1]/4<<16>>16);Hd(v[i+8>>2],e);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}e=dg(b,v[i+12>>2]);h=v[a+60>>2];j=h;b=Lb(o,-16777216,16776704);k=v[a+64>>2];g=Lb(g,-16777216,16776704);l=h>>31;h=e<<8;e=h;e=mqa(j,l,e,e>>31);j=jb;k=mqa(k,k>>31,b,b>>31);e=k+e|0;b=jb+j|0;b=e>>>0<k>>>0?b+1|0:b;l=e;e=v[a+68>>2];e=mqa(e,e>>31,g,g>>31);g=l+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}g=Ic(g,b,24);e=v[a+72>>2];j=v[a+32>>2];n=v[a+28>>2]+n|0;b=n>>12;l=(g|0)/256|0;v[c>>2]=v[c>>2]+B(b,l);m=j+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(l,k);e=g-(e&h)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[i+16>>2];j=v[f+8>>2];h=v[f+12>>2];g=o;o=e;continue}break}j=v[f+8>>2];h=v[f+12>>2];g=o;break a}k=m>>12;b=n>>12;e=o}v[a+40>>2]=m;v[a+20>>2]=b;v[a+36>>2]=n;v[a+48>>2]=g;v[a+44>>2]=e;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function Gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=gb+-64|0;gb=c;d=x[a+480190>>1];t[c+48|0]=0;ER(b,d+1|0,c+48|0);if(x[a+480192>>1]){g=nc(c+48|0);d=a+484344|0;k=c,l=Sb(d),v[k+40>>2]=l;k=c,l=Wb(d),v[k+32>>2]=l;if(Gb(c+40|0,c+32|0)){while(1){a:{i=v[c+40>>2];if(!hi(i)){break a}d=x[a+480188>>1];v[22640]=0;t[c+8|0]=0;U(1139,g|0,d|0,c+8|0);d=v[22640];v[22640]=0;if((d|0)!=1){b:{k=c,l=Sb(i),v[k+24>>2]=l;j=0;if(!v[i+12>>2]){break a}while(1){f=0;c:{if(!x[a+480188>>1]){break c}while(1){d:{d=v[c+24>>2];v[22640]=0;d=ce(d);e=v[22640];v[22640]=0;if((e|0)==1){break d}e:{if(!d){break e}d=w[v[c+24>>2]+1|0];t[c+23|0]=d;if(!w[v[c+24>>2]+1|0]){d=w[kc(g,f)|0];t[c+23|0]=d}if(d&255){u[c+8>>1]=0;f:{if(x[c+8>>1]>w[c+23|0]){break f}e=v[((w[v[c+24>>2]+1|0]<<2)+a|0)+900380>>2];if(!e){break f}e=x[sd(e+236|0,w[v[c+24>>2]]-1|0)>>1];if(e>>>0>x[a+480190>>1]){break f}oe(c+8|0,b,e);Af(c+8|0,1)}k=kc(g,f),l=d,t[k|0]=l;break e}d=x[a+480192>>1];if(!d){break e}e=d;while(1){h=v[((d<<2)+a|0)+900380>>2];g:{if(!h){break g}h=x[sd(h+236|0,w[v[c+24>>2]]-1|0)>>1];if(h>>>0>x[a+480190>>1]){break g}oe(c+8|0,b,h);Af(c+8|0,1)}d=d-1|0;e=e-1|0;if(e&65535){continue}break}}Wj(c+24|0);f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break c}break}break b}j=j+1|0;if(j>>>0<y[i+12>>2]){continue}break}break a}}a=P()|0;O()|0;gc(g);S(a|0);L()}fP(c+40|0);if(Gb(c+40|0,c+32|0)){continue}break}}d=x[a+480190>>1];h:{if(!d){f=0;break h}f=0;e=d;while(1){oe(c+8|0,b,d);if(!Cb(c+8|0)){f=Ld((B(d,104)+a|0)+484380|0)+f|0}d=d-1|0;e=e-1|0;if(e&65535){continue}break}}gc(g)}gb=c- -64|0;return f&65535}function h3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-384|0;gb=f;v[f+376>>2]=37;v[f+380>>2]=0;h=Is(f+376|1,18693,v[c+4>>2]);v[f+332>>2]=f+336;a=xe();a:{if(h){i=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=i;a=Ff(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;a=Ff(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=2434;i=ge(f+320|0,0,f+80|0);j=f+336|0;g=j;b:{c:{d:{if((a|0)>=30){e:{if(h){v[22640]=0;a=fa(2454)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[22640]=0;A[f+8>>3]=e;a=ca(2473,f+332|0,a|0,f+376|0,f|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){break e}break c}v[22640]=0;a=fa(2454)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[22640]=0;a=ca(2473,f+332|0,a|0,f+376|0,f+16|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}}if((a|0)==-1){v[22640]=0;X(2435);a=v[22640];v[22640]=0;if((a|0)==1){break c}break d}Ee(i,v[f+332>>2]);g=v[f+332>>2]}h=a+g|0;k=Pg(g,h,c);v[f+68>>2]=2434;g=ge(f+72|0,0,f+68|0);f:{g:{if(v[f+332>>2]==(f+336|0)){a=f+80|0;break g}a=Ad(a<<3);if(!a){v[22640]=0;X(2435);a=v[22640];v[22640]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(g,a);j=v[f+332>>2]}v[22640]=0;Ec(f+56|0,c);l=v[22640];v[22640]=0;h:{i:{if((l|0)!=1){v[22640]=0;ja(2482,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=v[22640];v[22640]=0;if((h|0)==1){break i}Vb(f+56|0);v[22640]=0;a=la(2483,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break h}Gc(g);Gc(i);gb=f+384|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Vb(f+56|0);break f}c=P()|0;O()|0}Gc(g);break b}L()}c=P()|0;O()|0}Gc(i);S(c|0);L()}function vH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-272|0;gb=h;g=v[b>>2];v[h+12>>2]=g;l=a?d:256;d=a?a:h+16|0;e=0;a:{b:{c:{if(!g|!l){break c}f=c>>>0>=l>>>0;if(!(c>>>0>32|c>>>0>=l>>>0)){break b}while(1){k=f?l:c;c=c-k|0;m=0;n=gb-16|0;gb=n;d:{e:{f:{g:{f=d;if(f){if(k>>>0>=4){break g}g=k;break f}f=0;j=v[h+12>>2];g=v[j>>2];if(!g){break d}while(1){if(g>>>0<=127){f=f+1|0}else{m=-1;k=sl(n+12|0,g,0);if((k|0)==-1){break d}f=f+k|0}g=v[j+4>>2];j=j+4|0;m=f;if(g){continue}break}break d}j=v[h+12>>2];g=k;while(1){i=v[j>>2];h:{if(i-1>>>0>=127){if(!i){t[f|0]=0;v[h+12>>2]=0;break e}m=-1;i=sl(f,i,0);if((i|0)==-1){break d}g=g-i|0;f=f+i|0;break h}t[f|0]=i;g=g-1|0;j=v[h+12>>2];f=f+1|0}j=j+4|0;v[h+12>>2]=j;if(g>>>0>3){continue}break}}if(g){j=v[h+12>>2];while(1){i=v[j>>2];i:{if(i-1>>>0>=127){if(!i){t[f|0]=0;v[h+12>>2]=0;break e}m=-1;i=sl(n+12|0,i,0);if((i|0)==-1){break d}if(g>>>0<i>>>0){break e}sl(f,v[j>>2],0);g=g-i|0;f=f+i|0;break i}t[f|0]=i;g=g-1|0;j=v[h+12>>2];f=f+1|0}j=j+4|0;v[h+12>>2]=j;if(g){continue}break}}m=k;break d}m=k-g|0}gb=n+16|0;if((m|0)==-1){l=0;g=v[h+12>>2];e=-1;break c}f=(h+16|0)==(d|0);l=l-(f?0:m)|0;d=f?d:d+m|0;e=e+m|0;g=v[h+12>>2];if(!g|!l){break c}f=c>>>0>=l>>>0;if(c>>>0>32|c>>>0>=l>>>0){continue}break}break b}if(!g){break a}}if(!l|!c){break a}f=e;while(1){j:{k=sl(d,v[g>>2],0);k:{if(k+1>>>0<=1){e=-1;if(k){break a}v[h+12>>2]=0;break k}g=v[h+12>>2]+4|0;v[h+12>>2]=g;f=f+k|0;l=l-k|0;if(l){break j}}e=f;break a}d=d+k|0;e=f;c=c-1|0;if(c){continue}break}}if(a){v[b>>2]=v[h+12>>2]}gb=h+272|0;return e|0}function s3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-208|0;gb=f;v[f+200>>2]=37;v[f+204>>2]=0;h=Is(f+200|1,18693,v[c+4>>2]);v[f+156>>2]=f+160;a=xe();a:{if(h){i=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=i;a=Ff(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;a=Ff(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=2434;i=ge(f+144|0,0,f+80|0);j=f+160|0;g=j;b:{c:{d:{if((a|0)>=30){e:{if(h){v[22640]=0;a=fa(2454)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[22640]=0;A[f+8>>3]=e;a=ca(2473,f+156|0,a|0,f+200|0,f|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){break e}break c}v[22640]=0;a=fa(2454)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[22640]=0;a=ca(2473,f+156|0,a|0,f+200|0,f+16|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break c}}if((a|0)==-1){v[22640]=0;X(2435);a=v[22640];v[22640]=0;if((a|0)==1){break c}break d}Ee(i,v[f+156>>2]);g=v[f+156>>2]}h=a+g|0;k=Pg(g,h,c);v[f+68>>2]=2434;g=ge(f+72|0,0,f+68|0);f:{g:{if(v[f+156>>2]==(f+160|0)){a=f+80|0;break g}a=Ad(a<<1);if(!a){v[22640]=0;X(2435);a=v[22640];v[22640]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}Ee(g,a);j=v[f+156>>2]}v[22640]=0;Ec(f+56|0,c);l=v[22640];v[22640]=0;h:{i:{if((l|0)!=1){v[22640]=0;ja(2474,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=v[22640];v[22640]=0;if((h|0)==1){break i}Vb(f+56|0);v[22640]=0;a=la(17,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break h}Gc(g);Gc(i);gb=f+208|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Vb(f+56|0);break f}c=P()|0;O()|0}Gc(g);break b}L()}c=P()|0;O()|0}Gc(i);S(c|0);L()}function Mga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;f=gb+-64|0;gb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}s=l-4|0;n=B(b,e);o=n-8|0;while(1){v[22640]=0;b=Q(228,c|0,l|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break b}if(!(b&m>>>0<n>>>0)){break g}v[22640]=0;U(320,f+40|0,c|0,d|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;R(774,f+16|0,f+40|0);b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;x=Rd(f+16|0);b=v[22640];v[22640]=0;if((b|0)==1){break f}p=v[f+16>>2];if(e){q=p-4|0;j=0;while(1){v[22640]=0;b=T(763,f+40|0)|0;h=v[22640];v[22640]=0;h:{if((h|0)!=1){v[f+12>>2]=b;v[22640]=0;b=T(353,f+40|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break f}v[f+8>>2]=b;Qd(f+8|0,0,89);v[22640]=0;Q(350,f+40|0,1)|0;b=v[22640];v[22640]=0;if((b|0)==1){break f}h=j+m|0;if(o>>>0<h>>>0){break h}k=0;b=e+j<<2;if(q>>>0<b>>>0){break h}while(1){i=zb(w[b+x|0]);r=k&1;i=r?i>>>4|0:i&15;g=v[f+8>>2];v[f+8>>2]=t[(i&7)+36932|0]+g;g=u[(g<<1)+36944>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;v[f+12>>2]=v[f+12>>2]+(i&8?0-g|0:g);Qd(f+8|0,0,88);Qd(f+12|0,-32768,32767);u[(h<<1)+a>>1]=v[f+12>>2];h=e+h|0;b=b+r|0;k=k+1|0;if((k|0)!=8){continue}if(h>>>0>o>>>0){break h}k=0;b=b+s|0;if(q>>>0>=b>>>0){continue}break}break h}break f}j=j+1|0;if((j|0)!=(e|0)){continue}break}}m=(p-l<<1)+m|0;xc(f+16|0);yb(f+40|0);continue}}yb(c);gb=f- -64|0;return}b=P()|0;O()|0;xc(f+16|0);break d}b=P()|0;O()|0}yb(f+40|0);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}yb(c);S(b|0);L()}function vL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0);d=gb-48|0;gb=d;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==v[v[a>>2]+24604>>2]){break d}hc(d+8|0,v[a>>2]+24604|0,40);v[d+8>>2]=b;Jz(v[a>>2],d+8|0);break d;case 2:f=a+24|0;a=v[f>>2];b=a+24664|0;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=a+24656|0;e=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=e;b=v[a+24652>>2];v[d+8>>2]=v[a+24648>>2];v[d+12>>2]=b;e=d;g=gb-16|0;gb=g;b=3;f:{g:{h:{a=c;if(!a|(a|0)>7){break h}b=2;if((a|0)>2){break h}b=1;if((a|0)==2){break h}b=0;if((a|0)>0){break h}a=aa(8)|0;v[22640]=0;c=Q(112,g|0,8119)|0;b=v[22640];v[22640]=0;i:{if((b|0)!=1){qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break g}b=P()|0;O()|0;vb(c);break i}b=P()|0;O()|0;da(a|0)}S(b|0);L()}gb=g+16|0;break f}L()}t[e+8|0]=b;if(!Dy(d+8|0,v[f>>2]+24648|0)){break d}Hz(v[f>>2],d+8|0);break d;case 3:b=a+24|0;hc(d+8|0,v[b>>2]+24604|0,40);a=d+8|0;e=gb-48|0;gb=e;j:{if((c|0)==-1){Ft(a,v[_q(e+8|0)+32>>2]);Ko(a,v[_q(e+8|0)+36>>2]);break j}if((c|0)<=0){Ft(a,0);Ko(a,0);break j}c=B(c,1e3);Ft(a,c);Ko(a,c)}gb=e+48|0;if(v[v[b>>2]+24640>>2]==v[d+44>>2]?v[v[b>>2]+24636>>2]==v[d+40>>2]:0){break d}Jz(v[b>>2],d+8|0);break d;default:a=aa(8)|0;v[22640]=0;b=Q(112,d+8|0,7711)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}qc(a,b);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b;case 0:break e}}h=a,i=me(C(10),C(C(c|0)*C(.0005000000237487257))),z[h+48>>2]=i}gb=d+48|0;return}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function Oha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;p=v[a+16>>2];i=Sd(f+16|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];q=i,r=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[i+16>>2];if(b){q=i,r=gg(a+8|0,b),v[q>>2]=r;v[i+4>>2]=jb}g=v[a+48>>2];m=v[a+40>>2];n=v[a+36>>2];o=v[a+44>>2];h=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=h;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(d){while(1){l=0;e=l;v[f+40>>2]=j;v[f+44>>2]=e;h=h+p|0;b:{if((b|0)<=0){break b}while(1){Id(v[i+8>>2],t[e+h|0]<<6);Hd(v[i+8>>2],4);Ub(f+40|0,i);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[i+8>>2];Ub(b,b+8|0);b=v[i+8>>2];e=v[b+4>>2];if(e){Id(b,t[h+v[f+44>>2]|0]<<6);Hd(v[i+8>>2],e);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}e=dg(b,v[i+12>>2]);h=v[a+60>>2];j=h;b=Lb(o,-16777216,16776704);k=v[a+64>>2];g=Lb(g,-16777216,16776704);l=h>>31;h=e<<8;e=h;e=mqa(j,l,e,e>>31);j=jb;k=mqa(k,k>>31,b,b>>31);e=k+e|0;b=jb+j|0;b=e>>>0<k>>>0?b+1|0:b;l=e;e=v[a+68>>2];e=mqa(e,e>>31,g,g>>31);g=l+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}g=Ic(g,b,24);e=v[a+72>>2];j=v[a+32>>2];n=v[a+28>>2]+n|0;b=n>>12;l=(g|0)/256|0;v[c>>2]=v[c>>2]+B(b,l);m=j+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(l,k);e=g-(e&h)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[i+16>>2];j=v[f+8>>2];h=v[f+12>>2];g=o;o=e;continue}break}j=v[f+8>>2];h=v[f+12>>2];g=o;break a}k=m>>12;b=n>>12;e=o}v[a+40>>2]=m;v[a+20>>2]=b;v[a+36>>2]=n;v[a+48>>2]=g;v[a+44>>2]=e;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=h;gb=f+48|0}function Tpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=Kb(a);j=Ab(b);v[22640]=0;R(481,f|0,j|0);a=v[22640];v[22640]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!j){break d}a=0;break e}e=P()|0;O()|0;break b}f:{while(1){g:{d=t[mc(b,e)|0];h=d&255;h:{i:{switch(a+1|0){case 1:a=1;j:{switch(h-123|0){case 2:a=3;break h;case 0:break h;default:break j}}a=0;v[22640]=0;W(482,f|0,1,d|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break h}break g;case 2:k:{switch(h-123|0){case 0:a=0;v[22640]=0;W(482,f|0,1,123)|0;d=v[22640];v[22640]=0;if((d|0)==1){break g}break h;case 2:l=1;d=g+1|0;a=0;if(ps(c)>>>0<=g>>>0){g=d;break h}g=xd(c,g);v[22640]=0;Q(483,f|0,g|0)|0;h=v[22640];v[22640]=0;g=d;if((h|0)!=1){break h}e=P()|0;O()|0;break b;default:break k}}a=-1;d=d-48|0;if((d&255)>>>0>9){break h}k=1;a=2;i=d;break h;case 3:a=-1;l:{switch(h-123|0){case 2:a=0;if(ps(c)>>>0<=i>>>0){break h}d=xd(c,i);v[22640]=0;Q(483,f|0,d|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break h}e=P()|0;O()|0;break b;case 0:break h;default:break l}}if((d-48&255)>>>0>9){break h}i=(d+B(i,10)|0)-48|0;k=1;a=2;break h;case 4:a=-1;if((d|0)!=125){break h}a=0;v[22640]=0;W(482,f|0,1,125)|0;d=v[22640];v[22640]=0;if((d|0)==1){break g}break h;case 0:break i;default:break h}}a=-1}e=e+1|0;if((j|0)!=(e|0)){continue}break f}break}e=P()|0;O()|0;break b}if((l?k:0)|a){break c}}return}a=aa(8)|0;v[22640]=0;T(222,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){v[22640]=0;U(223,a|0,27800,24);a=v[22640];v[22640]=0;if((a|0)!=1){break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;da(a|0)}vb(f);S(e|0)}L()}function b$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=Kb(a);j=Ab(b);v[22640]=0;R(219,f|0,j|0);a=v[22640];v[22640]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!j){break d}a=0;break e}e=P()|0;O()|0;break b}f:{while(1){g:{d=t[mc(b,e)|0];h=d&255;h:{i:{switch(a+1|0){case 1:a=1;j:{switch(h-123|0){case 2:a=3;break h;case 0:break h;default:break j}}a=0;v[22640]=0;W(220,f|0,1,d|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break h}break g;case 2:k:{switch(h-123|0){case 0:a=0;v[22640]=0;W(220,f|0,1,123)|0;d=v[22640];v[22640]=0;if((d|0)==1){break g}break h;case 2:l=1;d=g+1|0;a=0;if(ps(c)>>>0<=g>>>0){g=d;break h}g=xd(c,g);v[22640]=0;Q(221,f|0,g|0)|0;h=v[22640];v[22640]=0;g=d;if((h|0)!=1){break h}e=P()|0;O()|0;break b;default:break k}}a=-1;d=d-48|0;if((d&255)>>>0>9){break h}k=1;a=2;i=d;break h;case 3:a=-1;l:{switch(h-123|0){case 2:a=0;if(ps(c)>>>0<=i>>>0){break h}d=xd(c,i);v[22640]=0;Q(221,f|0,d|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break h}e=P()|0;O()|0;break b;case 0:break h;default:break l}}if((d-48&255)>>>0>9){break h}i=(d+B(i,10)|0)-48|0;k=1;a=2;break h;case 4:a=-1;if((d|0)!=125){break h}a=0;v[22640]=0;W(220,f|0,1,125)|0;d=v[22640];v[22640]=0;if((d|0)==1){break g}break h;case 0:break i;default:break h}}a=-1}e=e+1|0;if((j|0)!=(e|0)){continue}break f}break}e=P()|0;O()|0;break b}if((l?k:0)|a){break c}}return}a=aa(8)|0;v[22640]=0;T(222,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){v[22640]=0;U(223,a|0,27800,24);a=v[22640];v[22640]=0;if((a|0)!=1){break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;da(a|0)}vb(f);S(e|0)}L()}function yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;h=gb-16|0;gb=h;a:{b:{c:{j=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?j>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?j>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?j>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?j>>>0>2147483648:0){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}p=v[a+16>>2];g=v[a+48>>2];q=v[a+24>>2];r=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;v[h>>2]=j;v[h+4>>2]=f;e:{if(!d){b=k;k=g;break e}while(1){b=(i>>>16&65520)+m|0;f=u[b>>1];e=(e<<1)+p|0;i=u[e-6>>1];j=u[b+2>>1];s=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];o=v[a+60>>2];b=Lb(k,-16777216,16776704);l=v[a+64>>2];g=Lb(g,-16777216,16776704);b=mqa(l,l>>31,b,b>>31);l=jb;n=b;i=(((((((B(j,s)+B(f,i)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=i;f=mqa(o,o>>31,b,b>>31);e=n+f|0;b=jb+l|0;b=e>>>0<f>>>0?b+1|0:b;n=e;e=v[a+68>>2];e=mqa(e,e>>31,g,g>>31);g=n+e|0;b=jb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Ic(g,b,24);g=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,r);v[c+4>>2]=v[c+4>>2]+B(e,q);b=b-(g&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];g=k;k=b;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}o=v[a+16>>2];g=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(!d){b=k;k=g;break e}while(1){b=e+o|0;f=t[b+4|0];e=(j>>>16&65520)+m|0;j=u[e+14>>1];i=t[b+3|0];r=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=Lb(k,-16777216,16776704);l=v[a+64>>2];g=Lb(g,-16777216,16776704);b=mqa(l,l>>31,b,b>>31);l=jb;J=b;b=v[a+68>>2];n=mqa(b,b>>31,g,g>>31);g=J+n|0;b=jb+l|0;b=g>>>0<n>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,r)|0)+B(f,j)<<8)/32768<<8;f=mqa(H,I,e,e>>31);g=g+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Ic(g,b,24);g=v[a+72>>2];f=(b|0)/256|0;v[c>>2]=v[c>>2]+B(f,q);v[c+4>>2]=v[c+4>>2]+B(f,p);b=b-(g&e)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=k;k=b;continue}break}j=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=e;gb=h+16|0}function Zca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;e=b+1298264|0;if(!Bd(e)){d=i;f=gb-16|0;gb=f;c=rf(12);v[22640]=0;h=T(1646,c|0)|0;g=v[22640];v[22640]=0;a:{if((g|0)!=1){c=gb-16|0;gb=c;v[c+12>>2]=h;Cq(f+8|0,c+12|0);gb=c+16|0;gb=f+16|0;c=v[f+8>>2];break a}a=P()|0;O()|0;Zb(c);S(a|0);L()}v[d+8>>2]=c;iP(e,$d(i+8|0));cu(i+8|0)}d=v[e>>2];c=gb+-64|0;gb=c;eP(c+16|0,a);v[22640]=0;U(9,c+32|0,0,c+16|0);f=v[22640];v[22640]=0;b:{c:{d:{e:{f:{g:{if((f|0)!=1){v[22640]=0;bz(c+48|0,c+32|0);f=v[22640];v[22640]=0;if((f|0)!=1){vb(c+32|0);vb(c+16|0);k=c,l=Sb(d),v[k+8>>2]=l;k=c,l=Wb(d),v[k>>2]=l;h:{if(Gb(c+8|0,c)){f=0;d=0;while(1){h=0;e=v[c+8>>2];if(v[v[e>>2]+32>>2]==(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))){h=v[v[e>>2]+36>>2]==(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))}g=v[e>>2];v[22640]=0;R(1647,c+16|0,g+8|0);g=v[22640];v[22640]=0;if((g|0)==1){break h}v[22640]=0;g=uN(c+16|0,c+48|0);j=v[22640];v[22640]=0;i:{j:{if((j|0)!=1){vb(c+16|0);if(g|!h){break j}f=v[e>>2];d=3;break i}d=P()|0;O()|0;vb(c+16|0);break d}if((d|0)<2&h){f=v[e>>2];d=2;break i}h=v[e>>2];e=!g&(d|0)<1;f=e?h:f;d=e?1:d}Fg(c+8|0);if(Gb(c+8|0,c)){continue}break}break f}d=0;break e}d=P()|0;O()|0;break d}d=P()|0;O()|0;vb(c+32|0);break g}d=P()|0;O()|0}vb(c+16|0);break c}d=0;if(!f){break e}e=v[f+4>>2];if(!e){break e}v[22640]=0;a=W(e|0,f|0,b|0,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){d=(a|0)!=0;break e}d=P()|0;O()|0;break d}vb(c+48|0);gb=c- -64|0;break b}vb(c+48|0)}S(d|0);L()}gb=i+16|0;return d|0}function Yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];l=v[a+44>>2];v[b+32>>2]=l;j=v[a+48>>2];v[b+36>>2]=j;k=v[a+52>>2];v[b+40>>2]=k;i=v[a+56>>2];v[b+44>>2]=i;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];h=v[a>>2];v[b+24>>2]=h;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){j=h>>>18|0;l=1;e=((((e&2147483647)<<1|h>>>31)&2147483646)<<1)+q|0;g=0;k=1;f=0;while(1){i=f<<1;h=u[i+e>>1];v[(b+8|0)+(f<<2)>>2]=h+((B(j,u[e+(i|4)>>1]-h|0)|0)/16384|0);h=k&1;k=0;f=1;if(h){continue}break}while(1){k=(b+8|0)+(g<<2)|0;f=v[k>>2];j=v[a+60>>2];i=j;h=(b+32|0)+(g<<3)|0;p=v[h>>2];e=Lb(p,-16777216,16776704);o=v[a+64>>2];g=Lb(v[h+4>>2],-16777216,16776704);r=j>>31;j=f<<8;f=j;f=mqa(i,r,f,f>>31);i=jb;o=mqa(o,o>>31,e,e>>31);f=o+f|0;e=jb+i|0;e=f>>>0<o>>>0?e+1|0:e;i=f;f=v[a+68>>2];f=mqa(f,f>>31,g,g>>31);g=i+f|0;e=jb+e|0;e=f>>>0>g>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=Ic(g,e,24);v[h+4>>2]=p;g=v[a+72>>2];v[k>>2]=(e|0)/256;v[h>>2]=e-(g&j);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;g=m>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;h=v[b+24>>2];e=v[b+28>>2];continue}break}h=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];k=v[b+40>>2];j=v[b+36>>2];l=v[b+32>>2];break a}g=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=i;v[a+52>>2]=k;v[a+48>>2]=j;v[a+44>>2]=l;v[a+24>>2]=g;v[a>>2]=h;v[a+4>>2]=e;gb=b+48|0}function Rga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-48|0;gb=e;td(b,2);Gk(e+16|0,2,a+1|0);Bc(e+32|0,e+16|0);v[22640]=0;Q(335,b+43|0,e+32|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){vb(e+32|0);a:{if(!(w[a|0]?w[a|0]!=1:0)){if(w[a|0]==1){d=a+16|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+16>>2]=v[b>>2]-1;g=b,h=v[Fb(e+32|0,e+16|0)>>2],v[g+4>>2]=h;d=a+24|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);g=b,h=v[Fb(e+32|0,b)>>2],v[g+8>>2]=h;u[b+34>>1]=x[b+34>>1]&65533|w[a+31|0]<<1&2}d=v[b+8>>2];if(d>>>0>y[b+4>>2]?d>>>0>=2:0){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}if(w[a|0]!=2){break a}ti(e+16|0,a+16|0);d=e+32|0;f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;ti(e+16|0,a+20|0);d=e+32|0;f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d+4|0]=f;t[d+5|0]=f>>>8;t[d+6|0]=f>>>16;t[d+7|0]=f>>>24;ti(e+16|0,a+24|0);d=e+32|0;f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d+8|0]=f;t[d+9|0]=f>>>8;t[d+10|0]=f>>>16;t[d+11|0]=f>>>24;v[e+8>>2]=v[e+40>>2];d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;Po(b,1,e)}t[e+32|0]=w[a+28|0];t[e+16|0]=64;g=b,h=w[ac(e+32|0,e+16|0)|0]<<2,u[g+30>>1]=h;a=a+32|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=c?a&65535:a;v[b+24>>2]=a;b:{c:{if(!a){c=8363;break c}c=1024;if(a>>>0>1023){break b}}v[b+24>>2]=c}gb=e+48|0;return}a=P()|0;O()|0;vb(e+32|0);S(a|0);L()}function Zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;r=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;l=v[a+48>>2];v[b+36>>2]=l;k=v[a+52>>2];v[b+40>>2]=k;h=v[a+56>>2];v[b+44>>2]=h;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){j=i>>>10&4194048;e=(((e&2147483647)<<1|i>>>31)&-2)+r|0;g=0;l=1;k=1;f=0;while(1){i=t[e+f|0];v[(b+8|0)+(f<<2)>>2]=((B(j,t[e+(f|2)|0]-i|0)|0)/16384|0)+(i<<8);i=k&1;k=0;f=1;if(i){continue}break}while(1){k=(b+8|0)+(g<<2)|0;j=v[k>>2];h=v[a+60>>2];o=h;i=(b+32|0)+(g<<3)|0;q=v[i>>2];e=Lb(q,-16777216,16776704);g=v[a+64>>2];f=Lb(v[i+4>>2],-16777216,16776704);p=h>>31;j=j<<8;h=j;h=mqa(o,p,h,h>>31);o=jb;p=h;h=mqa(g,g>>31,e,e>>31);g=p+h|0;e=jb+o|0;e=g>>>0<h>>>0?e+1|0:e;h=g;g=v[a+68>>2];g=mqa(g,g>>31,f,f>>31);f=h+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Ic(f,e,24);v[i+4>>2]=q;f=v[a+72>>2];v[k>>2]=(e|0)/256;v[i>>2]=e-(f&j);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;g=n>>12;v[c>>2]=v[c>>2]+B(g,v[b+8>>2]);m=e+m|0;f=m>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];e=v[b+28>>2];h=v[b+44>>2];k=v[b+40>>2];l=v[b+36>>2];j=v[b+32>>2];break a}f=m>>12;g=n>>12}v[a+40>>2]=m;v[a+20>>2]=g;v[a+36>>2]=n;v[a+56>>2]=h;v[a+52>>2]=k;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=f;v[a>>2]=i;v[a+4>>2]=e;gb=b+48|0}function Wz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;h=89;i=92;j=91;k=85;l=84;m=83;n=5;o=111;p=107;q=106;r=96;c=88;s=82;t=80;u=78;v=79;w=77;x=57;y=47;d=10;e=8;f=7;a=bA(a);a:{b:{c:{d:{switch(b-1|0){default:c=(b|0)==16777216;if(!((b|0)!=32?c:1)){break c}Ob(a,0,1);Ob(a,7,1);Ob(a,8,1);Ob(a,9,1);Ob(a,10,1);Ob(a,11,1);Ob(a,12,1);Ob(a,13,1);Ob(a,14,1);Ob(a,15,1);Ob(a,16,1);Ob(a,17,1);Ob(a,18,1);Ob(a,19,1);Ob(a,20,1);Ob(a,21,1);Ob(a,22,1);Ob(a,23,1);Ob(a,24,1);Ob(a,25,1);Ob(a,26,1);Ob(a,27,1);Ob(a,28,1);Ob(a,29,1);Ob(a,30,1);Ob(a,31,1);Ob(a,32,1);Ob(a,33,1);Ob(a,34,1);Ob(a,35,1);Ob(a,36,1);Ob(a,37,1);Ob(a,38,1);Ob(a,39,1);Ob(a,40,1);Ob(a,41,1);Ob(a,42,1);Ob(a,43,1);Ob(a,44,1);Ob(a,45,1);Ob(a,46,1);Ob(a,47,1);Ob(a,48,1);Ob(a,103,1);Ob(a,50,1);Ob(a,87,1);Ob(a,88,1);Ob(a,100,1);Ob(a,102,1);Ob(a,104,1);if(!c){break a}d=111;e=105;f=99;break b;case 3:Ob(a,0,1);Ob(a,4,1);Ob(a,8,1);Ob(a,9,1);Ob(a,10,1);Ob(a,17,1);Ob(a,40,1);Ob(a,51,1);Ob(a,52,1);Ob(a,53,1);Ob(a,54,1);Ob(a,55,1);Ob(a,56,1);Ob(a,57,1);Ob(a,58,1);Ob(a,59,1);Ob(a,60,1);Ob(a,61,1);Ob(a,62,1);Ob(a,63,1);Ob(a,64,1);Ob(a,65,1);Ob(a,66,1);Ob(a,67,1);Ob(a,68,1);o=112;p=98;q=93;r=90;c=89;s=88;t=86;u=76;v=75;w=74;x=73;y=72;d=71;e=70;g=69;case 1:Ob(a,g,1);Ob(a,e,1);Ob(a,d,1);Ob(a,y,1);Ob(a,x,1);Ob(a,w,1);Ob(a,v,1);n=u;m=t;l=s;k=c;j=r;i=q;c=p;h=o;break;case 2:break c;case 0:break d}}Ob(a,n,1);Ob(a,m,1);Ob(a,l,1);Ob(a,k,1);g=j;f=i;e=c;d=h}Ob(a,g,1)}Ob(a,f,1);Ob(a,e,1);Ob(a,d,1)}}function ffa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-112|0;gb=c;Sm(c+88|0,b,1413829443);v[22640]=0;b=T(307,c+88|0)|0;d=v[22640];v[22640]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){v[22640]=0;U(1436,c- -64|0,a+140|0,1413894985);a=v[22640];v[22640]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){v[22640]=0;a=Q(1441,c- -64|0,11011)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}b=28591;if(a){b=Kb(c+48|0);v[22640]=0;a=T(492,c- -64|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break m}v[22640]=0;W(441,c- -64|0,b|0,a|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break m}v[22640]=0;d=Q(111,c+16|0,b|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break l}v[22640]=0;_(1442,c|0);a=v[22640];v[22640]=0;if((a|0)==1){break k}v[22640]=0;U(1443,c+32|0,d|0,c|0);a=v[22640];v[22640]=0;if((a|0)==1){break j}Eb(b,c+32|0);vb(c+32|0);vb(c);vb(d);v[22640]=0;U(13,c+32|0,2,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break h}v[22640]=0;a=T(981,c+32|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break g}vb(c+32|0);vb(b);b=a-1>>>0<19398657?1252:28591}yb(c- -64|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;vb(c)}vb(d);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c+32|0)}vb(b);break d}a=P()|0;O()|0}yb(c- -64|0);break b}v[22640]=0;a=Q(228,c+88|0,2)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}b=28591;if(!a){break a}v[22640]=0;b=T(319,c+88|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0}yb(c+88|0);S(a|0);L()}yb(c+88|0);gb=c+112|0;return b|0}function Mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];b=v[a+44>>2];v[e+32>>2]=b;g=v[a+48>>2];v[e+36>>2]=g;f=v[a+52>>2];v[e+40>>2]=f;l=v[a+56>>2];v[e+44>>2]=l;p=v[a+24>>2];q=v[a+20>>2];h=v[a+4>>2];k=v[a>>2];v[e+24>>2]=k;v[e+28>>2]=h;i=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=i;if(d){while(1){l=1;i=((((h&2147483647)<<1|k>>>31)&2147483646)<<1)+o|0;b=k>>>21&2040;k=u[b+46534>>1];j=u[b+46532>>1];m=u[b+46530>>1];n=u[b+46528>>1];f=0;b=1;g=0;while(1){h=g<<1;v[(e+8|0)+(g<<2)>>2]=(((B(u[h+i>>1],m)+B(u[i+(h|-4)>>1],n)|0)+B(u[i+(h|4)>>1],j)|0)+B(k,u[i+(h|8)>>1])|0)/16384;h=b;b=0;g=1;if(h){continue}break}while(1){k=(e+8|0)+(f<<2)|0;i=v[k>>2];j=v[a+60>>2];m=j;h=(e+32|0)+(f<<3)|0;n=v[h>>2];b=Lb(n,-16777216,16776704);f=v[a+64>>2];g=Lb(v[h+4>>2],-16777216,16776704);j=j>>31;i=i<<8;j=mqa(m,j,i,i>>31);m=jb;r=j;j=mqa(f,f>>31,b,b>>31);f=r+j|0;b=jb+m|0;b=f>>>0<j>>>0?b+1|0:b;j=f;f=v[a+68>>2];f=mqa(f,f>>31,g,g>>31);g=j+f|0;b=jb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Ic(g,b,24);v[h+4>>2]=n;g=v[a+72>>2];v[k>>2]=(b|0)/256;v[h>>2]=b-(g&i);f=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=v[e+24>>2];h=v[e+28>>2];continue}break}k=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];f=v[e+40>>2];g=v[e+36>>2];b=v[e+32>>2]}v[a+56>>2]=l;v[a+52>>2]=f;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=k;v[a+4>>2]=h;gb=e+48|0}function A3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-384|0;gb=a;v[a+368>>2]=c;v[a+376>>2]=b;ix(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Kb(a+200|0);b=Kc(d);v[22640]=0;R(118,d|0,b|0);b=v[22640];v[22640]=0;a:{b:{c:{if((b|0)!=1){c=mc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;b=v[a+232>>2];h=v[a+236>>2];while(1){d:{v[22640]=0;g=Q(2463,a+376|0,a+368|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+196>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+196>>2]=g+c}v[22640]=0;g=T(2465,a+376|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(hx(g,a+23|0,a+22|0,c,a+196|0,h,b,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[22640]=0;T(2467,a+376|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[22640]=0;Y(2453,a|0,c|0,v[a+196>>2],e|0);b=v[22640];v[22640]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];h=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=h;v[f+8>>2]=b;v[f+12>>2]=c;gf(a+216|0,a+32|0,v[a+28>>2],e);v[22640]=0;b=Q(2464,a+376|0,a+368|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];vb(d);vb(a+216|0);gb=a+384|0;break a}}b=P()|0;O()|0;vb(d);vb(a+216|0);S(b|0);L()}return b|0}function N3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-288|0;gb=a;v[a+272>>2]=c;v[a+280>>2]=b;lx(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Kb(a+208|0);b=Kc(d);v[22640]=0;R(118,d|0,b|0);b=v[22640];v[22640]=0;a:{b:{c:{if((b|0)!=1){c=mc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;b=t[a+238|0];h=t[a+239|0];while(1){d:{v[22640]=0;g=Q(2436,a+280|0,a+272|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+204>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+204>>2]=g+c}v[22640]=0;g=T(2438,a+280|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(kx(g,a+23|0,a+22|0,c,a+204|0,h,b,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[22640]=0;T(2440,a+280|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[22640]=0;Y(2453,a|0,c|0,v[a+204>>2],e|0);b=v[22640];v[22640]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];h=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=h;v[f+8>>2]=b;v[f+12>>2]=c;gf(a+224|0,a+32|0,v[a+28>>2],e);v[22640]=0;b=Q(2437,a+280|0,a+272|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];vb(d);vb(a+224|0);gb=a+288|0;break a}}b=P()|0;O()|0;vb(d);vb(a+224|0);S(b|0);L()}return b|0}function lP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=gb-16|0;gb=f;a:{if((b|0)==(c|0)){break a}v[f+12>>2]=-1953789045;Zz(b,c,f+12|0);c=c-b>>2;v[f+8>>2]=c;e=1;j=Nb(a);h=j+1|0;v[f+4>>2]=h;k=v[Jc(f+4|0,f+8|0)>>2];g=v[((v[f+8>>2]<<2)+b|0)-4>>2];i=c;d=11;b:{if(c>>>0>622){break b}d=7;if(c>>>0>67){break b}d=5;if(c>>>0>38){break b}d=3;if(c>>>0>6){break b}d=c-1>>>1|0}l=i-d>>>1|0;c=(l<<2)+b|0;i=B(_t(g^(v[c>>2]^v[b>>2])),1664525);v[c>>2]=i+v[c>>2];m=d+l|0;c=(m<<2)+b|0;d=c;g=v[c>>2];c=j+i|0;v[d>>2]=g+c;v[b>>2]=c;c=v[f+8>>2];if(j){while(1){g=e-1|0;d=((e+l>>>0)%(c>>>0)<<2)+b|0;n=(e>>>0)%(c>>>0)|0;o=(n<<2)+b|0;i=B(_t(v[((g>>>0)%(c>>>0)<<2)+b>>2]^(v[d>>2]^v[o>>2])),1664525);v[d>>2]=i+v[d>>2];d=Mb(a,g);c=v[f+8>>2];g=((e+m>>>0)%(c>>>0)<<2)+b|0;d=v[d>>2]+(i+n|0)|0;v[g>>2]=d+v[g>>2];v[o>>2]=d;e=e+1|0;if(j>>>0>=e>>>0){continue}break}}if(h>>>0<k>>>0){while(1){a=((h+l>>>0)%(c>>>0)<<2)+b|0;d=(h>>>0)%(c>>>0)|0;j=(d<<2)+b|0;e=B(_t(v[((h-1>>>0)%(c>>>0)<<2)+b>>2]^(v[a>>2]^v[j>>2])),1664525);v[a>>2]=e+v[a>>2];c=v[f+8>>2];a=((h+m>>>0)%(c>>>0)<<2)+b|0;i=a;g=v[a>>2];a=e+d|0;v[i>>2]=g+a;v[j>>2]=a;h=h+1|0;if((k|0)!=(h|0)){continue}break}}if(c+k>>>0<=k>>>0){break a}e=k;while(1){a=((e+l>>>0)%(c>>>0)<<2)+b|0;d=(e>>>0)%(c>>>0)|0;j=(d<<2)+b|0;h=B(_t(v[((e-1>>>0)%(c>>>0)<<2)+b>>2]+(v[a>>2]+v[j>>2]|0)|0),1566083941);v[a>>2]=h^v[a>>2];c=v[f+8>>2];a=((e+m>>>0)%(c>>>0)<<2)+b|0;i=a;g=v[a>>2];a=h-d|0;v[i>>2]=g^a;v[j>>2]=a;e=e+1|0;if(e>>>0<c+k>>>0){continue}break}}gb=f+16|0}function Fz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=gb-16|0;gb=j;k=j;a:{if(!Hj(c)){h=b;i=v[c+704>>2];g=gb-16|0;gb=g;v[g+12>>2]=d;f=0;b:{if(!d){break b}if(v[h+480180>>2]&20){e=h+1074312|0;Db(g,e,73);if(Cb(g)){d=d&65535;v[g+12>>2]=d}if(w[h+480208|0]&16){Db(g,e,73);e=Cb(g)?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;f=v[((d>>>0)%768<<2)+40752>>2]<<6>>>e|0;break b}if(!d){v[g+12>>2]=1;d=1}f=229079296/(d>>>0)|0;break b}f=227001280/(d>>>0)|0;if(fp(h)){break b}f=(d+i<<4)-133808|0;if(v[h+480180>>2]==64){break b}d=v[h+480180>>2];tc(g+12|0,16777215);if(d&17408){f=Uc(pqa(mqa(i?i:8363,0,3506176,0),jb,(v[g+12>>2]<<8)+e|0,0),jb);break b}if(qk(h)){f=e>>31;d=v[g+12>>2];h=d>>>24|0;i=d<<8;e=i+e|0;d=h+f|0;d=e>>>0<i>>>0?d+1|0:d;f=(d&15)<<28|e>>>4;break b}if(w[h+480208|0]&16){f=Uc(pqa(mqa(i?i:8363,0,7012352,0),jb,(v[g+12>>2]<<8)+e|0,0),jb);break b}f=Uc(pqa(-1485242368,13,(v[g+12>>2]<<8)+e|0,0),jb)}gb=g+16|0;e=f;break a}e=v[c+700>>2]}v[k+12>>2]=e;d=v[c+656>>2];c=u[c+774>>1];c:{if(!c){break c}c=d?B(t[d+33|0],c):c;if(!c){break c}e=xh(Ag(+(c|0)*25431315104166665e-22)*+(e>>>0));v[j+12>>2]=e}d:{if(!d){break d}c=v[d+40>>2];if(!c){break d}d=(c|0)/2|0;f=v[b+1074420>>2];f=mqa(f,f>>31,e,e>>31);e=d+f|0;d=jb+(d>>31)|0;l=j,m=zc(nqa(e,e>>>0<f>>>0?d+1|0:d,c,c>>31),jb),v[l+12>>2]=m}tc(j+12|0,2147483647);c=j;l=c,m=nqa(0,v[c+12>>2],v[b+24620>>2]<<4,0),v[l>>2]=m;v[c+4>>2]=jb;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;v[a+8>>2]=v[c+12>>2];gb=c+16|0}function Nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;b=v[a+48>>2];v[e+36>>2]=b;g=v[a+52>>2];v[e+40>>2]=g;l=v[a+56>>2];v[e+44>>2]=l;p=v[a+24>>2];q=v[a+20>>2];j=v[a+4>>2];k=v[a>>2];v[e+24>>2]=k;v[e+28>>2]=j;h=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=h;if(d){while(1){h=(((j&2147483647)<<1|k>>>31)&-2)+o|0;b=k>>>21&2040;k=u[b+46534>>1];i=u[b+46532>>1];m=u[b+46530>>1];n=u[b+46528>>1];g=0;l=1;b=1;f=0;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+h|0],m)+B(t[h+(f|-2)|0],n)|0)+B(t[h+(f|2)|0],i)|0)+B(k,t[h+(f|4)|0])<<8)/16384;j=b;b=0;f=1;if(j){continue}break}while(1){k=(e+8|0)+(g<<2)|0;h=v[k>>2];i=v[a+60>>2];m=i;j=(e+32|0)+(g<<3)|0;n=v[j>>2];b=Lb(n,-16777216,16776704);g=v[a+64>>2];f=Lb(v[j+4>>2],-16777216,16776704);i=i>>31;h=h<<8;i=mqa(m,i,h,h>>31);m=jb;r=i;i=mqa(g,g>>31,b,b>>31);g=r+i|0;b=jb+m|0;b=g>>>0<i>>>0?b+1|0:b;i=g;g=v[a+68>>2];g=mqa(g,g>>31,f,f>>31);f=i+g|0;b=jb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=Ic(f,b,24);v[j+4>>2]=n;f=v[a+72>>2];v[k>>2]=(b|0)/256;v[j>>2]=b-(f&h);g=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;k=v[e+24>>2];j=v[e+28>>2];continue}break}k=v[e+24>>2];j=v[e+28>>2];l=v[e+44>>2];g=v[e+40>>2];f=v[e+32>>2];b=v[e+36>>2]}v[a+56>>2]=l;v[a+52>>2]=g;v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=k;v[a+4>>2]=j;gb=e+48|0}function tO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=gb-16|0;gb=c;d=B(b,872)+a|0;a:{if(v[d+1075080>>2]&134218752){break a}if(!rk(d+1074992|0)){break a}h=v[(B(b,872)+a|0)+1075648>>2];if(w[h+15|0]&2){break a}d=Im(a,b,2,1);if(d-251>>>0<5|!d){break a}g=v[(B(d,160)+a|0)+906140>>2];if(!g){break a}e=B(b,872)+a|0;d=w[e+1075780|0];b:{if(w[e+1075782|0]==1){t[c+8|0]=64;f=w[ac(e+1075784|0,c+8|0)|0];break b}f=255;if(w[e+1075783|0]!=13){break b}t[c+8|0]=64;f=w[ac((B(b,872)+a|0)+1075785|0,c+8|0)|0]}j=a+1074312|0;Db(c+8|0,j,2);if(Cb(c+8|0)){if(d){e=a;f=b;if(ve(d)){d=w[lc(h+108|0,d-1|0)|0]}Jm(e,f,d,x[(B(b,872)+a|0)+1075680>>1]);break a}if((f|0)==255){break a}kb[v[v[g>>2]+76>>2]](g,39,f,b);break a}k=v[h+4>>2];if(d){e=k<<2;v[c+4>>2]=e;if(!w[h+35|0]){e=v[(B(b,872)+a|0)+1075680>>2];v[c+4>>2]=e}i=u[(B(b,872)+a|0)+1075768>>1];Db(c+8|0,j,28);l=c,m=(Cb(c+8|0)?i<<2:i)+e|0,v[l+4>>2]=m;Qd(c+4|0,0,256);e=d;i=b;if(ve(d)){e=w[lc(h+108|0,d-1|0)|0]}Jm(a,i,e&255,x[c+4>>1])}e=w[h+35|0];Db(c+8|0,j,101);i=(f|0)!=255;if(Cb(c+8|0)){a=(d|0)!=0}else{a=ve(d)}if(!(!a|(e|0)!=1?a?0:i:1)){break a}c:{switch(w[h+36|0]){case 1:if((f|0)!=255){IM(g,f<<1);break a}IM(g,k<<1);break a;case 0:break c;default:break a}}if((f|0)!=255){t[c+8|0]=127;t[c+4|0]=f<<1;m=g,n=7,o=w[ac(c+8|0,c+4|0)|0],p=b,l=v[v[g>>2]+76>>2],kb[l](m|0,n|0,o|0,p|0);break a}v[c+8>>2]=127;v[c+4>>2]=k<<1;p=g,o=7,n=w[Fb(c+8|0,c+4|0)|0],m=b,l=v[v[g>>2]+76>>2],kb[l](p|0,o|0,n|0,m|0)}gb=c+16|0}function Sha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;m=v[a+16>>2];h=Sd(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];q=h,r=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[h+16>>2];if(b){q=h,r=gg(a+8|0,b),v[q>>2]=r;v[h+4>>2]=jb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];g=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=g;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(!d){e=k;k=i;break a}while(1){e=0;v[f+40>>2]=j;v[f+44>>2]=e;g=(g<<1)+m|0;b:{if((b|0)<=0){break b}while(1){Id(v[h+8>>2],u[(e<<1)+g>>1]/4<<16>>16);Hd(v[h+8>>2],4);Ub(f+40|0,h);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Id(b,u[g+(v[f+44>>2]<<1)>>1]/4<<16>>16);Hd(v[h+8>>2],e);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=dg(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=Lb(k,-16777216,16776704);l=v[a+64>>2];i=Lb(i,-16777216,16776704);p=g>>31;g=e<<8;e=g;e=mqa(j,p,e,e>>31);j=jb;l=mqa(l,l>>31,b,b>>31);e=l+e|0;b=jb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=mqa(e,e>>31,i,i>>31);i=j+e|0;b=jb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=Ic(i,b,24);i=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=b-(g&i)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[h+16>>2];j=v[f+8>>2];g=v[f+12>>2];i=k;k=e;continue}break}j=v[f+8>>2];g=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function Koa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=gb-32|0;gb=f;t[f+24|0]=44;v[f+16>>2]=-1;v[f+20>>2]=0;v[f+8>>2]=1042;v[f+12>>2]=2;n=a;o=b;c=gb+-64|0;gb=c;p=c;j=f+8|0;b=v[j>>2]&2?16:10;g=gb-32|0;gb=g;d=Ge(g+16|0,1,0);a:{b:{c:{while(1){i=g+8|0;k=Jb(d);l=Jb(d)+Ab(d)|0;h=x[o>>1];e=b;d:{if((e|0)!=10){a=l;while(1){e:{if((a|0)==(k|0)){a=k;break e}m=h&65535;h=(m|0)/(e|0)|0;a=a-1|0;t[a|0]=w[(m-B(e,h)|0)+1991|0];if(h&65535){continue}}break}f:{if(!(h&65535)){e=l-a|0;if(e){break f}}v[i+4>>2]=61;v[i>>2]=l;break d}a=sh(k,a,e);v[i+4>>2]=0;v[i>>2]=a+e;break d}Ey(i,k,l,h)}if(!v[g+12>>2]){break c}a=Ab(d);v[22640]=0;v[g+4>>2]=a;e=wf(g+4|0);a=v[22640];v[22640]=0;if((a|0)!=1){v[22640]=0;U(117,d|0,e|0,0);a=v[22640];v[22640]=0;if((a|0)!=1){continue}}break}break b}b=v[g+8>>2];a=Jb(d);v[22640]=0;R(118,d|0,b-a|0);a=v[22640];v[22640]=0;g:{if((a|0)!=1){v[22640]=0;R(128,p|0,d|0);a=v[22640];v[22640]=0;if((a|0)!=1){break g}break b}break b}vb(d);gb=g+32|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}Al(c+16|0,c,j);v[22640]=0;U(135,c+32|0,c+16|0,j|0);a=v[22640];v[22640]=0;h:{i:{j:{k:{l:{if((a|0)!=1){v[22640]=0;U(136,c+48|0,c+32|0,j|0);a=v[22640];v[22640]=0;if((a|0)==1){break l}v[22640]=0;R(127,n|0,c+48|0);a=v[22640];v[22640]=0;if((a|0)==1){break k}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);gb=c- -64|0;break h}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}gb=f+32|0}function sM(a){var b=C(0),c=0,d=C(0),e=0,f=C(0),g=0,h=C(0),i=C(0),k=C(0),m=0,n=C(0),o=0,r=C(0);e=gb-16|0;gb=e;c=uf(v[a+16>>2]);o=a,r=me(C(10),C(C(C(z[a+4208>>2]*C(120))+C(-60))*C(.05000000074505806))),z[o+4232>>2]=r;f=C(C(c>>>0)*C(.0010000000474974513));o=a,r=me(C(10),C(C(-1)/C(C(C(z[a+4212>>2]*C(499.989990234375))+C(.009999999776482582))*f))),z[o+4236>>2]=r;o=a,r=me(C(10),C(C(-1)/C(C(C(z[a+4216>>2]*C(2950))+C(50))*f))),z[o+4240>>2]=r;v[e+12>>2]=1325400064;g=e;b=C(me(C(10),C(C(C(z[a+4220>>2]*C(60))+C(-60))*C(.05000000074505806)))*C(2147483648));c=(p(b),j(2));a:{b:{c:{if(!((c|0)>-1?c>>>0>=8388608:0)){d=C(C(-1)/C(b*b));if(!(c&2147483647)){break a}d=C(C(b-b)/C(0));if((c|0)<=-1){break a}c=(p(C(b*C(33554432))),j(2));m=-152;break c}if(c>>>0>2139095039){break b}m=-127;b=C(0);if((c|0)==1065353216){break b}}c=c+4913933|0;n=C((c>>>23|0)+m|0);b=C((l(2,(c&8388607)+1060439283|0),q())+C(-1));h=C(b/C(b+C(2)));i=C(h*h);k=C(i*i);d=b;b=C(b*C(b*C(.5)));b=C(C(n*C(.6931381225585938))+C(d+C(C(C(n*C(905800061445916e-20))+C(h*C(b+C(C(i*C(C(k*C(.2849878668785095))+C(.6666666269302368)))+C(k*C(C(k*C(.24279078841209412))+C(.40000972151756287)))))))-b)))}d=b}z[g+8>>2]=C(d*C(96817624))+C(67108864);o=a,r=C(z[Cm(e+12|0,e+8|0)>>2]*C(4.656612873077393e-10)),z[o+4244>>2]=r;z[a+4248>>2]=C(C(-1)/C(C(z[a+4224>>2]*C(99))+C(1)))+C(1);g=a;b=C(C(C(z[a+4228>>2]*C(4))*f)+C(2));d:{if(C(D(b))<C(2147483648)){a=~~b;break d}a=-2147483648}v[g+4252>>2]=a;gb=e+16|0}function mla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+56;a=c;d=v[a+4>>2];v[22640]=0;R(885,d|0,b|0);b=v[22640];v[22640]=0;a:{if((b|0)!=1){v[a+4>>2]=v[a+4>>2]+56;$b(a);gb=c+16|0;break a}b=P()|0;O()|0;$b(a);S(b|0);L()}return}l=gb-32|0;gb=l;j=a;e=wb(a);f=l+8|0;g=a;d=dr(a)+1|0;h=gb-16|0;gb=h;v[h+12>>2]=d;i=gb-16|0;gb=i;v[i+12>>2]=76695844;v[22640]=0;v[i+8>>2]=2147483647;k=Fb(i+12|0,i+8|0);c=v[22640];v[22640]=0;b:{if((c|0)!=1){gb=i+16|0;c=v[k>>2];break b}V(0)|0;O()|0;Bb();L()}c:{if(c>>>0>=d>>>0){d=DU(g);if(d>>>0<c>>>1>>>0){v[h+8>>2]=d<<1;c=v[Jc(h+8|0,h+12|0)>>2]}gb=h+16|0;break c}Rc();L()}d=dr(a);a=0;g=gb-16|0;gb=g;v[g+12>>2]=0;ef(f+12|0,e);if(c){a=c;if(a>>>0>=76695845){nd(8513);L()}a=Mc(B(a,56),4)}v[f>>2]=a;d=B(d,56)+a|0;v[f+8>>2]=d;v[f+4>>2]=d;m=cc(f),n=B(c,56)+a|0,v[m>>2]=n;gb=g+16|0;a=f;c=v[a+8>>2];v[22640]=0;R(885,c|0,b|0);b=v[22640];v[22640]=0;d:{if((b|0)!=1){v[a+8>>2]=v[a+8>>2]+56;b=a;f=a+4|0;k=f;c=v[j+4>>2];g=v[j>>2];if((c|0)!=(g|0)){d=v[k>>2];while(1){e=d-56|0;c=c-56|0;FB(e,c);FB(e+12|0,c+12|0);EB(e+24|0,c+24|0);u[e+52>>1]=x[c+52>>1];d=v[c+48>>2];v[e+44>>2]=v[c+44>>2];v[e+48>>2]=d;d=v[c+40>>2];v[e+36>>2]=v[c+36>>2];v[e+40>>2]=d;d=v[k>>2]-56|0;v[k>>2]=d;if((c|0)!=(g|0)){continue}break}}wc(j,f);wc(j+4|0,b+8|0);wc(wb(j),cc(b));v[b>>2]=v[b+4>>2];BU(a);gb=l+32|0;break d}b=P()|0;O()|0;BU(a);S(b|0);L()}}function Qma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){f=(d<<2)+a|0;i=w[f+4|0];j=lc(h,d),k=i+1|0,t[j|0]=k;f=f+6|0;f=w[f|0]|w[f+1|0]<<8;j=sd(g,d),k=f+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=120){continue}break}break a}g=b+236|0;while(1){h=((d<<2)+a|0)+6|0;h=w[h|0]|w[h+1|0]<<8;j=sd(g,d+12|0),k=h+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=96){continue}break}}VB(a+484|0,b+48|0,0);VB(a+590|0,b+68|0,0);VB(a+696|0,b+88|0,5);d=a+806|0;v[b>>2]=w[d|0]|w[d+1|0]<<8;d=a+808|0;g=w[d|0];b:{if(t[d|0]<=-1){t[b+34|0]=g-127;break b}if(!(!(t[a|0]&1)|g>>>0>16)){t[b+31|0]=w[d|0]+1;break b}if(!w[d|0]|w[d|0]>16){break b}t[b+31|0]=w[d|0]+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=a+809|0;if(t[d|0]>=0){u[b+28>>1]=w[d|0]+1}d=a+810|0;if(t[d|0]<0){break c}}t[b+30|0]=w[d|0]+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;j=b,k=w[ac(e+15|0,e+14|0)|0]>>>1|0,v[j+4>>2]=k}c=a+813|0;if((w[c|0]|w[c+1|0]<<8)>>>0<=256){v[b+8>>2]=w[c|0]|w[c+1|0]<<8;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];c=a+820|0;u[e+12>>1]=w[c|0]|w[c+1|0]<<8;u[e+10>>1]=100;j=b,k=w[Oc(e+12|0,e+10|0)|0],t[j+20|0]=k;c=a+822|0;u[e+8>>1]=w[c|0]|w[c+1|0]<<8;u[e+6>>1]=256;j=b,k=x[Oc(e+8|0,e+6|0)>>1]>>>2|0,t[j+19|0]=k;c=a+824|0;fm(b,w[c|0]&127,w[c|0]>>>7|0);a=a+825|0;em(b,w[a|0]&127,w[a|0]>>>7|0);gb=e+16|0}function zJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=gb-16|0;gb=i;a:{b:{c:{g=(b|0)>=0;f=a+8|0;d:{if(xl(f)){f=xl(f);break d}f=gq(f)}if(!((f|0)>(b|0)?g:0)){c=aa(8)|0;v[22640]=0;b=Q(112,i|0,3092)|0;a=v[22640];v[22640]=0;if((a|0)==1){break c}qc(c,b);v[22640]=0;U(223,c|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);break b}if(c>>>0>=120){c=aa(8)|0;v[22640]=0;b=Q(112,i|0,8658)|0;a=v[22640];v[22640]=0;if((a|0)!=1){qc(c,b);v[22640]=0;U(223,c|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);break b}a=P()|0;O()|0;da(c|0);break b}h=a+32|0;a=gA(v[h>>2],65535);j=(a|0)==65535?255:a;u[i>>1]=j;f=v[h>>2]+B(j,872)|0;g=f+1074992|0;$m(g,7,v[h>>2],65535,1024);a=c+1|0;t[f+1075794|0]=a;t[f+1075791|0]=a;u[f+1075778>>1]=0;Km(g);Do(v[h>>2],g,b+1|0,0,1,1);v[f+1075688>>2]=65536;ku(v[h>>2],g,a,0,1,1,65535);m=f+1075684|0,n=Oo(qA(e*128,-128,128)+128),v[m>>2]=n;m=f+1075680|0,n=Oo(qA(d*256,0,256)),v[m>>2]=n;a=v[h>>2]+1074478|0;k=a;f=(x[v[h>>2]+480212>>1]<<1)+a|0;l=f;g=i;c=i;b=f;e:{if((b|0)==(a|0)){break e}c=x[c>>1];while(1){if((c|0)==x[a>>1]){break e}a=a+2|0;if((b|0)!=(a|0)){continue}break}a=b}b=a;f:{if((l|0)==(a|0)){break f}c=b+2|0;if((f|0)==(c|0)){break f}while(1){if(x[c>>1]!=x[g>>1]){u[b>>1]=x[c>>1];b=b+2|0}c=c+2|0;if((f|0)!=(c|0)){continue}break}}a=ar(k,b);u[v[h>>2]+480212>>1]=a;gb=i+16|0;return j|0}a=P()|0;O()|0;da(c|0)}S(a|0)}L()}function Tha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=gb-48|0;gb=f;m=v[a+16>>2];h=Sd(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];q=h,r=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[q+12>>2]=r;b=v[h+16>>2];if(b){q=h,r=gg(a+8|0,b),v[q>>2]=r;v[h+4>>2]=jb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];g=v[a+4>>2];j=v[a>>2];v[f+8>>2]=j;v[f+12>>2]=g;e=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=e;a:{if(!d){e=k;k=i;break a}while(1){e=0;v[f+40>>2]=j;v[f+44>>2]=e;g=g+m|0;b:{if((b|0)<=0){break b}while(1){Id(v[h+8>>2],t[e+g|0]<<6);Hd(v[h+8>>2],4);Ub(f+40|0,h);if((b|0)<2){break b}b=b-1|0;e=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Ub(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Id(b,t[g+v[f+44>>2]|0]<<6);Hd(v[h+8>>2],e);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=dg(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=Lb(k,-16777216,16776704);l=v[a+64>>2];i=Lb(i,-16777216,16776704);p=g>>31;g=e<<8;e=g;e=mqa(j,p,e,e>>31);j=jb;l=mqa(l,l>>31,b,b>>31);e=l+e|0;b=jb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=mqa(e,e>>31,i,i>>31);i=j+e|0;b=jb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=Ic(i,b,24);i=v[a+72>>2];e=(b|0)/256|0;v[c>>2]=v[c>>2]+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=b-(g&i)|0;Ub(f+8|0,f);if(d){c=c+8|0;b=v[h+16>>2];j=v[f+8>>2];g=v[f+12>>2];i=k;k=e;continue}break}j=v[f+8>>2];g=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=g;gb=f+48|0}function dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];r=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=(g<<1)+r|0;n=u[e-6>>1];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];o=u[e-4>>1];p=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=Lb(m,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=mqa(j,j>>31,e,e>>31);j=jb;I=e;e=v[a+68>>2];q=mqa(e,e>>31,f,f>>31);e=I+q|0;f=jb+j|0;f=e>>>0<q>>>0?f+1|0:f;j=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(o,p)+B(i,n)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;i=mqa(G,H,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Ic(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;n=l>>12;p=(f|0)/256|0;v[c>>2]=v[c>>2]+B(n,p);k=i+k|0;o=k>>12;v[c+4>>2]=v[c+4>>2]+B(p,o);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=m;m=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=m;break a}o=k>>12;n=l>>12;e=m}v[a+40>>2]=k;v[a+20>>2]=n;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function lJ(a){var b=0,c=0,d=0,e=0;he(a,v[a+20>>2]);if(v[a+24>>2]>=1){while(1){he(a,v[v[a+28>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[a+24>>2]){continue}break}}he(a,v[a+28>>2]);a:{b=v[a+396>>2];if(!b|v[a+264>>2]<1){break a}while(1){c=B(e,24)+b|0;b=v[c+16>>2];if(b){d=a;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=1){he(a,v[b>>2]);b=1;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=2){while(1){he(a,v[v[c+16>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]){continue}break}}b=v[c+16>>2]}he(d,b)}he(a,v[c+20>>2]);e=e+1|0;if((e|0)>=v[a+264>>2]){break a}b=v[a+396>>2];continue}}b=v[a+124>>2];if(b){d=a;if(v[a+120>>2]>=1){c=0;while(1){b=B(c,2096)+b|0;he(a,v[b+8>>2]);he(a,v[b+28>>2]);he(a,v[b+32>>2]);he(a,v[b+2084>>2]);b=v[b+2088>>2];he(a,b?b-4|0:0);c=c+1|0;if((c|0)<v[a+120>>2]){b=v[a+124>>2];continue}break}b=v[a+124>>2]}he(d,b)}he(a,v[a+260>>2]);he(a,v[a+396>>2]);d=v[a+404>>2];if(d){b=1;c=a;if(v[a+400>>2]>=1){he(a,v[d+4>>2]);if(v[a+400>>2]>=2){while(1){he(a,v[(v[a+404>>2]+B(b,40)|0)+4>>2]);b=b+1|0;if((b|0)<v[a+400>>2]){continue}break}}d=v[a+404>>2]}he(c,d)}c=1;b:{if(v[a+4>>2]<1){break b}b=0;while(1){d=(b<<2)+a|0;he(a,v[d+800>>2]);he(a,v[d+928>>2]);he(a,v[d+996>>2]);if(b>>>0>14){break b}b=b+1|0;if((b|0)<v[a+4>>2]){continue}break}}b=0;while(1){b=(b<<2)+a|0;he(a,v[b+1068>>2]);he(a,v[b+1076>>2]);he(a,v[b+1084>>2]);he(a,v[b+1092>>2]);he(a,v[b+1100>>2]);b=1;d=c&1;c=0;if(d){continue}break}}function j1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=gb-16|0;gb=k;i=c;j=(c|0)==(d|0);a:{if(j){break a}while(1){if(!v[i>>2]){break a}i=i+4|0;if((i|0)!=(d|0)){continue}break}i=d}v[h>>2]=f;v[e>>2]=c;b:{c:{if(j|(f|0)==(g|0)){break c}m=1;while(1){j=v[b+4>>2];v[k+8>>2]=v[b>>2];v[k+12>>2]=j;l=gb-16|0;gb=l;v[l+12>>2]=v[a+8>>2];n=vi(l+8|0,l+12|0);v[22640]=0;j=vH(f,e,i-c>>2,g-f|0,b);o=v[22640];v[22640]=0;d:{if((o|0)!=1){ff(n);gb=l+16|0;break d}a=P()|0;O()|0;ff(n);S(a|0);L()}e:{f:{g:{h:{i:{j:{switch(j+1|0){case 0:v[h>>2]=f;k:{if(v[e>>2]==(c|0)){break k}while(1){b=bx(f,v[c>>2],k+8|0,v[a+8>>2]);if((b|0)==-1){break k}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;if((c|0)!=v[e>>2]){continue}break}}v[e>>2]=c;break i;case 1:break b;default:break j}}f=j+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break g}if((d|0)==(i|0)){c=v[e>>2];i=d;break e}j=bx(k+4|0,0,b,v[a+8>>2]);if((j|0)!=-1){break h}}m=2;break b}f=v[h>>2];if(j>>>0>g-f>>>0){break b}if(!j){break f}c=w[k+4|0];v[h>>2]=f+1;t[f|0]=c;i=k+4|0;c=j-1|0;if(!c){break f}while(1){j=w[i+1|0];f=v[h>>2];v[h>>2]=f+1;t[f|0]=j;i=i+1|0;c=c-1|0;if(c){continue}break}break f}c=v[e>>2];break c}c=v[e>>2]+4|0;v[e>>2]=c;f=c;i=d;l:{if((d|0)==(f|0)){break l}while(1){i=f;if(!v[f>>2]){break l}f=f+4|0;if((f|0)!=(d|0)){continue}break}i=d}f=v[h>>2]}if((c|0)==(d|0)){break c}if((f|0)!=(g|0)){continue}break}}m=(c|0)!=(d|0)}gb=k+16|0;return m|0}function eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];r=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=g+r|0;n=t[e-3|0];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];o=t[e-2|0];p=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=Lb(m,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=mqa(j,j>>31,e,e>>31);j=jb;J=e;e=v[a+68>>2];q=mqa(e,e>>31,f,f>>31);e=J+q|0;f=jb+j|0;f=e>>>0<q>>>0?f+1|0:f;j=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(o,p)+B(i,n)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;i=mqa(H,I,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Ic(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;n=l>>12;p=(f|0)/256|0;v[c>>2]=v[c>>2]+B(n,p);k=i+k|0;o=k>>12;v[c+4>>2]=v[c+4>>2]+B(p,o);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=m;m=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=m;break a}o=k>>12;n=l>>12;e=m}v[a+40>>2]=k;v[a+20>>2]=n;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function mja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;f=v[a+56>>2];v[b+44>>2]=f;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;a:{if(d){while(1){e=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+q|0;f=u[e>>1];v[b+8>>2]=f;v[b+12>>2]=u[e+2>>1];j=0;l=1;while(1){i=v[a+60>>2];k=i;g=(b+32|0)+(j<<3)|0;p=v[g>>2];e=Lb(p,-16777216,16776704);o=v[a+64>>2];h=Lb(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=mqa(k,r,f,f>>31);k=jb;o=mqa(o,o>>31,e,e>>31);f=o+f|0;e=jb+k|0;e=f>>>0<o>>>0?e+1|0:e;k=f;f=v[a+68>>2];h=mqa(f,f>>31,h,h>>31);f=k+h|0;e=jb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Ic(f,e,24);v[g+4>>2]=p;f=v[a+72>>2];v[(b+8|0)+(j<<2)>>2]=(e|0)/256;v[g>>2]=e-(f&i);if(l){j=1;l=0;f=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;j=n>>12;v[c>>2]=v[c>>2]+B(j,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];e=v[b+28>>2];continue}break}g=v[b+24>>2];e=v[b+28>>2];f=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];h=v[b+32>>2];break a}k=m>>12;j=n>>12}v[a+40>>2]=m;v[a+20>>2]=j;v[a+36>>2]=n;v[a+56>>2]=f;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=g;v[a+4>>2]=e;gb=b+48|0}function C3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=C(0);a=gb-368|0;gb=a;v[a+352>>2]=c;v[a+360>>2]=b;ix(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=Kc(d);v[22640]=0;R(118,d|0,b|0);b=v[22640];v[22640]=0;a:{b:{c:{if((b|0)!=1){c=mc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[22640]=0;g=Q(2463,a+360|0,a+352|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+180>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+180>>2]=g+c}v[22640]=0;g=T(2465,a+360|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break d}if(hx(g,a+7|0,a+6|0,c,a+180|0,i,b,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22640]=0;T(2467,a+360|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22640]=0;j=C(ya(2449,c|0,v[a+180>>2],e|0));b=v[22640];v[22640]=0;f:{if((b|0)==1){break f}z[f>>2]=j;gf(a+200|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2464,a+360|0,a+352|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];vb(d);vb(a+200|0);gb=a+368|0;break a}}b=P()|0;O()|0;vb(d);vb(a+200|0);S(b|0);L()}return b|0}function R3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=C(0);a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;lx(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=Kc(d);v[22640]=0;R(118,d|0,b|0);b=v[22640];v[22640]=0;a:{b:{c:{if((b|0)!=1){c=mc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=t[a+222|0];i=t[a+223|0];while(1){d:{v[22640]=0;g=Q(2436,a+264|0,a+256|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+188>>2]=g+c}v[22640]=0;g=T(2438,a+264|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break d}if(kx(g,a+7|0,a+6|0,c,a+188|0,i,b,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22640]=0;T(2440,a+264|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22640]=0;j=C(ya(2449,c|0,v[a+188>>2],e|0));b=v[22640];v[22640]=0;f:{if((b|0)==1){break f}z[f>>2]=j;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2437,a+264|0,a+256|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(d);vb(a+208|0);gb=a+272|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function aoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-32|0;gb=g;j=Zf(a,c);se(g+8|0,v[a+28>>2]);d=v[g+20>>2];v[g+24>>2]=v[g+16>>2];v[g+28>>2]=d;a:{if(!j){if(id(a,5)){break a}}d=gb-144|0;gb=d;h=wm(d+40|0,v[a+28>>2]);v[22640]=0;f=Q(640,d+24|0,50002)|0;e=v[22640];v[22640]=0;b:{c:{d:{e:{if((e|0)!=1){v[22640]=0;v[d+16>>2]=19923012;v[d+20>>2]=0;U(641,h|0,f|0,d+16|0);e=v[22640];v[22640]=0;if((e|0)==1){break e}Hb(f);if(!(v[h>>2]&1073741824)){break d}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(f);break c}k=d,l=Oe(b),u[k+16>>1]=l;u[d+14>>1]=65535;v[22640]=0;f=Q(640,d+24|0,7431)|0;e=v[22640];v[22640]=0;f:{if((e|0)!=1){v[22640]=0;e=W(1103,h|0,d+14|0,f|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break f}Hb(f);if((e|0)!=1){u[d+16>>1]=x[d+14>>1]}sg(d+16|0,4e3);g:{if(x[d+16>>1]<=Oe(b)>>>0){break g}v[22640]=0;R(364,b|0,x[d+16>>1]);e=v[22640];v[22640]=0;if((e|0)!=1){break g}e=P()|0;O()|0;break c}e=0;u[d+12>>1]=0;if(!x[d+16>>1]){break b}h:{while(1){i:{f=_b(b,e&65535);v[22640]=0;R(1498,d+24|0,d+12|0);i=v[22640];v[22640]=0;if((i|0)==1){break i}v[22640]=0;ca(1481,h|0,f|0,d+24|0,1499)|0;f=v[22640];v[22640]=0;if((f|0)==1){break h}Hb(d+24|0);e=e+1|0;u[d+12>>1]=e;if(x[d+16>>1]>(e&65535)>>>0){continue}break b}break}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(d+24|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;Hb(f)}ch(h);S(e|0);L()}ch(h);gb=d+144|0}Sf(a,j,c,g+24|0);gb=g+32|0}function B3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-368|0;gb=a;v[a+352>>2]=c;v[a+360>>2]=b;ix(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=Kc(d);v[22640]=0;R(118,d|0,b|0);b=v[22640];v[22640]=0;a:{b:{c:{if((b|0)!=1){c=mc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[22640]=0;g=Q(2463,a+360|0,a+352|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+180>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+180>>2]=g+c}v[22640]=0;g=T(2465,a+360|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break d}if(hx(g,a+7|0,a+6|0,c,a+180|0,i,b,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22640]=0;T(2467,a+360|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22640]=0;j=+oa(2452,c|0,v[a+180>>2],e|0);b=v[22640];v[22640]=0;f:{if((b|0)==1){break f}A[f>>3]=j;gf(a+200|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2464,a+360|0,a+352|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];vb(d);vb(a+200|0);gb=a+368|0;break a}}b=P()|0;O()|0;vb(d);vb(a+200|0);S(b|0);L()}return b|0}function nja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;f=v[a+56>>2];v[b+44>>2]=f;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;a:{if(d){while(1){e=(((e&2147483647)<<1|g>>>31)&-2)+q|0;f=t[e|0]<<8;v[b+8>>2]=f;v[b+12>>2]=t[e+1|0]<<8;j=0;l=1;while(1){i=v[a+60>>2];k=i;g=(b+32|0)+(j<<3)|0;p=v[g>>2];e=Lb(p,-16777216,16776704);o=v[a+64>>2];h=Lb(v[g+4>>2],-16777216,16776704);r=i>>31;i=f<<8;f=i;f=mqa(k,r,f,f>>31);k=jb;o=mqa(o,o>>31,e,e>>31);f=o+f|0;e=jb+k|0;e=f>>>0<o>>>0?e+1|0:e;k=f;f=v[a+68>>2];h=mqa(f,f>>31,h,h>>31);f=k+h|0;e=jb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Ic(f,e,24);v[g+4>>2]=p;f=v[a+72>>2];v[(b+8|0)+(j<<2)>>2]=(e|0)/256;v[g>>2]=e-(f&i);if(l){j=1;l=0;f=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;j=n>>12;v[c>>2]=v[c>>2]+B(j,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];e=v[b+28>>2];continue}break}g=v[b+24>>2];e=v[b+28>>2];f=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];h=v[b+32>>2];break a}k=m>>12;j=n>>12}v[a+40>>2]=m;v[a+20>>2]=j;v[a+36>>2]=n;v[a+56>>2]=f;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=g;v[a+4>>2]=e;gb=b+48|0}function sG(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-96|0;gb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{b=v[b>>2];j:{if(!b){Tb(a,6910);break j}if(!(b&65535)){d=gb-16|0;gb=d;e=Tb(d,1508);Dc(c+80|0,e);vb(e);gb=d+16|0;v[22640]=0;v[c+24>>2]=b>>>24;R(171,c- -64|0,c+24|0);d=v[22640];v[22640]=0;k:{l:{m:{n:{if((d|0)!=1){v[22640]=0;v[c+8>>2]=b>>>16&255;R(172,c+48|0,c+8|0);b=v[22640];v[22640]=0;if((b|0)==1){break n}v[22640]=0;Y(173,a|0,c+80|0,c- -64|0,c+48|0);a=v[22640];v[22640]=0;if((a|0)==1){break m}vb(c+48|0);vb(c- -64|0);Hb(c+80|0);break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;vb(c+48|0)}vb(c- -64|0)}break a}d=gb-16|0;gb=d;e=Tb(d,1232);Dc(c+80|0,e);vb(e);gb=d+16|0;v[22640]=0;v[c+44>>2]=b>>>24;R(171,c- -64|0,c+44|0);d=v[22640];v[22640]=0;if((d|0)==1){break i}v[22640]=0;v[c+40>>2]=b>>>16&255;R(172,c+48|0,c+40|0);d=v[22640];v[22640]=0;if((d|0)==1){break h}v[22640]=0;v[c+20>>2]=b>>>8&255;R(172,c+24|0,c+20|0);d=v[22640];v[22640]=0;if((d|0)==1){break g}v[22640]=0;v[c+4>>2]=b&255;R(172,c+8|0,c+4|0);b=v[22640];v[22640]=0;if((b|0)==1){break f}v[22640]=0;ka(174,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=v[22640];v[22640]=0;if((a|0)==1){break e}vb(c+8|0);vb(c+24|0);vb(c+48|0);vb(c- -64|0);Hb(c+80|0)}gb=c+96|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;vb(c+8|0)}vb(c+24|0)}vb(c+48|0)}vb(c- -64|0)}Hb(c+80|0);S(b|0);L()}function P3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-272|0;gb=a;v[a+256>>2]=c;v[a+264>>2]=b;lx(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=Kc(d);v[22640]=0;R(118,d|0,b|0);b=v[22640];v[22640]=0;a:{b:{c:{if((b|0)!=1){c=mc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;b=t[a+222|0];i=t[a+223|0];while(1){d:{v[22640]=0;g=Q(2436,a+264|0,a+256|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+188>>2]=g+c}v[22640]=0;g=T(2438,a+264|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break d}if(kx(g,a+7|0,a+6|0,c,a+188|0,i,b,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[22640]=0;T(2440,a+264|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[22640]=0;j=+oa(2452,c|0,v[a+188>>2],e|0);b=v[22640];v[22640]=0;f:{if((b|0)==1){break f}A[f>>3]=j;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2437,a+264|0,a+256|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];vb(d);vb(a+208|0);gb=a+272|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function aja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gb-48|0;gb=e;p=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;j=v[a+48>>2];v[e+36>>2]=j;k=v[a+52>>2];v[e+40>>2]=k;g=v[a+56>>2];v[e+44>>2]=g;q=v[a+24>>2];r=v[a+20>>2];b=v[a+4>>2];i=v[a>>2];v[e+24>>2]=i;v[e+28>>2]=b;h=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=h;s=a;if(d){while(1){l=i>>>18|0;k=1;g=((((b&2147483647)<<1|i>>>31)&2147483646)<<1)+p|0;f=0;b=1;j=0;while(1){h=j<<1;i=u[h+g>>1];v[(e+8|0)+(j<<2)>>2]=i+((B(l,u[g+(h|4)>>1]-i|0)|0)/16384|0);i=b;b=0;j=1;if(i){continue}break}while(1){j=(e+8|0)+(f<<2)|0;l=v[j>>2];h=v[a+60>>2];m=h;i=(e+32|0)+(f<<3)|0;o=v[i>>2];b=Lb(o,-16777216,16776704);f=v[a+64>>2];g=Lb(v[i+4>>2],-16777216,16776704);n=h>>31;l=l<<8;h=l;h=mqa(m,n,h,h>>31);m=jb;n=h;h=mqa(f,f>>31,b,b>>31);f=n+h|0;b=jb+m|0;b=f>>>0<h>>>0?b+1|0:b;h=f;f=v[a+68>>2];f=mqa(f,f>>31,g,g>>31);g=h+f|0;b=jb+b|0;b=f>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Ic(g,b,24);v[i+4>>2]=o;g=v[a+72>>2];v[j>>2]=(b|0)/256;v[i>>2]=b-(g&l);f=1;b=k&1;k=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;i=v[e+24>>2];b=v[e+28>>2];continue}break}i=v[e+24>>2];b=v[e+28>>2];k=v[e+40>>2];j=v[e+36>>2];f=v[e+32>>2];g=v[e+44>>2]}v[s+56>>2]=g;v[a+52>>2]=k;v[a+48>>2]=j;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=b;gb=e+48|0}function a1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];c=d>>>0>b>>>0;a:{if(b>>>0>=d>>>0|f>>>0>=g>>>0){break a}b:{c:{while(1){c=t[b|0];i=c&255;l=a;d:{if((c|0)>=0){u[f>>1]=i;b=b+1|0;break d}c=2;if(i>>>0<194){break b}if(i>>>0<=223){if((d-b|0)<2){break c}j=w[b+1|0];if((j&192)!=128){break a}u[f>>1]=j&63|i<<6&1984;b=b+2|0;break d}if(i>>>0<=239){if((d-b|0)<3){break c}k=w[b+2|0];j=w[b+1|0];e:{f:{if((i|0)!=237){if((i|0)!=224){break f}if((j&224)==160){break e}break a}if((j&224)==128){break e}break a}if((j&192)!=128){break a}}if((k&192)!=128){break a}u[f>>1]=k&63|((j&63)<<6|i<<12);b=b+3|0;break d}if(i>>>0>244){break b}c=1;if((d-b|0)<4){break a}k=w[b+3|0];j=w[b+2|0];b=w[b+1|0];g:{h:{switch(i-240|0){case 0:if((b+112&255)>>>0>=48){break b}break g;case 4:if((b&240)!=128){break b}break g;default:break h}}if((b&192)!=128){break b}}if((j&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}c=2;i=i&7;if((b<<12&196608|i<<18)>>>0>1114111){break a}b=b<<2;u[f>>1]=(j>>>4&3|(b&192|i<<8|b&60))+16320|55296;v[a+8>>2]=f+2;u[f+2>>1]=j<<6&960|k&63|56320;b=v[a+12>>2]+4|0}v[l+12>>2]=b;f=v[a+8>>2]+2|0;v[a+8>>2]=f;b=v[a+12>>2];c=d>>>0>b>>>0;if(b>>>0>=d>>>0){break a}if(f>>>0<g>>>0){continue}break}break a}c=1;break a}c=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return c|0}function a8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=gb-176|0;gb=b;d=Tb(b+8|0,8940);v[22640]=0;Q(112,b+20|0,8294)|0;e=v[22640];v[22640]=0;c=1;a:{b:{if((e|0)==1){break b}v[22640]=0;Q(112,b+32|0,8770)|0;c=v[22640];v[22640]=0;if((c|0)==1){c=2;break b}v[22640]=0;Q(112,b+44|0,8286)|0;c=v[22640];v[22640]=0;if((c|0)==1){c=3;break b}v[22640]=0;Q(112,b+56|0,5456)|0;c=v[22640];v[22640]=0;if((c|0)==1){c=4;break b}v[22640]=0;Q(112,b+68|0,8271)|0;c=v[22640];v[22640]=0;if((c|0)==1){c=5;break b}v[22640]=0;Q(112,b+80|0,5522)|0;c=v[22640];v[22640]=0;if((c|0)==1){c=6;break b}v[22640]=0;Q(112,b+92|0,2712)|0;c=v[22640];v[22640]=0;if((c|0)==1){c=7;break b}v[22640]=0;Q(112,b+104|0,9308)|0;c=v[22640];v[22640]=0;if((c|0)==1){c=8;break b}v[22640]=0;Q(112,b+116|0,8713)|0;c=v[22640];v[22640]=0;if((c|0)==1){c=9;break b}v[22640]=0;Q(112,b+128|0,9509)|0;c=v[22640];v[22640]=0;if((c|0)==1){c=10;break b}v[22640]=0;Q(112,b+140|0,2564)|0;c=v[22640];v[22640]=0;if((c|0)==1){c=11;break b}v[22640]=0;Q(112,b+152|0,4385)|0;c=v[22640];v[22640]=0;if((c|0)==1){c=12;break b}v[b+172>>2]=13;v[b+168>>2]=d;v[22640]=0;c=v[b+172>>2];v[b>>2]=v[b+168>>2];v[b+4>>2]=c;Q(2086,a|0,b|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){a=b+164|0;while(1){a=vb(a-12|0);if((d|0)!=(a|0)){continue}break}gb=b+176|0;return}a=b+164|0;break a}a=(b+8|0)+B(c,12)|0}b=P()|0;O()|0;while(1){a=vb(a-12|0);if((d|0)!=(a|0)){continue}break}S(b|0);L()}function Yh(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)==189){t[a+3843|0]=c>>>7;t[a+3844|0]=c>>>6&1;return}d=b&224;a:{if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=B(b>>>0<3?b:b+6|0,44)+a|0;f=e+148|0;e=e+16|0;g=c&d;b:{if(g){Ko(e,f);break b}Ko(e,0)}t[f+40|0]=!g;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}t[a+3842|0]=c>>>6&1;b=0;while(1){OA((B(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if((d-160&65535)>>>0<=32){d=b&15;if(d>>>0>8){break a}a=(B(b&256?d+9|0:d,44)+a|0)+16|0;d=v[a+36>>2];c:{b=b&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}b=c&32;eS(a,b>>>5|0);f=c>>>2&7;dS(a,f);e=a;a=c&3;cS(e,a);if(!d){break a}eS(d,(b|0)!=0);dS(d,f);cS(d,a);return}bS(a,c);if(!d){break a}bS(d,c);return}t[a+42|0]=(c&32)>>>5;t[a+41|0]=(c&16)>>>4;b=c>>>1&7;u[a+30>>1]=b?9-b|0:0;u[a+32>>1]=c&1;return}if((d|0)!=224?d>>>0>=129:0){break a}f=b&31;if(-4144960>>>f&1){break a}e=a;a=t[f+35664|0];a=(e+B(b&256?a+18|0:a,84)|0)+808|0;d:{switch(d-32>>>5|0){case 0:t[a+79|0]=c>>>7;t[a+80|0]=(c&64)>>>6;t[a+78|0]=(c&32)>>>5;t[a+77|0]=(c&16)>>>4;Lo(a);u[a+14>>1]=x[((c&15)<<1)+35696>>1];return;case 1:u[a+68>>1]=w[(c>>>6|0)+18678|0];aS(a);u[a+22>>1]=(c&63)<<2;return;case 2:u[a+24>>1]=c>>>4;Lo(a);u[a+26>>1]=c&15;Lo(a);return;case 3:b=c>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=c&15;Lo(a);return;case 6:break d;default:break a}}u[a+12>>1]=c&7}}function R4(){var a=0,b=0;a=gb-16|0;gb=a;_s(463328);v[115842]=463384;v[115840]=90240;v[115832]=78332;v[115844]=-1;t[463380]=0;Ts(a+8|0,463328);b=v[v[115832]+8>>2];v[22640]=0;R(b|0,463328,a+8|0);b=v[22640];v[22640]=0;a:{if((b|0)!=1){Vb(a+8|0);gb=a+16|0;break a}b=P()|0;O()|0;Vb(a+8|0);um(463328);S(b|0);L()}Bt(462656);v[115664]=76940;v[115662]=76920;v[115663]=0;v[22640]=0;R(2381,462656,463328);a=v[22640];v[22640]=0;if((a|0)==1){a=P()|0;O()|0;lh(462656);S(a|0);L()}a=gb-16|0;gb=a;mI(463392);v[115858]=463448;v[115856]=90240;v[115848]=78432;v[115860]=-1;t[463444]=0;Ts(a+8|0,463392);b=v[v[115848]+8>>2];v[22640]=0;R(b|0,463392,a+8|0);b=v[22640];v[22640]=0;b:{if((b|0)!=1){Vb(a+8|0);gb=a+16|0;break b}b=P()|0;O()|0;Vb(a+8|0);bq(463392);S(b|0);L()}MH(462744);v[115686]=76988;v[115684]=76968;v[115685]=0;v[22640]=0;R(2382,462744,463392);a=v[22640];v[22640]=0;if((a|0)==1){a=P()|0;O()|0;lh(462744);S(a|0);L()}QH(463456,90384,463504);Cx(462824,463456);PH(463512,90384,463560);Bx(462908,463512);QH(463568,89864,463616);Cx(462992,463568);Cx(463160,v[(v[v[115748]-12>>2]+462992|0)+24>>2]);PH(463624,89864,463672);Bx(463076,463624);Bx(463244,v[(v[v[115769]-12>>2]+463076|0)+24>>2]);OH(v[v[115662]-12>>2]+462648|0);NH(v[v[115684]-12>>2]+462736|0);YJ(v[v[115748]-12>>2]+462992|0);YJ(v[v[115769]-12>>2]+463076|0);OH(v[v[115748]-12>>2]+462992|0);NH(v[v[115769]-12>>2]+463076|0)}function bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gb-48|0;gb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;i=v[a+48>>2];v[e+36>>2]=i;b=v[a+52>>2];v[e+40>>2]=b;j=v[a+56>>2];v[e+44>>2]=j;p=v[a+24>>2];q=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=h;k=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=k;if(d){while(1){k=g>>>10&4194048;g=(((h&2147483647)<<1|g>>>31)&-2)+o|0;i=0;j=1;b=1;f=0;while(1){h=t[f+g|0];v[(e+8|0)+(f<<2)>>2]=((B(k,t[g+(f|2)|0]-h|0)|0)/16384|0)+(h<<8);h=b;b=0;f=1;if(h){continue}break}while(1){k=(e+8|0)+(i<<2)|0;f=v[k>>2];l=v[a+60>>2];m=l;h=(e+32|0)+(i<<3)|0;i=v[h>>2];b=Lb(i,-16777216,16776704);n=v[a+64>>2];g=Lb(v[h+4>>2],-16777216,16776704);r=l>>31;l=f<<8;f=l;f=mqa(m,r,f,f>>31);m=jb;n=mqa(n,n>>31,b,b>>31);f=n+f|0;b=jb+m|0;b=f>>>0<n>>>0?b+1|0:b;m=f;f=v[a+68>>2];f=mqa(f,f>>31,g,g>>31);g=m+f|0;b=jb+b|0;b=f>>>0>g>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=Ic(g,b,24);v[h+4>>2]=i;g=v[a+72>>2];v[k>>2]=(b|0)/256;v[h>>2]=b-(g&l);i=1;b=j&1;j=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];h=v[e+28>>2];continue}break}g=v[e+24>>2];h=v[e+28>>2];j=v[e+44>>2];i=v[e+36>>2];f=v[e+32>>2];b=v[e+40>>2]}v[a+56>>2]=j;v[a+52>>2]=b;v[a+48>>2]=i;v[a+44>>2]=f;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function Az(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;i=wO(b,c);a:{if(!v[b+656>>2]|!(t[i+6|0]&1)){break a}e=v[i>>2];j=a+1074312|0;Db(f+8|0,j,31);g=Cb(f+8|0);d=ew(v[b+656>>2],c);if($c(d)){break a}g=e+(g^1)|0;Db(f+8|0,j,31);h=Cb(f+8|0);e=w[d+12|0];k=c;b:{c:{if(!h){d:{if(!(e&2)){break d}h=x[Mb(d,w[d+14|0])>>1]+!(v[a+480180>>2]&1048580)|0;e=0;if(!(!(w[b+89|0]&8)|(!(w[d+12|0]&4)|w[d+14|0]!=w[d+16|0]))){Db(f+8|0,j,70);e=Cb(f+8|0)}if((g|0)!=(h|0)|e){break d}g=x[Mb(d,w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){if((x[Mb(d,w[d+16|0])>>1]+1|0)!=(g|0)){break b}g=x[Mb(d,w[d+15|0])>>1];Db(f+8|0,j,93);if(!Cb(f+8|0)|(c|0)!=1|v[b+88>>2]&2048){break b}t[i+6|0]=w[i+6|0]&254;break b}c=x[uo(d)>>1];if(c>>>0>=g>>>0){break b}g=c;c=0;break c}e:{f:{if(!(!(e&4)|w[b+669|0]&8)){if(x[i+4>>1]==65535){break f}Db(f+8|0,j,97);if(Cb(f+8|0)){break f}e=w[d+12|0]}if(e&2){e=x[Mb(d,w[d+13|0])>>1];c=0;h=x[Mb(d,w[d+14|0])>>1]+1|0;break e}e=x[uo(d)>>1];c=g>>>0>e>>>0;h=e;break e}e=x[Mb(d,w[d+15|0])>>1];c=0;h=x[Mb(d,w[d+16|0])>>1]+1|0}g=g>>>0<h>>>0?g:e;c=!c}if(k|c){break b}if(!(w[b+89|0]&8)|v[a+480180>>2]==16384?v[a+480180>>2]&16777248:1){v[b+88>>2]=v[b+88>>2]|4096}if(w[uo(d)+2|0]|!(v[a+480180>>2]&16777248?1:x[b+786>>1])){break b}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=v[b+88>>2]|4096}Db(f+8|0,j,31);l=i,m=Cb(f+8|0)+g|0,v[l>>2]=m}gb=f+16|0}function Moa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-80|0;gb=d;b=b&4095;u[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=gb-16|0;gb=e;f=Tb(e,1547);Dc(d- -64|0,f);vb(f);gb=e+16|0;v[22640]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=mqa(e,e>>31,1e4,0)+14780|0;b=jb;b=nqa(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((((b|0)/-4|0)+e|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<=-1){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(B(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;v[d+44>>2]=g+f;R(154,d+48|0,d+44|0);g=v[22640];v[22640]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){v[22640]=0;v[d+28>>2]=(e-B(f,12)|0)+1;R(156,d+32|0,d+28|0);e=v[22640];v[22640]=0;if((e|0)==1){break j}v[22640]=0;v[d+12>>2]=(((B(b,306)+5|0)/-10|0)+c|0)+1;R(156,d+16|0,d+12|0);b=v[22640];v[22640]=0;if((b|0)==1){break i}v[22640]=0;ha(576,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[22640];v[22640]=0;if((a|0)==1){break h}vb(d+16|0);vb(d+32|0);break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(d+16|0)}vb(d+32|0)}vb(d+48|0)}break a}Df(d- -64|0,1527);v[22640]=0;R(577,d+48|0,d+78|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;U(204,a|0,d- -64|0,d+48|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}}vb(d+48|0);Hb(d- -64|0);gb=d+80|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(d+48|0)}Hb(d- -64|0);S(b|0);L()}
function gJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=C(0);d=(b<<2)+a|0;g=d+1068|0;l=c<<1&-4;r=g,s=Zd(a,l),v[r>>2]=s;j=d+1076|0;r=j,s=Zd(a,l),v[r>>2]=s;k=Zd(a,c&-4);v[d+1084>>2]=k;a:{g=v[g>>2];if(!g){break a}j=v[j>>2];if(!j|!k){break a}b:{d=c;if((d|0)<4){break b}m=C(d|0);i=C(C(1)/m);q=d>>>2|0;while(1){n=e<<2;f=+C(C(C(h<<2)*C(3.1415927410125732))*i);r=n+g|0,t=C(Ke(f)),z[r>>2]=t;o=e|1;p=o<<2;r=p+g|0,t=C(-C(pi(f))),z[r>>2]=t;f=+C(C(C(o|0)*C(1.5707963705062866))*i);r=j+n|0,t=C(C(Ke(f))*C(.5)),z[r>>2]=t;r=j+p|0,t=C(C(pi(f))*C(.5)),z[r>>2]=t;e=e+2|0;h=h+1|0;if((q|0)!=(h|0)){continue}break}if((d|0)<8){break b}d=d>>3;d=(d|0)>1?d:1;i=C(C(1)/m);e=0;h=1;while(1){g=e|1;f=+C(C(C(g<<1)*C(3.1415927410125732))*i);r=k+(e<<2)|0,t=C(Ke(f)),z[r>>2]=t;r=k+(g<<2)|0,t=C(-C(pi(f))),z[r>>2]=t;if((d|0)==(h|0)){break b}e=e+2|0;h=h+1|0;continue}}e=(b<<2)+a|0;d=Zd(a,l);v[e+1092>>2]=d;if(!d){break a}b=c;if((b|0)>=2){b=b>>1;h=(b|0)>1?b:1;f=1/+(b|0);b=0;while(1){i=C(pi((+(b|0)*1.5707963705062866+.7853981852531433)*f));r=d+(b<<2)|0,t=C(pi(+C(i*i)*1.5707963705062866)),z[r>>2]=t;b=b+1|0;if((h|0)!=(b|0)){continue}break}}b=Zd(a,c>>2&-2);v[e+1100>>2]=b;if(!b){break a}a=c;d=Am(a);if((a|0)>=8){c=36-d|0;d=a>>>3|0;a=0;while(1){r=b+(a<<1)|0,s=ym(a)>>>c<<2,u[r>>1]=s;a=a+1|0;if((d|0)!=(a|0)){continue}break}}return 1}dc(a,3);return 0}function H3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);g=Vn(d,a+224|0);Un(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)!=1){c=mc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22640]=0;h=Q(2463,a+344|0,a+336|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+188>>2]=h+c}v[22640]=0;h=T(2465,a+344|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(nm(h,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,g)){break c}v[22640]=0;T(2467,a+344|0)|0;h=v[22640];v[22640]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22640]=0;b=ys(2444,c,v[a+188>>2],e,b);c=jb;g=v[22640];v[22640]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2464,a+344|0,a+336|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function D3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);g=Vn(d,a+224|0);Un(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)!=1){c=mc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22640]=0;h=Q(2463,a+344|0,a+336|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+188>>2]=h+c}v[22640]=0;h=T(2465,a+344|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(nm(h,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,g)){break c}v[22640]=0;T(2467,a+344|0)|0;h=v[22640];v[22640]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22640]=0;b=ys(2448,c,v[a+188>>2],e,b);c=jb;g=v[22640];v[22640]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2464,a+344|0,a+336|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=C(0),s=0;g=gb-16|0;gb=g;m=a+44|0;if(ki(m)){j=Md(m,0);k=Md(m,1);h=kd(m,0);i=kd(m,1);r=z[a+4212>>2];v[g+12>>2]=d;if(d){e=v[a+4224>>2];while(1){s=a;f=v[a+4220>>2];a:{if(f>>>0>e>>>0){v[g+8>>2]=f-e;f=v[Fb(g+12|0,g+8|0)>>2];b:{if(!(r<C(1))){if(!f){break b}e=1;while(1){z[h>>2]=z[j>>2];z[i>>2]=z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;if((e|0)==(f|0)){break b}e=e+1|0;continue}}e=v[a+4224>>2];l=f+e|0;if(e>>>0>=l>>>0){break b}o=C(C(1)/C(y[a+4220>>2]));while(1){n=C(C(e>>>0)*o);z[h>>2]=n*z[j>>2];z[i>>2]=z[k>>2]*n;i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((l|0)!=(e|0)){continue}break}}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+v[a+4224>>2]|0;break a}v[g+4>>2]=v[a+4216>>2]-e;f=v[Fb(g+12|0,g+4|0)>>2];c:{d:{if(!(r<C(1))){if(!f){break d}e=1;while(1){v[h>>2]=0;v[i>>2]=0;i=i+4|0;h=h+4|0;if((e|0)==(f|0)){break d}e=e+1|0;continue}}p=v[a+4216>>2];q=v[a+4224>>2];e=p-q|0;l=e-f|0;if(e>>>0<=l>>>0){break c}o=C(C(1)/C(y[a+4220>>2]));while(1){n=C(C(e>>>0)*o);z[h>>2]=z[j>>2]*n;z[i>>2]=z[k>>2]*n;i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e-1|0;if(l>>>0<e>>>0){continue}break}break c}e=f<<2;k=e+k|0;j=e+j|0;p=v[a+4216>>2];q=v[a+4224>>2]}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+q|0;e=e>>>0<p>>>0?e:0}v[s+4224>>2]=e;if(l){continue}break}}Ci(a,b,c,kd(m,0),kd(m,1),d)}gb=g+16|0}function I3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=Vn(d,a+224|0);Un(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)!=1){c=mc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22640]=0;g=Q(2463,a+344|0,a+336|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+188>>2]=g+c}v[22640]=0;g=T(2465,a+344|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(nm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22640]=0;T(2467,a+344|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22640]=0;b=ca(2441,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22640];v[22640]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2464,a+344|0,a+336|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}
function G3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=Vn(d,a+224|0);Un(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)!=1){c=mc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22640]=0;g=Q(2463,a+344|0,a+336|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+188>>2]=g+c}v[22640]=0;g=T(2465,a+344|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(nm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22640]=0;T(2467,a+344|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22640]=0;b=ca(2445,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22640];v[22640]=0;f:{if((c|0)==1){break f}u[f>>1]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2464,a+344|0,a+336|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function F3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=Vn(d,a+224|0);Un(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)!=1){c=mc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22640]=0;g=Q(2463,a+344|0,a+336|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+188>>2]=g+c}v[22640]=0;g=T(2465,a+344|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(nm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22640]=0;T(2467,a+344|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22640]=0;b=ca(2446,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22640];v[22640]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2464,a+344|0,a+336|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function E3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=gb-352|0;gb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Mh(d);h=Vn(d,a+224|0);Un(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)!=1){c=mc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[22640]=0;g=Q(2463,a+344|0,a+336|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+188>>2]=g+c}v[22640]=0;g=T(2465,a+344|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(nm(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,h)){break c}v[22640]=0;T(2467,a+344|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22640]=0;b=ca(2447,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22640];v[22640]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2464,a+344|0,a+336|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];vb(d);vb(a+208|0);gb=a+352|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function _R(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=b;a:{if(vk(a)){h=gb-16|0;gb=h;j=h+8|0;f=rf(3848);k=v[e+12>>2];c=f+808|0;b=f+16|0;while(1){v[b+16>>2]=0;v[b+20>>2]=0;v[b+36>>2]=0;t[b+40|0]=1;v[b+24>>2]=0;v[b+28>>2]=0;u[b+32>>1]=0;b=b+44|0;if((c|0)!=(b|0)){continue}break}c=f+3832|0;b=f+808|0;while(1){v[b>>2]=0;v[b+4>>2]=0;v[b+68>>2]=0;v[b+72>>2]=0;v[b+24>>2]=0;v[b+28>>2]=0;u[b+20>>1]=511;v[b+16>>2]=-1;u[b+14>>1]=1;u[b+6>>1]=0;u[b+8>>1]=0;u[b+10>>1]=0;u[b+12>>1]=0;t[b+73|0]=0;t[b+74|0]=0;t[b+75|0]=0;t[b+76|0]=0;t[b+77|0]=0;t[b+78|0]=0;t[b+79|0]=0;t[b+80|0]=0;b=b+84|0;if((c|0)!=(b|0)){continue}break}b=f;v[b+3832>>2]=0;v[b+3836>>2]=0;c=b+3837|0;t[c|0]=0;t[c+1|0]=0;t[c+2|0]=0;t[c+3|0]=0;t[c+4|0]=0;t[c+5|0]=0;t[c+6|0]=0;t[c+7|0]=0;while(1){bf((b+B(g,84)|0)+808|0,b);g=g+1|0;if((g|0)!=36){continue}break}while(1){v[(b+B(d,44)|0)+32>>2]=b;d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){c=(b+B(d,44)|0)+16|0;g=v[(d<<2)+35584>>2];b:{if(!(!(1<<d&3591)|d>>>0>11)){i=c;c=b+B(g,84)|0;gS(i,c+808|0,c+1060|0,c+1312|0,c+1564|0);break b}i=c;c=b+B(g,84)|0;gS(i,c+808|0,c+1060|0,0,0)}d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){Lo((b+B(d,84)|0)+808|0);d=d+1|0;if((d|0)!=36){continue}break}fS(b,k);b=v[Ni(j,f)>>2];gb=h+16|0;v[e+8>>2]=b;FA(a,e+8|0);Zm(e+8|0);break a}fS(v[a>>2],b)}MA(a);gb=e+16|0}function Z3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Wn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)!=1){c=mc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;g=t[a+223|0];while(1){d:{v[22640]=0;h=Q(2436,a+232|0,a+224|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+188>>2]=h+c}v[22640]=0;h=T(2438,a+232|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(om(h,b,c,a+188|0,a+8|0,g,a+208|0,a+16|0,a+12|0,83184)){break c}v[22640]=0;T(2440,a+232|0)|0;h=v[22640];v[22640]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22640]=0;b=ys(2444,c,v[a+188>>2],e,b);c=jb;g=v[22640];v[22640]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2437,a+232|0,a+224|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function T3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Wn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)!=1){c=mc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;g=t[a+223|0];while(1){d:{v[22640]=0;h=Q(2436,a+232|0,a+224|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(!h){break c}if(v[a+188>>2]==(Ab(d)+c|0)){h=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+188>>2]=h+c}v[22640]=0;h=T(2438,a+232|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(om(h,b,c,a+188|0,a+8|0,g,a+208|0,a+16|0,a+12|0,83184)){break c}v[22640]=0;T(2440,a+232|0)|0;h=v[22640];v[22640]=0;if((h|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[22640]=0;b=ys(2448,c,v[a+188>>2],e,b);c=jb;g=v[22640];v[22640]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2437,a+232|0,a+224|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Aia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=gb-32|0;gb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];i=v[a>>2];v[g+24>>2]=i;v[g+28>>2]=f;v[g+16>>2]=h;v[g+20>>2]=e;e:{if(d){while(1){e=((((f&2147483647)<<1|i>>>31)&2147483646)<<1)+m|0;b=(i>>>16&65520)+l|0;i=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],i)|0)/32768;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;h=k>>12;v[c>>2]=v[c>>2]+B(h,v[g+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;i=v[g+24>>2];f=v[g+28>>2];continue}break}i=v[g+24>>2];f=v[g+28>>2];break e}b=j>>12;h=k>>12}v[a+40>>2]=j;v[a+20>>2]=h;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=i;v[a+4>>2]=f;gb=g+32|0}function Uha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Sd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=gg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}k=v[a+40>>2];l=v[a+36>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+m|0;b:{if((b|0)<=0){break b}while(1){g=(i&2147483647)<<1|j>>>31;Id(v[f+8>>2],(u[(g<<1|2)+h>>1]+u[h+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Id(j,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);h=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;v[c>>2]=v[c>>2]+B(b,i);k=h+k|0;j=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2];break a}j=k>>12;i=l>>12}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function X3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Wn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)!=1){c=mc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22640]=0;g=Q(2436,a+232|0,a+224|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+188>>2]=g+c}v[22640]=0;g=T(2438,a+232|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(om(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83184)){break c}v[22640]=0;T(2440,a+232|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22640]=0;b=ca(2445,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22640];v[22640]=0;f:{if((c|0)==1){break f}u[f>>1]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2437,a+232|0,a+224|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function V3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Wn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)!=1){c=mc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22640]=0;g=Q(2436,a+232|0,a+224|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+188>>2]=g+c}v[22640]=0;g=T(2438,a+232|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(om(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83184)){break c}v[22640]=0;T(2440,a+232|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22640]=0;b=ca(2446,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22640];v[22640]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2437,a+232|0,a+224|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function U3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Wn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)!=1){c=mc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22640]=0;g=Q(2436,a+232|0,a+224|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+188>>2]=g+c}v[22640]=0;g=T(2438,a+232|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(om(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83184)){break c}v[22640]=0;T(2440,a+232|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22640]=0;b=ca(2447,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22640];v[22640]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2437,a+232|0,a+224|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function $3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-240|0;gb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Mh(d);Wn(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)!=1){c=mc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;h=t[a+223|0];while(1){d:{v[22640]=0;g=Q(2436,a+232|0,a+224|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Ab(d)+c|0)){g=Ab(d);c=Ab(d);v[22640]=0;R(118,d|0,c<<1);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=Kc(d);v[22640]=0;R(118,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=mc(d,0);v[a+188>>2]=g+c}v[22640]=0;g=T(2438,a+232|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break d}if(om(g,b,c,a+188|0,a+8|0,h,a+208|0,a+16|0,a+12|0,83184)){break c}v[22640]=0;T(2440,a+232|0)|0;g=v[22640];v[22640]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Ab(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[22640]=0;b=ca(2441,c|0,v[a+188>>2],e|0,b|0)|0;c=v[22640];v[22640]=0;f:{if((c|0)==1){break f}v[f>>2]=b;gf(a+208|0,a+16|0,v[a+12>>2],e);v[22640]=0;b=Q(2437,a+232|0,a+224|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];vb(d);vb(a+208|0);gb=a+240|0;break a}}b=P()|0;O()|0;vb(d);vb(a+208|0);S(b|0);L()}return b|0}function Uka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=gb-144|0;gb=k;DB(a);a:{b:{if(!Rf(a,64)){break b}c:{d:{if(!Tl(a,60)){break d}if(!pU(a,11467)){break d}g=15;l=450;break c}DB(a);if(!Rf(a,128)){break b}b=0;if(!Tl(a,124)){break a}if(!pU(a,12540)){break a}g=31;l=930}DB(a);e=1;while(1){b=0;h=0;f=gb-16|0;gb=f;c=gb-32|0;gb=c;ti(c+24|0,f+8|0);i=xb(c+24|0);d=v[c+28>>2];j=v[c+24>>2];v[c+8>>2]=j;v[c+12>>2]=d;v[c>>2]=j;v[c+4>>2]=d;d=a;qd(c+16|0,d,c);j=xb(c+16|0);if((j|0)==(i|0)){cd(d,xb(c+24|0))}gb=c+32|0;if((i|0)==(j|0)){c=f+8|0;h=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}gb=f+16|0;if(h>>>0>131072){break a}if((e&65535)>>>0<g>>>0){e=e+1|0;continue}break}cd(a,4);if(!Rf(a,2)){break b}f=0;e=gb-16|0;gb=e;c=gb-32|0;gb=c;Bn(c+24|0,e+8|0);g=xb(c+24|0);h=v[c+28>>2];i=v[c+24>>2];v[c+8>>2]=i;v[c+12>>2]=h;v[c>>2]=i;v[c+4>>2]=h;qd(c+16|0,a,c);h=xb(c+16|0);if((h|0)==(g|0)){cd(d,xb(c+24|0))}gb=c+32|0;if((h|0)==(g|0)){d=e+8|0;f=Ib(w[d|0]|w[d+1|0]<<8)}gb=e+16|0;if(f>>>0<178){break a}b=-1;if(!Rf(a,l)){break a}cd(a,l);d=gb-32|0;gb=d;f=k+8|0;nV(d+24|0,f);c=xb(d+24|0);e=v[d+28>>2];g=v[d+24>>2];v[d+8>>2]=g;v[d+12>>2]=e;v[d>>2]=g;v[d+4>>2]=e;qd(d+16|0,a,d);e=xb(d+16|0);if((e|0)==(c|0)){cd(a,xb(d+24|0))}gb=d+32|0;a=(c|0)==(e|0);if(!a){mV(f)}if(!a){break a}b=oU(k+8|0);break a}b=-1}gb=k+144|0;return b|0}function a_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1397771593){td(b,32);Yj(d,1,a+4|0);Bc(d+16|0,d);v[22640]=0;Q(335,b+43|0,d+16|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break a}vb(d+16|0);u[b+30>>1]=w[a+19|0]<<2;sg(b+30|0,256);u[b+32>>1]=w[a+17|0];sg(b+32|0,64);c=a+47|0;u[b+28>>1]=(w[c|0]&127)<<2;sg(b+28|0,256);if(t[c|0]<=-1){u[b+34>>1]=x[b+34>>1]|32}c=a+18|0;if(w[c|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[c|0]&32){u[b+34>>1]=x[b+34>>1]|8}if(w[c|0]&64){u[b+34>>1]=x[b+34>>1]|4}if(t[c|0]<=-1){u[b+34>>1]=x[b+34>>1]|16}c=a+60|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c?c:8363;v[b+24>>2]=c>>>0>256?c:256;c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a- -64|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+68|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);wk(b);t[b+38|0]=w[(w[a+79|0]&7)+46512|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=512;e=a+46|0;b:{if(w[e|0]!=64){c=16384;if(w[e|0]!=128){break b}}u[b+34>>1]=x[b+34>>1]|c}a=a+72|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=d+32|0;return c|0}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function l3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=gb-16|0;gb=k;m=Hx(g);g=jx(g);Qg(k,g);a:{b:{c:{if(dd(k)){v[22640]=0;Y(2470,m|0,a|0,c|0,d|0);g=v[22640];v[22640]=0;if((g|0)==1){break c}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;d:{e:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break e;default:break d}}v[22640]=0;j=Q(2480,m|0,h<<24>>24)|0;h=v[22640];v[22640]=0;if((h|0)==1){break c}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[22640]=0;h=Q(2480,m|0,48)|0;i=v[22640];v[22640]=0;if((i|0)==1){break c}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[22640]=0;h=Q(2480,m|0,h|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break c}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}mm(j,c);h=0;v[22640]=0;n=T(2468,g|0)|0;g=v[22640];v[22640]=0;f:{if((g|0)!=1){if(c>>>0<=j>>>0){break f}g=j;i=0;while(1){g:{if(!w[mc(k,h)|0]){break g}if(t[mc(k,h)|0]!=(i|0)){break g}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=n;h=(Ab(k)-1>>>0>h>>>0)+h|0;i=0}l=t[g|0];v[22640]=0;o=Q(2480,m|0,l|0)|0;l=v[22640];v[22640]=0;if((l|0)==1){break c}l=v[f>>2];v[f>>2]=l+4;v[l>>2]=o;i=i+1|0;g=g+1|0;if((g|0)!=(c|0)){continue}break}g=l+4|0;break b}break c}g=v[f>>2];break b}a=P()|0;O()|0;vb(k);S(a|0);L()}Hs((j-a<<2)+d|0,g);g=v[f>>2]}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;vb(k);gb=k+16|0}function Dea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=gb-32|0;gb=i;v[i+24>>2]=b;b=v[a>>2];p=i,q=Sb(a),v[p>>2]=q;b=b+B(St(i+24|0,i),6)|0;a:{b:{if(!c){break b}f=v[wb(a)>>2];g=v[a+4>>2];if((f-g|0)/6>>>0>=c>>>0){e=c;j=g-b|0;f=(j|0)/6|0;if(f>>>0<c>>>0){GC(a,c-f|0,d);e=f;if(!j){break b}}l=gb-16|0;gb=l;j=a;f=g;k=b;n=v[a+4>>2];o=B(c,6);h=B((n-(o+b|0)|0)/6|0,6)+b|0;m=Cr(l,a,(g-h|0)/6|0);if(g>>>0>h>>>0){g=v[m+4>>2];c=h;while(1){wb(j);HN(g,c);g=g+6|0;v[m+4>>2]=g;c=c+6|0;if(f>>>0>c>>>0){continue}break}}$b(m);c=h-k|0;if(c){sh(B((c|0)/-6|0,6)+n|0,k,c)}gb=l+16|0;c=b;d=d>>>0>=c>>>0?y[a+4>>2]>d>>>0?d+o|0:d:d;if(e){while(1){a=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;a=w[d+4|0]|w[d+5|0]<<8;t[c+4|0]=a;t[c+5|0]=a>>>8;c=c+6|0;e=e-1|0;if(e){continue}break}}break b}e=wb(a);e=JW(i,qC(a,Eg(a)+c|0),(b-v[a>>2]|0)/6|0,e);v[22640]=0;U(662,e|0,c|0,d|0);c=v[22640];v[22640]=0;if((c|0)==1){break a}EC(a);c=v[e+4>>2];j=e+4|0;HW(wb(a),v[a>>2],b,j);wb(a);f=e+8|0;h=f;d=v[a+4>>2];if((d|0)!=(b|0)){k=v[h>>2];while(1){HN(k,b);k=v[h>>2]+6|0;v[h>>2]=k;b=b+6|0;if((d|0)!=(b|0)){continue}break}}jc(a,j);jc(a+4|0,f);jc(wb(a),cc(e));v[e>>2]=v[e+4>>2];sC(a,Eg(a));b=c;kv(e)}bh(b);gb=i+32|0;return}a=P()|0;O()|0;kv(e);S(a|0);L()}function Bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];i=v[a+4>>2];h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(d){while(1){g=(((i&2147483647)<<1|h>>>31)&-2)+m|0;b=(h>>>16&65520)+l|0;h=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];w=u[b>>1];b=0;e=1;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+g|0],s)+B(t[(b|-6)+g|0],w)|0)+B(t[(b|-2)+g|0],r)|0)+B(t[b+g|0],q)|0)+B(t[(b|2)+g|0],p)|0)+B(t[(b|4)+g|0],o)|0)+B(t[(b|6)+g|0],n)|0)+B(t[(b|8)+g|0],h)<<8)/32768;i=e;e=0;b=1;if(i){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;e=k>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];i=v[f+28>>2];continue}break}h=v[f+24>>2];i=v[f+28>>2];break e}b=j>>12;e=k>>12}v[a+40>>2]=j;v[a+20>>2]=e;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=h;v[a+4>>2]=i;gb=f+32|0}function C2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=gb-448|0;gb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=2485;h=ge(a+24|0,a+32|0,a+20|0);v[22640]=0;Ec(a+16|0,e);b=v[22640];v[22640]=0;a:{b:{c:{d:{if((b|0)!=1){v[22640]=0;i=T(2458,a+16|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break b}t[a+15|0]=0;b=v[e+4>>2];v[22640]=0;b=ra(2493,a+440|0,c|0,d|0,a+16|0,b|0,f|0,a+15|0,i|0,h|0,a+20|0,a+432|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break b}if(!b){break c}c=gb-16|0;gb=c;b=g;e:{if(De(b)){d=v[b>>2];v[c+12>>2]=0;Fe(d,c+12|0);ee(b,0);break e}v[c+8>>2]=0;Fe(b,c+8|0);Ve(b,0)}gb=c+16|0;if(!w[a+15|0]){break d}v[22640]=0;b=Q(2480,i|0,45)|0;c=v[22640];v[22640]=0;if((c|0)==1){break b}v[22640]=0;R(105,g|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[22640]=0;b=Q(2480,i|0,48)|0;c=v[22640];v[22640]=0;if((c|0)==1){break b}e=v[h>>2];c=v[a+20>>2];d=c-4|0;f:{if(e>>>0>=d>>>0){break f}while(1){if((b|0)!=v[e>>2]){break f}e=e+4|0;if(d>>>0>e>>>0){continue}break}}v[22640]=0;U(2498,g|0,e|0,c|0);b=v[22640];v[22640]=0;if((b|0)!=1){break c}break b}v[22640]=0;b=Q(2464,a+440|0,a+432|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}b=v[a+440>>2];Vb(a+16|0);Gc(h);gb=a+448|0;return b|0}e=P()|0;O()|0;Vb(a+16|0)}Gc(h);S(e|0);L()}function hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=gb-16|0;gb=i;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];h=v[a>>2];v[i+8>>2]=h;v[i+12>>2]=g;e=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=(g<<1)+o|0;p=u[e-6>>1];g=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[g+24>>1];q=u[e-4>>1];r=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=Lb(k,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=mqa(j,j>>31,e,e>>31);j=jb;I=e;e=v[a+68>>2];l=mqa(e,e>>31,f,f>>31);e=I+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(q,r)+B(h,p)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;h=mqa(G,H,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Ic(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,n);v[c+4>>2]=v[c+4>>2]+B(h,m);e=f-(e&g)|0;Ub(i+8|0,i);d=d-1|0;if(d){c=c+8|0;h=v[i+8>>2];g=v[i+12>>2];f=k;k=e;continue}break}h=v[i+8>>2];g=v[i+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=i+16|0}function npa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-1072|0;gb=e;v[e+1068>>2]=c;l=de(b);g=$k(e+8|0,b);v[22640]=0;m=mp(g);c=v[22640];v[22640]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[22640]=0;c=T(492,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}v[e+4>>2]=c;v[22640]=0;v[e>>2]=536870911;c=Fb(e+4|0,e);d=v[22640];v[22640]=0;if((d|0)==1){break c}tc(e+1068|0,v[c>>2]<<3);v[22640]=0;k=Q(37,a|0,v[e+1068>>2])|0;a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;a=8;f=Q(236,g|0,8)|0;d=v[22640];v[22640]=0;c=1;e:{f:{if((d|0)==1){break f}d=zb(f&255);n=kc(k,0),o=d,t[n|0]=o;g:{if(y[e+1068>>2]<2){break g}while(1){v[22640]=0;j=a&255;d=Q(236,g|0,j|0)|0;h=v[22640];v[22640]=0;h:{i:{j:{k:{if((h|0)!=1){if(d){break k}if(j>>>0>8){break g}a=a+1|0;break j}break f}h=f;f=d>>>1|0;f=h+(d&1?0-f|0:f)|0;h=zb(f&255);n=kc(k,c),o=h,t[n|0]=o;c=c+1|0;if(!(d<<1>>>j|0)){break i}}i=0;break h}i=i+1|0;d=i&255;a=a-(j>>>0>1&d>>>0>=l>>>0)|0;i=d>>>0<l>>>0?i:0}if(y[e+1068>>2]>c>>>0){continue}break}}v[22640]=0;a=mp(g);c=v[22640];v[22640]=0;if((c|0)==1){break f}v[22640]=0;Q(227,b|0,((a-m|0)+3&-4)+m|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break e}}a=P()|0;O()|0;gc(k);break a}yb(g);gb=e+1072|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}yb(g);S(a|0);L()}function b1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c=v[a+12>>2];if(d>>>0>c>>>0){while(1){b=x[c>>1];c:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<1){break a}v[a+8>>2]=c+1;t[c|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break e}if((g-v[a+8>>2]|0)<4){break a}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;t[f|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;if(c>>>0<d>>>0){continue}break}}f=0;break a}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return f|0}function wu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{f=a;d=b;b:{c:{i=a+58|0;h=lc(i,b);b=t[h|0];if((b|0)==-1){break c}if((b|0)>-1){break b}b=b&127;e=sd(f+22|0,b);g=x[e>>1];if((d|0)!=(g|0)?(g|0)!=65535:0){break c}u[e>>1]=d;t[h|0]=b;break b}m=f+4|0;j=f+22|0;g=255;b=0;e=255;while(1){k=sd(j,b);l=x[k>>1];if((l|0)==65535){u[k>>1]=d;t[h|0]=b;break b}if(!(w[lc(m,b)|0]&32)){g=t[lc(i,l)|0]>-1?g:b;e=b}b=b+1|0;if((b|0)!=18){continue}break}if((e&255)!=255){b=(g&255)==255?e:g;e=sd(j,b&255);n=lc(i,x[e>>1]),o=255,t[n|0]=o;u[e>>1]=d;t[h|0]=b}b=Nl(f,d)}e=b&255;if((e|0)==255){break a}if(vk(a)){break a}d=ln(a+314|0,e);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[d+8|0]=b;t[d+9|0]=b>>>8;t[d+10|0]=b>>>16;t[d+11|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;t[d+4|0]=b;t[d+5|0]=b>>>8;t[d+6|0]=b>>>16;t[d+7|0]=b>>>24;g=ZR(e);h=g+3|0;b=0;d=1;while(1){f=d;d=d?g:h;Yh(v[a>>2],(d|32)&65535,w[lc(c,b)|0]);Yh(v[a>>2],(d|64)&65535,w[lc(c,b|2)|0]);Yh(v[a>>2],(d|96)&65535,w[lc(c,b|4)|0]);Yh(v[a>>2],(d|128)&65535,w[lc(c,b|6)|0]);Yh(v[a>>2],(d|224)&65535,w[lc(c,b|8)|0]);d=0;b=1;if(f){continue}break}Yh(v[a>>2],xu(e)|192,w[lc(c,10)|0])}}function iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;i=gb-16|0;gb=i;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];h=v[a>>2];v[i+8>>2]=h;v[i+12>>2]=g;e=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=g+o|0;p=t[e-3|0];g=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[g+24>>1];q=t[e-2|0];r=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=Lb(k,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=mqa(j,j>>31,e,e>>31);j=jb;J=e;e=v[a+68>>2];l=mqa(e,e>>31,f,f>>31);e=J+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(q,r)+B(h,p)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;h=mqa(H,I,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Ic(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,n);v[c+4>>2]=v[c+4>>2]+B(h,m);e=f-(e&g)|0;Ub(i+8|0,i);d=d-1|0;if(d){c=c+8|0;h=v[i+8>>2];g=v[i+12>>2];f=k;k=e;continue}break}h=v[i+8>>2];g=v[i+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=i+16|0}function rja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;o=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;i=v[a+48>>2];v[b+36>>2]=i;e=v[a+52>>2];v[b+40>>2]=e;k=v[a+56>>2];v[b+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];f=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=f;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;if(d){while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+o|0;e=u[f>>1];v[b+8>>2]=e;v[b+12>>2]=u[f+2>>1];i=0;k=1;while(1){j=v[a+60>>2];l=j;g=(b+32|0)+(i<<3)|0;n=v[g>>2];f=Lb(n,-16777216,16776704);m=v[a+64>>2];h=Lb(v[g+4>>2],-16777216,16776704);r=j>>31;j=e<<8;e=j;e=mqa(l,r,e,e>>31);l=jb;m=mqa(m,m>>31,f,f>>31);e=m+e|0;f=jb+l|0;f=e>>>0<m>>>0?f+1|0:f;l=e;e=v[a+68>>2];h=mqa(e,e>>31,h,h>>31);e=l+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Ic(e,f,24);v[g+4>>2]=n;e=v[a+72>>2];v[(b+8|0)+(i<<2)>>2]=(f|0)/256;v[g>>2]=f-(e&j);if(k){i=1;k=0;e=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],p);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];f=v[b+28>>2];continue}break}g=v[b+24>>2];k=v[b+44>>2];e=v[b+40>>2];h=v[b+32>>2];i=v[b+36>>2];f=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=e;v[a+48>>2]=i;v[a+44>>2]=h;v[a>>2]=g;v[a+4>>2]=f;gb=b+48|0}function i1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;k=gb-16|0;gb=k;i=c;j=(c|0)==(d|0);a:{if(j){break a}while(1){if(!w[i|0]){break a}i=i+1|0;if((i|0)!=(d|0)){continue}break}i=d}v[h>>2]=f;v[e>>2]=c;b:{c:{if(j|(f|0)==(g|0)){break c}while(1){j=v[b+4>>2];v[k+8>>2]=v[b>>2];v[k+12>>2]=j;l=gb-16|0;gb=l;v[l+12>>2]=v[a+8>>2];m=vi(l+8|0,l+12|0);v[22640]=0;j=uH(f,e,i-c|0,g-f>>2,b);n=v[22640];v[22640]=0;d:{if((n|0)!=1){ff(m);gb=l+16|0;break d}a=P()|0;O()|0;ff(m);S(a|0);L()}e:{f:{g:{h:{i:{j:{if((j|0)==-1){v[h>>2]=f;if(v[e>>2]!=(c|0)){while(1){k:{l:{m:{n:{b=HG(f,c,i-c|0,k+8|0,v[a+8>>2]);switch(b+2|0){case 1:break m;case 2:break n;case 0:break h;default:break l}}c=c+1|0;break k}v[e>>2]=c;break j}c=b+c|0}f=v[h>>2]+4|0;v[h>>2]=f;if(v[e>>2]!=(c|0)){continue}break}}v[e>>2]=c;break c}f=v[h>>2]+(j<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break g}c=v[e>>2];if((d|0)==(i|0)){i=d;break e}if(!HG(f,c,1,b,v[a+8>>2])){break i}}a=2;break b}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;f=c;i=d;if((c|0)==(d|0)){break f}while(1){if(!w[f|0]){i=f;break f}f=f+1|0;if((f|0)!=(d|0)){continue}break}break f}v[e>>2]=c;a=1;break b}c=v[e>>2];break c}f=v[h>>2]}if((c|0)==(d|0)){break c}if((f|0)!=(g|0)){continue}break}}a=(c|0)!=(d|0)}gb=k+16|0;return a|0}function fga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=c>>>4;v[e+16>>2]=v[a>>2];j=v[Fb(e+24|0,e+16|0)>>2];b=zb(b);if(j){a=v[a+20>>2];c=j;while(1){d=b;f=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=f;i=g<<8&16711680|g<<24;k=d<<24|g>>>8;f=d<<8|g>>>24;i=k&65280|f&255|i;v[e+24>>2]=((d&255)<<24|g>>>8)&-16777216|((d&16777215)<<8|g>>>24)&16711680|(d>>>8&65280|d>>>24)|l;v[e+28>>2]=i;v[e+16>>2]=0;v[e+20>>2]=-1074790400;v[e+8>>2]=0;v[e+12>>2]=1072693248;h=A[$g(e+24|0,e+16|0,e+8|0)>>3]*32768;A[e+24>>3]=h;d=a;h=fe(h);a:{if(D(h)<2147483648){f=~~h;break a}f=-2147483648}m=d,n=Sc(f),u[m>>1]=n;d=b;f=w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24);g=w[d+8|0]|w[d+9|0]<<8|(w[d+10|0]<<16|w[d+11|0]<<24);d=f;i=g<<8&16711680|g<<24;k=d<<24|g>>>8;f=d<<8|g>>>24;i=k&65280|f&255|i;v[e+24>>2]=((d&255)<<24|g>>>8)&-16777216|((d&16777215)<<8|g>>>24)&16711680|(d>>>8&65280|d>>>24)|l;v[e+28>>2]=i;v[e+16>>2]=0;v[e+20>>2]=-1074790400;v[e+8>>2]=0;v[e+12>>2]=1072693248;h=A[$g(e+24|0,e+16|0,e+8|0)>>3]*32768;A[e+24>>3]=h;d=a;h=fe(h);b:{if(D(h)<2147483648){f=~~h;break b}f=-2147483648}m=d,n=Sc(f),u[m+2>>1]=n;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=e+32|0;return j<<4}function xW(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;a:{d=w[a|0];b:{if(d>>>0>21){break b}t[a|0]=w[d+29264|0];c:{switch(d-8|0){case 0:t[b|0]=w[b|0]<<1;break b;case 4:t[b|0]=w[b|0]+1>>>1;break b;case 5:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);break b;case 6:d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{d=w[b|0];switch((d>>>4|0)-1|0){case 10:break e;case 9:break f;case 8:break g;case 6:break h;case 5:break i;case 4:break j;case 3:break k;case 1:break l;case 0:break m;case 11:case 12:case 13:break b;case 14:break d;default:break n}}t[a|0]=0;break b}t[a|0]=29;t[c+15|0]=w[b|0]&15;t[c+14|0]=14;e=b,f=w[ac(c+15|0,c+14|0)|0]<<4|15,t[e|0]=f;break b}t[a|0]=29;t[c+13|0]=w[b|0]&15;t[c+12|0]=14;e=b,f=w[ac(c+13|0,c+12|0)|0]|240,t[e|0]=f;break b}t[b|0]=d&15|48;break b}t[a|0]=35;t[b|0]=w[b|0]<<4^128;break b}t[b|0]=d&15|176;break b}t[b|0]=d&15|64;break b}t[a|0]=15;t[b|0]=w[b|0]&15;break b}t[a|0]=24;t[b|0]=(w[b|0]<<3&120)+8&240;break b}t[a|0]=24;t[b|0]=(w[b|0]&15)+1>>>1;break b}t[a|0]=10;break b;case 8:a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?-16:a<<2&240;break b}if(a>>>0<=239){t[b|0]=a<<2&48|15;break b}t[b|0]=a<<4|15;break b;case 9:break c;default:break b}}a=w[b|0];if(a>>>0<=223){break a}if(a>>>0>239){break b}t[b|0]=a>>>2&3|240}gb=c+16|0;return}t[b|0]=a>>>0>63?15:a>>>2|0;gb=c+16|0}function w3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=gb-16|0;gb=k;l=oD(g);g=px(g);Qg(k,g);a:{b:{if(dd(k)){v[22640]=0;Y(2450,l|0,a|0,c|0,d|0);g=v[22640];v[22640]=0;if((g|0)==1){break a}g=(c-a|0)+d|0;v[f>>2]=g;break b}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[22640]=0;j=Q(22,l|0,h<<24>>24)|0;h=v[22640];v[22640]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[22640]=0;h=Q(22,l|0,48)|0;i=v[22640];v[22640]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[22640]=0;h=Q(22,l|0,h|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}mm(j,c);h=0;v[22640]=0;o=T(2442,g|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break a}if(c>>>0>j>>>0){g=j;i=0;while(1){e:{if(!w[mc(k,h)|0]){break e}if(t[mc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(Ab(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[22640]=0;n=Q(22,l|0,n|0)|0;m=v[22640];v[22640]=0;if((m|0)==1){break a}m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;i=i+1|0;g=g+1|0;if((g|0)!=(c|0)){continue}break}}mm((j-a|0)+d|0,v[f>>2]);g=v[f>>2]}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;vb(k);gb=k+16|0;return}a=P()|0;O()|0;vb(k);S(a|0);L()}function t2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=gb-496|0;gb=a;Ec(a+488|0,d);v[22640]=0;m=T(2458,a+488|0)|0;g=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Ab(f)){g=v[kk(f,0)>>2];v[22640]=0;h=Q(2480,m|0,45)|0;k=v[22640];v[22640]=0;if((k|0)==1){break g}n=(g|0)==(h|0)}k=Kb(a+456|0);g=Kb(a+440|0);h=Kb(a+424|0);v[22640]=0;na(2502,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,g|0,h|0,a+420|0);c=v[22640];v[22640]=0;if((c|0)==1){break f}v[a+4>>2]=2434;c=ge(a+8|0,0,a+4|0);i=Ab(f);l=v[a+420>>2];h:{if((i|0)>(l|0)){i=Ab(f);j=((Ab(h)+(i-l<<1)|0)+Ab(g)|0)+1|0;break h}j=(Ab(h)+Ab(g)|0)+2|0}i=a+16|0;j=j+l|0;if(j>>>0<101){break e}Ee(c,Ad(j<<2));i=v[c>>2];if(i){break e}v[22640]=0;X(2435);b=v[22640];v[22640]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}j=v[d+4>>2];o=Jb(f);p=Jb(f);f=Ab(f);v[22640]=0;qa(2503,i|0,a+4|0,a|0,j|0,o|0,(f<<2)+p|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],k|0,g|0,h|0,l|0);f=v[22640];v[22640]=0;if((f|0)!=1){v[22640]=0;b=la(2483,b|0,i|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Gc(c)}Hc(h);Hc(g);vb(k)}Vb(a+488|0);S(f|0);L()}Gc(c);Hc(h);Hc(g);vb(k);Vb(a+488|0);gb=a+496|0;return b|0}function tna(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=jv(a);if(b>>>0<=63){k=gb-32|0;gb=k;a:{b:{j=64-b|0;c:{if(j>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/33>>>0){b=gb-16|0;gb=b;c=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+B(j,33);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){pC(a);a=a+33|0;v[c+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(c);gb=b+16|0;break c}i=wb(a);f=k+8|0;d=a;c=jv(a)+j|0;h=gb-16|0;gb=h;v[h+12>>2]=c;e=gb-16|0;gb=e;v[e+12>>2]=130150524;v[22640]=0;v[e+8>>2]=2147483647;g=Fb(e+12|0,e+8|0);b=v[22640];v[22640]=0;d:{if((b|0)!=1){gb=e+16|0;b=v[g>>2];break d}V(0)|0;O()|0;Bb();L()}e:{if(b>>>0>=c>>>0){c=tW(d);if(c>>>0<b>>>1>>>0){v[h+8>>2]=c<<1;b=v[Jc(h+8|0,h+12|0)>>2]}gb=h+16|0;break e}Rc();L()}d=jv(a);e=0;g=gb-16|0;gb=g;v[g+12>>2]=0;ef(f+12|0,i);if(b){c=b;if(b>>>0>=130150525){nd(8513);L()}e=Mc(B(c,33),1)}v[f>>2]=e;c=B(d,33)+e|0;v[f+8>>2]=c;v[f+4>>2]=c;l=cc(f),m=B(b,33)+e|0,v[l>>2]=m;gb=g+16|0;v[22640]=0;wW(f,j);b=v[22640];v[22640]=0;if((b|0)==1){break b}b=a;c=f;i=c+4|0;d=v[a+4>>2];a=v[a>>2];g=d-a|0;d=v[i>>2]+B((g|0)/-33|0,33)|0;v[i>>2]=d;if((g|0)>=1){hc(d,a,g)}wc(b,i);wc(b+4|0,c+8|0);wc(wb(b),cc(c));v[c>>2]=v[c+4>>2];vW(f)}gb=k+32|0;break a}a=P()|0;O()|0;vW(f);S(a|0);L()}return}if((b|0)!=64){Vk(a,v[a>>2]+2112|0)}}function sja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=gb-48|0;gb=b;o=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;i=v[a+48>>2];v[b+36>>2]=i;e=v[a+52>>2];v[b+40>>2]=e;k=v[a+56>>2];v[b+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];f=v[a+4>>2];g=v[a>>2];v[b+24>>2]=g;v[b+28>>2]=f;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;if(d){while(1){f=(((f&2147483647)<<1|g>>>31)&-2)+o|0;e=t[f|0]<<8;v[b+8>>2]=e;v[b+12>>2]=t[f+1|0]<<8;i=0;k=1;while(1){j=v[a+60>>2];l=j;g=(b+32|0)+(i<<3)|0;n=v[g>>2];f=Lb(n,-16777216,16776704);m=v[a+64>>2];h=Lb(v[g+4>>2],-16777216,16776704);r=j>>31;j=e<<8;e=j;e=mqa(l,r,e,e>>31);l=jb;m=mqa(m,m>>31,f,f>>31);e=m+e|0;f=jb+l|0;f=e>>>0<m>>>0?f+1|0:f;l=e;e=v[a+68>>2];h=mqa(e,e>>31,h,h>>31);e=l+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Ic(e,f,24);v[g+4>>2]=n;e=v[a+72>>2];v[(b+8|0)+(i<<2)>>2]=(f|0)/256;v[g>>2]=f-(e&j);if(k){i=1;k=0;e=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],p);Ub(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;g=v[b+24>>2];f=v[b+28>>2];continue}break}g=v[b+24>>2];k=v[b+44>>2];e=v[b+40>>2];h=v[b+32>>2];i=v[b+36>>2];f=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=e;v[a+48>>2]=i;v[a+44>>2]=h;v[a>>2]=g;v[a+4>>2]=f;gb=b+48|0}function kea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0);i=gb-16|0;gb=i;a:{if(u[d>>1]>u[d+2>>1]){break a}if(!Nb(b)){break a}g=u[e>>1];if((g|0)<u[d>>1]){break a}h=u[d+2>>1];if((h|0)<(g|0)){break a}if((Nb(b)-1&65535)>>>0>(h-g&65535)>>>0|y[a+36>>2]>65535){break a}b:{if(!Nb(b)){break b}while(1){if(!(z[Mb(b,f)>>2]<C(0))){f=f+1|0;if(Nb(b)>>>0>f>>>0){continue}break b}break}f=0;break a}f=0;if(z[c>>2]<=C(0)){break a}u[a>>1]=1;u[a+28>>1]=x[d>>1];l=a,m=tN(Nb(b)),u[l+30>>1]=m;z[a+32>>2]=D(z[c>>2]);g=a+4|0;El(g,(u[d+2>>1]-u[d>>1]|0)+1|0);c=Sb(b);f=Wb(b);l=i,m=Sb(g),v[l+8>>2]=m;h=Xo(i+8|0,u[e>>1]-u[d>>1]|0);b=gb-16|0;gb=b;yc(b+8|0,ap(Wl(c),Wl(f),Wl(h)));gb=b+16|0;c=u[a+28>>1];f=u[e>>1];c:{if((c|0)>=(f|0)){break c}b=f;while(1){b=b-1|0;j=z[Mb(g,u[a+30>>1]+(b-c|0)|0)>>2];k=z[a+32>>2];l=Mb(g,b-u[a+28>>1]|0),n=C(j/k),z[l>>2]=n;f=u[e>>1];c=u[a+28>>1];if((c|0)>=(b|0)){break c}if((f|0)!=-32768){continue}break}}d:{h=u[a+30>>1];b=h+f|0;if((b|0)>u[d+2>>1]|(32767-h|0)<(f|0)){break d}while(1){j=z[a+32>>2];k=z[Mb(g,b-((c<<16>>16)+h|0)|0)>>2];l=Mb(g,b-u[a+28>>1]|0),n=C(k*j),z[l>>2]=n;if(u[d+2>>1]<=(b|0)){break d}h=u[a+30>>1];if(u[e>>1]>(32767-h|0)){break d}b=b+1|0;c=x[a+28>>1];continue}}rq(a);f=1}gb=i+16|0;return f|0}function Vha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Sd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=gg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}k=v[a+40>>2];l=v[a+36>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=(((h&2147483647)<<1|g>>>31)&-2)+m|0;b:{if((b|0)<=0){break b}while(1){g=(i&2147483647)<<1|j>>>31;Id(v[f+8>>2],t[(g|1)+h|0]+t[h+(g&-2)|0]<<5);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Id(j,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);Hd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);h=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;v[c>>2]=v[c>>2]+B(b,i);k=h+k|0;j=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2];break a}j=k>>12;i=l>>12}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function Wfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-16|0;gb=h;b=a+8|0;eu(b,Vd(b));l=wb(b),m=0,v[l>>2]=m;l=b,m=ec(b),v[l>>2]=m;l=ec(b),m=0,v[l>>2]=m;v[a+32>>2]=0;v[a+36>>2]=0;d=a+4|0;v[v[d>>2]>>2]=0;b=v[a>>2];v[v[d>>2]+40>>2]=v[b+480196>>2];v[v[d>>2]+44>>2]=v[b+480204>>2];v[v[d>>2]+80>>2]=v[b+480200>>2];j=x[b+480188>>1];v[h+8>>2]=0;v[h+12>>2]=0;i=h+8|0;u[i+4>>1]=65280;v[i>>2]=0;g=gb-16|0;gb=g;v[g+12>>2]=j;f=a+20|0;a:{if(pg(f)>>>0>=j>>>0){l=g,m=of(f),v[l+8>>2]=m;c=v[f>>2];b=i;e=v[Fb(g+12|0,g+8|0)>>2];if(e){while(1){v[c>>2]=v[b>>2];u[c+4>>1]=x[b+4>>1];c=c+8|0;e=e-1|0;if(e){continue}break}}b=v[g+12>>2];c=v[g+8>>2];if(b>>>0>c>>>0){sP(f,b-c|0,i);break a}Vk(f,v[f>>2]+(b<<3)|0);break a}b=f;if(v[b>>2]){Nd(b);tP(v[b>>2],pg(b));l=wb(b),m=0,v[l>>2]=m;v[b>>2]=0;v[b+4>>2]=0}c=cs(f,j);if(ww()>>>0<c>>>0){Rc();L()}e=c;if(c>>>0>=536870912){nd(8513);L()}e=Mc(e<<3,4);v[b>>2]=e;v[b+4>>2]=e;l=wb(b),m=e+(c<<3)|0,v[l>>2]=m;sP(f,j,i)}gb=g+16|0;if(x[v[a>>2]+480188>>1]){while(1){b=B(k,872);$m((b+v[d>>2]|0)+616|0,7,v[a>>2],k&65535,134217728);t[(b+v[d>>2]|0)+1433|0]=0;t[(b+v[d>>2]|0)+1432|0]=0;t[(b+v[d>>2]|0)+1415|0]=0;t[(b+v[d>>2]|0)+1418|0]=0;t[(b+v[d>>2]|0)+1413|0]=0;k=k+1|0;if(k>>>0<x[v[a>>2]+480188>>1]){continue}break}}gb=h+16|0}function $pa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;f=gb-144|0;gb=f;v[22640]=0;l=T(444,a|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){a:{if(l){p=f+8|4;q=f+8|6;r=f+8|5;k=f+8|2;m=f+8|3;n=f+16|0;while(1){v[22640]=0;R(474,a|0,f+8|0);e=v[22640];v[22640]=0;if((e|0)==1){break a}e=f+8|0;e=Ib(w[e|0]|w[e+1|0]<<8);b:{if(!e|e>>>0>x[c+480192>>1]){break b}e=v[((e<<2)+c|0)+900380>>2];if(!e){break b}v[22640]=0;e=ii(e,b);g=v[22640];v[22640]=0;if((g|0)==1){break a}c:{if(!w[m|0]){break c}if(t[k|0]&1){t[e+12|0]=w[e+12|0]|1}if(w[k|0]&2){t[e+12|0]=w[e+12|0]|4}if(!(w[k|0]&4)){break c}t[e+12|0]=w[e+12|0]|2}t[f+4|0]=w[m|0];v[22640]=0;t[f+7|0]=31;g=ac(f+4|0,f+7|0);i=v[22640];v[22640]=0;if((i|0)==1){break a}g=w[g|0];v[22640]=0;i=g+1&255;R(475,e|0,i|0);g=v[22640];v[22640]=0;if((g|0)==1){break a}t[e+13|0]=w[r|0];t[e+14|0]=w[q|0];g=w[p|0];t[e+15|0]=g;t[e+16|0]=g;g=0;if(!i){break b}while(1){h=g<<2;j=h+n|0;j=Ib(w[j|0]|w[j+1|0]<<8);s=Mb(e,g),y=j,u[s>>1]=y;h=(h|2)+n|0;h=Ib(w[h|0]|w[h+1|0]<<8);u[f+4>>1]=d?h+128>>>2|0:h;sg(f+4|0,64);h=w[f+4|0];s=Mb(e,g),y=h,t[s+2|0]=y;g=g+1|0;if((i|0)!=(g|0)){continue}break}}o=o+1|0;if((o&65535)>>>0<l>>>0){continue}break}}yb(a);gb=f+144|0;return}}b=P()|0;O()|0;yb(a);S(b|0);L()}function zx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0;g=gb-1040|0;gb=g;s=v[115121];m=g+16|0;a:{b:{c:{n=g+16|0;e=b;h=v[22545];d:{e:{while(1){if((e|0)!=w[d+74672|0]){c=87;d=d+1|0;if((d|0)!=87){continue}break e}break}c=d;if(c){break e}e=74768;break d}d=74768;while(1){i=w[d|0];e=d+1|0;d=e;if(i){continue}d=e;c=c-1|0;if(c){continue}break}}c=v[h+20>>2];if(c){k=v[c+4>>2];d=e;f=v[c>>2];j=v[f>>2]+1794895138|0;l=pm(v[f+8>>2],j);h=pm(v[f+12>>2],j);i=pm(v[f+16>>2],j);f:{if(k>>>2>>>0<=l>>>0){break f}c=k-(l<<2)|0;if((h|i)&3|(c>>>0<=h>>>0|c>>>0<=i>>>0)){break f}u=i>>>2|0;x=h>>>2|0;while(1){o=l>>>1|0;h=o+p|0;i=h<<1;c=(i+x<<2)+f|0;q=pm(v[c>>2],j);c=pm(v[c+4>>2],j);if(c>>>0>=k>>>0|k-c>>>0<=q>>>0|w[(c+q|0)+f|0]){break f}c=uj(d,c+f|0);if(!c){d=(i+u<<2)+f|0;c=pm(v[d>>2],j);d=pm(v[d+4>>2],j);if(d>>>0>=k>>>0|c>>>0>=k-d>>>0){break f}r=w[(c+d|0)+f|0]?0:d+f|0;break f}if((l|0)==1){break f}c=(c|0)<0;l=c?o:l-o|0;p=c?p:h;continue}}}d=r?r:e;e=Lf(d);g:{if(e>>>0>=1024){hc(n,d,1023);t[n+1023|0]=0;e=68;break g}hc(n,d,e+1|0);e=0}switch(e+1|0){case 1:break a;case 0:break c;default:break b}}e=v[115121]}m=18693;if((e|0)==28){break a}cb();L()}if(!w[m|0]){v[g>>2]=b;Nx(g+16|0,1024,10395,g);m=g+16|0}v[115121]=s;Tb(a,m);gb=g+1040|0}function kqa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{g=b;if(g){e=c;if(!e){break j}f=d;if(!f){break i}f=E(f)-E(g)|0;if(f>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;hb=a-B(b,c)|0;ib=0;jb=0;return b}e=d;if(!a){break g}if(!e){break f}f=e-1|0;if(f&e){break f}hb=a;ib=f&g;a=g>>>lqa(e)|0;jb=0;return a}f=e-1|0;if(!(f&e)){break e}j=(E(e)+33|0)-E(g)|0;h=0-j|0;break c}j=f+1|0;h=63-f|0;break c}hb=0;a=(g>>>0)/(e>>>0)|0;ib=g-B(a,e)|0;jb=0;return a}f=E(e)-E(g)|0;if(f>>>0<31){break d}break b}hb=a&f;ib=0;if((e|0)==1){break a}c=a;a=lqa(e);d=a&31;if((a&63)>>>0>=32){f=0;a=b>>>d|0}else{f=b>>>d|0;a=((1<<d)-1&b)<<32-d|c>>>d}jb=f;return a}j=f+1|0;h=63-f|0}e=b;g=a;f=j&63;i=f&31;if((f&63)>>>0>=32){f=0;l=e>>>i|0}else{f=e>>>i|0;l=((1<<i)-1&e)<<32-i|g>>>i}a=h&63;h=a&31;if((a&63)>>>0>=32){e=g<<h;a=0}else{e=(1<<h)-1&g>>>32-h|b<<h;a=g<<h}b=e;if(j){g=d-1|0;e=c-1|0;g=(e|0)!=-1?g+1|0:g;h=e;while(1){e=l;f=f<<1|e>>>31;e=e<<1;k=f;f=b>>>31|e;m=k;e=k;k=f;i=g-((f>>>0>h>>>0)+e|0)|0;e=i>>31;i=i>>31;f=c&i;l=k-f|0;f=m-((d&e)+(f>>>0>k>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;e=0;m=e;k=i&1;n=k;j=j-1|0;if(j){continue}break}}hb=l;ib=f;e=b<<1|a>>>31;a=k|a<<1;jb=e|m;return a}hb=a;ib=b;a=0;b=0}jb=b;return a}function x2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=gb-192|0;gb=a;Ec(a+184|0,d);v[22640]=0;m=T(21,a+184|0)|0;g=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Ab(f)){g=w[mc(f,0)|0];v[22640]=0;h=Q(22,m|0,45)|0;k=v[22640];v[22640]=0;if((k|0)==1){break g}n=(g|0)==(h&255)}k=Kb(a+160|0);g=Kb(a+144|0);h=Kb(a+128|0);v[22640]=0;na(2500,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,k|0,g|0,h|0,a+124|0);c=v[22640];v[22640]=0;if((c|0)==1){break f}v[a+4>>2]=2434;c=ge(a+8|0,0,a+4|0);i=Ab(f);l=v[a+124>>2];h:{if((i|0)>(l|0)){i=Ab(f);j=((Ab(h)+(i-l<<1)|0)+Ab(g)|0)+1|0;break h}j=(Ab(h)+Ab(g)|0)+2|0}i=a+16|0;j=j+l|0;if(j>>>0<101){break e}Ee(c,Ad(j));i=v[c>>2];if(i){break e}v[22640]=0;X(2435);b=v[22640];v[22640]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}j=v[d+4>>2];o=Jb(f);p=Jb(f);f=Ab(f);v[22640]=0;qa(2501,i|0,a+4|0,a|0,j|0,o|0,f+p|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],k|0,g|0,h|0,l|0);f=v[22640];v[22640]=0;if((f|0)!=1){v[22640]=0;b=la(17,b|0,i|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Gc(c)}vb(h);vb(g);vb(k)}Vb(a+184|0);S(f|0);L()}Gc(c);vb(h);vb(g);vb(k);Vb(a+184|0);gb=a+192|0;return b|0}function bga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0;g=gb-32|0;gb=g;s=g,t=B(v[a>>2],bd(a)),v[s+4>>2]=t;tc(g+4|0,c>>>3|0);c=zb(b);i=A[e+8>>3];j=v[g+4>>2];a:{if(!j){break a}e=j;while(1){k=0;f=c;m=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);q=h<<24|h<<8&16711680;o=k;k=m<<24|h>>>8;f=m<<8|h>>>24;o=o|0;k=k&65280|f&255|q;f=m;l(0,((f&255)<<24|h>>>8)&-16777216|((f&16777215)<<8|h>>>24)&16711680|(f>>>8&65280|f>>>24)|o);l(1,k&2147483647);i=G(+n(),i);c=c+8|0;e=e-1|0;if(e){continue}break}if(i==0){break a}r=1/i;c=v[a+20>>2];while(1){e=b;a=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);f=h<<24;q=0;m=h<<8&16711680|f;o=a<<24|h>>>8;f=a<<8|h>>>24;e=a;l(0,((e&255)<<24|h>>>8)&-16777216|((e&16777215)<<8|h>>>24)&16711680|(e>>>8&65280|e>>>24)|q);l(1,m|(o&65280|f&255));s=g,x=+n()*r,A[s+24>>3]=x;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;p=A[$g(g+24|0,g+16|0,g+8|0)>>3]*32768;A[g+24>>3]=p;a=c;p=fe(p);b:{if(D(p)<2147483648){e=~~p;break b}e=-2147483648}s=a,t=Sc(e),u[s>>1]=t;b=b+8|0;c=c+2|0;j=j-1|0;if(j){continue}break}}if(d){A[d>>3]=i}gb=g+32|0;return v[g+4>>2]<<3}function qfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;j=gb-48|0;gb=j;m=-1;d=gb-32|0;gb=d;g=j+8|0;hF(d+24|0,g);i=xb(d+24|0);f=v[d+28>>2];e=v[d+24>>2];v[d+8>>2]=e;v[d+12>>2]=f;v[d>>2]=e;v[d+4>>2]=f;f=a;qd(d+16|0,f,d);e=xb(d+16|0);if((e|0)==(i|0)){cd(f,xb(d+24|0))}gb=d+32|0;f=(e|0)==(i|0);if(!f){gF(g)}a:{if(!f){break a}m=0;if(!dO(j+8|0)){break a}if(c){f=a;e=j+8|0;b:{if(!c){break b}l=Lf(c);if(!l){break b}q=v[f+12>>2];if(Tl(f,w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24))){c:{if(!(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))){break c}r=l?0:-1;while(1){if(!Rf(f,5)){break c}d:{if((w[e+4|0]|w[e+5|0]<<8)>>>0>=64){d=f;i=Kr(d);h=i&63;e:{if(!(i&64)){break e}g=6;while(1){k=Kr(d);h=(k&127)<<g|h;if(!(k&128)){break e}k=g>>>0<25;g=g+7|0;if(k){continue}break}}if(((i&128?0-h|0:h)|0)<1){break d}}g=Kr(f);f:{if(g){i=1;h=0;while(1){k=tq(g<<24>>24);n=h>>>0>=l>>>0;g=n&i;d=g;g:{if(n){break g}d=g;if(!(i&1)){break g}d=w[c+h|0]==(k&255)}i=d;h=h+1|0;g=Kr(f);if(g){continue}break}d=(h|0)==(l|0)&i;break f}d=r}cd(f,4);o=d&1?1:o}p=p+1|0;if(p>>>0<(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0){continue}break}}h=o&1}Tl(f,q)}if(!h){break a}}m=Ne(a,b,cO(j+8|0),0)}gb=j+48|0;return m|0}function Z0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];k=d>>>0>b>>>0;a:{if(b>>>0>=d>>>0|f>>>0>=g>>>0){break a}b:{while(1){i=t[b|0];c=i&255;j=b+1|0;c:{if((i|0)>=0){break c}k=2;if(c>>>0<194){break a}if(c>>>0<=223){if((d-b|0)<2){break b}i=w[b+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;j=b+2|0;break c}if(c>>>0<=239){if((d-b|0)<3){break b}j=w[b+2|0];i=w[b+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((j&192)!=128){break a}c=j&63|(c<<12&61440|(i&63)<<6);j=b+3|0;break c}if(c>>>0>244){break a}if((d-b|0)<4){break b}j=w[b+3|0];l=w[b+2|0];i=w[b+1|0];f:{g:{switch(c-240|0){case 0:if((i+112&255)>>>0<48){break f}break a;case 4:if((i&240)==128){break f}break a;default:break g}}if((i&192)!=128){break a}}if((l&192)!=128|(j&192)!=128){break a}c=j&63|(l<<6&4032|(c<<18&1835008|(i&63)<<12));if(c>>>0>1114111){break a}j=b+4|0}v[f>>2]=c;v[a+12>>2]=j;f=v[a+8>>2]+4|0;v[a+8>>2]=f;b=v[a+12>>2];k=d>>>0>b>>>0;if(b>>>0>=d>>>0){break a}if(f>>>0<g>>>0){continue}break}break a}k=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return k|0}function UP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-32|0;gb=e;d=v[b+64>>2];a:{b:{g=v[b+60>>2];f=x[b+68>>1];if(!((f|0)==65535?(g|0)==-1:0)){c:{if((d|0)==-1){break c}d=a+1074312|0;Db(e+24|0,d,68);if(Cb(e+24|0)){break c}Db(e+16|0,d,103);if(h=Cb(e+16|0),i=0,j=(f|0)!=65535,j?h:i){break c}Db(e+8|0,d,49);if(h=Cb(e+8|0),i=0,j=(f|0)!=65535,j?h:i){break c}d=v[b+64>>2];break b}if((f|0)==65535){u[b+68>>1]=x[b+72>>1]+1}if((g|0)==-1){v[b+60>>2]=0}d=x[b+68>>1];f=a+484360|0;d:{if(sc(Rb(f))>>>0>d>>>0){d=x[b+68>>1];break d}d=x[Rb(f)+28>>1];u[b+68>>1]=d}e:{if(x[b+72>>1]==(d&65535)){break e}d=a+1074312|0;Db(e+24|0,d,26);if(Cb(e+24|0)){break e}Db(e+16|0,d,68);if(Cb(e+16|0)|v[a+480180>>2]==1|!x[a+480188>>1]){break e}d=0;while(1){t[(B(d,872)+b|0)+1457|0]=0;d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}v[b+52>>2]=v[b+60>>2];if(c){c=1;if(w[a+480208|0]&32){break a}}u[b+74>>1]=x[b+68>>1];c=1;break a}if((d|0)!=-1){break b}c=0;break a}v[b+52>>2]=d;u[b+74>>1]=x[b+72>>1];f:{if(!v[b+20>>2]){break f}if(v[a+480180>>2]==32){Db(e+24|0,a+1074312|0,103);if(Cb(e+24|0)){break f}}if(v[a+480180>>2]==2){break f}v[b+52>>2]=v[b+52>>2]+1}c=0;if(y[b+64>>2]<y[_b(a+484344|0,x[b+70>>1])+12>>2]){break a}v[b+52>>2]=0;u[b+74>>1]=x[b+74>>1]+1;c=0}gb=e+32|0;return c}function Boa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-32|0;gb=c;a:{b:{if(!Pb(b,9)){break b}h=a+484344|0;i=a+480280|0;while(1){ep(b,c+28|0);d=og(b);c:{if(!((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1229999433|(w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1397771593|((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1297110104|(w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1297110099))){if(Pb(b,d)){break c}}lg(b,8);break b}rd(c+8|0,b,d);d=i;d:{if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1481001027){while(1){v[22640]=0;e=T(229,c+8|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break a}t[d+8|0]=e;d=d+32|0;if((h|0)!=(d|0)){continue}break d}}e:{if(w[c+28|0]!=70){break e}d=w[c+29|0];e=(d|0)==88;if(!((d-48&255)>>>0>9?e:1)){break e}f=w[c+30|0];if((f-48&255)>>>0>9){break e}g=w[c+31|0];if((g-48&255)>>>0>9){break e}d=(B(f,10)+(e?-16:B(d,100)+48|0)|0)+g&255;if(d>>>0>249){break d}v[22640]=0;R(625,c+8|0,(B(d,160)+a|0)+906300|0);d=v[22640];v[22640]=0;if((d|0)!=1){break d}break a}if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))!=1430540109){break d}v[a+1074308>>2]=0;j=1}yb(c+8|0);if(Pb(b,9)){continue}break}}gb=c+32|0;return j|0}a=P()|0;O()|0;yb(c+8|0);S(a|0);L()}function v8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb-2160|0;gb=b;Qb(b+112|0,0,2048);a:{b:{c:{f=v[c+4>>2];if(!f){a=aa(8)|0;v[22640]=0;b=Q(112,b+96|0,7779)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}qc(a,b);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}g=v[c>>2];d=v[c+12>>2];h=v[c+8>>2];v[b+88>>2]=h;v[b+92>>2]=d;c=v[b+92>>2];v[b+40>>2]=v[b+88>>2];v[b+44>>2]=c;v[b+84>>2]=f;v[b+80>>2]=g;c=v[b+84>>2];v[b+32>>2]=v[b+80>>2];v[b+36>>2]=c;c=b;j=b;i=jV(b+32|0);if(i){e=b- -64|0;v[e>>2]=h;v[b+68>>2]=d;d=v[e+4>>2];v[b+24>>2]=v[e>>2];v[b+28>>2]=d;v[b+60>>2]=f;v[b+56>>2]=g;d=v[b+60>>2];v[b+16>>2]=v[b+56>>2];v[b+20>>2]=d;d=fV(b+16|0)}else{d=0}v[j+72>>2]=d;v[c+76>>2]=0;c=0;d=2048;while(1){d:{e=kb[f|0](g,(b+112|0)+c|0,d)|0;c=e+c|0;if(!e){break d}d=d-e|0;if(d){continue}}break}c=Wd(b+48|0,zb(b+112|0),c);f=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=f;a=Vz(a,b+8|0,i?b+72|0:0);if(a+1>>>0>=3){a=aa(8)|0;v[22640]=0;b=Q(112,b+96|0,5270)|0;c=v[22640];v[22640]=0;if((c|0)!=1){qc(a,b);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}c=P()|0;O()|0;da(a|0);break b}gb=b+2160|0;return a|0}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function GI(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;k=gb-16|0;gb=k;a:{b:{c:{if((c|0)<=36){h=w[a|0];if(h){break c}f=a;break b}v[115121]=28;d=0;e=0;break a}f=a;d:{while(1){if(!xm(h<<24>>24)){break d}h=w[f+1|0];g=f+1|0;f=g;if(h){continue}break}f=g;break b}e:{g=w[f|0];switch(g-43|0){case 0:case 2:break e;default:break b}}m=(g|0)==45?-1:0;f=f+1|0}f:{if(!(c&-17|w[f|0]!=48)){o=1;if((w[f+1|0]&223)==88){f=f+2|0;l=16;break f}f=f+1|0;l=c?c:8;break f}l=c?c:10}p=l;q=l>>31;c=0;while(1){g:{g=t[f|0];h=g-48|0;h:{if((h&255)>>>0<=9){break h}if((g-97&255)>>>0<=25){h=g-87|0;break h}if((g-65&255)>>>0>25){break g}h=g-55|0}if((h|0)>=(l|0)){break g}pf(k,p,q,0,0,j,i,0,0);g=1;i:{if(v[k+8>>2]|v[k+12>>2]){break i}r=mqa(j,i,p,q);n=jb;s=h>>31;u=s^-1;if((n|0)==(u|0)&(h^-1)>>>0<r>>>0|n>>>0>u>>>0){break i}i=n+s|0;g=h+r|0;i=g>>>0<h>>>0?i+1|0:i;j=g;o=1;g=c}f=f+1|0;c=g;continue}break}if(b){v[b>>2]=o?f:a}j:{k:{if(c){v[115121]=68;a=d&1;m=a?0:m;j=d;i=e;break k}if((e|0)==(i|0)&d>>>0>j>>>0|e>>>0>i>>>0){break j}a=d&1}if(!(a|m)){v[115121]=68;a=d;d=a-1|0;e=e-(a>>>0<1)|0;break a}if((e|0)==(i|0)&d>>>0>=j>>>0|e>>>0>i>>>0){break j}v[115121]=68;break a}a=m;c=a^j;d=c-a|0;b=a>>31;e=(b^i)-((a>>>0>c>>>0)+b|0)|0}gb=k+16|0;jb=e;return d}function Ooa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;f=a;g=a+3|0;e=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=w[a+3|0];switch(b-14|0){case 8:break j;case 6:case 7:break k;case 1:break l;case 0:break m;case 2:case 3:case 4:case 5:break b;default:break n}}switch(b-31|0){case 2:break h;case 0:break i;default:break b}}o:{p:{c=w[a+5|0];if((c|0)!=240){if((c|0)==15){break p}if(c){break o}a=29214;break g}t[a+5|0]=239;break c}t[a+5|0]=254;break c}if(c>>>0>=16){t[a+5|0]=c|15;break c}t[a+5|0]=c|240;break c}t[a+5|0]=w[a+5|0]^128;break c}e=w[a+5|0];if(e>>>0>=16){t[d+15|0]=e>>>4;t[d+14|0]=15;h=a,i=w[ac(d+15|0,d+14|0)|0]|240,t[h+5|0]=i;break c}t[a+5|0]=e|224;break c}t[a+5|0]=((w[a+5|0]^-1)&254)>>>1;break c}h=a,i=di(w[a+5|0]<<1),t[h+5|0]=i;break c}b=32;q:{r:{s:{t:{u:{c=w[a+5|0];switch(c>>>4|0){case 12:case 13:break r;case 11:break s;case 10:break t;case 8:break u;case 0:break c;case 3:break d;case 5:break e;case 14:break f;default:break q}}b=64;break d}b=176;break d}b=224;break d}if(c){break c}}a=29200}t[e+3|0]=w[a|0];break a}t[a+5|0]=119;break c}b=48}t[a+5|0]=c&15|b}b=w[f+3|0]}if(b>>>0<36){t[f+3|0]=w[b+29200|0];if(w[a+2|0]|(b|0)!=12){break a}t[a+2|0]=1;t[a+3|0]=0;t[a+4|0]=w[a+5|0];g=a+5|0}t[g|0]=0}gb=d+16|0}function h_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=gb-1088|0;gb=f;e=Ih(f+24|0);h=$k(a,e);yb(e);v[a+1064>>2]=0;v[a+1068>>2]=0;v[a+1060>>2]=c;e=a+1072|0;v[e>>2]=0;v[e+4>>2]=0;e=0;v[a+1080>>2]=0;t[a+1084|0]=d;a:{b:{if(bd(c)){i=a+1064|0;while(1){v[a+1064>>2]=0;v[a+1068>>2]=0;c:{if(!v[c>>2]){break c}while(1){v[22640]=0;d=Q(228,b|0,2)|0;g=v[22640];v[22640]=0;d:{e:{f:{g:{if((g|0)!=1){if(!d){break c}v[22640]=0;d=T(319,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break g}if(!d){break d}v[22640]=0;U(320,f|0,b|0,d|0);d=v[22640];v[22640]=0;if((d|0)==1){break f}d=$k(f+24|0,f);od(h,d);hc(h+20|0,d+20|0,1040);yb(f+24|0);yb(f);v[a+1076>>2]=0;v[a+1080>>2]=0;g=ej(v[a+1060>>2]);d=v[a+1060>>2];if(g>>>0>=2){d=v[d+20>>2];v[22640]=0;R(321,a|0,d+(e<<1)|0);d=v[22640];v[22640]=0;if((d|0)!=1){break d}break e}d=v[d+20>>2];v[22640]=0;R(322,a|0,d+e|0);d=v[22640];v[22640]=0;if((d|0)==1){break e}break d}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=V(27860)|0;if((O()|0)!=(ea(27860)|0)){break a}Z(d|0)|0;v[22640]=0;X(20);d=v[22640];v[22640]=0;if((d|0)==1){break b}}if(y[i>>2]<y[c>>2]){continue}break}}e=e+1|0;if(bd(v[a+1060>>2])>>>0>e>>>0){continue}break}}gb=f+1088|0;return a|0}d=P()|0;O()|0}yb(a);S(d|0);L()}function ppa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-32|0;gb=h;v[h+24>>2]=b;b=v[a>>2];m=h,n=Sb(a),v[m>>2]=n;b=Xj(h+24|0,h)+b|0;a:{g=RX(c,d);b:{if((g|0)<1){break b}i=v[wb(a)>>2];e=v[a+4>>2];if((g|0)<=(i-e|0)){v[h>>2]=d;i=e-b|0;if((i|0)<(g|0)){v[h>>2]=c;dw(h,i);l=v[h>>2];k=gb-16|0;gb=k;j=Ri(k,a,g-i|0);wb(a);f=gb-16|0;gb=f;v[f>>2]=d;v[f+8>>2]=l;if(Gb(f+8|0,f)){while(1){jp(v[j+4>>2],v[f+8>>2]);Me(f+8|0);v[j+4>>2]=v[j+4>>2]+1;if(Gb(f+8|0,f)){continue}break}}gb=f+16|0;$b(j);gb=k+16|0;if((i|0)<1){break b}}k=gb-16|0;gb=k;f=e;j=b;i=a;l=v[a+4>>2];a=(l-(b+g|0)|0)+b|0;g=Ri(k,i,e-a|0);if(a>>>0<e>>>0){e=v[g+4>>2];d=a;while(1){wb(i);jp(e,d);e=e+1|0;v[g+4>>2]=e;d=d+1|0;if(f>>>0>d>>>0){continue}break}}$b(g);hn(j,a,l);gb=k+16|0;Ti(c,v[h>>2],b);break b}e=wb(a);e=dh(h,vh(a,pc(a)+g|0),b-v[a>>2]|0,e);v[22640]=0;QX(e,c,d);c=v[22640];v[22640]=0;if((c|0)==1){break a}sv(a);c=v[e+4>>2];j=e+4|0;xk(wb(a),v[a>>2],b,j);wb(a);i=e+8|0;d=i;g=v[a+4>>2];if((g|0)!=(b|0)){f=v[d>>2];while(1){jp(f,b);f=v[d>>2]+1|0;v[d>>2]=f;b=b+1|0;if((g|0)!=(b|0)){continue}break}}jc(a,j);jc(a+4|0,i);jc(wb(a),cc(e));v[e>>2]=v[e+4>>2];Lu(a,pc(a));b=c;ae(e)}bh(b);gb=h+32|0;return}a=P()|0;O()|0;ae(e);S(a|0);L()}function Fq(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];i:{if((b|0)<=2047){if((b|0)<=31){switch(b-1|0){case 2:case 4:case 5:case 6:break d;case 7:break g;case 0:case 1:case 3:break i;default:break e}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break b}break d}if((b|0)==256|(b|0)==512){break b}break d}d=1;if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break b}if((b|0)!=8192){break d}break b}if((b|0)==65536){break c}if((b|0)!=2097152){break d}break a}if((b|0)>67108863){break h}if((b|0)==4194304){break f}if((b|0)!=16777216){break d}}d=v[a+480180>>2];break a}if((b|0)==67108864|(b|0)==134217728){break a}if((b|0)!=536870912){break d}break a}d=4;if(x[a+480192>>1]){break a}a=a+484344|0;f=c,g=Sb(a),v[f+8>>2]=g;f=c,g=Wb(a),v[f>>2]=g;a=1;j:{if(!Gb(c+8|0,c)){break j}while(1){b=v[c+8>>2];if(!(!hi(b)|v[b+12>>2]==64)){a=4;break j}fP(c+8|0);if(Gb(c+8|0,c)){continue}break}}gb=c+16|0;return a}d=32;if(x[a+480188>>1]>16){break a}if(!x[a+480188>>1]){break b}b=0;while(1){e=(b<<5)+a|0;if(t[e+480281|0]&1|x[e+480286>>1]!=64){break a}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break b}if((b|0)==16){break b}}d=32;break a}d=16777216;break a}d=2}gb=c+16|0;return d}function _O(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b:{d=a+484360|0;if(sc(Rb(d))>>>0<=b>>>0){break b}if(Mo(Rb(d),b)){break b}while(1){b=b+1|0;c=b&65535;if(sc(Rb(d))>>>0<=c>>>0){break a}if(!Mo(Rb(d),b&65535)){continue}break}break a}c=b}if(sc(Rb(d))>>>0>c>>>0){d=a+1074312|0;f=a+1298224|0;c=a+1074992|0;while(1){t[c+797|0]=0;v[c+700>>2]=0;t[c+841|0]=0;t[c+805|0]=0;v[c+708>>2]=0;t[c+821|0]=0;v[c+764>>2]=0;t[c+819|0]=0;t[c+820|0]=0;Db(e+8|0,d,23);if(Cb(e+8|0)){t[c+807|0]=1;t[c+808|0]=0}t[c+839|0]=0;c=c+872|0;if((f|0)!=(c|0)){continue}break}ZO(a);c:{if(!(b&65535)){b=a;c=0;while(1){$m((b+B(c,872)|0)+1074992|0,7,b,c&65535,134217728);c=c+1|0;if((c|0)!=256){continue}break}Jo(b+1298224|0,1);v[b+1074456>>2]=v[b+480200>>2];v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+480208>>2]=v[b+480208>>2]&-769;iA(b+1074376|0);u[b+1074450>>1]=0;v[b+1074392>>2]=-2;c=b+1074428|0;v[c>>2]=0;v[c+4>>2]=0;c=b+1074396|0;v[c>>2]=0;v[c+4>>2]=0;v[b+1074376>>2]=0;v[b+1074380>>2]=0;break c}u[a+1074450>>1]=b;u[a+1074446>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}gb=e+16|0}function Ypa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-32|0;gb=f;t[f+16|0]=44;v[f+8>>2]=-1;v[f+12>>2]=0;v[f>>2]=1058;v[f+4>>2]=2;j=a;c=gb+-64|0;gb=c;k=c;a=f;h=v[a>>2]&2?16:10;g=gb-32|0;gb=g;d=Ge(g+16|0,1,0);a:{b:{c:{while(1){e=Jb(d);i=Jb(d);l=Ab(d);m=v[b>>2];v[22640]=0;ha(134,g+8|0,e|0,i+l|0,m|0,h|0);e=v[22640];v[22640]=0;if((e|0)==1){break b}if(!v[g+12>>2]){break c}e=Ab(d);v[22640]=0;v[g+4>>2]=e;e=wf(g+4|0);i=v[22640];v[22640]=0;if((i|0)!=1){v[22640]=0;U(117,d|0,e|0,0);e=v[22640];v[22640]=0;if((e|0)!=1){continue}}break}break b}b=v[g+8>>2];h=Jb(d);v[22640]=0;R(118,d|0,b-h|0);b=v[22640];v[22640]=0;if((b|0)!=1){v[22640]=0;R(119,k|0,d|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}vb(d);gb=g+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}Al(c+16|0,c,a);v[22640]=0;U(131,c+32|0,c+16|0,a|0);b=v[22640];v[22640]=0;d:{e:{f:{g:{h:{if((b|0)!=1){v[22640]=0;U(132,c+48|0,c+32|0,a|0);a=v[22640];v[22640]=0;if((a|0)==1){break h}v[22640]=0;R(114,j|0,c+48|0);a=v[22640];v[22640]=0;if((a|0)==1){break g}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);gb=c- -64|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}gb=f+32|0}function sea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=Of(a);if(f>>>0<b>>>0){j=gb-32|0;gb=j;a:{b:{d=b-f|0;c:{if(d>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/52>>>0){_y(a,d,c);break c}h=wb(a);e=EN(a,Of(a)+d|0);g=Of(a);f=0;i=gb-16|0;gb=i;v[i+12>>2]=0;b=j+8|0;ef(b+12|0,h);if(e){f=zN(e)}v[b>>2]=f;h=B(g,52)+f|0;v[b+8>>2]=h;v[b+4>>2]=h;m=cc(b),n=B(e,52)+f|0,v[m>>2]=n;gb=i+16|0;v[22640]=0;U(1497,b|0,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}c=a;PO(a);wb(a);f=b;k=b+4|0;i=k;h=v[a>>2];a=v[a+4>>2];if((h|0)!=(a|0)){d=v[i>>2];while(1){d=d-52|0;a=a-52|0;e=xN(d,wb(a));v[d>>2]=v[a>>2];v[d+4>>2]=v[a+4>>2];g=v[wb(a)>>2];m=wb(e),n=g,v[m>>2]=n;m=wb(a),n=0,v[m>>2]=n;v[a>>2]=0;v[a+4>>2]=0;v[d+20>>2]=v[a+20>>2];e=v[a+16>>2];v[d+12>>2]=v[a+12>>2];v[d+16>>2]=e;g=d+24|0;e=a+24|0;l=dE(g,wb(e));v[g>>2]=v[e>>2];v[g+4>>2]=v[e+4>>2];g=v[wb(e)>>2];m=wb(l),n=g,v[m>>2]=n;m=wb(e),n=0,v[m>>2]=n;v[e>>2]=0;v[e+4>>2]=0;Dc(d+36|0,a+36|0);v[d+48>>2]=v[a+48>>2];d=v[i>>2]-52|0;v[i>>2]=d;if((a|0)!=(h|0)){continue}break}}wc(c,k);wc(c+4|0,f+8|0);wc(wb(c),cc(f));v[f>>2]=v[f+4>>2];yN(c,Of(c));wN(b)}gb=j+32|0;break a}a=P()|0;O()|0;wN(b);S(a|0);L()}return}if(b>>>0<f>>>0){FN(a,v[a>>2]+B(b,52)|0)}}function b8(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-80|0;gb=d;a:{b:{c:{d:{e:{f:{g:{if(yj(a)){th(d+72|0);break g}mo(d+32|0,a);v[22640]=0;c=T(2084,d+32|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break f}v[d+72>>2]=c;Uf(d+32|0)}if(yj(a)){e=a+36|0}else{e=v[d+72>>2]}c=v[a+8>>2];if((c|0)!=-1){break c}c=v[e+4>>2]-24|0;h=jo(e);if(h){break e}break d}g=P()|0;O()|0;Uf(d+32|0);break a}j=A[c>>3];while(1){f=Ul(e,g);if(A[f>>3]+i>b){c=f;break d}i=j+i;g=g+1|0;if((h|0)!=(g|0)){continue}break}}b=b-i;break b}c=Ul(e,c)}e=a+24|0;f=v[e>>2];g=x[c+12>>1];v[22640]=0;R(2085,f|0,g|0);f=v[22640];v[22640]=0;if((f|0)!=1){h:{f=v[e>>2];g=w[a+64|0];c=uL(wV(d+32|0,b),w[c+16|0],x[c+12>>1],v[c+8>>2]);v[22640]=0;h=v[c+12>>2];v[d+16>>2]=v[c+8>>2];v[d+20>>2]=h;h=v[c+20>>2];v[d+24>>2]=v[c+16>>2];v[d+28>>2]=h;h=v[c+4>>2];v[d+8>>2]=v[c>>2];v[d+12>>2]=h;Y(2049,d+56|0,f|0,(g?7:1)|0,d+8|0);c=v[22640];v[22640]=0;if((c|0)==1){break h}c=VO(d+56|0);f=t[c+26|0]&1;g=v[(f?c+8|0:c+12|0)>>2];f=x[(f?c+20|0:c+22|0)>>1];b=A[c>>3];en(d+56|0);u[v[e>>2]+1074448>>1]=f;u[v[e>>2]+1074450>>1]=f;v[v[e>>2]+1074428>>2]=g;v[v[e>>2]+1074392>>2]=-2;b=b+i;A[a+16>>3]=b;yl(d+72|0);gb=d+80|0;return+b}}g=P()|0;O()|0;yl(d+72|0)}S(g|0);L()}function Eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=gb-32|0;gb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[g+24>>2]=f;v[g+28>>2]=b;v[g+16>>2]=h;v[g+20>>2]=e;if(d){while(1){e=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+j|0;b=(f>>>16&65520)+i|0;m=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],m)|0)/32768;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],k);Ub(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;f=v[g+24>>2];b=v[g+28>>2];continue}break}f=v[g+24>>2];b=v[g+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=g+32|0}function J2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=gb-160|0;gb=a;v[a+144>>2]=c;v[a+152>>2]=b;v[a+20>>2]=2485;b=ge(a+24|0,a+32|0,a+20|0);v[22640]=0;Ec(a+16|0,e);h=v[22640];v[22640]=0;a:{b:{c:{d:{if((h|0)!=1){v[22640]=0;h=T(21,a+16|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break b}t[a+15|0]=0;e=v[e+4>>2];v[22640]=0;c=ra(2486,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}if(!c){break c}Ye(g);if(!w[a+15|0]){break d}v[22640]=0;c=Q(22,h|0,45)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}v[22640]=0;R(103,g|0,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[22640]=0;h=Q(22,h|0,48)|0;c=v[22640];v[22640]=0;if((c|0)==1){break b}e=v[b>>2];i=v[a+20>>2];c=i-1|0;d=c>>>0<e>>>0?e:c;e:{if(c>>>0<=e>>>0){break e}h=h&255;while(1){if((h|0)!=w[e|0]){d=e;break e}e=e+1|0;if((c|0)!=(e|0)){continue}break}}v[22640]=0;U(2492,g|0,d|0,i|0);c=v[22640];v[22640]=0;if((c|0)!=1){break c}break b}v[22640]=0;c=Q(2437,a+152|0,a+144|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}if(c){v[f>>2]=v[f>>2]|2}c=v[a+152>>2];Vb(a+16|0);Gc(b);gb=a+160|0;return c|0}e=P()|0;O()|0;Vb(a+16|0)}Gc(b);S(e|0);L()}function Gea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;k=gb-16|0;gb=k;a:{b:{if(!Ld(a)){break b}if((b|0)==(c|0)|(bd(a)|0)!=2){break b}if(l=Ld(b),m=0,n=(a|0)!=(b|0),n?l:m){break b}if(l=Ld(c),m=0,n=(a|0)!=(c|0),n?l:m){break b}if((a|0)==(b|0)){j=v[b+20>>2]}else{j=Wq(v[a>>2],ej(a))}e=j;if((a|0)==(c|0)){f=v[c+20>>2]}else{f=Wq(v[a>>2],ej(a))}if(!(f?e:0)){if((a|0)!=(b|0)){Xq(j)}if((a|0)==(c|0)){break b}Xq(f);break b}c:{if((ej(a)|0)==2){g=j;e=f;h=v[a+20>>2];i=v[a>>2];if(i){while(1){u[g>>1]=x[h>>1];u[e>>1]=x[h+2>>1];h=h+4|0;e=e+2|0;g=g+2|0;i=i-1|0;if(i){continue}break}}break c}if((ej(a)|0)!=1){break c}g=j;e=f;h=v[a+20>>2];i=v[a>>2];if(i){while(1){t[g|0]=w[h|0];t[e|0]=w[h+1|0];h=h+2|0;e=e+1|0;g=g+1|0;i=i-1|0;if(i){continue}break}}}Zo(b,a);v[b+20>>2]=j;u[b+34>>1]=x[b+34>>1]&65471;Zo(c,a);v[c+20>>2]=f;u[c+34>>1]=x[c+34>>1]&65471;j=d+1298224|0;a=d+1074992|0;while(1){f=v[a+104>>2];if(!((c|0)!=(f|0)?(f|0)!=(b|0):0)){v[a+88>>2]=v[a+88>>2]&-65}a=a+872|0;if((j|0)!=(a|0)){continue}break}v[22640]=0;Zh(b,d,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}v[22640]=0;Zh(c,d,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}g=1}gb=k+16|0;return g|0}a=P()|0;O()|0;S(a|0);L()}function cZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=gb-32|0;gb=g;t[g+12|0]=0;l=DD(g+16|0,d,g+12|0);h=v[l>>2];v[g+12>>2]=d;f=d;a:{if(!b|!f){break a}while(1){m=g;i=b-1|0;f=w[a|0];b:{c:{if(!(!i|(f|0)!=(e&255))){f=w[a+1|0];v[22640]=0;v[g+8>>2]=f;f=Fb(g+8|0,g+12|0);i=v[22640];v[22640]=0;d:{if((i|0)!=1){k=a+2|0;i=b-2|0;if(!i){break d}j=v[f>>2];if(!(j&255)){break d}i=w[k|0];while(1){t[h|0]=i;f=v[g+12>>2]-1|0;v[g+12>>2]=f;h=h+1|0;j=j-1|0;if(j&255){continue}break}i=b-3|0;k=a+3|0;break b}a=P()|0;O()|0;gc(l);S(a|0);L()}t[h|0]=e;f=v[g+12>>2]-1|0;break c}k=a+1|0;t[h|0]=f;f=v[g+12>>2]-1|0}v[m+12>>2]=f;h=h+1|0}if(!i){break a}a=k;b=i;if(f){continue}break}}k=v[l>>2];e=d-f|0;if(e){h=128;i=0;while(1){b=w[k|0];j=0;f=0;while(1){a=c+i|0;t[a|0]=w[a|0]|(B(b&h,257)&65535)>>>(f-j&7);a=i+1|0;i=a>>>0<d>>>0?a:0;f=(a>>>0>=d>>>0)+f|0;h=(h<<8|h)>>>1&255;a=j&65535;j=j+1|0;if(a>>>0<7){continue}break}h=(B(h,257)&65535)>>>f&255;k=k+1|0;n=n+1|0;if((n|0)!=(e|0)){continue}break}j=0;while(1){d=c;f=d;m=j<<24>>24;b=t[d|0];d=128;e:{if((b|0)==-128){break e}a=b;d=a;if((a|0)>-1){break e}d=0-(b&127)|0}j=m-(d&255)|0;t[f|0]=j;c=c+1|0;e=e-1|0;if(e){continue}break}}gc(l);gb=g+32|0}function Yha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;k=v[a+16>>2];f=Sd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=gg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}l=v[a+24>>2];m=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;a:{if((b|0)<=0){break a}while(1){g=(i&2147483647)<<1|j>>>31;Id(v[f+8>>2],(u[(g<<1|2)+h>>1]+u[h+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Id(j,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Hd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function Yg(a,b,c,d){var e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;v[g+12>>2]=d;e=b-1|0;f=0;a:{if(e>>>0>249){break a}h=fp(a);f=v[a+480180>>2];if(!h){if(f&17408){a=((e&255)>>>0)/12|0;f=x[((e-B(a,12)&255)<<1)+40064>>1]<<4>>>a|0;break a}if(qk(a)){a=((e&255)>>>0)/12|0;b=mqa(v[(e-B(a,12)<<6&960)+43952>>2]<<a,0,d,0);a=jb;c=a>>>21|0;f=Uc((a&2097151)<<11|b>>>21,c);break a}if(w[a+480208|0]&16){a=((e&255)>>>0)/12|0;f=x[((e-B(a,12)&255)<<1)+40064>>1]<<5>>>a|0;break a}if(!d){v[g+12>>2]=8363}a=((e&255)>>>0)/12|0;tc(g+12|0,-1>>>a|0);f=Uc(pqa(mqa(x[((e-B(a,12)&255)<<1)+40064>>1],0,267616,0),jb,v[g+12>>2]<<a,0),jb);break a}if(f&20){d=e>>>0>12;if(v[a+480180>>2]==16){b=c<<4}else{Db(g,a+1074312|0,76);b=Cb(g)?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;f=(a|0)>1?a:1;break a}c=c-12|0;a=((c&255)>>>0)/12|0;c=((b|0)/16|0)+(c-B(a,12)<<3&248)|0;v[g>>2]=c+8;Qd(g,0,103);c=c+((b|0)<0?-1:1)|0;c=(c|0)>-8?c:-8;d=b;b=b>>31;b=(d+b^b)&15;f=B(x[(((c|0)<95?c:95)<<1)+40560>>1],b)+B(x[(v[g>>2]<<1)+40544>>1],16-b|0)<<1>>>a|0;break a}a=c>>>4&15;if(e>>>0<108?a|e>>>0<24:1){b=B(a,12);a=((e&255)>>>0)/12|0;f=x[(b+(e-B(a,12)&255)<<1)+39664>>1]<<5>>>a|0;break a}f=x[(b<<1)+39438>>1]<<2}gb=g+16|0;return f}function V$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if(Og(a,v[b+8>>2],e)){Rw(b,c,d);return}a:{if(Og(a,v[b>>2],e)){if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}d=v[a+12>>2];if((d|0)<=0){v[b+44>>2]=4;break b}i=((d<<3)+a|0)+16|0;f=a+16|0;j=b;c:{d:{while(1){e:{u[b+52>>1]=0;Qw(f,b,c,c,1,e);if(w[b+54|0]){break e}f:{if(!w[b+53|0]){break f}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break d}h=1;g=1;if(w[a+8|0]&2){break f}break d}h=1;d=g;if(!(t[a+8|0]&1)){break d}}f=f+8|0;if(i>>>0>f>>>0){continue}}break}d=g;a=4;if(!h){break c}}a=3}v[j+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}g=v[a+12>>2];f=a+16|0;As(f,b,c,d,e);if((g|0)<2){break a}g=f+(g<<3)|0;f=a+24|0;a=v[a+8>>2];if(v[b+36>>2]!=1?a&2:1){while(1){if(w[b+54|0]){break a}As(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}As(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|(v[b+24>>2]==1?v[b+36>>2]==1:0)){break a}As(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function MM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=C(0);c=gb-96|0;gb=c;d=v[b+4>>2];v[c+64>>2]=v[b>>2];v[c+68>>2]=d;b=Sd(c+56|0);d=v[c+68>>2];v[c+8>>2]=v[c+64>>2];v[c+12>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;d=gm(c+72|0,c+8|0,c);v[22640]=0;b=T(492,d|0)|0;e=v[22640];v[22640]=0;a:{if((e|0)==1){break a}v[22640]=0;b=W(1599,d|0,c+16|0,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break a}b:{if(!b|v[c+16>>2]!=542066252){break b}b=c+16|4;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break b}b=c+24|0;f=a,g=Fo((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4220>>2]=g;b=c+28|0;f=a,g=Fo((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4224>>2]=g;b=c+32|0;f=a,g=Fo((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4228>>2]=g;b=c+36|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<=5){v[a+4232>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)}b=c+40|0;v[a+4236>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+4240|0]=w[c+44|0]!=0;t[a+4241|0]=w[c+45|0]!=0;t[a+4242|0]=w[c+46|0]!=0;t[a+4243|0]=w[c+47|0]!=0;t[a+4244|0]=w[c+48|0]!=0;Nt(a)}yb(d);gb=c+96|0;return}a=P()|0;O()|0;yb(d);S(a|0);L()}function fT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=gb-16|0;gb=g;a:{if(w[d|0]){e=le(g+8|0,b);b=Mj(c,b);d=gb-16|0;gb=d;v[d+12>>2]=b;c=v[e+4>>2];b:{if(c){v[d+8>>2]=32-c;b=Fb(d+8|0,d+12|0);c=v[e>>2];b=v[b>>2];f=v[c>>2]&(-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b);if(f){pd(a,c,lqa(f));break b}f=v[d+12>>2];if((f|0)==(b|0)){hB(a,e,b);break b}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if(f){pd(a,c,lqa(f));break b}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}c:{if(!b){c=v[e>>2];break c}c=v[e>>2];e=v[c>>2]&-1>>>32-b;if(!e){break c}pd(a,c,lqa(e));break b}pd(a,c,b)}break a}e=le(g,b);b=Mj(c,b);d=gb-16|0;gb=d;v[d+12>>2]=b;c=v[e+4>>2];d:{if(c){v[d+8>>2]=32-c;b=v[Fb(d+8|0,d+12|0)>>2];c=v[e>>2];f=-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b&(v[c>>2]^-1);if(f){pd(a,c,lqa(f));break d}f=v[d+12>>2];if((f|0)==(b|0)){hB(a,e,b);break d}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if((f|0)!=-1){pd(a,c,lqa(f^-1));break d}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}e:{if(!b){c=v[e>>2];break e}c=v[e>>2];e=(v[c>>2]^-1)&-1>>>32-b;if(!e){break e}pd(a,c,lqa(e));break d}pd(a,c,b)}}gb=d+16|0;gb=g+16|0}function Lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;g=gb-16|0;gb=g;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];i=e;h=v[a>>2];v[g+8>>2]=h;v[g+12>>2]=e;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(d){while(1){e=i+q|0;i=t[e+2|0];m=t[e+1|0];n=t[e|0];o=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=mqa(j,j>>31,e,e>>31);j=jb;w=e;e=v[a+68>>2];p=mqa(e,e>>31,f,f>>31);e=w+p|0;f=jb+j|0;f=e>>>0<p>>>0?f+1|0:f;j=e;e=h>>>21&2040;i=(((B(n,u[e+46530>>1])+B(o,u[e+46528>>1])|0)+B(m,u[e+46532>>1])|0)+B(i,u[e+46534>>1])<<8)/16384<<8;e=i;h=mqa(r,s,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Ic(e,f,24);e=v[a+72>>2];h=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=h+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&i)|0;Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+8>>2];i=v[g+12>>2];f=b;b=e;continue}break}h=v[g+8>>2];i=v[g+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=h;v[a+4>>2]=i;gb=g+16|0}function Iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=gb-16|0;gb=g;i=g;c=gb-160|0;gb=c;e=c+24|0;h=Bt(e+56|0);v[e>>2]=77792;v[h>>2]=77812;v[22640]=0;f=e+4|0;W(137,e|0,77824,f|0)|0;d=v[22640];v[22640]=0;a:{if((d|0)!=1){b:{v[e>>2]=77792;v[h>>2]=77812;v[22640]=0;Q(138,f|0,16)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}break a}}a=P()|0;O()|0;lh(h);S(a|0);L()}h=v[v[e>>2]-12>>2];v[22640]=0;f=fa(121)|0;d=v[22640];v[22640]=0;c:{d:{e:{f:{g:{h:{if((d|0)==1){break h}v[22640]=0;U(122,c+16|0,h+(c+24|0)|0,f|0);d=v[22640];v[22640]=0;if((d|0)==1){break h}Vb(c+16|0);v[22640]=0;f=bh(17);d=v[22640];v[22640]=0;if((d|0)==1){break g}v[22640]=0;v[c>>2]=f;f=bL(e,c);d=v[22640];v[22640]=0;if((d|0)==1){break g}j=A[b>>3];v[22640]=0;Za(125,f|0,+j)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}v[22640]=0;R(126,c|0,e|0);b=v[22640];v[22640]=0;if((b|0)==1){break f}v[22640]=0;R(119,i|0,c|0);b=v[22640];v[22640]=0;if((b|0)==1){break e}vb(c);hq(e);gb=c+160|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(c)}hq(e);S(a|0);L()}v[22640]=0;R(114,a|0,g|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(g);gb=g+16|0;return}a=P()|0;O()|0;vb(g);S(a|0);L()}function Mm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;f=a+1074312|0;Db(e+8|0,f,96);d=Cb(e+8|0);v[b+660>>2]=(d?0:v[b+660>>2])+c;a:{if(!(w[b+88|0]&2)|(!(v[a+480180>>2]&18)|y[b+84>>2]>c>>>0)){break a}d=v[b+84>>2];if(!d){break a}g=c;c=v[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(v[a+480180>>2]==16384?v[b+88>>2]&1:0)|0;b:{if(ce(b+788|0)){d=v[b+656>>2];if(d){d=x[sd(d+236|0,w[b+788|0]-1|0)>>1];if(!d|d>>>0>x[a+480190>>1]){break b}}if(w[a+480210|0]&32){d=c;c=v[b+660>>2];v[b+660>>2]=d+c}v[b>>2]=0;v[b+4>>2]=c;if(!(w[b+88|0]&2)|y[b+84>>2]>c>>>0?y[b+76>>2]>c>>>0:0){break b}Db(e+8|0,f,57);if(h=Cb(e+8|0),i=1,j=v[a+480180>>2]!=16,j?h:i){v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break b}if(!(v[a+480180>>2]&1048581)){Db(e+8|0,f,27);if(Cb(e+8|0)){if(w[a+480208|0]&4){d=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=d;break b}v[b>>2]=0;v[b+4>>2]=0;break b}d=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=d;if(!(w[a+480208|0]&4)){break b}a=v[b+76>>2];if(a>>>0<5){break b}v[b>>2]=0;v[b+4>>2]=a-2;break b}if(!(w[b+88|0]&2)|v[a+480180>>2]!=1){break b}a=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=a;break b}if(!(v[a+480180>>2]&268582928)|y[b+76>>2]<=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=c}gb=e+16|0}function CV(a,b){var c=0,d=0;d=b;a:{b:{c:{d:{if(je(a,13854)){break d}if(je(a,14568)){break d}if(je(a,10923)){break d}if(je(a,11086)){break d}if(!je(a,11517)){break c}}v[b>>2]=9340;a=4;break b}e:{f:{if(je(a,14563)){break f}if(je(a,10928)){break f}if(!je(a,13844)){break e}}t[b+10|0]=1;v[b>>2]=5618;a=4;break b}g:{if(!je(a,11552)){if(!je(a,11557)){break g}}v[b>>2]=5382;a=8;break b}h:{if(!je(a,12530)){if(!je(a,12535)){break h}}v[b>>2]=14191;a=t[a+2|0]-48|0;break b}i:{if(!je(a,33560)){if(!je(a,33565)){break i}}v[b+4>>2]=1;v[b>>2]=13997;a=w[a|0]==56?8:4;break b}if(!(yd(a,12631,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=5736;a=t[a+3|0]-48|0;break b}j:{if(yd(a,11019,3)){if(yd(a,11143,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+13|0]=1;t[b+11|0]=1;v[b>>2]=5481;a=t[a+3|0]-48|0;break b}k:{if((w[a|0]-49&255)>>>0>8){break k}c=a;if(!yd(a+1|0,11164,3)){t[b+12|0]=1;v[b>>2]=5784;a=t[a|0]-48|0;break b}if((w[c+1|0]-48&255)>>>0>9|((w[a+2|0]|w[a+3|0]<<8)!=20035?(w[a+2|0]|w[a+3|0]<<8)!=18499:0)){break k}t[b+12|0]=1;v[b>>2]=5784;a=(t[a+1|0]+B(t[a|0],10)|0)-528|0;break b}c=0;if(yd(a,10814,3)|(w[a+3|0]-52&255)>>>0>5){break a}v[b>>2]=5645;a=t[a+3|0]-48|0}u[d+8>>1]=a;c=1}return c}function Gd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb+-64|0;gb=d;v[a+480180>>2]=b;b=Fq(a);Yz(d,b);e=v[d+12>>2];c=a+1074320|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074312>>2]=v[d>>2];v[a+1074316>>2]=c;$t(a+8|0,b);c=x[a+480192>>1];if(c){b=1;while(1){e=(((b&65535)<<2)+a|0)+900380|0;f=v[e>>2];if(f){Zb(hv(f));c=x[a+480192>>1]}v[e>>2]=0;b=b+1|0;if((b&65535)>>>0<=c>>>0){continue}break}}v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074304>>2]=0;v[a+1074308>>2]=0;u[a+480192>>1]=0;Xz(a,4);e=gb+-64|0;gb=e;b=a+484344|0;GN(b);f=Of(b);c=$y(e+8|0,b);v[22640]=0;U(1492,b|0,f|0,c|0);b=v[22640];v[22640]=0;a:{if((b|0)!=1){Hm(c);gb=e- -64|0;break a}a=P()|0;O()|0;Hm(c);S(a|0);L()}uS(a+484360|0);Ye(a+1298268|0);Ye(a+1298280|0);Ye(a+1298292|0);c=a+1298304|0;d=Qb(d,0,64);b=mP(d);Eb(c,b);Eb(c+12|0,b+12|0);Eb(c+24|0,b+24|0);Eb(c+36|0,b+36|0);Eb(c+48|0,b+48|0);v[c+60>>2]=v[b+60>>2];du(b);cD(a+1298368|0);Cg(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}gb=d- -64|0}function ada(a){a=a|0;var b=0,c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-32|0;gb=c;a:{b=v[a+20>>2];b:{if(!b){break b}v[b+148>>2]=-1;g=c,h=kb[v[v[a>>2]+40>>2]](a)|0,v[g+16>>2]=h;v[c+8>>2]=1073741822;e=v[ld(c+16|0,c+8|0)>>2];b=e<<2;if(!b){break b}d=v[a+20>>2];v[22640]=0;R(467,d+4|0,b+4|0);b=v[22640];v[22640]=0;c:{if((b|0)!=1){b=v[a+20>>2];v[22640]=0;be(c+8|0,b+4|0);b=v[22640];v[22640]=0;if((b|0)!=1){v[c>>2]=0;v[c+4>>2]=0;b=v[c+12>>2];v[c+16>>2]=v[c+8>>2];v[c+20>>2]=b;b=v[c+4>>2];v[c+24>>2]=v[c>>2];v[c+28>>2]=b;v[22640]=0;_(1636,c+16|0);b=v[22640];v[22640]=0;d:{e:{if((b|0)==1){break e}b=v[v[a>>2]+180>>2];v[22640]=0;R(b|0,a|0,-1);b=v[22640];v[22640]=0;if((b|0)==1){break e}b=0;if((e|0)>0){while(1){d=v[v[a>>2]+48>>2];v[22640]=0;f=C(Ya(d|0,a|0,b|0));d=v[22640];v[22640]=0;if((d|0)==1){break d}v[22640]=0;z[c+8>>2]=f;R(1637,c+16|0,c+8|0);d=v[22640];v[22640]=0;if((d|0)==1){break d}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=v[v[a>>2]+184>>2];v[22640]=0;_(b|0,a|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(88880)|0;break c}b=V(88880)|0;break c}b=V(88880)|0;break c}b=V(88880)|0}if((O()|0)!=(ea(88880)|0)){break a}Z(b|0)|0;zr(v[a+20>>2]+4|0);$()}gb=c+32|0;return}S(b|0);L()}function Fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;e=gb-32|0;gb=e;a:{b:{c:{f=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?f>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?f>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?f>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?f>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;v[e+16>>2]=f;v[e+20>>2]=g;g=a;if(d){while(1){f=(((b&2147483647)<<1|h>>>31)&-2)+j|0;a=(h>>>16&65520)+i|0;m=u[a+14>>1];n=u[a+12>>1];o=u[a+10>>1];p=u[a+8>>1];q=u[a+6>>1];r=u[a+4>>1];s=u[a+2>>1];w=u[a>>1];b=0;a=1;while(1){v[(e+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+f|0],s)+B(t[(b|-6)+f|0],w)|0)+B(t[(b|-2)+f|0],r)|0)+B(t[b+f|0],q)|0)+B(t[(b|2)+f|0],p)|0)+B(t[(b|4)+f|0],o)|0)+B(t[(b|6)+f|0],n)|0)+B(t[(b|8)+f|0],m)<<8)/32768;h=a;a=0;b=1;if(h){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],k);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];b=v[e+28>>2];continue}break}h=v[e+24>>2];b=v[e+28>>2]}v[g>>2]=h;v[g+4>>2]=b;gb=e+32|0}function Kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;e=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){f=(g<<1)+q|0;i=u[f>>1];m=u[f-2>>1];n=u[f+2>>1];r=u[f+4>>1];p=v[a+60>>2];f=Lb(b,-16777216,16776704);o=v[a+64>>2];g=Lb(e,-16777216,16776704);e=mqa(o,o>>31,f,f>>31);o=jb;f=e;e=j>>>21&2040;j=(((B(i,u[e+46530>>1])+B(m,u[e+46528>>1])|0)+B(n,u[e+46532>>1])|0)+B(r,u[e+46534>>1])|0)/16384<<8;e=j;i=mqa(p,p>>31,e,e>>31);f=f+i|0;e=jb+o|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=mqa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Ic(f,e,24);f=v[a+72>>2];g=v[a+32>>2];l=v[a+28>>2]+l|0;i=l>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);k=g+k|0;m=k>>12;v[c+4>>2]=v[c+4>>2]+B(n,m);f=e-(f&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}m=k>>12;i=l>>12;f=b}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=m;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function BI(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{c=v[a+4>>2];d:{if(c>>>0<y[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break d}c=jd(a)}switch(c-43|0){case 0:case 2:break b;default:break c}}e=c-48|0;break a}f=(c|0)==45;d=!b;b=v[a+4>>2];e:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break e}c=jd(a)}e=c-48|0;if(!(d|e>>>0<10|!v[a+104>>2])){v[a+4>>2]=v[a+4>>2]-1}}f:{if(e>>>0<=9){b=0;while(1){d=(b+c|0)-48|0;g=(d|0)>214748363;b=v[a+4>>2];g:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break g}c=jd(a)}e=c-48|0;if(!(g|e>>>0>9)){b=B(d,10);continue}break}b=d;d=b>>31;h:{if(e>>>0>=10){break h}while(1){d=mqa(b,d,10,0);b=d+c|0;c=jb;c=b>>>0<d>>>0?c+1|0:c;d=b;b=b-48|0;d=c-(d>>>0<48)|0;c=v[a+4>>2];i:{if(c>>>0<y[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break i}c=jd(a)}e=c-48|0;if(e>>>0>9){break h}if((d|0)<21474836?1:(d|0)<=21474836?b>>>0<2061584302:0){continue}break}}if(e>>>0<10){while(1){c=v[a+4>>2];j:{if(c>>>0<y[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break j}c=jd(a)}if(c-48>>>0<10){continue}break}}if(v[a+104>>2]){v[a+4>>2]=v[a+4>>2]-1}a=b;b=f?0-a|0:a;d=f?0-(((a|0)!=0)+d|0)|0:d;break f}b=0;d=-2147483648;if(!v[a+104>>2]){break f}v[a+4>>2]=v[a+4>>2]-1;jb=-2147483648;return 0}jb=d;return b}function Oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;td(b,0);f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=f;break a}g=b,h=xh(Ag(+(f+1408|0)*.0006510416666666666)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?f:f^128;t[b+36|0]=w[a+4|0]}t[e+15|0]=w[a+5|0];t[e+14|0]=64;g=b,h=w[ac(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;d=a+6|0;if((w[d|0]|w[d+1|0]<<8)>>>0<=256){u[b+28>>1]=w[d|0]|w[d+1|0]<<8;u[b+34>>1]=x[b+34>>1]|32}d=a+8|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+12|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+16|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;if(w[d|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[d|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[d+1|0]&1){u[b+34>>1]=x[b+34>>1]|8}if(w[d+1|0]&2){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+46512|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[e+13|0]=w[a+26|0];t[e+12|0]=64;g=b,h=w[ac(e+13|0,e+12|0)|0],u[g+32>>1]=h}c=a+27|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=a+31|0;v[b+16>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);gb=e+16|0}function mo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-80|0;gb=c;g=ad(a);e=b+24|0;a:{b:{if(Oi(v[e>>2]+484360|0)){if(Oi(v[e>>2]+484360|0)){b=0;while(1){f=v[e>>2];a=uL(xV(c+40|0,1),b&255,0,0);v[22640]=0;d=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=d;d=v[a+20>>2];v[c+16>>2]=v[a+16>>2];v[c+20>>2]=d;d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;Y(2049,c- -64|0,f|0,0,c|0);a=v[22640];v[22640]=0;c:{d:{if((a|0)!=1){i=c,j=Sb(c- -64|0),v[i+32>>2]=j;i=c,j=Wb(c- -64|0),v[i+24>>2]=j;if(Gb(c+32|0,c+24|0)){break d}break c}a=P()|0;O()|0;break b}while(1){e:{a=v[c+32>>2];h=A[a>>3];f=v[a+16>>2];d=x[a+24>>1];a=c+40|0;v[a+16>>2]=b;v[a+12>>2]=d;v[a+8>>2]=f;A[a>>3]=h;v[22640]=0;R(2050,g|0,a|0);a=v[22640];v[22640]=0;if((a|0)==1){break e}v[c+32>>2]=v[c+32>>2]+32;if(Gb(c+32|0,c+24|0)){continue}break c}break}a=P()|0;O()|0;en(c- -64|0);break b}en(c- -64|0);b=b+1|0;if(Oi(v[e>>2]+484360|0)>>>0>b>>>0){continue}break}}gb=c+80|0;return}b=aa(8)|0;v[22640]=0;c=Q(112,c+40|0,4360)|0;a=v[22640];v[22640]=0;if((a|0)!=1){qc(b,c);v[22640]=0;U(223,b|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=P()|0;O()|0;da(b|0)}Uf(g);S(a|0)}L()}function Eu(a,b){var c=0,d=0,e=0,f=0;f=gb-48|0;gb=f;uT(f+24|0,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);uT(f,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=1;e=f+24|0;a=v[e>>2];d=Ib(w[a|0]|w[a+1|0]<<8);a=f;c=v[a>>2];a:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break a}b=0;c=v[a>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break a}b=1;c=v[e+4>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[a+4>>2];b:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break b}b=0;c=v[a+4>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e+4>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break b}b=1;c=v[e+8>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[a+8>>2];c:{if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break c}b=0;c=v[a+8>>2];d=Ib(w[c|0]|w[c+1|0]<<8);c=v[e+8>>2];if(d>>>0<Ib(w[c|0]|w[c+1|0]<<8)>>>0){break c}b=1;c=v[e+12>>2];d=Ib(w[c|0]|w[c+1|0]<<8)<<16>>16;c=v[a+12>>2];d:{if((d|0)<Ib(w[c|0]|w[c+1|0]<<8)<<16>>16){break d}b=0;c=v[a+12>>2];d=Ib(w[c|0]|w[c+1|0]<<8)<<16>>16;c=v[e+12>>2];if((d|0)<Ib(w[c|0]|w[c+1|0]<<8)<<16>>16){break d}b=v[e+16>>2];c=Ib(w[b|0]|w[b+1|0]<<8);b=v[a+16>>2];b=c>>>0<Ib(w[b|0]|w[b+1|0]<<8)>>>0;if(!b){a=v[a+16>>2];Ib(w[a|0]|w[a+1|0]<<8);a=v[e+16>>2];Ib(w[a|0]|w[a+1|0]<<8)}}}}}gb=f+48|0;return b}function Ana(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b&63;if(jv(c)>>>0>d>>>0){g=yW(c,d);h=gb-16|0;gb=h;c=a;t[c+12|0]=0;Cg(c);f=gb-32|0;gb=f;a:{b:{d=c;if(ye(d)>>>0<=14){e=wb(d);e=zp(f+8|0,15,Nb(d),e);v[22640]=0;R(332,d|0,e|0);d=v[22640];v[22640]=0;if((d|0)==1){break b}cj(e)}gb=f+32|0;break a}a=P()|0;O()|0;cj(e);S(a|0);L()}d=w[g+1|0];c:{if(!d){break c}f=0-d|0;while(1){t[h+7|0]=64;f=(f<<16>>16)+d|0;j=qr(h+8|0,f&65535,w[ac(((i<<1)+g|0)+2|0,h+7|0)|0]);d=c;d:{if(y[d+4>>2]<y[wb(d)>>2]){sW(d,j);break d}k=gb-32|0;gb=k;e=d;l=wb(d);d=zp(k+8|0,_g(d,Nb(d)+1|0),Nb(d),l);m=v[d+8>>2];v[22640]=0;gn(l,m,j);j=v[22640];v[22640]=0;e:{f:{if((j|0)==1){break f}v[d+8>>2]=v[d+8>>2]+4;v[22640]=0;R(332,e|0,d|0);e=v[22640];v[22640]=0;if((e|0)==1){break f}cj(d);gb=k+32|0;break e}a=P()|0;O()|0;cj(d);S(a|0);L()}}i=i+1|0;if((i|0)==15){break c}d=w[((i<<1)+g|0)+1|0];if(d){continue}break}}d=w[g+32|0];t[c+14|0]=d>>>4;t[c+13|0]=d&15;d=w[g+31|0];e=d&15;t[c+15|0]=e;t[c+16|0]=e;if(d&16){t[c+12|0]=w[c+12|0]|4}if(d&32){t[c+12|0]=w[c+12|0]|2}gb=h+16|0}g:{if(b<<24>>24>=0){c=w[a+12|0]&-2;a=a+12|0;break g}b=$c(a);c=w[a+12|0]&-2|b^1;a=a+12|0}t[a|0]=c}function TJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb+-64|0;gb=d;c=v[a>>2];g=v[c>>2];e=v[g+4>>2];v[d+40>>2]=v[g+20>>2];a=v[g+16>>2];v[d+32>>2]=v[g+12>>2];v[d+36>>2]=a;Hf(d+48|0,d+32|0,e);e=v[c+4>>2];i=v[e+4>>2];j=v[e+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[e+8>>2];a=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=a;l=d+16|0;e=gb-32|0;gb=e;a=d;a:{if(i>>>0<=y[d+4>>2]){if(i>>>0<=y[l+4>>2]){if(j>>>0<=y[a+8>>2]){if(Gf(l)>>>0>=j>>>0){if(j){g=b+12|0;while(1){h=0;if(i){while(1){f=fe(A[Tg(a,h,k)>>3]*134217728);c=Mb(b,h);m=c;c=Ym(f)+(v[c>>2]>>1)|0;n=c;c=st(g)+c&-4096;v[m>>2]=n-c;A[e+24>>3]=+(c|0)*7.450580596923828e-9;c=e;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;f=A[$g(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=f;f=fe(f);b:{if(D(f)<2147483648){c=~~f;break b}c=-2147483648}c=Sc(c);o=fo(l,h,k),p=c,u[o>>1]=p;h=h+1|0;if((i|0)!=(h|0)){continue}break}}k=k+1|0;if((j|0)!=(k|0)){continue}break}}gb=e+32|0;break a}ba(2959,6225,80,5936);L()}ba(2989,6225,79,5936);L()}ba(4217,6225,78,5936);L()}ba(4252,6225,77,5936);L()}gb=d- -64|0}function $J(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb+-64|0;gb=d;c=v[a>>2];g=v[c>>2];e=v[g+4>>2];v[d+40>>2]=v[g+20>>2];a=v[g+16>>2];v[d+32>>2]=v[g+12>>2];v[d+36>>2]=a;Hf(d+48|0,d+32|0,e);e=v[c+4>>2];i=v[e+4>>2];j=v[e+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[e+8>>2];a=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=a;l=d+16|0;e=gb-32|0;gb=e;a=d;a:{if(i>>>0<=y[d+4>>2]){if(i>>>0<=y[l+4>>2]){if(j>>>0<=y[a+8>>2]){if(Gf(l)>>>0>=j>>>0){if(j){g=b+12|0;while(1){h=0;if(i){while(1){f=fe(A[Tg(a,h,k)>>3]*134217728);c=Mb(b,h);m=c;c=Ym(f)+(v[c>>2]>>1)|0;n=c;c=st(g)+c&-4096;v[m>>2]=n-c;A[e+24>>3]=+(c|0)*7.450580596923828e-9;c=e;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;f=A[$g(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=f;f=fe(f);b:{if(D(f)<2147483648){c=~~f;break b}c=-2147483648}c=Sc(c);o=go(l,h,k),p=c,u[o>>1]=p;h=h+1|0;if((i|0)!=(h|0)){continue}break}}k=k+1|0;if((j|0)!=(k|0)){continue}break}}gb=e+32|0;break a}ba(2959,6225,80,5936);L()}ba(2989,6225,79,5936);L()}ba(4217,6225,78,5936);L()}ba(4252,6225,77,5936);L()}gb=d- -64|0}function dO(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-1641380927){break a}d=a+16|0;b=d;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}e=a+24|0;b=e;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}f=a+32|0;b=f;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<36){break a}c=a+12|0;b=c;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}b=c;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>858993459){break a}b=a+20|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>536870911){break a}a=a+28|0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>1073741823|B(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24),-5)-1>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0){break a}if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))<<3^-1)>>>0){break a}g=(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<=((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))<<2^-1)>>>0}return g}function wga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(y[a+4>>2]<y[wb(a)>>2]){h=gb-16|0;gb=h;c=h;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+28;a=wb(a);d=v[c+4>>2];v[22640]=0;qu(a,d,b);a=v[22640];v[22640]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+28;$b(c);gb=h+16|0;break a}a=P()|0;O()|0;$b(c);S(a|0);L()}return}i=gb-32|0;gb=i;h=a;j=wb(a);e=i+8|0;c=Ch(a)+1|0;f=gb-16|0;gb=f;v[f+12>>2]=c;d=c;c=gb-16|0;gb=c;g=a;wb(a);v[c+12>>2]=153391689;v[22640]=0;v[c+8>>2]=2147483647;k=Fb(c+12|0,c+8|0);l=v[22640];v[22640]=0;b:{if((l|0)!=1){gb=c+16|0;c=v[k>>2];break b}V(0)|0;O()|0;Bb();L()}c:{if(c>>>0>=d>>>0){d=Wi(g);if(d>>>0<c>>>1>>>0){v[f+8>>2]=d<<1;c=v[Jc(f+8|0,f+12|0)>>2]}gb=f+16|0;break c}Rc();L()}g=Ch(a);a=0;d=gb-16|0;gb=d;v[d+12>>2]=0;uh(e+12|0,j);if(c){a=c;if(a>>>0>153391689){nd(8513);L()}a=Mc(B(a,28),4)}v[e>>2]=a;g=B(g,28)+a|0;v[e+8>>2]=g;v[e+4>>2]=g;m=cc(e),n=B(c,28)+a|0,v[m>>2]=n;gb=d+16|0;a=v[e+8>>2];v[22640]=0;qu(j,a,b);a=v[22640];v[22640]=0;d:{e:{if((a|0)==1){break e}v[e+8>>2]=v[e+8>>2]+28;v[22640]=0;_Q(h,e);a=v[22640];v[22640]=0;if((a|0)==1){break e}ZQ(e);gb=i+32|0;break d}a=P()|0;O()|0;ZQ(e);S(a|0);L()}}function Vja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=gb-48|0;gb=j;if(Oe(b)>>>0>c>>>0){while(1){f=l&65535;if(hi($e(b,f))){e=Sb($e(b,f));f=Wb($e(b,f));m=oT(j,d);n=m;h=gb-16|0;gb=h;v[h>>2]=f;v[h+8>>2]=e;if(Gb(h+8|0,h)){while(1){f=n;i=gb-16|0;gb=i;e=v[h+8>>2];if(!(w[e+3|0]!=4|w[e+5|0])){oe(i+8|0,f,x[f+14>>1]);Af(i+8|0,0);t[e+3|0]=0}g=w[e+2|0];a:{if((g|0)!=11){break a}g=11;if(w[e+4|0]){break a}oe(i+8|0,f,x[f+14>>1]);g=0;Af(i+8|0,0);t[e+2|0]=0}b:{c:{d:{if(!w[e|0]){oe(i+8|0,f,x[f+14>>1]);if(Cb(i+8|0)){break d}g=w[e+2|0]}k=w[e+3|0];oe(i+8|0,f,x[f+14>>1]);Af(i+8|0,(k|0)==4|(g|0)==11);g=w[e+3|0];break c}g=w[e+3|0];k=w[e+2|0];if(!(g|(k|0)==11)){t[e+5|0]=0;t[e+3|0]=4;break b}if(k|(g|0)==4){break c}t[e+4|0]=0;t[e+2|0]=11}e:{if(!(!w[f+16|0]|g)){t[e+5|0]=125;t[e+3|0]=17;break e}f:{switch(g-16|0){case 1:break e;case 0:break f;default:break b}}if(w[e+5|0]){break b}t[e+5|0]=6;t[f+16|0]=1;break b}t[f+16|0]=0}u[f+14>>1]=(x[f+14>>1]+1>>>0)%x[f+12>>1];gb=i+16|0;Wj(h+8|0);if(Gb(h+8|0,h)){continue}break}}nT(j+24|0,n);gb=h+16|0;Ce(j+24|0);Ce(m)}l=l+1|0;if((l&65535)>>>0<=c>>>0){continue}break}}nT(a,d);gb=j+48|0}function Wha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Sd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=gg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}j=v[a+40>>2];k=v[a+36>>2];g=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=g;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){l=0;i=l;v[e+40>>2]=h;v[e+44>>2]=i;g=(g<<1)+m|0;b:{if((b|0)<=0){break b}while(1){Id(v[f+8>>2],u[(i<<1)+g>>1]/4<<16>>16);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){Id(b,u[g+(v[e+44>>2]<<1)>>1]/4<<16>>16);Hd(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);g=v[a+32>>2];k=v[a+28>>2]+k|0;i=k>>12;v[c>>2]=v[c>>2]+B(b,i);j=g+j|0;l=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];h=v[e+8>>2];g=v[e+12>>2];continue}break}h=v[e+8>>2];g=v[e+12>>2];break a}l=j>>12;i=k>>12}v[a+40>>2]=j;v[a+20>>2]=i;v[a+36>>2]=k;v[a+24>>2]=l;v[a>>2]=h;v[a+4>>2]=g;gb=e+48|0}function vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),t=0,u=0,w=0,x=C(0);a:{if(!v[a+4272>>2]){break a}i=a+44|0;if(!ki(i)){break a}k=Md(i,0);l=Md(i,1);m=kd(i,0);n=kd(i,1);if(d){j=a+4256|0;f=v[a+4268>>2];p=a+4236|0;q=a+4240|0;o=d;while(1){e=z[l>>2];g=z[k>>2];w=Mb(j,f<<1),x=g,z[w>>2]=x;w=Mb(j,v[a+4268>>2]<<1|1),x=e,z[w>>2]=x;e=C(D(oM(C(C(C(D(g))+C(D(e)))*C(536870912)),31,5)));g=z[a+4276>>2];e=C(e*C(4.656612873077393e-10));e=C(C(z[(g>e?q:p)>>2]*C(g-e))+e);z[a+4276>>2]=e;r=m;s=C(z[a+4232>>2]*C(4.656612873077393e-10));g=z[a+4244>>2];e=C(C(C(z[a+4248>>2]*C(2147483648))*C(g-C(G(e,g))))+C(2147483392));b:{if(e<C(4294967296)&e>=C(0)){f=~~e>>>0;break b}f=0}h=f<<5;t=h;u=h|-2147483648;h=f>>>0<67108864;e=C(s*C((h?t:u)>>>(h?31:32-(f>>>26|0)|0)>>>0));f=v[a+4272>>2];f=(((f+(v[a+4252>>2]+(v[a+4268>>2]<<12)|0)|0)-1|0)/4096|0)%(f|0)<<1;w=r,x=C(e*z[Mb(j,f)>>2]),z[w>>2]=x;w=n,x=C(e*z[Mb(j,f|1)>>2]),z[w>>2]=x;h=v[a+4268>>2];f=h-1|0;v[a+4268>>2]=f;if(!h){f=v[a+4272>>2]+f|0;v[a+4268>>2]=f}n=n+4|0;m=m+4|0;l=l+4|0;k=k+4|0;o=o-1|0;if(o){continue}break}}Ci(a,b,c,kd(i,0),kd(i,1),d)}}function rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=gb-16|0;gb=h;if(!w[a+4242|0]){Ty(a);a:{if(!w[a+4240|0]){break a}e=aP(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;Mt(a)}f=a+4256|0;b:{if(w[a+4244|0]){g=f;if(!(A[f>>3]<=1)){v[g>>2]=0;v[g+4>>2]=1072693248}break b}j=(v[a+4232>>2]&-2)!=4;e=A[f>>3];c:{if(D(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(j|(g|0)<1)){Ry(a);e=A[a+4256>>3]}A[f>>3]=e-+(g|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=pi(A[f>>3]*6.283185307179586);break d;case 1:e=D(A[f>>3]+-.5)*-4+1;break d;case 2:e=A[f>>3];e=e+e+-1;break d;case 3:e=A[f>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];i=A[a+4272>>3];e=e*e*e*(A[a+4280>>3]-i)*((e*6+-15)*e+10)+i}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];dQ(h+8|0,1);f=jk(a);f:{if(!f){break f}g=v[a+4236>>2];if(w[a+4243|0]){l=f,m=g>>>8&15|176|(g&127)<<8|fn(A[h+8>>3]*127)<<16,k=v[v[f>>2]+68>>2],kb[k](l|0,m|0)|0;break f}kb[v[v[f>>2]+44>>2]](f,g,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4256>>3]+A[a+4264>>3]*+(d>>>0)}g=a;a=a+44|0;Ci(g,b,c,Md(a,0),Md(a,1),d);gb=h+16|0}function bv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-32|0;gb=e;t[e+16|0]=44;v[e+8>>2]=-1;v[e+12>>2]=0;v[e>>2]=1058;v[e+4>>2]=2;i=a;c=gb+-64|0;gb=c;j=c;a=e;h=v[a>>2]&2?16:10;f=gb-32|0;gb=f;d=Ge(f+16|0,1,0);a:{b:{c:{while(1){aK(f+8|0,Jb(d),Jb(d)+Ab(d)|0,w[b|0],h);if(!v[f+12>>2]){break c}g=Ab(d);v[22640]=0;v[f+4>>2]=g;g=wf(f+4|0);k=v[22640];v[22640]=0;if((k|0)!=1){v[22640]=0;U(117,d|0,g|0,0);g=v[22640];v[22640]=0;if((g|0)!=1){continue}}break}break b}b=v[f+8>>2];h=Jb(d);v[22640]=0;R(118,d|0,b-h|0);b=v[22640];v[22640]=0;d:{if((b|0)!=1){v[22640]=0;R(119,j|0,d|0);b=v[22640];v[22640]=0;if((b|0)!=1){break d}break b}break b}vb(d);gb=f+32|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}Al(c+16|0,c,a);v[22640]=0;U(131,c+32|0,c+16|0,a|0);b=v[22640];v[22640]=0;e:{f:{g:{h:{i:{if((b|0)!=1){v[22640]=0;U(132,c+48|0,c+32|0,a|0);a=v[22640];v[22640]=0;if((a|0)==1){break i}v[22640]=0;R(114,i|0,c+48|0);a=v[22640];v[22640]=0;if((a|0)==1){break h}vb(c+48|0);vb(c+32|0);vb(c+16|0);vb(c);gb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;vb(c+48|0)}vb(c+32|0)}vb(c+16|0);vb(c);S(a|0);L()}gb=e+32|0}function Yca(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb+-64|0;gb=c;g=ad(a);v[22640]=0;_(1649,g|0);b=v[22640];v[22640]=0;a:{if((b|0)!=1){b=50752;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){d=Rg(44);if(d){h=v[b>>2];f=v[b+4>>2];v[22640]=0;f=Q(112,c+32|0,f|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break k}v[22640]=0;R(1650,c+48|0,f|0);e=v[22640];v[22640]=0;if((e|0)==1){break j}e=v[b+8>>2];v[22640]=0;e=Q(112,c|0,e|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break i}v[22640]=0;R(1650,c+16|0,e|0);i=v[22640];v[22640]=0;if((i|0)==1){break h}v[22640]=0;ca(1651,d|0,h|0,c+48|0,c+16|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break g}Hb(c+16|0);vb(e);Hb(c+48|0);vb(f);v[c+60>>2]=d;v[22640]=0;R(1652,g|0,c+60|0);d=v[22640];v[22640]=0;if((d|0)==1){break b}d=v[c+60>>2];v[d+32>>2]=v[b+12>>2];v[d+36>>2]=v[b+16>>2];t[d+40|0]=w[b+20|0];t[d+41|0]=w[d+41|0]&253|w[b+21|0]<<1}b=b+24|0;if((b|0)!=51040){continue}break}gb=c- -64|0;return a|0}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;Hb(c+16|0)}vb(e)}Hb(c+48|0)}vb(f)}Zb(d);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}Gl(g);S(b|0);L()}function Zha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-48|0;gb=e;k=v[a+16>>2];f=Sd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];o=f,p=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[o+12>>2]=p;b=v[f+16>>2];if(b){o=f,p=gg(a+8|0,b),v[o>>2]=p;v[f+4>>2]=jb}l=v[a+24>>2];m=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;j=g;v[e+40>>2]=g;v[e+44>>2]=n;h=(((h&2147483647)<<1|g>>>31)&-2)+k|0;a:{if((b|0)<=0){break a}while(1){g=(i&2147483647)<<1|j>>>31;Id(v[f+8>>2],t[(g|1)+h|0]+t[h+(g&-2)|0]<<5);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;j=v[e+40>>2];i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){j=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Id(j,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);Hd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,m);v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=gb-16|0;gb=k;o=k,p=Wb(a),v[o>>2]=p;d=v[Fd(k+8|0,k)>>2];h=gb-32|0;gb=h;v[h+24>>2]=d;d=v[a>>2];o=h,p=Sb(a),v[o>>2]=p;d=d+(tp(h+24|0,h)<<1)|0;a:{b:{f=ar(b,c);c:{if((f|0)<1){break c}i=v[wb(a)>>2];e=v[a+4>>2];if((f|0)<=i-e>>1){j=e-d|0;i=j>>1;d:{if((i|0)>=(f|0)){g=c;break d}v[h>>2]=b;rS(h,i);g=v[h>>2];kS(a,g,c,f-i|0);if((j|0)<1){break c}}m=gb-16|0;gb=m;i=e;j=d;l=a;n=v[a+4>>2];a=(n-((f<<1)+d|0)|0)+d|0;f=ji(m,l,e-a>>1);if(a>>>0<e>>>0){e=v[f+4>>2];c=a;while(1){wb(l);Qo(e,c);e=e+2|0;v[f+4>>2]=e;c=c+2|0;if(i>>>0>c>>>0){continue}break}}$b(f);hn(j,a,n);gb=m+16|0;ap(b,g,d);break c}g=wb(a);e=En(h,Rk(a,sc(a)+f|0),d-v[a>>2]>>1,g);v[22640]=0;gR(e,b,c);b=v[22640];v[22640]=0;if((b|0)==1){break b}b=a;Fp(a);c=e;i=v[c+4>>2];g=d;l=c+4|0;xk(wb(a),v[a>>2],d,l);wb(a);f=c+8|0;j=f;d=v[a+4>>2];if((g|0)!=(d|0)){a=v[j>>2];while(1){Qo(a,g);a=v[j>>2]+2|0;v[j>>2]=a;g=g+2|0;if((d|0)!=(g|0)){continue}break}}jc(b,l);jc(b+4|0,f);jc(wb(b),cc(c));v[c>>2]=v[c+4>>2];Wr(b,sc(b));d=i;Gh(e)}bh(d);gb=h+32|0;break a}a=P()|0;O()|0;Gh(e);S(a|0);L()}gb=k+16|0}function qka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;i=gb-16|0;gb=i;td(d,32);LT(i+8|0,a+20|0,b);p=i+8|0;g=ec(i+8|0);LT(i,a+36|0,c);q=i;a=0;g=v[g>>2];if(g-1>>>0<=838859){a=v[ec(i)>>2];v[d>>2]=B(g,320);u[d+34>>1]=1;n=_m(d);if(n){r=+(g>>>0);s=+(a>>>0);m=g<<2;o=1/+(m>>>0);z=1/+y[d>>2];g=0;while(1){k=+(g>>>0);a=v[p>>2];j=0;if(Ld(b)){e=k*r*o+ +(a>>>0);a:{if(e<4294967296&e>=0){a=~~e>>>0;break a}a=0}f=bd(b);h=B(a,f);e=e-J(e);b:{if(t[b+34|0]&1){l=v[b+20>>2];a=u[l+(h<<1)>>1];f=x[l+(f+h<<1)>>1];break b}a=v[b+20>>2];f=w[a+(f+h|0)|0]<<8;a=w[a+h|0]<<8}j=+(a<<16>>16);j=(+(f<<16>>16)-j)*e+j}a=v[q>>2];if(Ld(c)){e=k*s*o+ +(a>>>0);c:{if(e<4294967296&e>=0){a=~~e>>>0;break c}a=0}f=bd(c);h=B(a,f);e=e-J(e);d:{if(t[c+34|0]&1){l=v[c+20>>2];a=u[l+(h<<1)>>1];f=x[l+(f+h<<1)>>1];break d}a=v[c+20>>2];f=w[a+(f+h|0)|0]<<8;a=w[a+h|0]<<8}k=+(a<<16>>16);e=(+(f<<16>>16)-k)*e+k}else{e=0}e=e-j;f=1;a=g;while(1){h=KT(e*+(a>>>0)*z+j);u[v[d+20>>2]+(a<<1)>>1]=h;if((f|0)!=80){a=a+m|0;f=f+1|0;continue}break}g=g+1|0;if((m|0)!=(g|0)){continue}break}}a=(n|0)!=0}gb=i+16|0;return a|0}function hc(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){_a(a|0,b|0,c|0)|0;return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if(!(a&3)){c=a;break b}if((c|0)<1){c=a;break b}c=a;while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if(!(c&3)){break b}if(c>>>0<e>>>0){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+-64|0;if(f>>>0<c>>>0){break c}while(1){v[c>>2]=v[b>>2];v[c+4>>2]=v[b+4>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=v[b+12>>2];v[c+16>>2]=v[b+16>>2];v[c+20>>2]=v[b+20>>2];v[c+24>>2]=v[b+24>>2];v[c+28>>2]=v[b+28>>2];v[c+32>>2]=v[b+32>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=v[b+40>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=v[b+48>>2];v[c+52>>2]=v[b+52>>2];v[c+56>>2]=v[b+56>>2];v[c+60>>2]=v[b+60>>2];b=b- -64|0;c=c- -64|0;if(f>>>0>=c>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){v[c>>2]=v[b>>2];b=b+4|0;c=c+4|0;if(d>>>0>c>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e-4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){t[c|0]=w[b|0];t[c+1|0]=w[b+1|0];t[c+2|0]=w[b+2|0];t[c+3|0]=w[b+3|0];b=b+4|0;c=c+4|0;if(d>>>0>=c>>>0){continue}break}}if(c>>>0<e>>>0){while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function Kda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=Qf(a);if(c>>>0<b>>>0){f=gb-32|0;gb=f;a:{b:{e=b-c|0;c:{if(e>>>0<=v[wb(a)>>2]-v[a+4>>2]>>11>>>0){c=gb-16|0;gb=c;g=a;b=c;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(e<<11);d:{a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){wb(g);v[22640]=0;Sy(a);e=v[22640];v[22640]=0;if((e|0)==1){break d}a=a+2048|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0;break c}a=P()|0;O()|0;$b(b);S(a|0);L()}h=wb(a);i=f+8|0;b=Qf(a)+e|0;d=gb-16|0;gb=d;v[d+12>>2]=b;c=b;b=gb-16|0;gb=b;g=a;wb(a);v[b+12>>2]=2097151;v[22640]=0;v[b+8>>2]=2147483647;j=Fb(b+12|0,b+8|0);k=v[22640];v[22640]=0;e:{if((k|0)!=1){gb=b+16|0;b=v[j>>2];break e}V(0)|0;O()|0;Bb();L()}f:{if(b>>>0>=c>>>0){c=Cl(g);if(c>>>0<b>>>1>>>0){v[d+8>>2]=c<<1;b=v[Jc(d+8|0,d+12|0)>>2]}gb=d+16|0;break f}Rc();L()}b=VM(i,b,Qf(a),h);v[22640]=0;R(1545,b|0,e|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}v[22640]=0;R(1541,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Pt(b)}gb=f+32|0;break a}a=P()|0;O()|0;Pt(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<11)|0;Qf(a);UM(a,b);WM(a)}}function Bc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{f=w[b+8|0];c=v[b>>2];d=v[b+4>>2];b=gb-48|0;gb=b;e=Kb(a);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((f|0)!=1){if(!d|(f|0)!=4){break k}break l}if(d){break l}a=c;break j}d=d-1|0}m:{switch(f-1|0){case 0:case 1:break m;case 2:case 3:break i;default:break h}}a=c+d|0}t[b+32|0]=0;a=Dm(c,a,b+32|0);v[22640]=0;U(110,e|0,c|0,a|0);a=v[22640];v[22640]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}v[22640]=0;U(110,e|0,c|0,c+d|0);a=v[22640];v[22640]=0;if((a|0)==1){break g}c=wd(e);d=df(e);f=wd(e);a=gb-32|0;gb=a;v[a+16>>2]=d;v[a+24>>2]=c;v[a+8>>2]=f;if(Gb(a+24|0,a+16|0)){while(1){c=t[v[a+24>>2]];t[v[a+8>>2]]=c?c:32;Me(a+24|0);Me(a+8|0);if(Gb(a+24|0,a+16|0)){continue}break}}gb=a+32|0;v[22640]=0;c=Q(111,b+16|0,e|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break f}v[22640]=0;d=Q(112,b|0,14878)|0;a=v[22640];v[22640]=0;if((a|0)==1){break e}v[22640]=0;U(113,b+32|0,c|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break d}Eb(e,b+32|0);vb(b+32|0);vb(d);vb(c)}gb=b+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(d)}vb(c)}vb(e);S(a|0);L()}}function Xha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;m=v[a+16>>2];f=Sd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=gg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}j=v[a+40>>2];k=v[a+36>>2];g=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=g;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){l=0;i=l;v[e+40>>2]=h;v[e+44>>2]=i;g=g+m|0;b:{if((b|0)<=0){break b}while(1){Id(v[f+8>>2],t[g+i|0]<<6);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break b}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){Id(b,t[g+v[e+44>>2]|0]<<6);Hd(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);g=v[a+32>>2];k=v[a+28>>2]+k|0;i=k>>12;v[c>>2]=v[c>>2]+B(b,i);j=g+j|0;l=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,l);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];h=v[e+8>>2];g=v[e+12>>2];continue}break}h=v[e+8>>2];g=v[e+12>>2];break a}l=j>>12;i=k>>12}v[a+40>>2]=j;v[a+20>>2]=i;v[a+36>>2]=k;v[a+24>>2]=l;v[a>>2]=h;v[a+4>>2]=g;gb=e+48|0}function ST(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=ah(a);if(c>>>0<b>>>0){j=gb-32|0;gb=j;a:{b:{i=b-c|0;c:{if(i>>>0<=v[wb(a)>>2]-v[a+4>>2]>>8>>>0){b=gb-16|0;gb=b;c=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(i<<8);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){nB(a);a=a+256|0;v[c+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(c);gb=b+16|0;break c}k=wb(a);e=j+8|0;d=a;b=ah(a)+i|0;f=gb-16|0;gb=f;v[f+12>>2]=b;g=gb-16|0;gb=g;v[g+12>>2]=16777215;v[22640]=0;v[g+8>>2]=2147483647;h=Fb(g+12|0,g+8|0);c=v[22640];v[22640]=0;d:{if((c|0)!=1){gb=g+16|0;c=v[h>>2];break d}V(0)|0;O()|0;Bb();L()}e:{if(b>>>0<=c>>>0){b=rB(d);if(b>>>0<c>>>1>>>0){v[f+8>>2]=b<<1;c=v[Jc(f+8|0,f+12|0)>>2]}gb=f+16|0;break e}Rc();L()}d=ah(a);b=0;h=gb-16|0;gb=h;v[h+12>>2]=0;ef(e+12|0,k);if(c){b=c;if(b>>>0>=16777216){nd(8513);L()}b=Mc(b<<8,1)}v[e>>2]=b;d=(d<<8)+b|0;v[e+8>>2]=d;v[e+4>>2]=d;l=cc(e),m=(c<<8)+b|0,v[l>>2]=m;gb=h+16|0;v[22640]=0;xT(e,i);b=v[22640];v[22640]=0;if((b|0)==1){break b}Uk(a,e);wT(e)}gb=j+32|0;break a}a=P()|0;O()|0;wT(e);S(a|0);L()}return}if(b>>>0<c>>>0){Vk(a,v[a>>2]+(b<<8)|0)}}function d7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb+-64|0;gb=c;d=v[a>>2];a=v[d>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Hf(c+48|0,c+32|0,g);a=v[d+4>>2];e=v[a+4>>2];h=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;j=c+16|0;d=gb-32|0;gb=d;g=c;a:{if(y[c+4>>2]>=e>>>0){if(y[j+4>>2]>=e>>>0){if(y[g+8>>2]>=h>>>0){if(Gf(j)>>>0>=h>>>0){if(h){k=b+12|0;while(1){b=0;if(e){while(1){l=d,m=+(Ym(fe(A[Tg(g,b,i)>>3]*134217728))+ed(rt(k),21)|0)*7.450580596923828e-9,A[l+24>>3]=m;a=d;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;f=A[$g(a+24|0,a+16|0,a+8|0)>>3]*32768;A[a+24>>3]=f;f=fe(f);b:{if(D(f)<2147483648){a=~~f;break b}a=-2147483648}a=Sc(a);l=go(j,b,i),n=a,u[l>>1]=n;b=b+1|0;if((b|0)!=(e|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}gb=d+32|0;break a}ba(2959,6225,80,5936);L()}ba(2989,6225,79,5936);L()}ba(4217,6225,78,5936);L()}ba(4252,6225,77,5936);L()}gb=c- -64|0}function V6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=gb+-64|0;gb=c;d=v[a>>2];a=v[d>>2];g=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;Hf(c+48|0,c+32|0,g);a=v[d+4>>2];e=v[a+4>>2];h=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;j=c+16|0;d=gb-32|0;gb=d;g=c;a:{if(y[c+4>>2]>=e>>>0){if(y[j+4>>2]>=e>>>0){if(y[g+8>>2]>=h>>>0){if(Gf(j)>>>0>=h>>>0){if(h){k=b+12|0;while(1){b=0;if(e){while(1){l=d,m=+(Ym(fe(A[Tg(g,b,i)>>3]*134217728))+ed(rt(k),21)|0)*7.450580596923828e-9,A[l+24>>3]=m;a=d;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;f=A[$g(a+24|0,a+16|0,a+8|0)>>3]*32768;A[a+24>>3]=f;f=fe(f);b:{if(D(f)<2147483648){a=~~f;break b}a=-2147483648}a=Sc(a);l=fo(j,b,i),n=a,u[l>>1]=n;b=b+1|0;if((b|0)!=(e|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}gb=d+32|0;break a}ba(2959,6225,80,5936);L()}ba(2989,6225,79,5936);L()}ba(4217,6225,78,5936);L()}ba(4252,6225,77,5936);L()}gb=c- -64|0}function qK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;v[a+4>>2]=c;v[a>>2]=b;b=(c>>>0)/48|0;g=((B(b,48)|0)!=(c|0))+b|0;v[a+12>>2]=g;b=(c>>>0)/(g>>>0)|0;v[a+8>>2]=b;i=b>>>0<64;e=a;j=a;d=b;f=d&31;if((d&63)>>>0>=32){d=-1<<f}else{d=(1<<f)-1&-1>>>32-f|-1<<f}f=i?0:0;v[j+24>>2]=f;j=e;e=i?d&65536:0;v[j+28>>2]=e;a:{b:{d=f;i=0-d|0;f=pqa(d,e,g,0);e=65536-(e+((d|0)!=0)|0)|0;d=jb;if((e|0)==(d|0)&f>>>0<i>>>0|d>>>0<e>>>0){g=g+1|0;v[a+12>>2]=g;b=(c>>>0)/(g>>>0)|0;v[a+8>>2]=b;if(b>>>0>63){break b}d=b;f=d&31;if((d&63)>>>0>=32){d=-1<<f}else{d=(1<<f)-1&-1>>>32-f|-1<<f}v[a+24>>2]=0;v[a+28>>2]=d&65536}v[a+16>>2]=g-((c>>>0)%(g>>>0)|0);if(b>>>0>62){break a}h=1;c=b+1|0;d=c&31;if((c&63)>>>0>=32){d=-1<<d}else{d=(1<<d)-1&-1>>>32-d|-1<<d}k=d&65536;break a}v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=(B(b,g)-c|0)+g}v[a+32>>2]=l;v[a+36>>2]=k;c=a;f=a;d=63-b|0;e=d&31;if((d&63)>>>0>=32){d=0;e=-1>>>e|0}else{d=-1>>>e|0;e=(1<<e)-1<<32-e|-1>>>e}v[f+48>>2]=h?e:-1;v[c+52>>2]=h?d:-1;h=b;e=a;b=64-b|0;d=b&31;if((b&63)>>>0>=32){b=0;d=-1>>>d|0}else{b=-1>>>d|0;d=(1<<d)-1<<32-d|-1>>>d}v[e+40>>2]=h?d:0;v[c+44>>2]=h?b:0;return a}function JZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-32|0;gb=h;d=b;e=sc(d);f=c;a:{if(e>>>0<f>>>0){l=gb-32|0;gb=l;b:{c:{i=f-e|0;d:{if(i>>>0<=v[wb(d)>>2]-v[d+4>>2]>>1>>>0){e=gb-16|0;gb=e;e:{f=ji(e,d,i);g=v[f+4>>2];i=v[f+8>>2];if((g|0)!=(i|0)){while(1){wb(d);v[22640]=0;Kk(g);j=v[22640];v[22640]=0;if((j|0)==1){break e}g=g+2|0;v[f+4>>2]=g;if((g|0)!=(i|0)){continue}break}}$b(f);gb=e+16|0;break d}a=P()|0;O()|0;$b(f);S(a|0);L()}k=wb(d);f=Rk(d,sc(d)+i|0);m=sc(d);j=gb-16|0;gb=j;v[j+12>>2]=0;e=l+8|0;uh(e+12|0,k);if(f){g=f;if(f>>>0>2147483647){nd(8513);L()}g=Mc(g<<1,1)}v[e>>2]=g;k=(m<<1)+g|0;v[e+8>>2]=k;v[e+4>>2]=k;n=cc(e),o=(f<<1)+g|0,v[n>>2]=o;gb=j+16|0;v[22640]=0;R(385,e|0,i|0);f=v[22640];v[22640]=0;if((f|0)==1){break c}v[22640]=0;R(386,d|0,e|0);d=v[22640];v[22640]=0;if((d|0)==1){break c}VD(e)}gb=l+32|0;break b}a=P()|0;O()|0;VD(e);S(a|0);L()}break a}if(e>>>0>f>>>0){zn(d,v[d>>2]+(f<<1)|0)}}c=Pb(a,c<<1);if(c){d=gb-16|0;gb=d;bc(h+24|0,v[b>>2],sc(b)<<1);gb=d+16|0;b=v[h+28>>2];v[h+8>>2]=v[h+24>>2];v[h+12>>2]=b;gd(h+16|0,a,h+8|0)}gb=h+32|0;return c|0}function Cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-16|0;gb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];f=v[a+4>>2];k=v[a>>2];v[g+8>>2]=k;v[g+12>>2]=f;v[g>>2]=h;v[g+4>>2]=e;e:{if(d){while(1){h=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;e=(f<<1)+m|0;f=(k>>>16&65520)+l|0;f=(((((((B(u[e-4>>1],u[f+2>>1])+B(u[e-6>>1],u[f>>1])|0)+B(u[e-2>>1],u[f+4>>1])|0)+B(u[e>>1],u[f+6>>1])|0)+B(u[e+2>>1],u[f+8>>1])|0)+B(u[e+4>>1],u[f+10>>1])|0)+B(u[e+6>>1],u[f+12>>1])|0)+B(u[e+8>>1],u[f+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,f);i=h+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,h);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;k=v[g+8>>2];f=v[g+12>>2];continue}break}k=v[g+8>>2];f=v[g+12>>2];break e}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=k;v[a+4>>2]=f;gb=g+16|0}function it(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=a;a=gb+-64|0;gb=a;j=a;g=v[c>>2]&2?16:10;f=gb-32|0;gb=f;d=Ge(f+16|0,1,0);a:{b:{c:{while(1){e=Jb(d);h=Jb(d);k=Ab(d);l=v[b>>2];v[22640]=0;ha(133,f+8|0,e|0,h+k|0,l|0,g|0);e=v[22640];v[22640]=0;if((e|0)==1){break b}if(!v[f+12>>2]){break c}e=Ab(d);v[22640]=0;v[f+4>>2]=e;e=wf(f+4|0);h=v[22640];v[22640]=0;if((h|0)!=1){v[22640]=0;U(117,d|0,e|0,0);e=v[22640];v[22640]=0;if((e|0)!=1){continue}}break}break b}b=v[f+8>>2];g=Jb(d);v[22640]=0;R(118,d|0,b-g|0);b=v[22640];v[22640]=0;if((b|0)!=1){v[22640]=0;R(128,j|0,d|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}vb(d);gb=f+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}Al(a+16|0,a,c);v[22640]=0;U(135,a+32|0,a+16|0,c|0);b=v[22640];v[22640]=0;d:{e:{f:{g:{h:{if((b|0)!=1){v[22640]=0;U(136,a+48|0,a+32|0,c|0);b=v[22640];v[22640]=0;if((b|0)==1){break h}v[22640]=0;R(127,i|0,a+48|0);b=v[22640];v[22640]=0;if((b|0)==1){break g}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function LV(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=a;a=gb+-64|0;gb=a;j=a;g=v[c>>2]&2?16:10;f=gb-32|0;gb=f;d=Ge(f+16|0,1,0);a:{b:{c:{while(1){e=Jb(d);h=Jb(d);k=Ab(d);l=v[b>>2];v[22640]=0;ha(133,f+8|0,e|0,h+k|0,l|0,g|0);e=v[22640];v[22640]=0;if((e|0)==1){break b}if(!v[f+12>>2]){break c}e=Ab(d);v[22640]=0;v[f+4>>2]=e;e=wf(f+4|0);h=v[22640];v[22640]=0;if((h|0)!=1){v[22640]=0;U(117,d|0,e|0,0);e=v[22640];v[22640]=0;if((e|0)!=1){continue}}break}break b}b=v[f+8>>2];g=Jb(d);v[22640]=0;R(118,d|0,b-g|0);b=v[22640];v[22640]=0;if((b|0)!=1){v[22640]=0;R(119,j|0,d|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}vb(d);gb=f+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}Al(a+16|0,a,c);v[22640]=0;U(131,a+32|0,a+16|0,c|0);b=v[22640];v[22640]=0;d:{e:{f:{g:{h:{if((b|0)!=1){v[22640]=0;U(132,a+48|0,a+32|0,c|0);b=v[22640];v[22640]=0;if((b|0)==1){break h}v[22640]=0;R(114,i|0,a+48|0);b=v[22640];v[22640]=0;if((b|0)==1){break g}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function Gw(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{i=a;a=gb+-64|0;gb=a;j=a;g=v[c>>2]&2?16:10;f=gb-32|0;gb=f;d=Ge(f+16|0,1,0);b:{c:{d:{while(1){e=Jb(d);h=Jb(d);k=Ab(d);l=v[b>>2];v[22640]=0;ha(134,f+8|0,e|0,h+k|0,l|0,g|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}if(!v[f+12>>2]){break d}e=Ab(d);v[22640]=0;v[f+4>>2]=e;e=wf(f+4|0);h=v[22640];v[22640]=0;if((h|0)!=1){v[22640]=0;U(117,d|0,e|0,0);e=v[22640];v[22640]=0;if((e|0)!=1){continue}}break}break c}b=v[f+8>>2];g=Jb(d);v[22640]=0;R(118,d|0,b-g|0);b=v[22640];v[22640]=0;if((b|0)!=1){v[22640]=0;R(128,j|0,d|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}vb(d);gb=f+32|0;break b}}a=P()|0;O()|0;vb(d);S(a|0);L()}Al(a+16|0,a,c);v[22640]=0;U(135,a+32|0,a+16|0,c|0);b=v[22640];v[22640]=0;e:{f:{g:{h:{if((b|0)!=1){v[22640]=0;U(136,a+48|0,a+32|0,c|0);b=v[22640];v[22640]=0;if((b|0)==1){break h}v[22640]=0;R(127,i|0,a+48|0);b=v[22640];v[22640]=0;if((b|0)==1){break g}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break a}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=gb-32|0;gb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];g=e;h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){i=((((g&2147483647)<<1|h>>>31)&2147483646)<<1)+m|0;e=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];t=u[e+24>>1];j=0;e=1;while(1){g=j<<1;v[(f+8|0)+(j<<2)>>2]=(((((B(u[(g|8)+i>>1],o)+B(u[(g|4)+i>>1],p)|0)+B(u[(g|12)+i>>1],n)|0)+B(u[(g|16)+i>>1],h)|0)/2|0)+((((B(u[(g|-8)+i>>1],s)+B(u[(g|-12)+i>>1],t)|0)+B(u[(g|-4)+i>>1],r)|0)+B(u[g+i>>1],q)|0)/2|0)|0)/16384;g=e;e=0;j=1;if(g){continue}break}e=v[a+32>>2];l=v[a+28>>2]+l|0;j=l>>12;v[c>>2]=v[c>>2]+B(j,v[f+8>>2]);k=e+k|0;e=k>>12;v[c+4>>2]=v[c+4>>2]+B(e,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];g=v[f+28>>2];continue}break}h=v[f+24>>2];g=v[f+28>>2];break a}e=k>>12;j=l>>12}v[a+40>>2]=k;v[a+20>>2]=j;v[a+36>>2]=l;v[a+24>>2]=e;v[a>>2]=h;v[a+4>>2]=g;gb=f+32|0}function $ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=g+q|0;m=t[e+1|0];e=t[e|0];g=v[a+60>>2];n=g;o=g>>31;g=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);g=mqa(j,j>>31,g,g>>31);j=jb;r=g;g=v[a+68>>2];p=mqa(g,g>>31,f,f>>31);g=r+p|0;f=jb+j|0;f=g>>>0<p>>>0?f+1|0:f;j=g;g=((B(m-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=g;i=mqa(n,o,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Ic(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=i+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function $m(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;if(b&2){t[a+841|0]=0;v[a+708>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;t[a+797|0]=0;v[a+764>>2]=0;u[a+802>>1]=0;u[a+804>>1]=0;v[a+696>>2]=0;v[a+668>>2]=0;v[a+88>>2]=v[a+88>>2]|6144;Db(f+8|0,c+1074312|0,23);if(Cb(f+8|0)){t[a+807|0]=1;t[a+808|0]=0}t[a+846|0]=0;t[a+839|0]=0;u[a+774>>1]=0;t[a+850|0]=255;v[a+660>>2]=0;t[a+851|0]=w[a+851|0]&240;Yo(a+788|0)}if(b&4){v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;t[a+845|0]=0;t[a+838|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+820>>1]=0;t[a+819|0]=0;u[a+836>>1]=32512;u[a+842>>1]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+852>>2]=0;v[a+856>>2]=0;t[a+851|0]=w[a+851|0]&207}if(b&1){a:{if(d>>>0<=126){b=(d<<5)+c|0;c=v[b+480280>>2];v[a+88>>2]=c;v[a+692>>2]=x[b+480284>>1];v[a+748>>2]=x[b+480286>>1];if(!(c&1024)){break a}v[a+88>>2]=c&-1025|e;break a}v[a+748>>2]=64;v[a+692>>2]=128;v[a+88>>2]=0}u[a+784>>1]=0;t[a+795|0]=0;t[a+796|0]=0}gb=f+16|0}function _ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];g=e;i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=(g<<1)+q|0;m=u[e+2>>1];e=u[e>>1];g=v[a+60>>2];n=g;o=g>>31;g=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);g=mqa(j,j>>31,g,g>>31);j=jb;r=g;g=v[a+68>>2];p=mqa(g,g>>31,f,f>>31);g=r+p|0;f=jb+j|0;f=g>>>0<p>>>0?f+1|0:f;j=g;g=e+((B(m-e|0,i>>>18|0)|0)/16384|0)<<8;e=g;i=mqa(n,o,e,e>>31);e=j+i|0;f=jb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Ic(e,f,24);e=v[a+72>>2];i=v[a+32>>2];l=v[a+28>>2]+l|0;m=l>>12;o=(f|0)/256|0;v[c>>2]=v[c>>2]+B(m,o);k=i+k|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(o,n);e=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=b;break a}n=k>>12;m=l>>12;e=b}v[a+40>>2]=k;v[a+20>>2]=m;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function Dia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];k=v[a>>2];v[f+8>>2]=k;v[f+12>>2]=b;v[f>>2]=g;v[f+4>>2]=e;e:{if(d){while(1){g=v[a+32>>2];j=v[a+28>>2]+j|0;e=j>>12;h=b+m|0;b=(k>>>16&65520)+l|0;b=(((((((B(t[h-2|0],u[b+2>>1])+B(t[h-3|0],u[b>>1])|0)+B(t[h-1|0],u[b+4>>1])|0)+B(t[h|0],u[b+6>>1])|0)+B(t[h+1|0],u[b+8>>1])|0)+B(t[h+2|0],u[b+10>>1])|0)+B(t[h+3|0],u[b+12>>1])|0)+B(t[h+4|0],u[b+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,b);i=g+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,g);Ub(f+8|0,f);d=d-1|0;if(d){c=c+8|0;k=v[f+8>>2];b=v[f+12>>2];continue}break}k=v[f+8>>2];b=v[f+12>>2];break e}g=i>>12;e=j>>12}v[a+40>>2]=i;v[a+20>>2]=e;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=k;v[a+4>>2]=b;gb=f+16|0}function eJ(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0;a:{if(w[b+21|0]){l=v[f>>2];j=v[e>>2];o=1;b:{if((h|0)>=1){p=B(d,g);m=v[b>>2];while(1){if(v[a+1396>>2]<=9){tl(a)}k=v[a+1392>>2];g=u[(((k&1023)<<1)+b|0)+36>>1];c:{if((g|0)>=0){i=k;k=w[g+v[b+8>>2]|0];v[a+1392>>2]=i>>>k;i=v[a+1396>>2]-k|0;k=(i|0)<0;v[a+1396>>2]=k?0:i;g=k?-1:g;break c}g=zm(a,b)}if((g|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((g|0)<=-1){if(!w[a+1376|0]){o=0;if(v[a+1384>>2]){break b}}dc(a,21);return 0}k=B(d,l);m=(k+(j+m|0)|0)>(p|0)?(j+p|0)-k|0:m;k=B(g,v[b>>2]);d:{if(w[b+22|0]){g=0;n=C(0);if((m|0)<=0){break d}while(1){n=C(z[v[b+28>>2]+(g+k<<2)>>2]+n);i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+n}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}break d}g=0;if((m|0)<=0){break d}while(1){i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+z[v[b+28>>2]+(g+k<<2)>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}}h=h-m|0;if((h|0)>0){continue}break}}v[e>>2]=j;v[f>>2]=l}return o}dc(a,21);return 0}ba(4590,10568,1872,3614);L()}function nna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-432|0;gb=e;vc(b);kC(b,e+376|0,e+296|0,e+8|0);d=e;f=e+408|0;if(Xb(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))){f=w[e+427|0]+1|0}else{f=1}n=d,o=di(f),t[n+4|0]=o;h=w[ac(29392,e+4|0)|0];t[e+7|0]=h;u[e+4>>1]=4;a:{b:{if(!h){break b}f=e+392|0;k=e+291|0;while(1){d=e+8|0;d=Ib(w[d|0]|w[d+1|0]<<8);c:{d:{if(w[k|0]>63){break d}d=d<<16>>16;if((d|0)<0){break d}if(d){l=d&65535;g=0;while(1){d=f;e:{if(!Xc(b,Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(g<<2)|0)){break e}if(!Xc(b,Jv(b))){break e}d=e;f:{if(!c){j=de(b);break f}j=Lv(b)}u[d+2>>1]=j;n=e,o=x[Ie(e+4|0,e+2|0)>>1],u[n+4>>1]=o}g=g+1|0;if((l|0)!=(g|0)){continue}break}}d=e+296|0;if(Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0>m>>>0){d=e+296|0;if(Xc(b,Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)))){break c}}t[e+7|0]=i+1;break b}Sr(a);break a}d=e+296|0;m=Xb(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));kC(b,e+376|0,e+296|0,e+8|0);i=i+1|0;if((i&255)>>>0<h>>>0){continue}break}}hC(a,e+4|0,e+7|0)}gb=e+432|0}function Mc(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if(_E(b)){j=b>>>0>4?b:4;b=a?a:1;a:{b:{while(1){f=gb-16|0;gb=f;v[f+12>>2]=0;c=b;c:{d:{a=j;if((a|0)!=8){if(a&3|a>>>0<4){break c}d=a>>>2|0;if(d-1&d|c>>>0>-64-a>>>0){break c}d=16;e=a>>>0>16?a:16;e:{if(!(e-1&e)){a=e;break e}while(1){a=d;d=a<<1;if(a>>>0<e>>>0){continue}break}}if(c>>>0>=-64-a>>>0){v[115121]=48;break c}g=c>>>0<11?16:c+11&-8;c=Ad((g+a|0)+12|0);if(!c){break c}d=c-8|0;f:{if(!(c&a-1)){a=d;break f}i=c-4|0;e=v[i>>2];c=((a+c|0)-1&0-a)-8|0;a=c-d>>>0>15?c:a+c|0;h=a-d|0;c=(e&-8)-h|0;if(!(e&3)){d=v[d>>2];v[a+4>>2]=c;v[a>>2]=d+h;break f}v[a+4>>2]=c|v[a+4>>2]&1|2;e=a+c|0;v[e+4>>2]=v[e+4>>2]|1;v[i>>2]=h|v[i>>2]&1|2;e=d+h|0;v[e+4>>2]=v[e+4>>2]|1;zs(d,h)}e=v[a+4>>2];g:{if(!(e&3)){break g}d=e&-8;if(d>>>0<=g+16>>>0){break g}v[a+4>>2]=g|e&1|2;c=a+g|0;e=d-g|0;v[c+4>>2]=e|3;d=a+d|0;v[d+4>>2]=v[d+4>>2]|1;zs(c,e)}a=a+8|0;break d}a=Ad(c);if(a){break d}break c}v[f+12>>2]=a}gb=f+16|0;a=v[f+12>>2];if(!a){a=v[116448];if(!a){break b}kb[a|0]();continue}break}break a}a=aa(4)|0;km(a);ia(a|0,88880,1928);L()}return a}return rf(a)}function Zpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-32|0;gb=f;v[f+24>>2]=b;b=v[a>>2];m=f,n=Sb(a),v[m>>2]=n;b=b+(tp(f+24|0,f)<<1)|0;d=v[a+4>>2];a:{b:{if(d>>>0<y[wb(a)>>2]){if((b|0)!=(d|0)){break b}d=gb-16|0;gb=d;a=ji(d,a,1);Gr(v[a+4>>2],c);v[a+4>>2]=v[a+4>>2]+2;$b(a);gb=d+16|0;break a}d=wb(a);e=lD(f,MY(a,sc(a)+1|0),b-v[a>>2]>>1,d);v[22640]=0;R(476,e|0,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){c=v[e+4>>2];j=e+4|0;cl(v[a>>2],b,j);h=e+8|0;i=h;g=v[a+4>>2];if((g|0)!=(b|0)){d=v[i>>2];while(1){Gr(d,b);d=v[i>>2]+2|0;v[i>>2]=d;b=b+2|0;if((g|0)!=(b|0)){continue}break}}wc(a,j);wc(a+4|0,h);wc(wb(a),cc(e));v[e>>2]=v[e+4>>2];b=c;rp(e);break a}a=P()|0;O()|0;rp(e);S(a|0);L()}l=gb-16|0;gb=l;j=d;k=v[a+4>>2];i=b;e=b+(k-(b+2|0)|0)|0;h=ji(l,a,d-e>>1);if(d>>>0>e>>>0){g=v[h+4>>2];d=e;while(1){Gr(g,d);g=g+2|0;v[h+4>>2]=g;d=d+2|0;if(j>>>0>d>>>0){continue}break}}$b(h);if((e|0)!=(i|0)){while(1){k=k-2|0;e=e-2|0;CY(k,e);if((e|0)!=(i|0)){continue}break}}gb=l+16|0;a=b>>>0<=c>>>0?y[a+4>>2]>c>>>0?c+2|0:c:c;t[b|0]=w[a|0];t[b+1|0]=w[a+1|0]}bh(b);gb=f+32|0}function JV(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;g=x[c>>1];a:{if(w[d|0]<=4){while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!kf(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!kf(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!kf(a,f+13|0)){break a}d=w[f+13|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!kf(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!kf(a,f+11|0)){break a}d=w[f+11|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}gb=f+16|0}function Rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),x=0,y=0,A=C(0);h=a+44|0;g=Md(h,0);k=Md(h,1);m=kd(h,0);n=kd(h,1);p=B(w[a+4233|0],v[v[a+16>>2]+1074404>>2]);e=p<<1;i=a+4208|0;if(Nb(i)>>>0<e>>>0){El(i,e)}j=EM(a);a:{if(j){if(!d){break a}e=v[a+4220>>2];x=j-1|0;j=0;while(1){if(e>>>0>=p>>>0){v[a+4220>>2]=0;e=0}s=z[k>>2];t=z[g>>2];o=e;e=e-p|0;e=((e|0)<0?o:e)<<1;u=z[Mb(i,e)>>2];f=z[Mb(i,e|1)>>2];q=C(u+t);z[m>>2]=q;r=C(f+s);z[n>>2]=r;f=C(0);l=C(0);b:{c:{switch(x|0){case 0:f=z[a+4224>>2];l=C(f*r);f=C(f*q);break b;case 1:case 2:f=z[a+4224>>2];l=C(f*q);f=C(f*r);break b;case 3:break c;default:break b}}f=C(z[a+4224>>2]*C(u+C(C(s+t)*C(.5))));l=f}n=n+4|0;m=m+4|0;k=k+4|0;g=g+4|0;y=Mb(i,v[a+4220>>2]<<1),A=C(D(f))<C(1.0000000195414814e-24)?C(0):f,z[y>>2]=A;y=Mb(i,v[a+4220>>2]<<1|1),A=C(D(l))<C(1.0000000195414814e-24)?C(0):l,z[y>>2]=A;e=v[a+4220>>2]+1|0;v[a+4220>>2]=e;j=j+1|0;if((j|0)!=(d|0)){continue}break}break a}o=g;g=d<<2;DM(o,o+g|0,m);DM(k,g+k|0,n)}Ci(a,b,c,kd(h,0),kd(h,1),d)}function dpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;td(b,32);e=a+4|0;h=b,i=Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[h>>2]=i;e=a+10|0;e=Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));v[b+4>>2]=e;g=e;e=a+14|0;h=b,i=g+Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|0,v[h+8>>2]=i;e=b;if(c?d:1){c=a+46|0;c=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))}v[e+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;if(!Ib(w[d|0]|w[d+1|0]<<8)){break a}if((Ib(w[d|0]|w[d+1|0]<<8)|0)==48){break a}c=(c-(Ib(w[d|0]|w[d+1|0]<<8)<<7)|0)+6144|0}No(b,+(c|0)*.0006510416666666666);t[f+15|0]=w[a+9|0];t[f+14|0]=64;h=b,i=w[ac(f+15|0,f+14|0)|0]<<2,u[h+30>>1]=i;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}gb=f+16|0}function lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];h=e;i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){j=(((h&2147483647)<<1|i>>>31)&-2)+m|0;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];w=u[e+24>>1];g=0;e=1;while(1){v[(f+8|0)+(g<<2)>>2]=(((((B(t[(g|4)+j|0],o)+B(t[(g|2)+j|0],p)|0)+B(t[(g|6)+j|0],n)|0)+B(t[(g|8)+j|0],i)<<8)/2|0)+((((B(t[(g|-4)+j|0],s)+B(t[(g|-6)+j|0],w)|0)+B(t[(g|-2)+j|0],r)|0)+B(t[g+j|0],q)<<8)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}h=v[a+32>>2];l=v[a+28>>2]+l|0;e=l>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);k=h+k|0;g=k>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[f+12>>2]);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];h=v[f+28>>2];continue}break}i=v[f+24>>2];h=v[f+28>>2];break a}g=k>>12;e=l>>12}v[a+40>>2]=k;v[a+20>>2]=e;v[a+36>>2]=l;v[a+24>>2]=g;v[a>>2]=i;v[a+4>>2]=h;gb=f+32|0}function Pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;g=gb-16|0;gb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];i=v[a+4>>2];h=v[a>>2];v[g+8>>2]=h;v[g+12>>2]=i;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=i+n|0;i=t[e+2|0];o=t[e+1|0];p=t[e|0];q=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=mqa(j,j>>31,e,e>>31);j=jb;w=e;e=v[a+68>>2];k=mqa(e,e>>31,f,f>>31);e=w+k|0;f=jb+j|0;f=e>>>0<k>>>0?f+1|0:f;j=e;e=h>>>21&2040;i=(((B(u[e+46530>>1],p)+B(q,u[e+46528>>1])|0)+B(o,u[e+46532>>1])|0)+B(i,u[e+46534>>1])<<8)/16384<<8;e=i;h=mqa(r,s,e,e>>31);e=j+h|0;f=jb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Ic(e,f,24);e=v[a+72>>2];h=(f|0)/256|0;v[c>>2]=v[c>>2]+B(h,m);v[c+4>>2]=v[c+4>>2]+B(h,l);e=f-(e&i)|0;Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+8>>2];i=v[g+12>>2];f=b;b=e;continue}break}h=v[g+8>>2];i=v[g+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=h;v[a+4>>2]=i;gb=g+16|0}function Foa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;f=b;d=Nb(f);e=c;a:{if(d>>>0<e>>>0){l=gb-32|0;gb=l;b:{c:{h=e-d|0;d:{if(h>>>0<=v[wb(f)>>2]-v[f+4>>2]>>2>>>0){i=gb-16|0;gb=i;e:{d=yg(i,f,h);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){wb(f);v[22640]=0;Ik(e);j=v[22640];v[22640]=0;if((j|0)==1){break e}e=e+4|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}$b(d);gb=i+16|0;break d}a=P()|0;O()|0;$b(d);S(a|0);L()}k=wb(f);i=_g(f,Nb(f)+h|0);m=Nb(f);e=0;j=gb-16|0;gb=j;v[j+12>>2]=0;d=l+8|0;uh(d+12|0,k);if(i){e=QW(i)}v[d>>2]=e;k=(m<<2)+e|0;v[d+8>>2]=k;v[d+4>>2]=k;n=cc(d),o=(i<<2)+e|0,v[n>>2]=o;gb=j+16|0;v[22640]=0;R(682,d|0,h|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}v[22640]=0;R(683,f|0,d|0);f=v[22640];v[22640]=0;if((f|0)==1){break c}RW(d)}gb=l+32|0;break b}a=P()|0;O()|0;RW(d);S(a|0);L()}break a}if(d>>>0>e>>>0){dj(f,v[f>>2]+(e<<2)|0)}}c=Pb(a,c<<2);if(c){f=gb-16|0;gb=f;bc(g+24|0,v[b>>2],Nb(b)<<2);gb=f+16|0;b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function Hla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=gb+-64|0;gb=d;o=d,p=xf(a)>>>5|0,u[o+32>>1]=p;u[d+16>>1]=3999;o=c,p=x[Oc(d+32|0,d+16|0)>>1],u[o+480190>>1]=p;UU(b,x[c+480190>>1],0);a:{if(x[c+480190>>1]){h=d+62|0;k=d+58|0;l=d+56|0;n=d+52|0;m=d+60|0;i=1;j=1;while(1){f=Sl(c,j&65535);Xu(a,d+32|0);td(f,0);Vj(d,2,d+32|0);Bc(d+16|0,d);v[22640]=0;Q(333,((i<<5)+c|0)+946304|0,d+16|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break a}vb(d+16|0);u[f+32>>1]=64;v[f+24>>2]=8287;o=d,p=Ib(w[m|0]|w[m+1|0]<<8),u[o+16>>1]=p;u[d>>1]=64;o=f,p=x[Oc(d+16|0,d)>>1]<<2,u[o+30>>1]=p;e=n;o=f,p=Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))&-2,v[o>>2]=p;e=Ib(w[l|0]|w[l+1|0]<<8);g=Ib(w[k|0]|w[k+1|0]<<8);b:{if(g>>>0<2){break b}g=e+g<<1;if(g>>>0>y[f>>2]){break b}v[f+16>>2]=g;v[f+12>>2]=e<<1;u[f+34>>1]=x[f+34>>1]|8}if(Ib(w[h|0]|w[h+1|0]<<8)){e=(Ib(w[h|0]|w[h+1|0]<<8)|0)==2}else{e=1}oe(d+16|0,b,i-1|0);Af(d+16|0,e);j=j+1|0;i=j&65535;if(i>>>0<=x[c+480190>>1]){continue}break}}gb=d- -64|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function Yaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-32|0;gb=g;e=gb-16|0;gb=e;XW(e+8|0,b);gb=e+16|0;v[g+16>>2]=v[e+8>>2];d=gb-32|0;gb=d;h=b;c=a;b=Vd(c);e=ec(c);a:{b:{if(b){c:{while(1){d:{f=b+16|0;e:{if(ru(wb(c),h,f)){if(!v[b>>2]){break b}e=b;break e}if(!ru(wb(c),f,h)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=ec(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){h=gb-16|0;gb=h;b=ec(a);i=Mc(40,4);f=h+8|0;t[f+4|0]=0;v[f>>2]=b;c=gb-16|0;gb=c;v[c+12>>2]=i;v[22640]=0;b=d+8|0;WQ(b,c+12|0,f);f=v[22640];v[22640]=0;f:{if((f|0)!=1){gb=c+16|0;break f}V(0)|0;O()|0;Bb();L()}c=v[b>>2];v[22640]=0;f=c+16|0;c=v[22640];v[22640]=0;g:{if((c|0)!=1){c=gb-16|0;gb=c;v[c+8>>2]=v[g+16>>2];Dc(f,v[c+8>>2]);Kb(f+12|0);gb=c+16|0;j=ec(b),k=1,t[j+4|0]=k;gb=h+16|0;break g}a=P()|0;O()|0;XQ(b);S(a|0);L()}HS(a,v[d+28>>2],e,v[d+8>>2]);b=$d(d+8|0);t[d+27|0]=1;XQ(d+8|0)}j=g,k=v[yc(d+8|0,b)>>2],v[j+24>>2]=k;t[g+28|0]=w[d+27|0];gb=d+32|0;a=ue(g+24|0);gb=g+32|0;return a+12|0}function Eja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=gb-48|0;gb=f;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;ep(b,f+44|0);a:{if(!WS(f+44|0)){break a}c=w[f+46|0];g=w[f+47|0];e=w[f+45|0];t[a+4|0]=1;h=e>>>3&3;d=(h|0)!=3;i=e>>>1&3;e=i^3;g=g>>>0<192;u[a+2>>1]=x[(B(d,6)+(e<<1)|0)+34040>>1]<<g;e=B(B(w[(e+B(d,3)|0)+33817|0],x[((B(d,90)+B(e,30)|0)+(c>>>3&30)|0)+33824>>1]),1e3);c=c>>>1|0;c=B(((e>>>0)/x[(B(h,6)+(c&6)|0)+34016>>1]|0)+(c&1)|0,(i|0)==3?4:1);u[a>>1]=c;e=w[(g|d<<1)+34052|0];if(e+8>>>0>(c&65535)>>>0){break a}d=f;c=gb-48|0;gb=c;v[c+44>>2]=e+4;v[c+24>>2]=36;g=v[Fb(c+44|0,c+24|0)>>2];if(!Pb(b,g)){g=xf(b)}_r(c+24|0,d);h=Wd(c+32|0,v[c+24>>2],g);i=v[h+4>>2];v[c+8>>2]=v[h>>2];v[c+12>>2]=i;fc(c+16|0,b,c+8|0);_r(c+24|0,d);Qb(v[c+24>>2]+g|0,0,36-g|0);Yb(b,v[c+44>>2]);gb=c+48|0;b=2;if(e>>>0>2){while(1){if(w[b+f|0]){break a}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=a;d=e+f|0;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1868983881){d=1}else{d=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1735289176}t[b+5|0]=d}gb=f+48|0;return a|0}function Bpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-2608|0;gb=f;d=f;$k(d,a);v[d+1060>>2]=0;v[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){t[a+4|0]=0;u[a>>1]=0;u[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}v[22640]=0;_(515,d|0);a=v[22640];v[22640]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!c){break d}f:{while(1){v[22640]=0;j=Q(236,d|0,1)|0;a=v[22640];v[22640]=0;if((a|0)==1){break f}a=0;g:{while(1){v[22640]=0;k=Q(236,d|0,1)|0;e=v[22640];v[22640]=0;if((e|0)==1){break g}a=B(a,6)+d|0;a=u[(k?a+1070|0:a+1068|0)>>1];h:{if((a|0)>255){break h}e=B(a,6)+d|0;g=w[e+1072|0];if(u[e+1068>>1]<0){break h}if(u[e+1070>>1]>-1){continue}}break}g=(j?-1:0)^g;i=(i&255)+(g&255)|0;t[b+h|0]=i;h=h+1|0;if((h|0)!=(c|0)){continue}break d}break}a=V(27860)|0;break e}a=V(27860)|0;break e}a=V(27860)|0}if((O()|0)!=(ea(27860)|0)){break a}Z(a|0)|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)==1){break c}}v[22640]=0;b=mp(d);a=v[22640];v[22640]=0;if((a|0)==1){break b}yb(d);gb=f+2608|0;return b|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}yb(d);S(a|0);L()}function Oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=(g<<1)+o|0;j=u[e>>1];p=u[e-2>>1];q=u[e+2>>1];r=u[e+4>>1];l=v[a+60>>2];e=Lb(b,-16777216,16776704);k=v[a+64>>2];g=Lb(f,-16777216,16776704);f=mqa(k,k>>31,e,e>>31);k=jb;e=f;f=i>>>21&2040;i=(((B(j,u[f+46530>>1])+B(p,u[f+46528>>1])|0)+B(u[f+46532>>1],q)|0)+B(r,u[f+46534>>1])|0)/16384<<8;f=i;j=mqa(l,l>>31,f,f>>31);e=e+j|0;f=jb+k|0;f=e>>>0<j>>>0?f+1|0:f;j=e;e=v[a+68>>2];g=mqa(e,e>>31,g,g>>31);e=j+g|0;f=jb+f|0;f=e>>>0<g>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=Ic(e,f,24);e=v[a+72>>2];g=(f|0)/256|0;v[c>>2]=v[c>>2]+B(g,n);v[c+4>>2]=v[c+4>>2]+B(g,m);e=f-(e&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function _oa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-112|0;gb=d;Ye(b);a:{b:{if(Pb(a,1)){c:{d:{e:{f:{g:{h:{while(1){v[22640]=0;JX(d+24|0,d+48|0);e=v[22640];v[22640]=0;if((e|0)==1){break e}v[22640]=0;e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;U(558,d+32|0,a|0,d+8|0);e=v[22640];v[22640]=0;if((e|0)==1){break e}h=d,i=xb(d+32|0),v[h+44>>2]=i;e=Ab(b);v[22640]=0;v[d+20>>2]=c-e;e=Fb(d+44|0,d+20|0);f=v[22640];v[22640]=0;if((f|0)==1){break h}e=v[e>>2];if(!e){break c}t[d+32|0]=0;f=e+(d+48|0)|0;e=Dm(d+48|0,f,d+32|0);h=d,i=df(b),v[h+32>>2]=i;Fd(d+16|0,d+32|0);v[22640]=0;ca(559,b|0,v[d+16>>2],d+48|0,e|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break g}v[22640]=0;Q(350,a|0,e-(d+48|0)|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break f}if(e>>>0>=f>>>0){continue}break}v[22640]=0;Q(350,a|0,1)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break c}a=V(88880)|0;break d}a=V(88880)|0;break d}a=V(88880)|0;break d}a=V(88880)|0;break d}a=V(88880)|0}if((O()|0)!=(ea(88880)|0)){break b}Z(a|0)|0;$()}e=(Ab(b)|0)!=0}gb=d+112|0;break a}S(a|0);L()}return e|0}function ek(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=gb-32|0;gb=i;v[i+16>>2]=c;v[i+24>>2]=b;Ec(i+8|0,d);v[22640]=0;j=T(2458,i+8|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){Vb(i+8|0);v[e>>2]=0;a:{if((g|0)==(h|0)){break a}while(1){b:{if(ll(i+24|0,i+16|0)){break b}c:{if((Qn(j,v[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}d:{e:{b=Qn(j,v[c>>2]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+8|0)==(h|0)){break b}k=b;b=Qn(j,v[g+8>>2])}l=i,m=kb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+8|0;break c}if(ml(j,8192,v[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(ml(j,8192,v[g>>2])){continue}}break}if(!sm(i+24|0,i+16|0)){break c}while(1){if(!ml(j,8192,rm(i+24|0))){break c}qm(i+24|0);if(sm(i+24|0,i+16|0)){continue}break}break c}if((rn(j,rm(i+24|0))|0)==(rn(j,v[g>>2])|0)){g=g+4|0;qm(i+24|0);break c}v[e>>2]=4}if((g|0)==(h|0)){break a}if(!v[e>>2]){continue}break a}break}v[e>>2]=4}if(ll(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}gb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Vb(i+8|0);S(a|0);L()}function Dja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=zb(b);a:{b:{c:{d:{e:{while(1){b=c;if(!c){break e}c=b-1|0;if(!w[h+c|0]){continue}break}if((d|0)!=4){break c}c=0;while(1){f:{g:{h:{d=w[c+h|0];switch(d-10|0){case 3:break h;case 0:break g;default:break f}}e=e+1|0;break f}f=f+1|0}i=((g&255)==13&(c|0)!=0&(d|0)==10)+i|0;g=d;c=c+1|0;if((c|0)!=(b|0)){continue}break}c=(e|0)==(i|0);break d}if((d|0)!=4){break b}c=1}i:{if((e|0)==(f|0)){d=2;if(c){break i}}if(e){d=0;if(!f){break i}}d=e?3:f?1:3}if(!b){break b}}g=0;f=(d|0)!=2;c=0;e=0;while(1){e=(f|w[c+h|0]!=10)+e|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}break a}b=0;g=1;e=0}jq(a,e);if(!g){g=(d|0)==2;f=d&-3;i=(d|0)==1?32:13;c=0;e=0;while(1){j:{k:{l:{m:{n:{o:{d=t[c+h|0];switch(d-10|0){case 1:case 2:break l;case 0:break n;case 3:break o;default:break m}}j=mc(a,e),k=i,t[j|0]=k;c=c+g|0;break j}d=mc(a,e);if(f){t[d|0]=13;break j}t[d|0]=32;break j}if(!d){break k}}j=mc(a,e),k=d,t[j|0]=k;break j}j=mc(a,e),k=32,t[j|0]=k}e=e+1|0;c=c+1|0;if(c>>>0<b>>>0){continue}break}}return 1}function rD(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b:{if((w[a|0]-1&255)>>>0>14){break b}b=a+1954|0;d=a+1698|0;while(1){if(t[d|0]<=-2){break b}d=d+1|0;if((b|0)!=(d|0)){continue}break}d=0;while(1){c=B(d,13)+a|0;if(w[c+14|0]){break a}e=(d<<4)+a|0;b=e+418|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break a}b=e+422|0;if(w[c+942|0]|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>=1048576){break a}c=B(d,11)+a|0;g=c+1346|0;if(w[g|0]>=16|w[c+1351|0]>=4|w[c+1356|0]>=4){break a}c:{if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break c}c=e+430|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>1048574){break c}if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0){break a}e=e+426|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){break a}}d:{e:{if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)|f){break e}if(yd(g,28861,11)){break e}f=0;break d}f=1}d=d+1|0;if((d|0)!=32){continue}break}}return f}return 0}function fk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=gb-32|0;gb=i;v[i+16>>2]=c;v[i+24>>2]=b;Ec(i+8|0,d);v[22640]=0;j=T(21,i+8|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){Vb(i+8|0);v[e>>2]=0;a:{if((g|0)==(h|0)){break a}while(1){b:{if(hk(i+24|0,i+16|0)){break b}c:{if((Rn(j,t[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=Rn(j,t[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=Rn(j,t[g+2|0])}l=i,m=kb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+2|0;break c}if(jh(j,8192,t[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(jh(j,8192,t[g|0])){continue}}break}if(!ik(i+24|0,i+16|0)){break c}while(1){if(!jh(j,8192,rl(i+24|0))){break c}ql(i+24|0);if(ik(i+24|0,i+16|0)){continue}break}break c}if((ox(j,rl(i+24|0))|0)==(ox(j,t[g|0])|0)){g=g+1|0;ql(i+24|0);break c}v[e>>2]=4}if((g|0)==(h|0)){break a}if(!v[e>>2]){continue}break a}break}v[e>>2]=4}if(hk(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}gb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Vb(i+8|0);S(a|0);L()}function dJ(a,b,c,d,e){var f=C(0),g=C(0),h=0,i=C(0),j=C(0),k=0;if(!(a&3)){if((a|0)>=4){k=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;while(1){b=d-4|0;g=z[b>>2];i=z[d>>2];j=z[a>>2];z[a>>2]=i+j;c=a-4|0;f=z[c>>2];z[c>>2]=z[b>>2]+f;i=C(j-i);f=C(f-g);z[d>>2]=C(z[e>>2]*i)-C(z[e+4>>2]*f);z[b>>2]=C(z[e+4>>2]*i)+C(z[e>>2]*f);b=d-12|0;i=z[b>>2];c=a-8|0;f=z[c>>2];h=c;c=d-8|0;j=z[c>>2];z[h>>2]=j+f;h=a-12|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+32>>2]*f)-C(z[e+36>>2]*g);z[b>>2]=C(z[e+36>>2]*f)+C(z[e+32>>2]*g);b=d-20|0;i=z[b>>2];c=a-16|0;f=z[c>>2];h=c;c=d-16|0;j=z[c>>2];z[h>>2]=j+f;h=a-20|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+64>>2]*f)-C(z[e+68>>2]*g);z[b>>2]=C(z[e+68>>2]*f)+C(z[e+64>>2]*g);b=d-28|0;i=z[b>>2];c=a-24|0;f=z[c>>2];h=c;c=d-24|0;j=z[c>>2];z[h>>2]=j+f;h=a-28|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+96>>2]*f)-C(z[e+100>>2]*g);z[b>>2]=C(z[e+100>>2]*f)+C(z[e+96>>2]*g);d=d-32|0;a=a-32|0;e=e+128|0;b=(k|0)>1;k=k-1|0;if(b){continue}break}}return}ba(12932,10568,2408,6386);L()}function tm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;v[a+4>>2]=0;if(w[rj(f+8|0,a,1)|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[v[a>>2]-12>>2];v[22640]=0;b=v[(a+b|0)+24>>2];d=v[22640];v[22640]=0;if((d|0)==1){break c}v[22640]=0;b=T(2287,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}if(He(b,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;if(!He(b,c)){continue}break}d=0;break a}if(v[a+4>>2]>=(b|0)){break a}while(1){d:{d=v[v[a>>2]-12>>2];v[22640]=0;d=v[(a+d|0)+24>>2];e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;e=T(2287,d|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}if(He(e,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;d=0;if(He(e,c)){break a}if(v[a+4>>2]<(b|0)){continue}break a}break}}b=V(0)|0;O()|0;Z(b|0)|0;d=1;qj(v[v[a>>2]-12>>2]+a|0,1);e:{f:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22640]=0;X(2027);a=v[22640];v[22640]=0;if((a|0)!=1){break e}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){break f}S(a|0);L()}$();break a}V(0)|0;O()|0;Bb()}L()}d=2}fh(v[v[a>>2]-12>>2]+a|0,d)}gb=f+16|0;return a|0}function l5(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;v[22640]=0;g=Q(15,d+24|0,a|0)|0;c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)!=1){d:{if(!w[g|0]){break d}c=v[v[a>>2]-12>>2];v[22640]=0;Ec(d+16|0,a+c|0);c=v[22640];v[22640]=0;e:{f:{g:{if((c|0)!=1){v[22640]=0;c=T(2295,d+16|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break g}Vb(d+16|0);e=_i(d+8|0,a);f=v[v[a>>2]-12>>2];v[22640]=0;f=a+f|0;h=T(16,f|0)|0;i=v[22640];v[22640]=0;if((i|0)==1){break f}e=v[e>>2];v[22640]=0;c=Qa(2296,c|0,e|0,f|0,h|0,+b)|0;e=v[22640];v[22640]=0;if((e|0)==1){break f}v[d+16>>2]=c;if(!Wv(d+16|0)){break d}c=v[v[a>>2]-12>>2];v[22640]=0;R(18,a+c|0,5);c=v[22640];v[22640]=0;if((c|0)!=1){break d}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;Vb(d+16|0);break e}c=V(0)|0;O()|0}pl(g);break c}pl(g);break b}c=V(0)|0;O()|0}Z(c|0)|0;c=v[v[a>>2]-12>>2];v[22640]=0;_(19,a+c|0);c=v[22640];v[22640]=0;if((c|0)==1){break a}$()}gb=d+32|0;return a|0}a=P()|0;O()|0;v[22640]=0;X(20);d=v[22640];v[22640]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function t$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;a=nc(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((ws(b,c,0)|0)!=-1){while(1){f=ws(b,c,e);v[22640]=0;Y(177,d|0,b|0,e|0,f-e|0);f=v[22640];v[22640]=0;if((f|0)==1){break j}v[22640]=0;R(178,d+16|0,d|0);f=v[22640];v[22640]=0;if((f|0)==1){break i}v[22640]=0;R(179,a|0,d+16|0);f=v[22640];v[22640]=0;if((f|0)==1){break h}vb(d+16|0);vb(d);e=ws(b,c,e)+Ab(c)|0;if((ws(b,c,e)|0)!=-1){continue}break}}k:{if($c(a)){v[22640]=0;Y(177,d+16|0,b|0,e|0,-1);c=v[22640];v[22640]=0;if((c|0)==1){break f}c=Ab(d+16|0);vb(d+16|0);if(!c){break k}}v[22640]=0;Y(177,d|0,b|0,e|0,-1);b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;R(178,d+16|0,d|0);b=v[22640];v[22640]=0;if((b|0)==1){break d}v[22640]=0;R(179,a|0,d+16|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}vb(d+16|0);vb(d)}gb=d+32|0;return}e=P()|0;O()|0;break a}e=P()|0;O()|0;break g}e=P()|0;O()|0;vb(d+16|0)}vb(d);break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;vb(d+16|0)}vb(d)}jm(a);S(e|0);L()}function Pu(a,b){a=a|0;b=b|0;a:{b:{switch((w[a+3|0]|64)+-64|0){case 0:t[a+3|0]=w[a+5|0]?37:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(b){break a}b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=b?32:31;return;case 29:t[a+3|0]=b?33:0;return;case 27:t[a+3|0]=b?34:0;return;case 30:t[a+3|0]=b?35:0;return;case 31:t[a+3|0]=b?36:0;return;default:break b}}t[a+3|0]=0}}function Yx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=gb-32|0;gb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;i=c;a:{if((f|0)==(e|0)&c>>>0>c>>>0|e>>>0>f>>>0){e=d<<4|c>>>28;c=c<<4|b>>>28;b=b&268435455;h=b;if((b|0)==134217728&a>>>0>=1|b>>>0>134217728){e=e+1073741824|0;a=c+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}f=c;e=e+1073741824|0;if(a|h^134217728){break a}b=c&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!i&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){f=c;c=d<<4|c>>>28;f=f<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;If(g+16|0,a,b,c,e,h-15233|0);lm(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;c=a;b=v[g>>2]|((v[g+16>>2]|v[g+24>>2])!=0|(v[g+20>>2]|v[g+28>>2])!=0);if((a|0)==134217728&b>>>0>=1|a>>>0>134217728){a=f+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}if(b|c^134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}gb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function jz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;d=a+2|0;if(!(w[d|0]==255|!w[d|0])){v[f+12>>2]=w[d|0]+1;v[f+8>>2]=10;hh(b,v[ld(f+12|0,f+8|0)>>2]);d=w[a+3|0];t[b+15|0]=d;t[b+16|0]=d;t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];d=0;g=511;a:{b:{switch(c-1|0){case 1:e=4096;g=128;break a;case 0:break b;default:break a}}e=32768;g=1024}if(Nb(b)){c=g>>>1|e;while(1){h=(d<<2)+a|0;e=h+6|0;e=w[e|0]|w[e+1|0]<<8;i=Mb(b,d),j=e>>>4|0,u[i>>1]=j;e=0;c:{if(d){e=d-1|0;if(x[Mb(b,d)>>1]>=x[Mb(b,e)>>1]){break c}e=x[Mb(b,e)>>1]+1|0}i=Mb(b,d),j=e,u[i>>1]=j}e=h+8|0;v[f+12>>2]=(c+((w[e|0]|w[e+1|0]<<8)<<16>>16)|0)/(g|0);v[f+8>>2]=0;v[f+4>>2]=64;e=v[Tm(f+12|0,f+8|0,f+4|0)>>2];i=Mb(b,d),j=e,t[i+2|0]=j;d=d+1|0;if(Nb(b)>>>0>d>>>0){continue}break}}t[b+12|0]=w[b+12|0]&254|t[a|0]&1;c=b;if(w[a|0]&2){d=w[b+15|0];e=Nb(b);d=w[b+12|0]&-5|(d>>>0<=e>>>0)<<2}else{d=w[b+12|0]&-5}t[c+12|0]=d;c=b;d:{e:{if(w[a|0]&4){a=w[b+13|0];if(a>>>0<=w[b+14|0]){break e}}a=w[b+12|0]&-3;break d}d=Nb(b);a=w[b+12|0]&-3|(a>>>0<=d>>>0)<<1}t[c+12|0]=a}gb=f+16|0}function e7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=gb+-64|0;gb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;Hf(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;j=b+16|0;c=gb-32|0;gb=c;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[j+4>>2]){if(y[a+8>>2]>=e>>>0){if(Gf(j)>>>0>=e>>>0){if(e){while(1){f=0;if(d){while(1){k=c,l=A[Tg(a,f,h)>>3],A[k+24>>3]=l;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;g=A[$g(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=g;g=fe(g);b:{if(D(g)<2147483648){i=~~g;break b}i=-2147483648}i=Sc(i);k=go(j,f,h),m=i,u[k>>1]=m;f=f+1|0;if((d|0)!=(f|0)){continue}break}}h=h+1|0;if((h|0)!=(e|0)){continue}break}}gb=c+32|0;break a}ba(2959,6225,80,5936);L()}ba(2989,6225,79,5936);L()}ba(4217,6225,78,5936);L()}ba(4252,6225,77,5936);L()}gb=b- -64|0}function W6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=gb+-64|0;gb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;Hf(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;j=b+16|0;c=gb-32|0;gb=c;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[j+4>>2]){if(y[a+8>>2]>=e>>>0){if(Gf(j)>>>0>=e>>>0){if(e){while(1){f=0;if(d){while(1){k=c,l=A[Tg(a,f,h)>>3],A[k+24>>3]=l;v[c+16>>2]=0;v[c+20>>2]=-1074790400;v[c+8>>2]=0;v[c+12>>2]=1072693248;g=A[$g(c+24|0,c+16|0,c+8|0)>>3]*32768;A[c+24>>3]=g;g=fe(g);b:{if(D(g)<2147483648){i=~~g;break b}i=-2147483648}i=Sc(i);k=fo(j,f,h),m=i,u[k>>1]=m;f=f+1|0;if((d|0)!=(f|0)){continue}break}}h=h+1|0;if((h|0)!=(e|0)){continue}break}}gb=c+32|0;break a}ba(2959,6225,80,5936);L()}ba(2989,6225,79,5936);L()}ba(4217,6225,78,5936);L()}ba(4252,6225,77,5936);L()}gb=b- -64|0}function rq(a){a=a|0;var b=0,c=0,d=0,e=C(0),f=0,g=0,h=C(0),i=0,j=0,k=0,l=C(0);b=v[a+36>>2];if(!b){Cg(a+16|0);return}a:{b:{c:{switch(x[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Cg(c);return}El(c,b);b=x[a+28>>1];d=a+4|0;Nb(d);e=Fm(a,(b<<16)+65536>>16);f=u[a+28>>1];Nb(d);b=1;e=me(C(e/Fm(a,f)),C(C(1)/C(v[a+36>>2]+1>>>0)));if(!v[a+36>>2]){break b}while(1){h=me(e,C(b>>>0));k=Mb(c,b-1|0),l=h,z[k>>2]=l;b=b+1|0;if(b>>>0<=y[a+36>>2]){continue}break};break b;case 1:c=a+16|0;d=x[a+30>>1];if(d>>>0>1e3/(b>>>0)>>>0){Cg(c);return}El(c,B(b,d));b=u[a+28>>1];Nb(a+4|0);i=b;b=x[a+30>>1];i=qo(i,b);if(!d){break b}while(1){b=qo(f+i<<16>>16,b&65535)<<16;j=b>>16;e=me(C(Fm(a,b+65536>>16)/Fm(a,j)),C(C(1)/C(v[a+36>>2]+1>>>0)));d:{if(!v[a+36>>2]){break d}b=1;g=0;while(1){h=me(e,C((b&65535)>>>0));k=Mb(c,B(v[a+36>>2],j)+g|0),l=h,z[k>>2]=l;b=b+1|0;g=b&65535;if(g>>>0>y[a+36>>2]){break d}g=g-1|0;continue}}f=f+1|0;if(d>>>0<=(f&65535)>>>0){break b}b=x[a+30>>1];continue};case 0:break a;default:break c}}Cg(a+16|0);v[a+36>>2]=0}return}Cg(a+16|0)}function JP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;g=B(b,872)+a|0;a:{if(c){Db(e+8|0,a+1074312|0,90);if(!Cb(e+8|0)){t[(B(b,872)+a|0)+1075803|0]=c}t[(B(b,872)+a|0)+1075804|0]=c;break a}c=w[g+1075804|0]}f=g+1074992|0;h=c&255;j=0-h|0;i=d?i:!(v[a+480180>>2]&204473357);EP(a,b,j,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}g=v[(B(b,872)+a|0)+1075648>>2];if(!g|!v[g+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){DP(a,f,240-h|0);break b}if(!(b>>>0<224|d)){CP(f,224-h|0);break b}BP(f,j);break b}if(v[a+480180>>2]==268435456){v[(B(b,872)+a|0)+1075700>>2]=65535}if((c&255)>>>0>223&i){d:{d=h&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}zP(a,f,d);break b}if(v[a+480180>>2]==524288){break d}GP(a,f,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break e}if(v[a+1074416>>2]==1){Db(e+8|0,a+1074312|0,6);if(Cb(e+8|0)){break e}}if(v[a+480180>>2]==64){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}ok(a,f,(B(b,872)+a|0)+1075692|0,0-(h<<2)|0,0)}gb=e+16|0}function UO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{b:{switch(w[a+480224|0]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=mqa(c,c>>31,5e4,0);f=jb;b=v[Jc(d+12|0,d+8|0)>>2];c=zc(nqa(c,f,b,b>>31),jb);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=mqa(c,c>>31,1e4,0);f=jb;b=v[Jc(d+12|0,d+8|0)>>2];c=zc(nqa(c,f,b,b>>31),jb);break a;case 1:break b}}e=+y[a+24620>>2]*60/(+y[b+44>>2]*1e-4*(+(mqa(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(jb>>>0)*4294967296));c:{d:{c=a+484344|0;if(!ke(c,x[b+70>>1])){break d}if(!($c(_b(c,x[b+70>>1])+24|0)^1)){break d}c=_b(c,x[b+70>>1])+24|0;break c}c=a+480248|0}if(!$c(c)){e=e*5.960464477539063e-8*+y[Mb(c,y[b+48>>2]%(Nb(c)>>>0)|0)>>2]}e:{if(D(e)<2147483648){c=~~e;break e}c=-2147483648}e=e-+(c>>>0)+A[b+8>>3];A[b+8>>3]=e;if(!(e<1)){A[b+8>>3]=e+-1;c=c+1|0;break a}if(A[a+1074384>>3]>-1){break a}A[b+8>>3]=e+1;c=c-1|0}b=mqa(v[a+480244>>2],0,c,0)+32768|0;a=jb;a=b>>>0<32768?a+1|0:a;a=Uc((a&65535)<<16|b>>>16,a>>>16|0);gb=d+16|0;return(a?a:1)|0}function Sv(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=a;a=gb+-64|0;gb=a;i=a;g=v[c>>2]&2?16:10;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){aK(e+8|0,Jb(d),Jb(d)+Ab(d)|0,w[b|0],g);if(!v[e+12>>2]){break c}f=Ab(d);v[22640]=0;v[e+4>>2]=f;f=wf(e+4|0);j=v[22640];v[22640]=0;if((j|0)!=1){v[22640]=0;U(117,d|0,f|0,0);f=v[22640];v[22640]=0;if((f|0)!=1){continue}}break}break b}b=v[e+8>>2];g=Jb(d);v[22640]=0;R(118,d|0,b-g|0);b=v[22640];v[22640]=0;d:{if((b|0)!=1){v[22640]=0;R(128,i|0,d|0);b=v[22640];v[22640]=0;if((b|0)!=1){break d}break b}break b}vb(d);gb=e+32|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}Al(a+16|0,a,c);v[22640]=0;U(135,a+32|0,a+16|0,c|0);b=v[22640];v[22640]=0;e:{f:{g:{h:{i:{if((b|0)!=1){v[22640]=0;U(136,a+48|0,a+32|0,c|0);b=v[22640];v[22640]=0;if((b|0)==1){break i}v[22640]=0;R(127,h|0,a+48|0);b=v[22640];v[22640]=0;if((b|0)==1){break h}vb(a+48|0);vb(a+32|0);vb(a+16|0);vb(a);gb=a- -64|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;vb(a+48|0)}vb(a+32|0)}vb(a+16|0);vb(a);S(b|0);L()}}function l_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-112|0;gb=d;vc(b);ls(a);a:{if(!eF(b,d+72|0)){break a}if(!fF(d+72|0)){break a}b:{if(!c){break b}c=d+72|4;if(!Pb(b,Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))-28|0)){break a}Jw(a);g=d,h=Iw(),v[g+48>>2]=h;Hw(hj(a)+32|0,d+48|0);js(d+48|0);f=v[hj(a)+32>>2];v[22640]=0;R(313,d+48|0,b|0);b=v[22640];v[22640]=0;c:{if((b|0)==1){break c}e=v[d+48>>2];c=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));b=Xb(w[d+84|0]|w[d+85|0]<<8|(w[d+86|0]<<16|w[d+87|0]<<24));v[22640]=0;c=ca(314,e|0,c-28|0,f|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}e=0;if(!c){break a}be(d+32|0,f);b=v[d+36>>2];v[d+16>>2]=v[d+32>>2];v[d+20>>2]=b;Lh(d+40|0,d+16|0);c=Sd(d+24|0);b=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=b;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;b=gm(d+48|0,d+8|0,d);od(hj(a)+12|0,b);yb(b);break b}b=Ca(88880,28664)|0;a=O()|0;d:{if((ea(88880)|0)!=(a|0)){if((ea(28664)|0)!=(a|0)){break d}}Z(b|0)|0;$();e=0;break a}S(b|0);L()}e=1}gb=d+112|0;return e|0}function J3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=kb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Ec(g,d);v[22640]=0;b=T(2458,g|0)|0;a=v[22640];v[22640]=0;d:{e:{f:{g:{if((a|0)!=1){Vb(g);Ec(g,d);v[22640]=0;a=T(2459,g|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break g}Vb(g);v[22640]=0;R(2460,g|0,a|0);d=v[22640];v[22640]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[22640]=0;R(2461,g|12,a|0);a=v[22640];v[22640]=0;if((a|0)==1){break e}v[22640]=0;d=g+24|0;a=sa(2462,g+24|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[22640];v[22640]=0;if((b|0)==1){break f}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Hc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Vb(g);break d}b=P()|0;O()|0;Vb(g);break d}b=P()|0;O()|0;while(1){d=Hc(d-12|0);if((g|0)!=(d|0)){continue}break}break d}b=P()|0;O()|0;Hc(g)}S(b|0);L()}t[f|0]=0}gb=g+32|0;return b|0}function b4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=kb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Ec(g,d);v[22640]=0;b=T(21,g|0)|0;a=v[22640];v[22640]=0;d:{e:{f:{g:{if((a|0)!=1){Vb(g);Ec(g,d);v[22640]=0;a=T(2430,g|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break g}Vb(g);v[22640]=0;R(2431,g|0,a|0);d=v[22640];v[22640]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[22640]=0;R(2432,g|12,a|0);a=v[22640];v[22640]=0;if((a|0)==1){break e}v[22640]=0;d=g+24|0;a=sa(2433,g+24|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[22640];v[22640]=0;if((b|0)==1){break f}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=vb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Vb(g);break d}b=P()|0;O()|0;Vb(g);break d}b=P()|0;O()|0;while(1){d=vb(d-12|0);if((g|0)!=(d|0)){continue}break}break d}b=P()|0;O()|0;vb(g)}S(b|0);L()}t[f|0]=0}gb=g+32|0;return b|0}function SB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gb-32|0;gb=h;vV(a,b);i=gb-16|0;gb=i;td(c,1);a=b+22|0;k=c,l=Ib(w[a|0]|w[a+1|0]<<8)<<1,v[k>>2]=l;t[c+37|0]=w[b+24|0]<<4;t[i+15|0]=w[b+25|0];t[i+14|0]=64;k=c,l=w[ac(i+15|0,i+14|0)|0]<<2,u[k+30>>1]=l;a=b+26|0;j=Ib(w[a|0]|w[a+1|0]<<8);a=j<<1;f=b+28|0;g=Ib(w[f|0]|w[f+1|0]<<8);f=g<<1;a:{if(g>>>0<=1){g=v[c>>2];break a}g=v[c>>2];a=a+f>>>0<=g>>>0?a:g>>>0<f+j>>>0?a:j}b:{c:{switch(g|0){case 2:v[c>>2]=0;break b;case 0:break b;default:break c}}v[c+4>>2]=a;f=a+f|0;v[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;v[c+4>>2]=a}if(f-a>>>0>3?f>>>0<4|a>>>0>f>>>0:1){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){v[c+8>>2]=0;break b}if(a>>>0>=f>>>0){break b}u[c+34>>1]=x[c+34>>1]|2}gb=i+16|0;Mk(h,3,b);Bc(h+16|0,h);v[22640]=0;Q(333,d|0,h+16|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){a=d+32|0;vb(h+16|0);while(1){if((w[d|0]-1&255)>>>0<=30){t[d|0]=32}d=d+1|0;if((a|0)!=(d|0)){continue}break}a=TB(b);gb=h+32|0;return a}a=P()|0;O()|0;vb(h+16|0);S(a|0);L()}function dq(a,b,c,d,e,f){var g=C(0),h=C(0),i=0,j=C(0),k=C(0),l=0;if((a|0)>=4){l=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;b=f<<2;while(1){c=d-4|0;h=z[c>>2];j=z[d>>2];k=z[a>>2];z[a>>2]=j+k;f=a-4|0;g=z[f>>2];z[f>>2]=z[c>>2]+g;j=C(k-j);g=C(g-h);z[d>>2]=C(z[e>>2]*j)-C(z[e+4>>2]*g);z[c>>2]=C(z[e+4>>2]*j)+C(z[e>>2]*g);f=d-12|0;j=z[f>>2];c=a-8|0;g=z[c>>2];i=c;c=d-8|0;k=z[c>>2];z[i>>2]=k+g;i=a-12|0;h=z[i>>2];z[i>>2]=z[f>>2]+h;i=c;c=b+e|0;g=C(g-k);h=C(h-j);z[i>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[f>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=d-20|0;j=z[e>>2];f=a-16|0;g=z[f>>2];i=f;f=d-16|0;k=z[f>>2];z[i>>2]=k+g;i=a-20|0;h=z[i>>2];z[i>>2]=z[e>>2]+h;c=b+c|0;g=C(g-k);h=C(h-j);z[f>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[e>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=d-28|0;j=z[e>>2];f=a-24|0;g=z[f>>2];i=f;f=d-24|0;k=z[f>>2];z[i>>2]=k+g;i=a-28|0;h=z[i>>2];z[i>>2]=z[e>>2]+h;c=b+c|0;g=C(g-k);h=C(h-j);z[f>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[e>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=b+c|0;d=d-32|0;a=a-32|0;c=(l|0)>1;l=l-1|0;if(c){continue}break}}}function _ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;j=v[a+16>>2];f=Sd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=gg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}k=v[a+24>>2];l=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;v[e+40>>2]=g;v[e+44>>2]=m;h=(h<<1)+j|0;a:{if((b|0)<=0){break a}while(1){Id(v[f+8>>2],u[(i<<1)+h>>1]/4<<16>>16);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Id(b,u[h+(v[e+44>>2]<<1)>>1]/4<<16>>16);Hd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function KP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;h=B(b,872)+a|0;a:{if(c){Db(e+8|0,a+1074312|0,90);if(!Cb(e+8|0)){t[(B(b,872)+a|0)+1075804|0]=c}t[(B(b,872)+a|0)+1075803|0]=c;break a}c=w[h+1075803|0]}f=h+1074992|0;g=c&255;i=d?i:!(v[a+480180>>2]&204473357);EP(a,b,g,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}h=v[(B(b,872)+a|0)+1075648>>2];if(!h|!v[h+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){DP(a,f,g-240|0);break b}if(!(b>>>0<224|d)){CP(f,g-224|0);break b}BP(f,g);break b}if(v[a+480180>>2]==268435456){v[(B(b,872)+a|0)+1075700>>2]=1}if((c&255)>>>0>223&i){d:{d=g&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}AP(a,f,d);break b}if(v[a+480180>>2]==524288){break d}FP(a,f,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break e}if(v[a+1074416>>2]==1){Db(e+8|0,a+1074312|0,6);if(Cb(e+8|0)){break e}}if(v[a+480180>>2]==64){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}ok(a,f,(B(b,872)+a|0)+1075692|0,g<<2,0)}gb=e+16|0}function oja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){j=u[(g<<1)+o>>1];i=v[a+60>>2];f=Lb(b,-16777216,16776704);n=v[a+64>>2];g=Lb(e,-16777216,16776704);j=j<<8;e=j;e=mqa(i,i>>31,e,e>>31);i=jb;k=mqa(n,n>>31,f,f>>31);f=k+e|0;e=jb+i|0;e=f>>>0<k>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=mqa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Ic(f,e,24);f=v[a+72>>2];g=v[a+32>>2];m=v[a+28>>2]+m|0;i=m>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);l=g+l|0;k=l>>12;v[c+4>>2]=v[c+4>>2]+B(n,k);f=e-(f&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}k=l>>12;i=m>>12;f=b}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function Td(a){var b=0,c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;v[c+12>>2]=0;v[c+8>>2]=2537;d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=v[c+4>>2];b=c+16|0;v[b+4>>2]=v[c>>2];v[b+8>>2]=d;v[b>>2]=a;d=gb-16|0;gb=d;e=a;if(v[a>>2]!=-1){yc(d,tT(d+8|0,b));b=d;a:{b:{c:{if(!v[e>>2]){d:{bf(e,1);v[22640]=0;f=v[22640];v[22640]=0;e:{if((f|0)==1){break e}v[22640]=0;_(2543,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;b=v[22640];v[22640]=0;if((b|0)==1){break e}v[e>>2]=-1;v[22640]=0;b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;b=v[22640];v[22640]=0;if((b|0)!=1){break d}}a=V(0)|0;O()|0;Z(a|0)|0;v[22640]=0;a=v[22640];v[22640]=0;f:{if((a|0)==1){break f}bf(e,0);v[22640]=0;a=v[22640];v[22640]=0;if((a|0)==1){break f}v[22640]=0;a=v[22640];v[22640]=0;if((a|0)==1){break f}v[22640]=0;X(2027);a=v[22640];v[22640]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[22640]=0;X(20);d=v[22640];v[22640]=0;if((d|0)==1){break c}S(a|0);L()}}break a}V(0)|0;O()|0;Bb()}L()}}gb=d+16|0;gb=c+32|0;return v[a+4>>2]-1|0}function RO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-560|0;gb=e;u[e+558>>1]=b;a:{b:{if((b-1&65535)>>>0>254){break b}d=((b<<2)+a|0)+900380|0;f=v[d>>2];c:{if(f){c=MS(e,c);d=v[c+4>>2];b=f;v[b>>2]=v[c>>2];v[b+4>>2]=d;d=w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24);g=w[c+7|0]|w[c+8|0]<<8|(w[c+9|0]<<16|w[c+10|0]<<24);t[b+7|0]=g;t[b+8|0]=g>>>8;t[b+9|0]=g>>>16;t[b+10|0]=g>>>24;t[b+11|0]=d;t[b+12|0]=d>>>8;t[b+13|0]=d>>>16;t[b+14|0]=d>>>24;t[b+15|0]=w[c+15|0];d=v[c+44>>2];v[b+40>>2]=v[c+40>>2];v[b+44>>2]=d;d=v[c+36>>2];v[b+32>>2]=v[c+32>>2];v[b+36>>2]=d;d=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=d;d=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=d;Pz(b+48|0,c+48|0);Pz(b+68|0,c+68|0);Pz(b+88|0,c+88|0);hc(b+108|0,c+108|0,448);hv(c);break c}b=Rg(556);if(!b){f=0;v[d>>2]=0;break b}v[22640]=0;f=Q(1331,b|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break a}v[d>>2]=b}h=a,i=x[Ie(a+480192|0,e+558|0)>>1],u[h+480192>>1]=i}gb=e+560|0;return f|0}a=P()|0;O()|0;Zb(b);S(a|0);L()}function pja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){j=t[g+o|0];i=v[a+60>>2];f=Lb(b,-16777216,16776704);n=v[a+64>>2];g=Lb(e,-16777216,16776704);j=j<<16;e=j;e=mqa(i,i>>31,e,e>>31);i=jb;k=mqa(n,n>>31,f,f>>31);f=k+e|0;e=jb+i|0;e=f>>>0<k>>>0?e+1|0:e;i=f;f=v[a+68>>2];g=mqa(f,f>>31,g,g>>31);f=i+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Ic(f,e,24);f=v[a+72>>2];g=v[a+32>>2];m=v[a+28>>2]+m|0;i=m>>12;n=(e|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);l=g+l|0;k=l>>12;v[c+4>>2]=v[c+4>>2]+B(n,k);f=e-(f&j)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}j=v[h+8>>2];g=v[h+12>>2];e=b;break a}k=l>>12;i=m>>12;f=b}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=g;gb=h+16|0}function UN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{c=gb-16|0;gb=c;d=Kb(a);h=b;b:{if(Ab(b)){while(1){a=v[kk(h,f)>>2];c:{if(a>>>0>=2097152){v[22640]=0;R(108,d|0,63);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break b}b=0;d:{e:{f:{while(1){e=a&63;t[(c+10|0)+b|0]=e;if(a>>>0<64){break f}a=a>>>6|0;b=b+1|0;if((b|0)!=6){continue}break}b=7;a=1;break e}if(!b){v[22640]=0;R(108,d|0,t[c+10|0]);a=v[22640];v[22640]=0;if((a|0)!=1){break c}break b}a=7-b|0;b=b+1|0;if((b|0)!=2){break e}if((e|0)==1){break d}b=2;a=6}i=(-1<<b^-1)<<a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){g:{if((a|0)==(b|0)){a=w[j|0];v[22640]=0;R(108,d|0,(a|i)<<24>>24);g=v[22640];v[22640]=0;a=e;if((g|0)!=1){break g}break b}v[22640]=0;a=a-1|0;R(108,d|0,t[a+(c+10|0)|0]|-128);g=v[22640];v[22640]=0;if((g|0)==1){break b}}if(a){continue}break}break c}v[22640]=0;R(108,d|0,t[c+10|0]|64);a=v[22640];v[22640]=0;if((a|0)==1){break b}}f=f+1|0;if(Ab(h)>>>0>f>>>0){continue}break}}gb=c+16|0;break a}a=P()|0;O()|0;vb(d);S(a|0);L()}}function _0(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=gb-16|0;gb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{b=v[a+12>>2];d:{if(d>>>0>b>>>0){while(1){c=v[b>>2];if(c>>>0>1114111|(c&-2048)==55296){break b}e:{if(c>>>0<=127){f=v[a+8>>2];b=1;if((g-f|0)<1){break d}v[a+8>>2]=f+1;t[f|0]=c;break e}if(c>>>0<=2047){b=v[a+8>>2];if((g-b|0)<2){break c}v[a+8>>2]=b+1;t[b|0]=c>>>6|192;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128;break e}b=v[a+8>>2];f=g-b|0;if(c>>>0<=65535){if((f|0)<3){break c}v[a+8>>2]=b+1;t[b|0]=c>>>12|224;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>6&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128;break e}if((f|0)<4){break c}v[a+8>>2]=b+1;t[b|0]=c>>>18|240;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>12&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c>>>6&63|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=c&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;if(b>>>0<d>>>0){continue}break}}b=0}break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];gb=a+16|0;return b|0}function Cfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;e=d;b=gb-32|0;gb=b;v[b+16>>2]=1073741824;u[b+22>>1]=12;v[b+12>>2]=15;c=rf(64);v[22640]=0;f=T(1323,c|0)|0;g=v[22640];v[22640]=0;a:{b:{c:{if((g|0)!=1){c=is(b+8|0,f);f=v[c>>2];v[22640]=0;R(1324,f|0,a|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}a=v[c>>2];v[22640]=0;a=W(1325,a|0,b+22|0,b+16|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break c}d:{if(!a){Rz(b+24|0);break d}a=v[c>>2];v[22640]=0;R(1326,a|0,b+12|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}ni(b+24|0,c)}Dg(c);gb=b+32|0;a=v[b+24>>2];break a}a=P()|0;O()|0;Zb(c);break b}a=P()|0;O()|0;Dg(c)}S(a|0);L()}v[e+24>>2]=a;a=0;e:{f:{g:{while(1){b=v[d+24>>2];v[22640]=0;u[d+22>>1]=a;e=Q(2,d+8|0,(a<<2)+38800|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break g}v[22640]=0;U(1322,b|0,d+22|0,e|0);b=v[22640];v[22640]=0;if((b|0)==1){break f}vb(e);a=a+1|0;if((a|0)!=12){continue}break}gb=d+32|0;return v[d+24>>2]}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(e)}Dg(d+24|0);S(a|0);L()}function $K(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;a:{b:{c:{d:{e:{f:{g:{if(yj(a)){th(c+24|0);break g}mo(c+8|0,a);v[22640]=0;d=T(2084,c+8|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break f}v[c+24>>2]=d;Uf(c+8|0)}if(yj(a)){d=a+36|0}else{d=v[c+24>>2]}if((b|0)==-1){f=4194304;e=0;break d}if((b|0)>=0){e=b;if((jo(d)|0)>(b|0)){break d}}b=aa(8)|0;v[22640]=0;d=Q(112,c+8|0,8255)|0;a=v[22640];v[22640]=0;if((a|0)==1){break e}qc(b,d);v[22640]=0;U(223,b|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(d);break c}a=P()|0;O()|0;Uf(c+8|0);break b}a=P()|0;O()|0;da(b|0);break c}v[a+8>>2]=b;b=a+24|0;g=v[b>>2];v[g+480208>>2]=v[g+480208>>2]&-4194305|f;b=v[b>>2];f=w[Ul(d,e)+16|0];v[22640]=0;Pi(b+484360|0,f);b=v[22640];v[22640]=0;h:{if((b|0)==1){break h}b=Ul(d,e);d=v[b+8>>2];b=v[b+12>>2];v[22640]=0;+oa(1944,a|0,b|0,d|0);b=v[22640];v[22640]=0;if((b|0)==1){break h}v[a+16>>2]=0;v[a+20>>2]=0;yl(c+24|0);gb=c+32|0;return}a=P()|0;O()|0}yl(c+24|0)}S(a|0)}L()}function Zea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-32|0;gb=f;g=gb-16|0;gb=g;d=b;c=a+33|0;v[d>>2]=w[c+206|0]|w[c+207|0]<<8;_N(c,d+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);_N(c,d+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);h=d+236|0;while(1){j=w[c+e|0];k=sd(h,e+12|0),l=j,u[k>>1]=l;e=e+1|0;if((e|0)!=96){continue}break}if(w[c+208|0]){t[d+31|0]=w[c+209|0]+1;h=w[d+31|0];a:{b:{if(!h){e=1;break b}e=16;if(h>>>0<17){break a}}t[d+31|0]=e}u[g+14>>1]=w[c+210|0]|w[c+211|0]<<8;u[g+12>>1]=127;k=d,l=w[Oc(g+14|0,g+12|0)|0]+1|0,t[k+30|0]=l}t[d+33|0]=w[c+212|0];gb=g+16|0;c=b+236|0;while(1){d=0;e=a+i|0;if(w[e+33|0]<(w[a+27|0]|w[a+28|0]<<8)>>>0){d=w[e+33|0]}k=sd(c,i+12|0),l=d,u[k>>1]=l;i=i+1|0;if((i|0)!=96){continue}break}Mk(f,3,a+4|0);Bc(f+16|0,f);v[22640]=0;Q(333,b+492|0,f+16|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){vb(f+16|0);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}gb=f+32|0;return}a=P()|0;O()|0;vb(f+16|0);S(a|0);L()}function QI(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-208|0;gb=d;v[d+8>>2]=1;v[d+12>>2]=0;a:{h=b<<2;if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;f=4;e=2;while(1){g=f;f=b;b=(b+4|0)+g|0;v[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;if(b>>>0<h>>>0){continue}break}b:{f=(a+h|0)-4|0;if(f>>>0<=a>>>0){e=1;b=1;break b}e=1;b=1;while(1){c:{if((e|0)==3){Ux(a,c,b,d+16|0);ft(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(y[(d+16|0)+(g<<2)>>2]>=f-a>>>0){et(a,c,d+8|0,b,0,d+16|0);break d}Ux(a,c,b,d+16|0)}if((b|0)==1){dt(d+8|0,1);b=0;break c}dt(d+8|0,g);b=1}e=v[d+8>>2]|1;v[d+8>>2]=e;a=a+4|0;if(f>>>0<=a>>>0){break b}e=e&3;continue}}et(a,c,d+8|0,b,0,d+16|0);while(1){e:{f:{g:{if(!((b|0)!=1|(e|0)!=1)){if(v[d+12>>2]){break g}break a}if((b|0)>1){break f}}f=OI(d+8|0);ft(d+8|0,f);e=v[d+8>>2];b=b+f|0;break e}dt(d+8|0,2);v[d+8>>2]=v[d+8>>2]^7;ft(d+8|0,1);g=a-4|0;f=b-2|0;et(g-v[(d+16|0)+(f<<2)>>2]|0,c,d+8|0,b-1|0,1,d+16|0);dt(d+8|0,1);e=v[d+8>>2]|1;v[d+8>>2]=e;et(g,c,d+8|0,f,1,d+16|0);b=f}a=a-4|0;continue}}gb=d+208|0}function P8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+24;rK(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+24;$b(c);gb=c+16|0;return}i=gb-32|0;gb=i;j=wb(a);d=i+8|0;e=a;h=jo(a)+1|0;f=gb-16|0;gb=f;v[f+12>>2]=h;a:{c=FV();if(h>>>0<=c>>>0){e=av(e);if(e>>>0<c>>>1>>>0){v[f+8>>2]=e<<1;c=v[Jc(f+8|0,f+12|0)>>2]}gb=f+16|0;break a}Rc();L()}h=jo(a);f=gb-16|0;gb=f;v[f+12>>2]=0;ef(d+12|0,j);if(c){e=c;if(c>>>0>=178956971){nd(8513);L()}g=Mc(B(e,24),8)}v[d>>2]=g;e=B(h,24)+g|0;v[d+8>>2]=e;v[d+4>>2]=e;k=cc(d),l=B(c,24)+g|0,v[k>>2]=l;gb=f+16|0;c=d;rK(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+24;b=a;e=c+4|0;g=v[a>>2];a=v[a+4>>2]-g|0;f=v[e>>2]+B((a|0)/-24|0,24)|0;v[e>>2]=f;if((a|0)>=1){hc(f,g,a)}wc(b,e);wc(b+4|0,d+8|0);wc(wb(b),cc(d));v[d>>2]=v[d+4>>2];a=c;b=v[c+8>>2];d=v[c+4>>2];if((b|0)!=(d|0)){v[a+8>>2]=b+B(((b-d|0)-24>>>0)/24^-1,24)}a=v[c>>2];if(a){vy(a,(v[cc(c)>>2]-v[c>>2]|0)/24|0)}gb=i+32|0}function Lea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;td(c,0);d=a+36|0;u[e+14>>1]=w[d|0]|w[d+1|0]<<8;u[e+12>>1]=32767;f=c,g=(x[Oc(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,u[f+28>>1]=g;d=a+38|0;u[e+10>>1]=w[d|0]|w[d+1|0]<<8;u[e+8>>1]=32767;f=c,g=(x[Oc(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,u[f+30>>1]=g;u[c+32>>1]=64;d=a+44|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+56|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+166|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+49402|0]}t[c+39|0]=w[b+167|0];d=b+171|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+169|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+40|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}gb=e+16|0}function h$(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb+-64|0;gb=c;a=Kb(a);v[22640]=0;b=fa(184)|0;d=v[22640];v[22640]=0;a:{b:{if((d|0)==1){break b}c:{d:{if(!b){break d}v[22640]=0;d=Q(2,c+32|0,6174)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;b=fa(184)|0;e=v[22640];v[22640]=0;e:{f:{g:{h:{if((e|0)==1){break h}v[22640]=0;v[c+12>>2]=b;R(190,c+16|0,c+12|0);b=v[22640];v[22640]=0;if((b|0)==1){break h}v[22640]=0;U(3,c+48|0,d|0,c+16|0);b=v[22640];v[22640]=0;if((b|0)==1){break g}Eb(a,c+48|0);vb(c+48|0);vb(c+16|0);vb(d);v[22640]=0;b=fa(186)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}if(!b){break e}v[22640]=0;Q(191,a|0,14571)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break e}break b}b=P()|0;O()|0;break f}b=P()|0;O()|0;vb(c+16|0)}vb(d);break a}v[22640]=0;b=fa(185)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}if(!b){break d}v[22640]=0;Q(191,a|0,13910)|0;b=v[22640];v[22640]=0;if((b|0)==1){break b}}gb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0}vb(a);S(b|0);L()}function aia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-48|0;gb=e;j=v[a+16>>2];f=Sd(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=eg(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=gg(a+8|0,b),v[n>>2]=o;v[f+4>>2]=jb}k=v[a+24>>2];l=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=h;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;if(d){while(1){i=0;v[e+40>>2]=g;v[e+44>>2]=m;h=h+j|0;a:{if((b|0)<=0){break a}while(1){Id(v[f+8>>2],t[h+i|0]<<6);Hd(v[f+8>>2],4);Ub(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Ub(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Id(b,t[h+v[e+44>>2]|0]<<6);Hd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=dg(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(e+8|0,e);if(d){c=c+8|0;b=v[f+16>>2];g=v[e+8>>2];h=v[e+12>>2];continue}break}g=v[e+8>>2];h=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=h;gb=e+48|0}function rL(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){v[22640]=0;b=c;T(1299,b|0)|0;a=v[22640];v[22640]=0;a:{if((a|0)!=1){c=v[b+4>>2];if(c){a=c;tk(a);if(v[a>>2]){f=a;g=v[a>>2];d=v[a+4>>2];b:{while(1){if((d|0)==(g|0)){break b}e=wb(f);v[22640]=0;d=d-4|0;R(1333,e|0,d|0);e=v[22640];v[22640]=0;if((e|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[f+4>>2]=g;Wh(wb(a),v[a>>2],ye(a))}Zb(c)}v[b+4>>2]=0;aA(b+1298368|0);du(b+1298304|0);vb(b+1298292|0);vb(b+1298280|0);vb(b+1298268|0);cu(b+1298264|0);bu(b+1298260|0);Jq(b+1298224|0);a=b+946300|0;c=b+906300|0;while(1){a=Hq(a-160|0);if((c|0)!=(a|0)){continue}break}zu(b+484360|0);_z(b+484344|0);Lc(b+480248|0);break a}V(0)|0;O()|0;aA(b+1298368|0);du(b+1298304|0);vb(b+1298292|0);vb(b+1298280|0);vb(b+1298268|0);cu(b+1298264|0);bu(b+1298260|0);Jq(b+1298224|0);a=b+946300|0;c=b+906300|0;while(1){a=Hq(a-160|0);if((c|0)!=(a|0)){continue}break}zu(b+484360|0);_z(b+484344|0);Lc(b+480248|0);Bb();L()}Zb(b)}}}function oia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=gb-32|0;gb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];i=v[a+4>>2];e=i;g=v[a>>2];v[f+24>>2]=g;v[f+28>>2]=e;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;i=a;if(d){while(1){h=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;a=(((g>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];t=u[a+24>>1];g=0;a=1;while(1){e=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[(e|8)+h>>1],o)+B(u[(e|4)+h>>1],p)|0)+B(u[(e|12)+h>>1],n)|0)+B(u[(e|16)+h>>1],m)|0)/2|0)+((((B(u[(e|-8)+h>>1],s)+B(u[(e|-12)+h>>1],t)|0)+B(u[(e|-4)+h>>1],r)|0)+B(u[e+h>>1],q)|0)/2|0)|0)/16384;e=a;a=0;g=1;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;g=v[f+24>>2];e=v[f+28>>2];continue}break}g=v[f+24>>2];e=v[f+28>>2]}v[i>>2]=g;v[i+4>>2]=e;gb=f+32|0}function lu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-16|0;gb=e;g=a+1074312|0;Db(e+8|0,g,77);a:{if(j=Cb(e+8|0),k=0,l=v[c+88>>2]&134218752,l?j:k){break a}b:{c:{i=c;if(d){f=w[c+841|0];if(!f){break c}d=f-1|0;t[c+841|0]=d;if(d&255){break b}Db(e+8|0,g,16);if(!(j=Cb(e+8|0),k=1,l=v[a+480180>>2]!=2,l?j:k)){break a}a=v[b+48>>2]+1|0}else{a=v[b+48>>2]}v[i+764>>2]=a;break a}Db(e+8|0,g,17);if(!(Cb(e+8|0)|v[a+480180>>2]&3|!x[a+480188>>1])){f=b+616|0;while(1){if(w[f+841|0]?(c|0)!=(f|0):0){break a}f=f+872|0;h=h+1|0;if(x[a+480188>>1]>(h&65535)>>>0){continue}break}}t[c+841|0]=d}d=v[c+764>>2];v[b+56>>2]=d;d:{if((d|0)==-1){break d}e:{if(v[b+60>>2]==-1){break e}Db(e+8|0,g,68);if(!Cb(e+8|0)){break e}v[b+60>>2]=d}v[b+64>>2]=d;Db(e+8|0,g,103);if(!Cb(e+8|0)){break d}u[b+68>>1]=65535}if(!x[a+480188>>1]|v[a+480180>>2]!=2){break a}d=0;while(1){f=B(d,872)+b|0;v[f+1380>>2]=v[c+764>>2];t[f+1457|0]=w[c+841|0];d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}gb=e+16|0}function dja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(!d){g=b;b=f;break a}while(1){g=e+o|0;p=t[g+1|0];g=t[g|0];e=v[a+60>>2];q=e;r=e>>31;e=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=mqa(j,j>>31,e,e>>31);j=jb;k=e;e=v[a+68>>2];l=mqa(e,e>>31,f,f>>31);e=k+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;k=e;e=((B(p-g|0,i>>>10&4194048)|0)/16384|0)+(g<<8)<<8;i=mqa(q,r,e,e>>31);g=k+i|0;f=jb+f|0;f=g>>>0<i>>>0?f+1|0:f;g=g+8388608|0;if(g>>>0<8388608){f=f+1|0}f=Ic(g,f,24);g=v[a+72>>2];i=(f|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);v[c+4>>2]=v[c+4>>2]+B(i,m);g=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=b;b=g;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=g;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function OS(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0;f=gb-16|0;gb=f;if(Hj(a)){e=w[(ve(w[a+797|0])?a+797|0:a+799|0)|0];Db(f+8|0,d+1074312|0,34);a:{if(!Cb(f+8|0)){break a}d=e;if(e){if(d>>>0>120){break a}e=w[lc(v[a+656>>2]+108|0,d-1|0)|0];break a}e=0}d=a;k=C(C(v[a+704>>2]<<4)*b);e=(c+e<<16)-3997696>>16;c=v[v[a+656>>2]+44>>2];i=v[c+36>>2];a=v[a+852>>2]+u[a+772>>1]|0;b:{if(!(a?i:0)){b=Fm(c,a+e<<16>>16);break b}j=i+1|0;l=Xy(a,j);g=qo(a,j);a=u[c+28>>1];h=c+4|0;Nb(h);b=C(1);e=e+l<<16>>16;c:{if((e|0)<(a|0)){break c}if((e|0)>(x[c+28>>1]+Nb(h)<<16)-65536>>16){break c}if(!g){b=z[Mb(h,e-u[c+28>>1]|0)>>2];break b}a=x[c>>1];d:{if((a|0)==3){a=c+16|0;if(Nb(a)){b=z[Mb(a,g-1|0)>>2];break d}a=x[c>>1]}e:{if((a&65535)!=1){break e}a=c+16|0;if(!Nb(a)){break e}b=z[Mb(a,(B(i,qo(e,x[c+30>>1])<<16>>16)+g|0)-1|0)>>2];break d}b=me(C(Fm(c,(e<<16)+65536>>16)/Fm(c,e)),C(C(g|0)/C(j|0)))}b=C(z[Mb(h,e-u[c+28>>1]|0)>>2]*b)}}m=d,n=Gj(C(k*b)),v[m+700>>2]=n}gb=f+16|0}function Gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{c:{h=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?h>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?h>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?h>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=(b<<1)+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+4>>1],u[e+10>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;gb=f+16|0}function cja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=gb-16|0;gb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(!d){g=b;b=f;break a}while(1){g=(e<<1)+o|0;p=u[g+2>>1];g=u[g>>1];e=v[a+60>>2];q=e;r=e>>31;e=Lb(b,-16777216,16776704);j=v[a+64>>2];f=Lb(f,-16777216,16776704);e=mqa(j,j>>31,e,e>>31);j=jb;k=e;e=v[a+68>>2];l=mqa(e,e>>31,f,f>>31);e=k+l|0;f=jb+j|0;f=e>>>0<l>>>0?f+1|0:f;k=e;e=g+((B(p-g|0,i>>>18|0)|0)/16384|0)<<8;i=mqa(q,r,e,e>>31);g=k+i|0;f=jb+f|0;f=g>>>0<i>>>0?f+1|0:f;g=g+8388608|0;if(g>>>0<8388608){f=f+1|0}f=Ic(g,f,24);g=v[a+72>>2];i=(f|0)/256|0;v[c>>2]=v[c>>2]+B(i,n);v[c+4>>2]=v[c+4>>2]+B(i,m);g=f-(e&g)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=b;b=g;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=g;v[a>>2]=i;v[a+4>>2]=e;gb=h+16|0}function Py(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);b=gb+-64|0;gb=b;d=v[a+20>>2];a:{if(!d){break a}if(pc(d+4|0)>>>0<4){break a}be(b+32|0,v[a+20>>2]+4|0);d=Sd(b+24|0);c=v[b+36>>2];v[b+16>>2]=v[b+32>>2];v[b+20>>2]=c;c=v[d+4>>2];v[b+8>>2]=v[d>>2];v[b+12>>2]=c;d=gm(b+40|0,b+16|0,b+8|0);v[22640]=0;c=T(229,d|0)|0;f=v[22640];v[22640]=0;b:{if((f|0)!=1){if(c){break b}c=v[v[a>>2]+40>>2];v[22640]=0;c=T(c|0,a|0)|0;f=v[22640];v[22640]=0;c:{if((f|0)==1){break c}if(pc(v[a+20>>2]+4|0)-4>>>0<c<<2>>>0){break b}e=v[v[a>>2]+172>>2];f=0;v[22640]=0;R(e|0,a|0,-1);e=v[22640];v[22640]=0;if((e|0)==1){break c}if(c){while(1){v[22640]=0;g=C(Ba(655,d|0));e=v[22640];v[22640]=0;if((e|0)==1){break c}e=v[v[a>>2]+44>>2];v[22640]=0;Aa(e|0,a|0,f|0,C(g));e=v[22640];v[22640]=0;if((e|0)==1){break c}f=f+1|0;if((c|0)!=(f|0)){continue}break}}c=v[v[a>>2]+176>>2];v[22640]=0;_(c|0,a|0);a=v[22640];v[22640]=0;if((a|0)!=1){break b}}}a=P()|0;O()|0;yb(d);S(a|0);L()}yb(d)}gb=b- -64|0}function Mf(a){a=a|0;var b=0;a:{b:{switch(w[a+3|0]){case 0:if(!w[a+5|0]){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 14:t[a+3|0]=19;return;case 15:if(w[a+5|0]<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=37;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function hx(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=gb-16|0;gb=m;v[m+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Ab(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Ab(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=gx(l,l+128|0,m+12|0)-l|0;if((f|0)>124){break a}g=w[(f>>2)+83184|0];d:{e:{switch(qqa(f-88|0,30)|0){case 2:case 3:b=v[e>>2];if((w[b-1|0]&95)!=(w[c|0]&127)?(b|0)!=(d|0):0){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:case 1:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Ab(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>84){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}gb=m+16|0;return a}function Zf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-80|0;gb=c;d=v[a+28>>2];sp(v[v[d>>2]-12>>2]+d|0,0);if(!id(a,4)){nx(a)}a:{if(!v[a+4>>2]){break a}if(id(a,6)){break a}if(id(a,7)){break a}g=v[a+28>>2];e=v[a+84>>2];h=B(v[a+20>>2],v[a+4>>2]);f=h+v[a+80>>2]|0;e=Bh(c- -64|0,f,f>>>0<h>>>0?e+1|0:e);f=v[e+12>>2];v[c+24>>2]=v[e+8>>2];v[c+28>>2]=f;d=v[e+4>>2];v[c+16>>2]=v[e>>2];v[c+20>>2]=d;gk(g,c+16|0)}d=0;b:{if(!id(a,5)){break b}g=0;e=a+44|0;h=qf(e);d=0;if(!h){break b}d=a+32|0;while(1){c:{f=(v[a+96>>2]+g>>>0)%(h>>>0)|0;if(y[Qc(e,f)>>2]>=pc(d)>>>0){break c}i=Xn(c+48|0,kc(d,v[Qc(e,f)>>2]),x[Qc(e,f)+12>>1]);j=xx(b,i);Hb(i);if(!j){break c}v[a+96>>2]=(f+1>>>0)%(h>>>0);b=v[Qc(e,f)+4>>2];if(b){h=v[a+28>>2];g=b+v[a+8>>2]|0;a=v[a+12>>2];a=Bh(c+32|0,g,b>>>0>g>>>0?a+1|0:a);b=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=b;b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;gk(h,c)}d=Qc(e,f);break b}g=g+1|0;if((h|0)!=(g|0)){continue}break}d=0}gb=c+80|0;return d}function kJ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=v[a+32>>2];a:{b:{c:{b=v[a+1380>>2];d:{if((b|0)==-1){h=1;b=-1;break d}d=v[a+1116>>2];e:{if((d|0)<=(b|0)){break e}while(1){e=w[(a+b|0)+1120|0];c=e+c|0;if((e|0)!=255){break e}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}if(y[a+40>>2]<c>>>0){break c}b=(b|0)==(d|0)?-1:b}while(1){if((b|0)!=-1){return 1}g=v[a+40>>2];if(g>>>0<=c+26>>>0){dc(a,1);break a}if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(w[89848]|w[89849]<<8|(w[89850]<<16|w[89851]<<24))){dc(a,21);break a}if(w[c+4|0]){dc(a,21);break a}f:{if(h){if(!v[a+992>>2]|!(t[c+5|0]&1)){break f}dc(a,21);break a}if(t[c+5|0]&1){break f}dc(a,21);break a}d=c+27|0;e=w[c+26|0];c=d+e|0;if(g>>>0<c>>>0){break b}h=0;b=0;f=0;g:{if(!e){break g}while(1){i=w[b+d|0];c=i+c|0;f=b;if((i|0)!=255){break g}b=b+1|0;if((e|0)!=(b|0)){continue}break}f=e}d=f;b=(d|0)==(e|0)?-1:d;if(c>>>0<=g>>>0){continue}break}dc(a,1);break a}dc(a,1);break a}dc(a,1)}return 0}function Hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{c:{h=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?h>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?h>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?h>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=b+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])|0)+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+2|0],u[e+10>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Ub(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;gb=f+16|0}function u8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-80|0;gb=e;v[e+72>>2]=c;c=ni(a,e+72|0);g=th(a+4|0);h=th(a+24|0);i=th(a+32|0);j=ad(a+36|0);v[a+56>>2]=3;k=nc(a+68|0);v[22640]=0;R(2079,a|0,d|0);f=v[22640];v[22640]=0;a:{b:{c:{d:{if((f|0)!=1){f=v[b>>2];l=v[b+4>>2];m=v[b+12>>2];v[e+40>>2]=v[b+8>>2];v[e+44>>2]=m;v[e+32>>2]=f;v[e+36>>2]=l;b=Sd(e+24|0);f=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=f;v[22640]=0;f=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;U(2073,e+48|0,e+8|0,e|0);b=v[22640];v[22640]=0;if((b|0)==1){break d}v[22640]=0;U(2080,a|0,e+48|0,d|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}yb(e+48|0);v[22640]=0;_(2081,a|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}bg(e+72|0);gb=e+80|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(e+48|0);break a}a=P()|0;O()|0}vd(k);Uf(j);iq(i);Bi(h);Ai(g);bg(c);bg(e+72|0);S(a|0);L()}function bK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb+-64|0;gb=d;e=v[a>>2];f=v[e>>2];c=v[f+4>>2];v[d+40>>2]=v[f+20>>2];a=v[f+16>>2];v[d+32>>2]=v[f+12>>2];v[d+36>>2]=a;Hf(d+48|0,d+32|0,c);c=v[e+4>>2];h=v[c+4>>2];i=v[c+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[c+8>>2];a=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=a;k=d+16|0;a=d;a:{if(h>>>0<=y[d+4>>2]){if(h>>>0<=y[k+4>>2]){if(i>>>0<=y[a+8>>2]){if(Gf(k)>>>0>=i>>>0){if(i){f=b+12|0;while(1){g=0;if(h){while(1){e=Ug(a,g,j);c=Mb(b,g);l=c;c=v[e>>2]+(v[c>>2]>>1)|0;e=c;c=st(f)+c&-4096;v[l>>2]=e-c;c=ed(c|2048,12);if((c|0)<-32768){c=-32768}if((c|0)>32767){c=32767}m=go(k,g,j),n=c,u[m>>1]=n;g=g+1|0;if((h|0)!=(g|0)){continue}break}}j=j+1|0;if((i|0)!=(j|0)){continue}break}}break a}ba(2959,6225,36,5969);L()}ba(2989,6225,35,5969);L()}ba(4217,6225,34,5969);L()}ba(4252,6225,33,5969);L()}gb=d- -64|0}function VJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb+-64|0;gb=d;e=v[a>>2];f=v[e>>2];c=v[f+4>>2];v[d+40>>2]=v[f+20>>2];a=v[f+16>>2];v[d+32>>2]=v[f+12>>2];v[d+36>>2]=a;Hf(d+48|0,d+32|0,c);c=v[e+4>>2];h=v[c+4>>2];i=v[c+8>>2];a=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=a;a=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=a;v[d+8>>2]=v[c+8>>2];a=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=a;k=d+16|0;a=d;a:{if(h>>>0<=y[d+4>>2]){if(h>>>0<=y[k+4>>2]){if(i>>>0<=y[a+8>>2]){if(Gf(k)>>>0>=i>>>0){if(i){f=b+12|0;while(1){g=0;if(h){while(1){e=Ug(a,g,j);c=Mb(b,g);l=c;c=v[e>>2]+(v[c>>2]>>1)|0;e=c;c=st(f)+c&-4096;v[l>>2]=e-c;c=ed(c|2048,12);if((c|0)<-32768){c=-32768}if((c|0)>32767){c=32767}m=fo(k,g,j),n=c,u[m>>1]=n;g=g+1|0;if((h|0)!=(g|0)){continue}break}}j=j+1|0;if((i|0)!=(j|0)){continue}break}}break a}ba(2959,6225,36,5969);L()}ba(2989,6225,35,5969);L()}ba(4217,6225,34,5969);L()}ba(4252,6225,33,5969);L()}gb=d- -64|0}function pia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=gb-32|0;gb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];h=v[a+4>>2];i=h;e=v[a>>2];v[f+24>>2]=e;v[f+28>>2]=h;h=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=h;h=a;if(d){while(1){g=(((i&2147483647)<<1|e>>>31)&-2)+l|0;a=(((e>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];w=u[a+24>>1];e=0;a=1;while(1){v[(f+8|0)+(e<<2)>>2]=(((((B(t[(e|4)+g|0],o)+B(t[(e|2)+g|0],p)|0)+B(t[(e|6)+g|0],n)|0)+B(t[(e|8)+g|0],m)<<8)/2|0)+((((B(t[(e|-4)+g|0],s)+B(t[(e|-6)+g|0],w)|0)+B(t[(e|-2)+g|0],r)|0)+B(t[e+g|0],q)<<8)/2|0)|0)/16384;i=a;a=0;e=1;if(i){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Ub(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;e=v[f+24>>2];i=v[f+28>>2];continue}break}e=v[f+24>>2];i=v[f+28>>2]}v[h>>2]=e;v[h+4>>2]=i;gb=f+32|0}function kx(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=gb-16|0;gb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Ab(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Ab(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=Dm(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+83184|0];d:{e:{switch(f-22|0){case 2:case 3:b=v[e>>2];if((w[b-1|0]&95)!=(w[c|0]&127)?(b|0)!=(d|0):0){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:case 1:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Ab(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}gb=m+16|0;return a}function gga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[d+24>>2]=c>>>4;v[d+16>>2]=v[a>>2];h=v[Fb(d+24|0,d+16|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+24>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+28>>2]=f;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;e=A[$g(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=e;f=a;e=fe(e);a:{if(D(e)<2147483648){g=~~e;break a}g=-2147483648}i=f,j=Sc(g),u[i>>1]=j;f=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);v[d+24>>2]=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);v[d+28>>2]=f;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;e=A[$g(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=e;f=a;e=fe(e);b:{if(D(e)<2147483648){g=~~e;break b}g=-2147483648}i=f,j=Sc(g),u[i+2>>1]=j;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=d+32|0;return h<<4}function Kma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;i=8;t[e+15|0]=8;u[e+12>>1]=0;v[e+8>>2]=0;if(d){m=B(c,d);c=0;while(1){if((m|0)>=1){j=(l<<1)+b|0;p=j+(m<<1)|0;n=c;while(1){u[e+6>>1]=0;JV(a,e+14|0,e+12|0,e+15|0,e+6|0);a:{if(!i){h=x[e+6>>1];break a}h=x[e+6>>1];c=x[e+12>>1];f=i;while(1){b:{g=c<<1;c=g&254;u[e+12>>1]=c;if(c){k=(g&65534)>>>0>255}else{if(!kf(a,e+5|0)){break b}g=w[e+5|0];c=g<<1&254|1;u[e+12>>1]=c;k=g>>>7|0}h=k|h<<1;f=f-1|0;if(f&255){continue}}break}u[e+6>>1]=h}k=e;o=h&65535;if(o>>>0<=3){c=i+1|0}else{c=15;while(1){f=c;g=c&255;if(!(o>>>g&1)){c=f-1|0;if(g>>>0>1){continue}}break}c=f+i|0}i=c>>>1&127;t[k+15|0]=i;c=h&1;t[e+14|0]=c;f=c-1^(h&65534)>>>1;c=f+x[e+8>>1]|0;u[j>>1]=c;v[e+8>>2]=((f>>1)-(n<<16>>16)|0)+(c<<16>>16<<1);Qd(e+8|0,-32768,32767);n=c;j=(d<<1)+j|0;if(p>>>0>j>>>0){continue}break}}l=l+1|0;if((l|0)!=(d|0)){continue}break}}gb=e+16|0}function AI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-32|0;gb=h;f=d&2147483647;g=f;e=f-1065418752|0;i=f-1082064896|0;f=c;a:{if((e|0)==(i|0)&f>>>0<f>>>0|e>>>0<i>>>0){g=(d&33554431)<<7|c>>>25;f=0;j=f;i=c&33554431;if(!(!f&(i|0)==16777216?!(a|b):!f&i>>>0<16777216)){e=g+1073741825|0;break a}e=g+1073741824|0;if(i^16777216|a|(b|j)){break a}e=(g&1)+e|0;break a}if(!(!f&(g|0)==2147418112?!(a|b):g>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(g>>>0>1082064895){break a}e=0;f=g>>>16|0;if(f>>>0<16145){break a}g=c;e=d&65535|65536;If(h+16|0,a,b,g,e,f-16129|0);lm(h,a,b,g,e,16257-f|0);b=v[h+8>>2];e=(v[h+12>>2]&33554431)<<7|b>>>25;g=v[h+4>>2];f=g;a=0;i=a;j=v[h>>2]|((v[h+16>>2]|v[h+24>>2])!=0|(v[h+20>>2]|v[h+28>>2])!=0);b=b&33554431;if(!(!a&(b|0)==16777216?!(f|j):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|j|(f|i)){break a}e=(e&1)+e|0}gb=h+32|0;return l(2,d&-2147483648|e),q()}function KH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-32|0;gb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;b:{e=v[Nf(c+24|0,a+44|0)>>2];if((e|0)>=1){h=(e|0)>0?e:0;while(1){f=Ps(v[a+32>>2]);if((f|0)==-1){break b}t[(c+24|0)+d|0]=f;d=d+1|0;if((h|0)!=(d|0)){continue}break}}c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];f=v[d>>2];i=v[d+4>>2];e:{g=d;d=(c+24|0)+e|0;switch(YH(v[a+36>>2],g,c+24|0,d,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}g=v[a+40>>2];v[g>>2]=f;v[g+4>>2]=i;if((e|0)==8){break b}f=Ps(v[a+32>>2]);if((f|0)==-1){break b}t[d|0]=f;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((Os(Ig(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break b}}j=a,k=Ig(t[c+23|0]),v[j+48>>2]=k}d=Ig(t[c+23|0]);break a}d=-1}gb=c+32|0;return d}function _N(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=gb-16|0;gb=k;t[k+15|0]=c;t[k+14|0]=12;hh(b,w[ac(k+15|0,k+14|0)|0]);if(Nb(b)){c=0;l=a+96|0;a=a+144|0;while(1){a:{b:{c:{switch(h|0){case 0:i=c<<2;j=i+l|0;j=w[j|0]|w[j+1|0]<<8;n=Mb(b,c),o=j,u[n>>1]=o;i=(i|2)+l|0;break b;case 1:break c;default:break a}}i=c<<2;j=i+a|0;j=w[j|0]|w[j+1|0]<<8;n=Mb(b,c),o=j,u[n>>1]=o;i=a+(i|2)|0}i=w[i|0];n=Mb(b,c),o=i,t[n+2|0]=o}d:{if(!c){break d}i=c-1|0;if(x[Mb(b,c)>>1]>=x[Mb(b,i)>>1]){break d}if(x[Mb(b,c)>>1]>255){break d}j=w[Mb(b,i)+1|0];m=Mb(b,c);u[m>>1]=x[m>>1]|j<<8;if(x[Mb(b,c)>>1]>=x[Mb(b,i)>>1]){break d}i=Mb(b,c);u[i>>1]=x[i>>1]+256}c=c+1|0;if(Nb(b)>>>0>c>>>0){continue}break}}t[b+12|0]=0;e:{if(!(d&1)){break e}if($c(b)){break e}t[b+12|0]=w[b+12|0]|1}if(e>>>0<=11){if(d&2){t[b+12|0]=w[b+12|0]|4}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=w[b+12|0]|2}t[b+14|0]=g;t[b+13|0]=f}gb=k+16|0}function oO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;b=v[a>>2];yc(g+8|0,b);a:{b:{c:{d:{e=b+16|0;e:{if(Bd(e)){while(1){f:{d=v[e>>2];v[22640]=0;d=T(98,d|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break f}f=d|f;c=c+32|0;if(c>>>0<32){continue}break e}break}c=V(88856)|0;if((O()|0)!=(ea(88856)|0)){break c}Z(c|0)|0;t[b+20|0]=0;v[22640]=0;_(81,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break d}v[22640]=0;X(20);c=v[22640];v[22640]=0;if((c|0)!=1){break e}c=P()|0;O()|0;break c}t[b+20|0]=0}if(!w[b+20|0]){b=v[b+24>>2];c=v[b+2496>>2];e=(c<<2)+b|0;h=v[b+((c+397>>>0)%624<<2)>>2];d=(c+1>>>0)%624|0;c=v[b+(d<<2)>>2];c=h^(c&2147483647|v[e>>2]&-2147483648)>>>1^B(c&1,-1727483681);v[e>>2]=c;v[b+2496>>2]=d;b=c^c>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;f=f^(b>>>18^b)}gb=g+16|0;break a}c=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)==1){break b}}S(c|0);L()}V(0)|0;O()|0;Bb();L()}return v[a+28>>2]&f}function pT(a,b,c){var d=0;d=w[a|0]&15;t[a|0]=w[d+33760|0];a:{b:{c:{switch(d|0){case 0:if(c>>>0>50?w[b|0]:0){break b}t[a|0]=0;return;case 5:d=w[b|0];if(!((d&240)!=32?(d&15)!=2:0)){t[a|0]=20;t[b|0]=159;d=159}if((d&15)!=12&(d&240)!=192|c>>>0<51){break b}t[a|0]=25;t[b|0]=0;return;case 7:if(c>>>0>51){break b}t[a|0]=0;return;case 10:a=w[b|0]&240;if(!a){break b}t[b|0]=a;return;case 11:t[b|0]=B(w[b|0]&15,17);return;case 12:t[b|0]=w[b|0]>>>2;return;case 13:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);return;case 14:d:{switch((w[b|0]>>>4|0)-1|0){case 0:t[a|0]=2;break a;case 1:t[a|0]=3;break a;case 7:if(c>>>0<52){break b}t[a|0]=20;t[b|0]=w[b|0]&15|96;return;case 8:t[a|0]=15;t[b|0]=w[b|0]&15;return;case 9:t[a|0]=11;t[b|0]=w[b|0]<<4|15;return;case 10:t[a|0]=11;break a;case 11:case 12:break d;default:break b}}t[a|0]=20;return;case 15:break c;default:break b}}if(w[b|0]<48){break b}t[a|0]=17}return}t[b|0]=w[b|0]|240}function fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=C(0),r=C(0),s=C(0),t=0,u=0,x=0,y=0,A=0,B=C(0);f=gb-16|0;gb=f;a:{if(!v[a+4240>>2]){break a}g=a+44|0;if(!ki(g)){break a}s=z[a+4220>>2];y=f,A=Md(g,0),v[y+8>>2]=A;y=f,A=Md(g,1),v[y+12>>2]=A;y=f,A=kd(g,0),v[y>>2]=A;y=f,A=kd(g,1),v[y+4>>2]=A;if(d){m=a+4208|0;j=d;while(1){h=0;i=1;k=0;while(1){n=(w[a+4264|0]?1-k|0:h)&255;t=v[((n<<2)+a|0)+4248>>2];u=v[a+4240>>2];x=v[a+4244>>2];o=h<<2;p=o+(f+8|0)|0;e=v[p>>2];v[p>>2]=e+4;l=z[e>>2];e=x-t|0;q=z[Mb(m,n+((e>>31&u)+e<<1)|0)>>2];r=C(C(z[a+4224>>2]*q)+C(l*z[a+4260>>2]));y=Mb(m,v[a+4244>>2]<<1|h),B=C(D(r))<C(1.0000000195414814e-24)?C(0):r,z[y>>2]=B;h=f+o|0;e=v[h>>2];v[h>>2]=e+4;z[e>>2]=l+C(C(q-l)*s);k=k+1|0;e=i;i=0;h=1;if(e){continue}break}i=v[a+4244>>2]+1|0;v[a+4244>>2]=(i|0)==v[a+4240>>2]?0:i;j=j-1|0;if(j){continue}break}}Ci(a,b,c,kd(g,0),kd(g,1),d)}gb=f+16|0}function $0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;a=c;a:{if(!e|d>>>0<=a>>>0){break a}while(1){i=d;f=t[a|0];b=a+1|0;b:{if((f|0)>=0){break b}b=f&255;if(b>>>0<194){break a}if(b>>>0<=223){if((w[a+1|0]&192)!=128|(d-a|0)<2){break a}b=a+2|0;break b}if(b>>>0<=239){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];c:{d:{if((b|0)!=237){if((b|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)==128){break c}break a}if((f&192)!=128){break a}}if((h&192)!=128){break a}b=a+3|0;break b}if((d-a|0)<4|b>>>0>244|e-g>>>0<2){break a}h=w[a+3|0];j=w[a+2|0];f=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((j&192)!=128|(h&192)!=128|(b<<18&1835008|(f&48)<<12)>>>0>1114111){break a}g=g+1|0;b=a+4|0}a=b;if(i>>>0<=a>>>0){break a}g=g+1|0;if(g>>>0<e>>>0){continue}break}}return a-c|0}function Ida(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=0,x=C(0);if(v[a+4220>>2]){f=a+44|0;i=Md(f,0);j=Md(f,1);k=kd(f,0);l=kd(f,1);if(d){h=a+4208|0;e=v[a+4224>>2];m=d;while(1){n=z[j>>2];o=z[i>>2];e=e-v[a+4228>>2]|0;e=(v[a+4220>>2]&e>>31)+e<<1;p=z[Mb(h,e)>>2];e=Mb(h,e|1);r=z[a+4248>>2];s=z[a+4256>>2];t=z[a+4252>>2];u=z[a+4244>>2];q=z[e>>2];g=C(C(C(C(n*r)+C(o*s))+C(p*t))+C(u*q));w=Mb(h,v[a+4224>>2]<<1),x=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[w>>2]=x;g=C(C(C(C(r*o)+C(s*n))+C(t*q))+C(u*p));w=Mb(h,v[a+4224>>2]<<1|1),x=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[w>>2]=x;e=v[a+4224>>2]+1|0;e=(e|0)==v[a+4220>>2]?0:e;v[a+4224>>2]=e;z[k>>2]=C(p*z[a+4236>>2])+C(o*z[a+4240>>2]);z[l>>2]=C(q*z[a+4236>>2])+C(n*z[a+4240>>2]);l=l+4|0;k=k+4|0;j=j+4|0;i=i+4|0;m=m-1|0;if(m){continue}break}}Ci(a,b,c,kd(f,0),kd(f,1),d)}}function ofa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;f=Kb(d+16|0);a:{b:{c:{if(c>>>0<=63){break c}v[22640]=0;c=T(1425,b|0)|0;e=v[22640];v[22640]=0;d:{if((e|0)!=1){v[d+12>>2]=c;if((c|0)>0){break d}v[22640]=0;Q(112,a|0,18693)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break b}}break a}v[22640]=0;c=T(492,b|0)|0;e=v[22640];v[22640]=0;e:{if((e|0)==1){break e}c=Si(c);v[22640]=0;v[d+8>>2]=c;c=ld(d+12|0,d+8|0);e=v[22640];v[22640]=0;if((e|0)==1){break e}c=v[c>>2];v[22640]=0;R(102,f|0,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){break c}}break a}f:{while(1){g:{v[22640]=0;c=T(353,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break g}if(!c){break f}v[22640]=0;W(1426,f|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}}break}break a}v[22640]=0;Q(350,b|0,4)|0;b=v[22640];v[22640]=0;if((b|0)==1){break a}Dc(a,f)}vb(f);gb=d+32|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function Qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];f=b;g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;b=g>>>21&2040;g=u[b+46534>>1];m=u[b+46532>>1];n=u[b+46530>>1];o=u[b+46528>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+k>>1],n)+B(u[(f|-4)+k>>1],o)|0)+B(u[(f|4)+k>>1],m)|0)+B(u[(f|8)+k>>1],g)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;v[c>>2]=v[c>>2]+B(h,v[e+8>>2]);i=b+i|0;b=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];f=v[e+28>>2];continue}break}g=v[e+24>>2];f=v[e+28>>2];break a}b=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=f;gb=e+32|0}function K1(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=Nb(465584);if(b>>>0<a>>>0){g=gb-32|0;gb=g;e=a-b|0;a:{if(e>>>0<=v[116400]-v[116397]>>2>>>0){TG(e);break a}f=Yw(465584);b=g+8|0;d=Nb(465584)+e|0;c=gb-16|0;gb=c;v[c+12>>2]=d;b:{a=kp();if(d>>>0<=a>>>0){d=BG(465584);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;break b}Rc();L()}h=Nb(465584);c=0;d=gb-16|0;gb=d;v[d+12>>2]=0;ef(b+12|0,f);if(a){c=CG(v[b+16>>2],a)}v[b>>2]=c;f=(h<<2)+c|0;v[b+8>>2]=f;v[b+4>>2]=f;i=cc(b),j=(a<<2)+c|0,v[i>>2]=j;gb=d+16|0;d=gb-16|0;gb=d;a=Pk(d,b+8|0,e);c=v[a>>2];if((c|0)!=v[a+4>>2]){while(1){Vo(c);c=v[a>>2]+4|0;v[a>>2]=c;if(v[a+4>>2]!=(c|0)){continue}break}}Yc(a);gb=d+16|0;a=b+4|0;cl(v[116396],v[116397],a);wc(465584,a);wc(465588,b+8|0);wc(465600,cc(b));v[b>>2]=v[b+4>>2];a=b;dC(a);b=v[a>>2];if(b){AG(v[a+16>>2],b,pk(a))}}gb=g+32|0;return}if(a>>>0<b>>>0){ee(465584,v[116396]+(a<<2)|0)}}function MS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;d=WA(a+48|0);e=WA(a+68|0);f=WA(a+88|0);v[22640]=0;Yq(a+492|0);c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}v[22640]=0;Yq(a+524|0);c=v[22640];v[22640]=0;if((c|0)==1){break a}v[22640]=0;fm(a,0,0);c=v[22640];v[22640]=0;if((c|0)==1){break a}v[22640]=0;em(a,0,0);c=v[22640];v[22640]=0;if((c|0)==1){break a}v[a+40>>2]=0;v[a+44>>2]=0;v[22640]=0;pr(a,b);b=v[22640];v[22640]=0;if((b|0)==1){break a}d=a+108|0;b=0;while(1){c=lc(d,b);b=b+1|0;t[c|0]=b;if(b>>>0<128){continue}break}return a|0}a=P()|0;O()|0;$o(f);$o(e);$o(d);S(a|0);L()}function jka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=Ae(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>5>>>0){f=gb-16|0;gb=f;d=pB(f,e,i);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){IB(e);e=e+32|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}$b(d);gb=f+16|0;break d}j=wb(e);f=$q(e,Ae(e)+i|0);m=Ae(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;ef(d+12|0,j);if(f){h=f;if(f>>>0>=134217728){nd(8513);L()}h=Mc(h<<5,1)}v[d>>2]=h;j=(m<<5)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=cc(d),o=(f<<5)+h|0,v[n>>2]=o;gb=l+16|0;v[22640]=0;DT(d,i);f=v[22640];v[22640]=0;if((f|0)==1){break c}Uk(e,d);CT(d)}gb=k+32|0;break b}a=P()|0;O()|0;CT(d);S(a|0);L()}break a}if(d>>>0<f>>>0){Vk(e,v[e>>2]+(d<<5)|0)}}if(Pb(a,c<<5)){bc(g+24|0,v[b>>2],Ae(b)<<5);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0}function hka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=qf(e);d=c;a:{if(f>>>0<d>>>0){k=gb-32|0;gb=k;b:{c:{i=d-f|0;d:{if(i>>>0<=v[wb(e)>>2]-v[e+4>>2]>>4>>>0){f=gb-16|0;gb=f;d=Zp(f,e,i);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){xv(e);e=e+16|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}$b(d);gb=f+16|0;break d}j=wb(e);f=fx(e,qf(e)+i|0);m=qf(e);l=gb-16|0;gb=l;v[l+12>>2]=0;d=k+8|0;ef(d+12|0,j);if(f){h=f;if(f>>>0>=268435456){nd(8513);L()}h=Mc(h<<4,1)}v[d>>2]=h;j=(m<<4)+h|0;v[d+8>>2]=j;v[d+4>>2]=j;n=cc(d),o=(f<<4)+h|0,v[n>>2]=o;gb=l+16|0;v[22640]=0;zT(d,i);f=v[22640];v[22640]=0;if((f|0)==1){break c}Uk(e,d);yT(d)}gb=k+32|0;break b}a=P()|0;O()|0;yT(d);S(a|0);L()}break a}if(d>>>0<f>>>0){Vk(e,v[e>>2]+(d<<4)|0)}}if(Pb(a,c<<4)){bc(g+24|0,v[b>>2],qf(b)<<4);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0}function Fea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb+-64|0;gb=e;g=ro(a);a:{b:{if(b-1>>>0>1023){break b}f=v[a+12>>2];if((f|0)==(b|0)){break b}if(c){c=v[g+8>>2];if(y[c+40>>2]<b>>>0|y[c+36>>2]>b>>>0){break b}f=v[a+12>>2]}f=B(Hi(a),b>>>0>f>>>0?b-f|0:f-b|0);c:{if(y[a+12>>2]<b>>>0){c=e;d:{if(d){d=Wb(a);break d}d=Sb(a)}v[c+48>>2]=d;c=Fd(e+56|0,e+48|0);gi(e+40|0);c=v[c>>2];v[22640]=0;Y(1479,a|0,c|0,f|0,e+40|0);c=v[22640];v[22640]=0;if((c|0)!=1){break c}a=V(88880)|0;if((O()|0)!=(ea(88880)|0)){break a}Z(a|0)|0;$();break b}if(d){i=e,j=Wb(a),v[i+48>>2]=j;i=e,j=MC(e+48|0,f),v[i+40>>2]=j;c=Fd(e+32|0,e+40|0);i=e,j=Wb(a),v[i+16>>2]=j;d=Fd(e+24|0,e+16|0);ON(a,v[c>>2],v[d>>2]);break c}i=e,j=Sb(a),v[i+40>>2]=j;c=Fd(e+8|0,e+40|0);i=e,j=Sb(a),v[i+16>>2]=j;i=e,j=yX(e+16|0,f),v[i+48>>2]=j;d=Fd(e,e+48|0);ON(a,v[c>>2],v[d>>2])}v[a+12>>2]=b;h=1}gb=e- -64|0;return h|0}S(a|0);L()}function z5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[rj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22640]=0;Ec(c+16|0,a+d|0);d=v[22640];v[22640]=0;d:{e:{f:{g:{h:{if((d|0)!=1){v[22640]=0;d=T(2280,c+16|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break h}e=_i(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22640]=0;ka(2283,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0);d=v[22640];v[22640]=0;if((d|0)==1){break h}Vb(c+16|0);break f}b=V(0)|0;O()|0;break g}b=V(0)|0;O()|0;Vb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;qj(v[v[a>>2]-12>>2]+a|0,b);if(!(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1)){break e}v[22640]=0;X(2027);a=v[22640];v[22640]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){break c}S(a|0);L()}d=v[c+20>>2];v[b>>2]=d;break d}$()}fh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function Zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Fb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Wf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;d=a;f=re(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=d,k=Sc(g),u[j>>1]=k;d=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Wf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;d=a;f=re(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=d,k=Sc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function HH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb-32|0;gb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;b:{e=v[Nf(c+24|0,a+44|0)>>2];if((e|0)>=1){h=(e|0)>0?e:0;while(1){f=Ps(v[a+32>>2]);if((f|0)==-1){break b}t[(c+24|0)+d|0]=f;d=d+1|0;if((h|0)!=(d|0)){continue}break}}c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];f=v[d>>2];i=v[d+4>>2];e:{g=d;d=(c+24|0)+e|0;switch(YH(v[a+36>>2],g,c+24|0,d,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}g=v[a+40>>2];v[g>>2]=f;v[g+4>>2]=i;if((e|0)==8){break b}f=Ps(v[a+32>>2]);if((f|0)==-1){break b}t[d|0]=f;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((Os(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break b}}v[a+48>>2]=v[c+20>>2]}d=v[c+20>>2];break a}d=-1}gb=c+32|0;return d}function Y0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;a=c;a:{if(!e|d>>>0<=a>>>0){break a}while(1){i=d;f=t[a|0];b=a+1|0;b:{if((f|0)>=0){break b}b=f&255;if(b>>>0<194){break a}if(b>>>0<=223){if((w[a+1|0]&192)!=128|(d-a|0)<2){break a}b=a+2|0;break b}if(b>>>0<=239){if((d-a|0)<3){break a}g=w[a+2|0];f=w[a+1|0];c:{d:{if((b|0)!=237){if((b|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)==128){break c}break a}if((f&192)!=128){break a}}if((g&192)!=128){break a}b=a+3|0;break b}if((d-a|0)<4|b>>>0>244){break a}g=w[a+3|0];j=w[a+2|0];f=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((j&192)!=128|(g&192)!=128|(b<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=a+4|0}a=b;if(i>>>0<=a>>>0){break a}h=h+1|0;if(h>>>0<e>>>0){continue}break}}return a-c|0}function Jma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;u[e+12>>1]=0;v[e+8>>2]=0;if(d){g=4;l=B(c,d);o=(l|0)<1;c=0;while(1){if(!o){j=b+k|0;p=l+j|0;m=c;while(1){t[e+7|0]=0;IV(a,e+15|0,e+12|0,e+7|0);a:{if(!g){h=w[e+7|0];break a}h=w[e+7|0];c=x[e+12>>1];f=g;b:{while(1){i=c<<1;c=i&254;c:{if(c){i=(i&65534)>>>0>255;break c}if(!kf(a,e+6|0)){break b}c=w[e+6|0];i=c>>>7|0;c=c<<1&254|1}h=h<<1|i;f=f-1|0;if(f&255){continue}break}t[e+7|0]=h;u[e+12>>1]=c;break a}t[e+7|0]=h;u[e+12>>1]=0}i=h&255;if(i>>>0<=3){g=g+1|0}else{c=7;while(1){f=c;n=c&255;if(!(i>>>n&1)){c=f-1|0;if(n>>>0>1){continue}}break}g=g+f|0}c=h&1;t[e+15|0]=c;f=c-1^(h&254)>>>1;c=f+w[e+8|0]|0;t[j|0]=c;v[e+8>>2]=((f>>1)-(m<<24>>24)|0)+(c<<24>>24<<1);Qd(e+8|0,-128,127);g=(g&254)>>>1|0;m=c;j=d+j|0;if(p>>>0>j>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function z9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22640]=0;_(2007,a|0);e=v[22640];v[22640]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[22640]=0;_(1960,b|0);e=v[22640];v[22640]=0;if((e|0)==1){break e}e=0;v[22640]=0;_(2008,c|0);f=v[22640];v[22640]=0;if((f|0)==1){break e}a=Qb(c,0,d);if(!w[b|0]){break b}if(uj(b,4316)|(d|0)!=8){break d}v[a+4>>2]=2009;v[a>>2]=2010;break c}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,9570,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();return 0}if(uj(b,8581)|(d|0)!=64){break b}v[a+60>>2]=2011;v[a+56>>2]=2012;v[a+52>>2]=2013;v[a+48>>2]=2014;v[a+44>>2]=2015;v[a+40>>2]=2016;v[a+36>>2]=2017;v[a+32>>2]=2018;v[a+28>>2]=2019;v[a+24>>2]=2020;v[a+20>>2]=2021;v[a+16>>2]=2022;v[a+12>>2]=2023;v[a+8>>2]=2024;v[a+4>>2]=2025;v[a>>2]=2026}e=1}return e|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function cga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0;f=gb-32|0;gb=f;m=f,o=B(v[a>>2],bd(a)),v[m+4>>2]=o;tc(f+4|0,c>>>3|0);c=zb(b);g=A[e+8>>3];h=v[f+4>>2];a:{if(!h){break a}e=h;while(1){j=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&2147483647;l(0,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));l(1,j|0);g=G(+n(),g);c=c+8|0;e=e-1|0;if(e){continue}break}if(g==0){break a}k=1/g;c=v[a+20>>2];while(1){a=b;e=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);l(0,w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24));l(1,e|0);m=f,p=+n()*k,A[m+24>>3]=p;v[f+16>>2]=0;v[f+20>>2]=-1074790400;v[f+8>>2]=0;v[f+12>>2]=1072693248;i=A[$g(f+24|0,f+16|0,f+8|0)>>3]*32768;A[f+24>>3]=i;a=c;i=fe(i);b:{if(D(i)<2147483648){e=~~i;break b}e=-2147483648}m=a,o=Sc(e),u[m>>1]=o;b=b+8|0;c=c+2|0;h=h-1|0;if(h){continue}break}}if(d){A[d>>3]=g}gb=f+32|0;return v[f+4>>2]<<3}function vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-16|0;gb=g;v[g+12>>2]=1;a:{if($h(a)){n=g,o=Ae(a),v[n+8>>2]=o;f=v[a>>2];c=b;k=v[Fb(g+12|0,g+8|0)>>2];if(k){while(1){d=c;if((c|0)!=(f|0)){h=Sb(d);l=Wb(d);i=gb-16|0;gb=i;j=eD(h,l);e=f;b:{if(j>>>0<=Lg(e)>>>0){if(sc(e)>>>0<j>>>0){v[i+8>>2]=h;rS(i+8|0,sc(e));m=h;h=v[i+8>>2];Ti(m,h,v[e>>2]);zS(e,h,l,j-sc(e)|0);break b}zn(e,Ti(h,l,v[e>>2]));break b}yS(e);JB(e,Rk(e,j));zS(e,h,l,j)}gb=i+16|0;dk(f+12|0,d+12|0);u[f+28>>1]=x[d+28>>1]}f=f+32|0;k=k-1|0;if(k){continue}break}}d=v[g+12>>2];c=v[g+8>>2];if(d>>>0>c>>>0){TA(a,d-c|0,b);break a}tS(a,v[a>>2]+(d<<5)|0);break a}c=a;if(v[c>>2]){Ae(c);oS(c);mS(c);Tk(wb(c),v[c>>2],$h(c));n=wb(c),o=0,v[n>>2]=o;v[c>>2]=0;v[c+4>>2]=0}f=$q(a,1);if(BT()>>>0<f>>>0){Rc();L()}wb(c);d=lS(f);v[c>>2]=d;v[c+4>>2]=d;n=wb(c),o=d+(f<<5)|0,v[n>>2]=o;SA(c,0);TA(a,1,b)}gb=g+16|0}function Ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=(((g&2147483647)<<1|h>>>31)&-2)+l|0;b=h>>>21&2040;h=u[b+46534>>1];m=u[b+46532>>1];n=u[b+46530>>1];o=u[b+46528>>1];f=0;b=1;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+k|0],n)+B(t[(f|-2)+k|0],o)|0)+B(t[(f|2)+k|0],m)|0)+B(t[(f|4)+k|0],h)<<8)/16384;g=b;b=0;f=1;if(g){continue}break}g=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=g+i|0;f=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];g=v[e+28>>2];continue}break}h=v[e+24>>2];g=v[e+28>>2];break a}f=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=f;v[a>>2]=h;v[a+4>>2]=g;gb=e+32|0}function N8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-32|0;gb=c;i=c,j=tL(),v[i+24>>2]=j;rL(a+24|0,$d(c+24|0));Bi(c+24|0);u[a+28>>1]=0;f=AS();v[c+16>>2]=4;d=c;g=gb-16|0;gb=g;e=rf(144);h=v[c+16>>2];v[22640]=0;f=W(2052,e|0,f|0,h|0)|0;h=v[22640];v[22640]=0;a:{if((h|0)!=1){e=v[Ni(g+8|0,f)>>2];gb=g+16|0;break a}a=P()|0;O()|0;Zb(e);S(a|0);L()}v[d+24>>2]=e;qL(a+32|0,$d(c+24|0));iq(c+24|0);i=c,j=sL(v[a>>2]),v[i+24>>2]=j;pL(a+4|0,$d(c+24|0));Ai(c+24|0);lo(v[a+24>>2],v[a+4>>2]);v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;t[a- -64|0]=0;i=c,j=or(b),v[i+24>>2]=j;i=c,j=zh(b),v[i+16>>2]=j;b:{if(kg(c+24|0,c+16|0)){while(1){d=ue(c+24|0);b=cg(c,d);v[22640]=0;Y(2e3,a|0,b|0,d+12|0,0);d=v[22640];v[22640]=0;if((d|0)==1){break b}vb(b);Oj(c+24|0);if(kg(c+24|0,c+16|0)){continue}break}}gb=c+32|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function zU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=gb-48|0;gb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+44>>2]=0;wb(b);cf(a+8|0,c+44|0,c+40|0);if(v[b+4>>2]){Tr(a,v[b+4>>2]);yk(c+32|0,b);Rl(c+24|0,b);b=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=b;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;b=gb-80|0;gb=b;i=a;f=v[a+4>>2];d=v[c+20>>2];k=d;g=v[c+16>>2];v[b+72>>2]=g;v[b+76>>2]=d;e=v[c+12>>2];l=e;h=v[c+8>>2];v[b+64>>2]=h;v[b+68>>2]=e;v[b+24>>2]=g;v[b+28>>2]=d;v[b+16>>2]=h;v[b+20>>2]=e;d=yU(b+24|0,b+16|0)+v[a+4>>2]|0;v[a+4>>2]=d;a:{b:{if(!f){e=d-1|0;break b}e=d-1|0;if((e^f-1)>>>0<32){break a}}j=v[i>>2];v[(d>>>0<33?j:(e>>>3&536870908)+j|0)>>2]=0}v[b+48>>2]=h;v[b+52>>2]=l;v[b+56>>2]=g;v[b+60>>2]=k;yp(b+40|0,i,f);d=v[b+60>>2];v[b+8>>2]=v[b+56>>2];v[b+12>>2]=d;d=v[b+52>>2];v[b>>2]=v[b+48>>2];v[b+4>>2]=d;TU(b+32|0,b+8|0,b,b+40|0);gb=b+80|0}gb=c+48|0;return a|0}function boa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;g=Zf(a,c);se(e+8|0,v[a+28>>2]);d=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=d;a:{if(!g){if(id(a,5)){break a}}d=gb-48|0;gb=d;h=v[a+28>>2];Xf(h,d+46|0);b:{c:{d:{e:{f:{if(x[d+46>>1]>=4001){j=v[b+12>>2];f=gb-16|0;gb=f;i=Tb(f,13068);Dc(d+16|0,i);vb(i);gb=f+16|0;v[22640]=0;U(1101,d+32|0,d+16|0,d+46|0);f=v[22640];v[22640]=0;if((f|0)==1){break f}v[22640]=0;U(580,j|0,2,d+32|0);f=v[22640];v[22640]=0;if((f|0)==1){break e}vb(d+32|0);Hb(d+16|0);u[d+46>>1]=4e3}yf(Nj(b,0),x[d+46>>1]);b=Nj(b,0);k=d,l=Sb(b),v[k+32>>2]=l;k=d,l=Wb(b),v[k+16>>2]=l;if(Gb(d+32|0,d+16|0)){break c}break b}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(d+32|0)}Hb(d+16|0);S(a|0);L()}while(1){b=v[d+32>>2];Xf(h,d+14|0);u[b>>1]=x[d+14>>1];mf(d+32|0);if(Gb(d+32|0,d+16|0)){continue}break}}gb=d+48|0}Sf(a,g,c,e+24|0);gb=e+32|0}function zm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;tl(a);a:{b:{c:{g=v[b+32>>2];d:{if(!g){d=v[b+2084>>2];if(d){break d}break b}f=v[b+4>>2];if((f|0)<9){break c}d=v[b+2084>>2];if(!d){break c}}h=v[a+1392>>2];j=ym(h);e=v[b+2092>>2];if((e|0)>=2){while(1){f=e>>>1|0;i=f+c|0;g=j>>>0<y[(i<<2)+d>>2];c=g?c:i;e=g?f:e-f|0;if((e|0)>1){continue}break}}e=a;d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;a=0;break e}v[a+1392>>2]=h>>>b;a=d-b|0}v[e+1396>>2]=a;return c}if(w[b+23|0]){break a}if((f|0)>=1){d=v[b+8>>2];while(1){f:{e=w[c+d|0];if((e|0)==255){break f}h=v[a+1392>>2];if(v[g+(c<<2)>>2]!=(h&(-1<<e^-1))){break f}d=v[a+1396>>2];if((d|0)>=(e|0)){v[a+1392>>2]=h>>>e;v[a+1396>>2]=d-w[v[b+8>>2]+c|0];return c}v[a+1396>>2]=0;break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}}dc(a,21);v[a+1396>>2]=0}return-1}ba(8718,10568,1690,2537);L()}function f7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb+-64|0;gb=c;e=v[a>>2];a=v[e>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;Hf(c+48|0,c+32|0,f);a=v[e+4>>2];e=v[a+4>>2];f=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;h=c+16|0;a=c;a:{if(y[c+4>>2]>=e>>>0){if(y[h+4>>2]>=e>>>0){if(y[a+8>>2]>=f>>>0){if(Gf(h)>>>0>=f>>>0){if(f){i=b+12|0;while(1){b=0;if(e){while(1){d=ed((v[Ug(a,b,g)>>2]+ed(rt(i),21)|0)+2048|0,12);if((d|0)<-32768){d=-32768}if((d|0)>32767){d=32767}j=go(h,b,g),k=d,u[j>>1]=k;b=b+1|0;if((b|0)!=(e|0)){continue}break}}g=g+1|0;if((g|0)!=(f|0)){continue}break}}break a}ba(2959,6225,36,5969);L()}ba(2989,6225,35,5969);L()}ba(4217,6225,34,5969);L()}ba(4252,6225,33,5969);L()}gb=c- -64|0}function X6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb+-64|0;gb=c;e=v[a>>2];a=v[e>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;Hf(c+48|0,c+32|0,f);a=v[e+4>>2];e=v[a+4>>2];f=v[a+8>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;h=c+16|0;a=c;a:{if(y[c+4>>2]>=e>>>0){if(y[h+4>>2]>=e>>>0){if(y[a+8>>2]>=f>>>0){if(Gf(h)>>>0>=f>>>0){if(f){i=b+12|0;while(1){b=0;if(e){while(1){d=ed((v[Ug(a,b,g)>>2]+ed(rt(i),21)|0)+2048|0,12);if((d|0)<-32768){d=-32768}if((d|0)>32767){d=32767}j=fo(h,b,g),k=d,u[j>>1]=k;b=b+1|0;if((b|0)!=(e|0)){continue}break}}g=g+1|0;if((g|0)!=(f|0)){continue}break}}break a}ba(2959,6225,36,5969);L()}ba(2989,6225,35,5969);L()}ba(4217,6225,34,5969);L()}ba(4252,6225,33,5969);L()}gb=c- -64|0}function tja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=u[(g<<1)+n>>1];j=v[a+60>>2];f=Lb(b,-16777216,16776704);k=v[a+64>>2];g=Lb(e,-16777216,16776704);i=i<<8;e=i;e=mqa(j,j>>31,e,e>>31);j=jb;k=mqa(k,k>>31,f,f>>31);f=k+e|0;e=jb+j|0;e=f>>>0<k>>>0?e+1|0:e;j=f;f=v[a+68>>2];g=mqa(f,f>>31,g,g>>31);f=j+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Ic(f,e,24);f=v[a+72>>2];g=(e|0)/256|0;v[c>>2]=v[c>>2]+B(g,m);v[c+4>>2]=v[c+4>>2]+B(g,l);f=e-(f&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function gA(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+480188>>1];a:{if(d>>>0<=255){f=a+1298260|0;while(1){e=B(d,872)+a|0;c=e+1075068|0;b:{if(v[c>>2]){break b}if(!rk(e+1074992|0)){break a}if(v[c>>2]){break b}if(w[e+1075081|0]&24){break a}}if(w[e+1075081|0]&2){if(!Bd(f)){break a}if(!PP(v[f>>2],d&65535)){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}g=8388608;if(b>>>0<=255){b=B(b,872)+a|0;if(!v[b+1075688>>2]){d=65535;if(v[b+1075068>>2]){break a}}g=v[b+1075680>>2]|v[b+1075672>>2]<<9}d=65535;b=x[a+480188>>1];if(b>>>0>255){break a}e=0;while(1){c=B(b,872)+a|0;if(!(v[c+1075688>>2]?0:v[c+1075068>>2])){f=(v[c+1075680>>2]|v[c+1075672>>2]<<9)>>>(v[c+1075080>>2]>>>1&1)|0;c:{d:{if(f>>>0<g>>>0){c=v[c+1075716>>2];break d}if((f|0)!=(g|0)){break c}c=v[c+1075716>>2];if(e>>>0>=c>>>0){break c}}g=f;d=b;e=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function uja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=gb-16|0;gb=h;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=t[g+n|0];j=v[a+60>>2];f=Lb(b,-16777216,16776704);k=v[a+64>>2];g=Lb(e,-16777216,16776704);i=i<<16;e=i;e=mqa(j,j>>31,e,e>>31);j=jb;k=mqa(k,k>>31,f,f>>31);f=k+e|0;e=jb+j|0;e=f>>>0<k>>>0?e+1|0:e;j=f;f=v[a+68>>2];g=mqa(f,f>>31,g,g>>31);f=j+g|0;e=jb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=Ic(f,e,24);f=v[a+72>>2];g=(e|0)/256|0;v[c>>2]=v[c>>2]+B(g,m);v[c+4>>2]=v[c+4>>2]+B(g,l);f=e-(f&i)|0;Ub(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+12>>2];e=b;b=f;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=g;gb=h+16|0}function raa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-48|0;gb=b;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)!=1){d=Kb(b+32|0);c=v[a+24>>2];v[22640]=0;R(1959,b+16|0,c|0);c=v[22640];v[22640]=0;d:{if((c|0)!=1){e=b,f=Sb(b+16|0),v[e+8>>2]=f;e=b,f=Wb(b+16|0),v[e>>2]=f;if(!Gb(b+8|0,b)){break b}while(1){e:{c=v[b+8>>2];v[22640]=0;Q(1183,d|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break e}sr(b+8|0);e=b,f=Wb(b+16|0),v[e>>2]=f;if(!Gb(b+8|0,b)){break b}v[22640]=0;Q(1917,d|0,11862)|0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}}break}c=V(0)|0;O()|0;vd(b+16|0);break d}c=V(0)|0;O()|0}vb(d);break c}c=V(0)|0;O()|0}Z(c|0)|0;c=0;v[22640]=0;Y(1911,3654,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}c=ie(Jb(d));vd(b+16|0);vb(d)}gb=b+48|0;return c|0}function p$(){var a=0,b=0,c=0,d=0;c=gb-32|0;gb=c;a:{a=Tb(c+16|0,12228);if(!Ab(a)){break a}b:{if((rg(a,11887)|0)!=-1){b=rg(a,11887);v[22640]=0;Y(188,c|0,a|0,b+1|0,-1);b=v[22640];v[22640]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((rg(a,13908)|0)!=-1){b=rg(a,13908);v[22640]=0;Y(188,c|0,a|0,b+1|0,-1);b=v[22640];v[22640]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((rg(a,11223)|0)!=-1){b=rg(a,11223);v[22640]=0;Y(188,c|0,a|0,0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((rg(a,11098)|0)!=-1){b=rg(a,11098);v[22640]=0;Y(188,c|0,a|0,0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}if((rg(a,11141)|0)!=-1){b=rg(a,11141);v[22640]=0;Y(188,c|0,a|0,0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}Eb(a,c);vb(c)}v[22640]=0;b=T(189,a|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;vb(a);S(c|0);L()}vb(a);gb=c+32|0;return b|0}function vx(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=Lf(a);a:{if(!v[115924]|!w[a|0]){break a}b=a;b:{if(b&3){while(1){c=w[b|0];if(!c|(c|0)==61){break b}b=b+1|0;if(b&3){continue}break}}c=v[b>>2];c:{if((c^-1)&c-16843009&-2139062144){break c}while(1){c=c^1027423549;if((c^-1)&c-16843009&-2139062144){break c}c=v[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;d=w[b|0];if(d){b=c+1|0;if((d|0)!=61){continue}}break}b=c}if(w[b|0]==61?b:0){break a}e=v[v[115924]>>2];if(!e){break a}d:{while(1){h=v[115924];b=a;c=g;d=0;e:{if(!c){break e}d=w[b|0];f:{if(d){while(1){i=w[e|0];if(!i){break f}c=c-1|0;if(!c){break f}g:{if((d|0)==(i|0)){break g}break f}e=e+1|0;d=w[b+1|0];b=b+1|0;if(d){continue}break}}d=0}d=d-w[e|0]|0}if(!d){b=v[(f<<2)+h>>2]+g|0;if(w[b|0]==61){break d}}f=f+1|0;e=v[(f<<2)+h>>2];if(e){continue}break}return 0}f=b+1|0}return f}function M9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-48|0;gb=b;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)!=1){d=Kb(b+32|0);c=v[a+24>>2];v[22640]=0;R(1994,b+16|0,c|0);c=v[22640];v[22640]=0;d:{if((c|0)!=1){e=b,f=Sb(b+16|0),v[e+8>>2]=f;e=b,f=Wb(b+16|0),v[e>>2]=f;if(!Gb(b+8|0,b)){break b}while(1){e:{c=v[b+8>>2];v[22640]=0;Q(1183,d|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break e}sr(b+8|0);e=b,f=Wb(b+16|0),v[e>>2]=f;if(!Gb(b+8|0,b)){break b}v[22640]=0;Q(1917,d|0,11862)|0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}}break}c=V(0)|0;O()|0;vd(b+16|0);break d}c=V(0)|0;O()|0}vb(d);break c}c=V(0)|0;O()|0}Z(c|0)|0;c=0;v[22640]=0;Y(1911,4117,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}c=ie(Jb(d));vd(b+16|0);vb(d)}gb=b+48|0;return c|0}function dea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;v[e+24>>2]=d;i=Zf(a,c);se(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!i){if(id(a,5)){break a}}k=v[e+24>>2];d=gb-48|0;gb=d;h=v[a+28>>2];jl(h,d+40|0);f=v[d+44>>2];if(!f&y[d+40>>2]>=257|f){v[d+40>>2]=256;v[d+44>>2]=0}b:{c:{d:{e:{f:{if(v[d+40>>2]|v[d+44>>2]){while(1){Xf(h,d+38|0);f=Kb(d+24|0);v[22640]=0;W(674,h|0,f|0,255)|0;g=v[22640];v[22640]=0;if((g|0)==1){break f}v[22640]=0;U(13,d+8|0,k|0,f|0);g=v[22640];v[22640]=0;if((g|0)==1){break e}v[22640]=0;g=Q(1519,b|0,d+38|0)|0;l=v[22640];v[22640]=0;if((l|0)==1){break d}Eb(g,d+8|0);vb(d+8|0);vb(f);f=v[d+44>>2];j=j+1|0;if(!f&j>>>0<y[d+40>>2]|f){continue}break}}gb=d+48|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;vb(d+8|0)}vb(f);S(a|0);L()}}Sf(a,i,c,e+16|0);gb=e+32|0}function mia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-16|0;gb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=(e<<1)+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function $ha(){var a=0,b=0,c=0;b=gb-16|0;gb=b;Kb(90572);a=gb-16|0;gb=a;v[a+12>>2]=0;v[22646]=v[a+12>>2];gb=a+16|0;t[90588]=0;a=gb-16|0;gb=a;v[a+12>>2]=0;v[22648]=v[a+12>>2];gb=a+16|0;v[22640]=0;a=fa(79)|0;c=v[22640];v[22640]=0;a:{b:{c:{d:{e:{if((c|0)!=1){v[b+8>>2]=a;hS(90584,$d(b+8|0));ZA(b+8|0);t[90588]=0;a=0;break e}a=Ca(88880,88856)|0;c=O()|0;if((ea(88880)|0)==(c|0)){Z(a|0)|0;v[22640]=0;X(80);a=v[22640];v[22640]=0;if((a|0)==1){break c}L()}if((ea(88856)|0)!=(c|0)){break b}Z(a|0)|0;v[22640]=0;t[90588]=0;X(20);a=v[22640];v[22640]=0;if((a|0)==1){a=P()|0;O()|0;break b}a=w[90588]}if(a&255){break d}v[22640]=0;_(81,90568);a=v[22640];v[22640]=0;if((a|0)!=1){break d}a=P()|0;O()|0;break b}gb=b+16|0;return}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){break a}}Zm(90592);ZA(90584);vb(90572);S(a|0);L()}V(0)|0;O()|0;Bb();L()}function s8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb+-64|0;gb=f;v[f+56>>2]=d;d=ni(a,f+56|0);g=th(a+4|0);h=th(a+24|0);i=th(a+32|0);j=ad(a+36|0);v[a+56>>2]=3;k=nc(a+68|0);v[22640]=0;R(2079,a|0,e|0);l=v[22640];v[22640]=0;a:{b:{c:{d:{if((l|0)!=1){v[22640]=0;bc(f+24|0,b,c);b=v[22640];v[22640]=0;if((b|0)==1){break d}b=Sd(f+16|0);v[22640]=0;c=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=c;c=v[b+4>>2];v[f>>2]=v[b>>2];v[f+4>>2]=c;U(2083,f+32|0,f+8|0,f|0);b=v[22640];v[22640]=0;if((b|0)==1){break d}v[22640]=0;U(2080,a|0,f+32|0,e|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}yb(f+32|0);v[22640]=0;_(2081,a|0);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(f+32|0)}vd(k);Uf(j);iq(i);Bi(h);Ai(g);bg(d);bg(f+56|0);S(a|0);L()}bg(f+56|0);gb=f- -64|0;return a|0}function pJ(a,b,c,d){var e=0,f=0,g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=C(0),o=0;e=gb-96|0;gb=e;if((d|0)>=1){while(1){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];f=0;while(1){j=f<<3;h=f<<4;i=z[(h|8)+a>>2];g=z[(h|4)+a>>2];z[(e+48|0)+(j|4)>>2]=i+g;k=f<<1;z[(8-k<<2)+e>>2]=g-i;i=z[(a+h|0)+16>>2];g=z[(h|12)+a>>2];z[(7-k<<2)+e>>2]=i-g;z[(e+j|0)+56>>2]=-C(g+i);f=f+1|0;if((f|0)!=4){continue}break}oJ(e+48|0);oJ(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];h=0;while(1){f=h<<2;j=f+b|0;i=z[j>>2];g=z[f+67952>>2];l=z[f+(e+48|0)>>2];m=z[e+f>>2];n=z[f+67988>>2];z[j>>2]=C(g*l)-C(m*n);j=a+f|0;f=c+f|0;g=C(C(g*m)+C(n*l));z[j>>2]=C(i*z[f>>2])-C(z[f+36>>2]*g);z[(17-h<<2)+a>>2]=C(z[f>>2]*g)+C(i*z[f+36>>2]);h=h+1|0;if((h|0)!=9){continue}break}b=b+36|0;a=a+72|0;o=o+1|0;if((o|0)!=(d|0)){continue}break}}gb=e+96|0}function dga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=C(0),i=C(0),j=C(0),k=0,m=0;f=gb-16|0;gb=f;k=f,m=B(v[a>>2],bd(a)),v[k>>2]=m;tc(f,c>>>2|0);c=zb(b);h=z[e+4>>2];e=v[f>>2];if(e){while(1){g=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);h=C(G(C(D((l(2,g<<24|g<<8&16711680|(g>>>8&65280|g>>>24)),q()))),h));c=c+4|0;e=e-1|0;if(e){continue}break}}c=h==C(0);a:{if(c){break a}e=v[f>>2];if(!e){break a}j=c?C(1):C(C(1)/h);c=v[a+20>>2];while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[f+12>>2]=j*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());v[f+8>>2]=-1082130432;v[f+4>>2]=1065353216;i=C(z[Wf(f+12|0,f+8|0,f+4|0)>>2]*C(32768));z[f+12>>2]=i;a=c;i=re(i);b:{if(C(D(i))<C(2147483648)){g=~~i;break b}g=-2147483648}k=a,m=Sc(g),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=h}gb=f+16|0;return v[f>>2]<<2}function g7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Hf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;h=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[h+4>>2]){if(e>>>0<=y[a+8>>2]){if(Gf(h)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){f=ed(v[Ug(a,c,g)>>2]+2048|0,12);if((f|0)<-32768){f=-32768}if((f|0)>32767){f=32767}i=go(h,c,g),j=f,u[i>>1]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}break a}ba(2959,6225,36,5969);L()}ba(2989,6225,35,5969);L()}ba(4217,6225,34,5969);L()}ba(4252,6225,33,5969);L()}gb=b- -64|0}function Y6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Hf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;h=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[h+4>>2]){if(e>>>0<=y[a+8>>2]){if(Gf(h)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){f=ed(v[Ug(a,c,g)>>2]+2048|0,12);if((f|0)<-32768){f=-32768}if((f|0)>32767){f=32767}i=fo(h,c,g),j=f,u[i>>1]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}break a}ba(2959,6225,36,5969);L()}ba(2989,6225,35,5969);L()}ba(4217,6225,34,5969);L()}ba(4252,6225,33,5969);L()}gb=b- -64|0}function xp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;a:{if(!b){break a}if(c){c=le(f+8|0,a);a=gb-16|0;gb=a;v[a+12>>2]=b;d=v[c+4>>2];b:{if(!d){d=v[c>>2];break b}v[a+8>>2]=32-d;b=Fb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]|-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b;b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Qb(e,255,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]|-1>>>32-b}gb=a+16|0;break a}c=le(f,a);a=gb-16|0;gb=a;v[a+12>>2]=b;d=v[c+4>>2];c:{if(!d){d=v[c>>2];break c}v[a+8>>2]=32-d;b=Fb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]&(-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b^-1);b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Qb(e,0,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]&(-1>>>32-b^-1)}gb=a+16|0}gb=f+16|0}function jga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];c=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(c){a=v[a+20>>2];h=c;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;f=C(z[Wf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=f;e=a;f=re(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}i=e,j=Sc(g),u[i>>1]=j;e=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;f=C(z[Wf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=f;e=a;f=re(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}i=e,j=Sc(g),u[i+2>>1]=j;a=a+4|0;b=b+8|0;h=h-1|0;if(h){continue}break}}gb=d+16|0;return c<<3}function Xfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+32;wb(a);rP(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;$b(c);gb=c+16|0;return}g=gb-32|0;gb=g;f=wb(a);d=$q(a,Ae(a)+1|0);i=Ae(a);h=gb-16|0;gb=h;v[h+12>>2]=0;c=g+8|0;ef(c+12|0,f);if(d){e=d;if(d>>>0>=134217728){nd(8513);L()}e=Mc(e<<5,8)}v[c>>2]=e;f=(i<<5)+e|0;v[c+8>>2]=f;v[c+4>>2]=f;j=cc(c),k=(d<<5)+e|0,v[j>>2]=k;gb=h+16|0;rP(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;Yu(a);wb(a);b=c+4|0;cl(v[a>>2],v[a+4>>2],b);wc(a,b);wc(a+4|0,c+8|0);wc(wb(a),cc(c));v[c>>2]=v[c+4>>2];SA(a,Ae(a));a=c;b=c;c=v[c+4>>2];a:{while(1){d=v[b+8>>2];if((d|0)==(c|0)){break a}v[b+8>>2]=d-32;v[22640]=0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){lV(v[a+16>>2],b,oB(a))}gb=g+32|0}function mka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-32|0;gb=g;j=g,k=br(b),v[j+16>>2]=k;c=gb-32|0;gb=c;e=b;d=a;b=Vd(d);f=ec(d);a:{b:{if(b){wb(d);c:{while(1){d:{d=b+13|0;e:{if(Du(e,d)){if(!v[b>>2]){break b}f=b;break e}if(!Du(d,e)){break c}f=b+4|0;if(!v[b+4>>2]){break d}b=f;f=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=f;break a}v[c+28>>2]=b;b=f;break a}b=ec(d)}v[c+28>>2]=b}f=b;b=v[b>>2];t[c+27|0]=0;if(!b){h=gb-16|0;gb=h;b=ec(a);i=Pj(c+8|0,YB(),Qj(h+8|0,b));e=v[i>>2];d=gb-16|0;gb=d;v[d+8>>2]=v[g+16>>2];b=v[d+8>>2];b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[e+17|0]=0;t[e+13|0]=b;t[e+14|0]=b>>>8;t[e+15|0]=b>>>16;t[e+16|0]=b>>>24;gb=d+16|0;j=ec(i),k=1,t[j+4|0]=k;gb=h+16|0;Ak(a,v[c+28>>2],f,v[c+8>>2]);b=$d(c+8|0);t[c+27|0]=1;ZB(c+8|0)}Rj(g+24|0,yc(c+8|0,b),c+27|0);gb=c+32|0;gb=g+32|0;return v[g+24>>2]+17|0}function Ow(a){var b=0,c=0,d=0,e=0,f=0,g=0;o(+a);e=j(1)|0;j(0)|0;b=e;e=b>>>31|0;a:{b:{c:{d:{d=a;e:{f:{b=b&2147483647;g:{if(b>>>0>=1082532651){o(+a);b=j(1)|0;b=b&2147483647;if((b|0)==2146435072&(j(0)|0)!=0|b>>>0>2146435072){return a}if(a>709.782712893384){return a*8.98846567431158e307}if(!(a<-708.3964185322641)|!(a<-745.1332191019411)){break g}break b}if(b>>>0<1071001155){break d}if(b>>>0<1072734898){break f}}a=a*1.4426950408889634+A[(e<<3)+89808>>3];if(D(a)<2147483648){b=~~a;break e}b=-2147483648;break e}b=!e-e|0}c=+(b|0);a=d+c*-.6931471803691238;f=c*1.9082149292705877e-10;d=a-f;break c}if(b>>>0<=1043333120){break a}b=0;d=a}c=d;g=a;c=c*c;a=d-c*(c*(c*(c*(c*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);c=g+(d*a/(2-a)-f)+1;if(!b){break b}c=$i(c,b)}return c}return a+1}function x5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[rj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22640]=0;Ec(c+16|0,a+d|0);d=v[22640];v[22640]=0;d:{e:{f:{if((d|0)!=1){v[22640]=0;d=T(2280,c+16|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break f}e=_i(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22640]=0;ka(2284,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break f}Vb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Vb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;qj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22640]=0;X(2027);a=v[22640];v[22640]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){break c}S(a|0);L()}$()}fh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function v5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[rj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22640]=0;Ec(c+16|0,a+d|0);d=v[22640];v[22640]=0;d:{e:{f:{if((d|0)!=1){v[22640]=0;d=T(2280,c+16|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break f}e=_i(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22640]=0;ka(2285,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break f}Vb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Vb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;qj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22640]=0;X(2027);a=v[22640];v[22640]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){break c}S(a|0);L()}$()}fh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function t5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[rj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22640]=0;Ec(c+16|0,a+d|0);d=v[22640];v[22640]=0;d:{e:{f:{if((d|0)!=1){v[22640]=0;d=T(2280,c+16|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break f}e=_i(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22640]=0;ka(2286,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break f}Vb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Vb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;qj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22640]=0;X(2027);a=v[22640];v[22640]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){break c}S(a|0);L()}$()}fh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function VF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[22640]=0;g=Q(15,d+24|0,a|0)|0;e=v[22640];v[22640]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!w[g|0]){break e}e=_i(d+8|0,a);h=v[(v[v[a>>2]-12>>2]+a|0)+4>>2];f=v[v[a>>2]-12>>2];v[22640]=0;f=a+f|0;i=T(16,f|0)|0;j=v[22640];v[22640]=0;if((j|0)==1){break d}e=v[e>>2];v[22640]=0;c=b+c|0;b=la(17,e|0,b|0,((h&176)==32?c:b)|0,c|0,f|0,i|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break d}v[d+16>>2]=b;if(!Wv(d+16|0)){break e}b=v[v[a>>2]-12>>2];v[22640]=0;R(18,a+b|0,5);b=v[22640];v[22640]=0;if((b|0)!=1){break e}break d}pl(g);break b}b=V(0)|0;O()|0;pl(g);break c}b=V(0)|0;O()|0}Z(b|0)|0;b=v[v[a>>2]-12>>2];v[22640]=0;_(19,a+b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}$()}gb=d+32|0;return a}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){V(0)|0;O()|0;Bb();L()}S(a|0);L()}function E5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[rj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22640]=0;Ec(c+16|0,a+d|0);d=v[22640];v[22640]=0;d:{e:{f:{if((d|0)!=1){v[22640]=0;d=T(2280,c+16|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break f}e=_i(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22640]=0;ka(2281,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break f}Vb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Vb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;qj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22640]=0;X(2027);a=v[22640];v[22640]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){break c}S(a|0);L()}$()}fh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function B5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;v[c+28>>2]=0;a:{b:{c:{if(w[rj(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[22640]=0;Ec(c+16|0,a+d|0);d=v[22640];v[22640]=0;d:{e:{f:{if((d|0)!=1){v[22640]=0;d=T(2280,c+16|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break f}e=_i(c+8|0,a);f=Ui(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[22640]=0;ka(2282,d|0,e|0,f|0,a+g|0,c+28|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break f}Vb(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Vb(c+16|0)}Z(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;qj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22640]=0;X(2027);a=v[22640];v[22640]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){break c}S(a|0);L()}$()}fh(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}gb=c+32|0;break a}V(0)|0;O()|0;Bb()}L()}return a|0}function rN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;i=f,j=br(b),v[i+16>>2]=j;c=gb-32|0;gb=c;g=b;d=a;b=Vd(d);e=ec(d);a:{b:{if(b){d=wb(d);c:{while(1){d:{h=b+16|0;e:{if(jN(d,g,h)){if(!v[b>>2]){break b}e=b;break e}if(!iN(h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=e;break a}v[c+28>>2]=b;b=e;break a}b=ec(d)}v[c+28>>2]=b}e=b;b=v[b>>2];t[c+27|0]=0;if(!b){g=gb-16|0;gb=g;b=ec(a);d=Pj(c+8|0,ZW(),Qj(g+8|0,b));b=v[d>>2];v[22640]=0;h=b+16|0;b=v[22640];v[22640]=0;f:{if((b|0)!=1){b=gb-16|0;gb=b;v[b+8>>2]=v[f+16>>2];u[h>>1]=x[v[b+8>>2]>>1];Kb(h+4|0);gb=b+16|0;i=ec(d),j=1,t[i+4|0]=j;gb=g+16|0;break f}a=P()|0;O()|0;hN(d);S(a|0);L()}Ak(a,v[c+28>>2],e,v[c+8>>2]);b=$d(c+8|0);t[c+27|0]=1;hN(c+8|0)}Rj(f+24|0,yc(c+8|0,b),c+27|0);gb=c+32|0;a=ue(f+24|0);gb=f+32|0;return a+4|0}function Ws(a){a=a|0;var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;c=v[v[a>>2]-12>>2];v[22640]=0;c=v[(a+c|0)+24>>2];b=v[22640];v[22640]=0;a:{b:{c:{d:{e:{if((b|0)!=1){if(!c){break b}v[22640]=0;c=Q(15,d+8|0,a|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break d}if(!w[c|0]){break e}b=v[v[a>>2]-12>>2];v[22640]=0;b=v[(a+b|0)+24>>2];e=v[22640];v[22640]=0;f:{if((e|0)==1){break f}v[22640]=0;b=T(2278,b|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break f}if((b|0)!=-1){break e}b=v[v[a>>2]-12>>2];v[22640]=0;R(18,a+b|0,1);b=v[22640];v[22640]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;pl(c);break c}b=V(0)|0;O()|0;break c}pl(c);break b}b=V(0)|0;O()|0}Z(b|0)|0;c=v[v[a>>2]-12>>2];v[22640]=0;_(19,a+c|0);c=v[22640];v[22640]=0;if((c|0)==1){break a}$()}gb=d+16|0;return a|0}a=P()|0;O()|0;v[22640]=0;X(20);c=v[22640];v[22640]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function J8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;i=a;a:{b:{if(!((b|0)==(c|0)|(e|0)>-1)){t[b|0]=45;f=d;d=0-d|0;e=0-(((f|0)!=0)+e|0)|0;b=b+1|0}f=c-b|0;if((f|0)<=19){g=E(e);g=B(64-((g|0)==32?E(d|1)+32|0:g)|0,1233)>>>12|0;h=(g<<3)+27584|0;j=f;f=v[h+4>>2];if((j|0)<((g-((e|0)==(f|0)&d>>>0<y[h>>2]|e>>>0<f>>>0)|0)+1|0)){break b}}c=a;c:{if(!e&d>>>0<=99999999){a=Px(b,d);break c}if((e|0)==2328306&d>>>0<=1874919423|e>>>0<2328306){a=pqa(d,e,1e8,0);e=jb;f=Px(b,a);a=d-mqa(a,e,1e8,0)|0;b=(a>>>0)/1e4|0;a=tj(tj(f,b),a-B(b,1e4)|0);break c}a=pqa(d,e,1874919424,2328306);f=jb;g=Ox(b,a);a=mqa(a,f,1874919424,2328306);b=d-a|0;a=pqa(b,e-(jb+(a>>>0>d>>>0)|0)|0,1e8,0);e=jb;f=(a>>>0)/1e4|0;d=tj(tj(g,f),a-B(f,1e4)|0);a=b-mqa(a,e,1e8,0)|0;b=(a>>>0)/1e4|0;a=tj(tj(d,b),a-B(b,1e4)|0)}v[c>>2]=a;a=0;break a}v[a>>2]=c;a=61}v[i+4>>2]=a}function Yz(a,b){var c=0;c=gb-16|0;gb=c;a=bA(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Ob(a,7,1);Ob(a,9,1);Ob(a,10,1);Ob(a,13,1);Ob(a,15,1);Ob(a,16,1);Ob(a,17,1);Ob(a,18,1);Ob(a,20,1);Ob(a,21,1);Ob(a,24,1);Ob(a,25,1);Ob(a,26,1);Ob(a,28,1);Ob(a,30,1);Ob(a,31,1);Ob(a,33,1);Ob(a,34,1);Ob(a,39,1);Ob(a,41,1);Ob(a,44,1);Ob(a,46,1);Ob(a,45,1);Ob(a,47,1);Ob(a,48,1);Ob(a,50,1);Ob(a,99,1);Ob(a,102,1);Ob(a,104,1);Ob(a,105,1);break a;case 1:Wz(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Yf(a,107);break a;case 3:Wz(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Yf(a,4);break a;case 2:break b;case 0:break c}}Ob(a,88,1);break a}Wz(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}gb=c+16|0}function bda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=gb-4112|0;gb=c;i=kb[v[v[a>>2]+116>>2]](a)|0;if(!i){kb[v[v[a>>2]+120>>2]](a)}v[c+12>>2]=0;d=gb-16|0;gb=d;h=a+44|0;if(Qf(h)){while(1){f=Gn(h,e);g=Gn(h,e);v[d+12>>2]=0;g=(g+2048|0)-f>>2;if((g|0)>=1){while(1){z[f>>2]=z[d+12>>2];f=f+4|0;j=(g|0)>1;g=g-1|0;if(j){continue}break}}e=e+1|0;if(Qf(h)>>>0>e>>>0){continue}break}}gb=d+16|0;if(b){f=c+2064|0;while(1){v[c+8>>2]=b;tc(c+8|0,512);Uo(c+16|0);kb[v[v[a>>2]+60>>2]](a,c+16|0,f,v[c+8>>2]);e=0;if(v[c+8>>2]){while(1){d=(c+16|0)+(e<<2)|0;z[c+4>>2]=D(z[d>>2]);k=c,l=z[Qy(c+12|0,c+4|0)>>2],z[k+12>>2]=l;z[c+4>>2]=D(z[d+2048>>2]);k=c,l=z[Qy(c+12|0,c+4|0)>>2],z[k+12>>2]=l;e=e+1|0;d=v[c+8>>2];if(e>>>0<d>>>0){continue}break}b=b-d|0}if(b){continue}break}}if(!i){kb[v[v[a>>2]+124>>2]](a)}gb=c+4112|0;return C(z[c+12>>2])}function nia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=gb-16|0;gb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=e+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0);i=gb-16|0;gb=i;j=a+44|0;if(ki(j)){h=Md(j,0);v[i+8>>2]=h;k=Md(j,1);v[i+12>>2]=k;e=kd(j,0);v[i>>2]=e;f=kd(j,1);v[i+4>>2]=f;a:{if(z[a+4216>>2]!=C(.5)){if(!d){break a}h=d;while(1){f=0;k=1;while(1){f=f<<2;e=f+(i+8|0)|0;g=v[e>>2];v[e>>2]=g+4;e=a+f|0;m=e+4248|0;p=z[m>>2];l=z[g>>2];q=z[a+4228>>2];r=z[a+4224>>2];s=z[a+4220>>2];t=z[a+4236>>2];u=z[a+4232>>2];g=e+4240|0;n=z[g>>2];z[m>>2]=n;z[g>>2]=l;g=e+4264|0;w=z[g>>2];e=e+4256|0;o=z[e>>2];z[g>>2]=o;l=C(C(C(C(n*r)+C(s*l))+C(p*q))-C(C(w*t)+C(o*u)));z[e>>2]=l;f=f+i|0;e=v[f>>2];v[f>>2]=e+4;z[e>>2]=l;e=k;k=0;f=1;if(e){continue}break}h=h-1|0;if(h){continue}break}break a}g=h;h=d<<2;hc(e,g,h);hc(f,k,h)}Ci(a,b,c,kd(j,0),kd(j,1),d)}gb=i+16|0}function H9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-32|0;gb=e;v[22640]=0;_(1934,a|0);d=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[22640]=0;_(1960,b|0);d=v[22640];v[22640]=0;if((d|0)==1){break g}v[22640]=0;_(1960,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break g}f=v[a+24>>2];v[22640]=0;d=Q(112,e+16|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}v[22640]=0;c=Q(112,e|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break f}v[22640]=0;Y(2e3,f|0,d|0,c|0,1);b=v[22640];v[22640]=0;if((b|0)==1){break e}vb(c);vb(d);b=1;break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;vb(c)}vb(d)}Z(b|0)|0;b=0;v[22640]=0;Y(1911,3472,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$()}gb=e+32|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function RY(a,b){var c=0,d=0;d=w[a|0];if(d>>>0>=36){t[a|0]=0;return}c=w[d+28896|0];t[a|0]=c;a:{b:{c:{d:{e:{f:{if(c>>>0<=16){if(c-6>>>0>=2){if((c|0)==1){break f}if((c|0)!=11){break a}}c=w[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}t[b|0]=a;return}switch(c-17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break b}}if(w[b|0]){break a}t[a|0]=0;return}a=w[b|0];if(a>>>0<=64){t[b|0]=a<<1;return}t[b|0]=128;return}g:{h:{i:{j:{c=w[b|0];switch((c&240)-48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}t[a|0]=20;t[b|0]=159;return}t[a|0]=20;t[b|0]=192;return}if(c&14){break a}t[a|0]=21;t[b|0]=(w[b|0]!=80)<<6;return}t[a|0]=20;t[b|0]=w[b|0]&15|160;return}if(w[b|0]>31){break a}t[a|0]=16;return}if((c|0)!=31){break a}t[b|0]=(d<<5|w[b|0]<<24>>>27)^128}}function UU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-80|0;gb=d;a:{b:{e=v[a+4>>2];if(e>>>0<b>>>0){g=Sd(d+72|0);f=b-e|0;b=Uu(a);if(!(f>>>0>b>>>0|e>>>0>b-f>>>0)){Rl(d+56|0,a);b=v[d+60>>2];v[d+72>>2]=v[d+56>>2];v[d+76>>2]=b;v[a+4>>2]=v[a+4>>2]+f;break b}wb(a);b=Vu(d+56|0);e=v[a+4>>2];v[22640]=0;e=Q(847,a|0,e+f|0)|0;h=v[22640];v[22640]=0;c:{if((h|0)==1){break c}v[22640]=0;R(848,b|0,e|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}v[b+4>>2]=v[a+4>>2]+f;yk(d+40|0,a);Rl(d+32|0,a);yk(d+24|0,b);v[22640]=0;e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;e=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=e;Y(849,d+48|0,d+8|0,d|0,d+24|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}e=v[d+52>>2];v[d+72>>2]=v[d+48>>2];v[d+76>>2]=e;GB(a,b);Ce(b);break b}a=P()|0;O()|0;Ce(b);S(a|0);L()}v[a+4>>2]=b;break a}xp(le(d+16|0,g),f,c)}gb=d+80|0}function Eq(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;a:{b:{switch(w[a+480224|0]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;d=mqa(b,d,5e4,0);e=jb;b=v[Jc(c+8|0,c)>>2];b=zc(nqa(d,e,b,b>>31),jb);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=mqa(v[a+1074420>>2],0,mqa(v[a+1074408>>2],0,v[a+1074416>>2],0),jb),v[g>>2]=h;v[c+4>>2]=jb;d=gb-16|0;gb=d;e=c+8|0;f=iw(e,c);gb=d+16|0;d=mqa(b,0,6e5,0);b=f?c:e;b=pqa(d,jb,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];d=mqa(b,d,1e4,0);e=jb;b=v[Jc(c+8|0,c)>>2];b=zc(nqa(d,e,b,b>>31),jb);v[a+1074404>>2]=b}d=a+1074404|0;a=v[a+480244>>2];b=mqa(a,a>>31,b,b>>31)+32768|0;a=jb;a=zc(nqa(b,b>>>0<32768?a+1|0:a,65536,0),jb);v[d>>2]=a?a:1;gb=c+16|0}function ry(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Hf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Gf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Ym(fe(A[Tg(a,c,f)>>3]*134217728));i=sy(g,c,f),j=C(+(h|0)*7.450580596923828e-9),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}ba(2959,6225,80,5936);L()}ba(2989,6225,79,5936);L()}ba(4217,6225,78,5936);L()}ba(4252,6225,77,5936);L()}gb=b- -64|0}function py(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Hf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Gf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Ym(fe(A[Tg(a,c,f)>>3]*134217728));i=qy(g,c,f),j=C(+(h|0)*7.450580596923828e-9),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}ba(2959,6225,80,5936);L()}ba(2989,6225,79,5936);L()}ba(4217,6225,78,5936);L()}ba(4252,6225,77,5936);L()}gb=b- -64|0}function Z9(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;R(1980,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break i}if(Cc(d)>>>0<2147483647){break h}c=aa(8)|0;v[22640]=0;Q(1981,c|0,4467)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}v[22640]=0;U(223,c|0,89228,242);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18693;j:{if((b|0)<0){break j}if((Cc(d)|0)<=(b|0)){break j}a=Jb(xd(d,b))}b=ie(a);vd(d);break d}b=V(0)|0;O()|0;da(c|0)}vd(d)}Z(b|0)|0;b=0;v[22640]=0;Y(1911,9215,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function Y9(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;R(1982,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break i}if(Cc(d)>>>0<2147483647){break h}c=aa(8)|0;v[22640]=0;Q(1981,c|0,4467)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}v[22640]=0;U(223,c|0,89228,242);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18693;j:{if((b|0)<0){break j}if((Cc(d)|0)<=(b|0)){break j}a=Jb(xd(d,b))}b=ie(a);vd(d);break d}b=V(0)|0;O()|0;da(c|0)}vd(d)}Z(b|0)|0;b=0;v[22640]=0;Y(1911,9183,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function X9(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;R(1983,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break i}if(Cc(d)>>>0<2147483647){break h}c=aa(8)|0;v[22640]=0;Q(1981,c|0,4467)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}v[22640]=0;U(223,c|0,89228,242);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18693;j:{if((b|0)<0){break j}if((Cc(d)|0)<=(b|0)){break j}a=Jb(xd(d,b))}b=ie(a);vd(d);break d}b=V(0)|0;O()|0;da(c|0)}vd(d)}Z(b|0)|0;b=0;v[22640]=0;Y(1911,9121,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function W9(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;R(1984,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break i}if(Cc(d)>>>0<2147483647){break h}c=aa(8)|0;v[22640]=0;Q(1981,c|0,4467)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}v[22640]=0;U(223,c|0,89228,242);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18693;j:{if((b|0)<0){break j}if((Cc(d)|0)<=(b|0)){break j}a=Jb(xd(d,b))}b=ie(a);vd(d);break d}b=V(0)|0;O()|0;da(c|0)}vd(d)}Z(b|0)|0;b=0;v[22640]=0;Y(1911,9151,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function V9(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;R(1985,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break i}if(Cc(d)>>>0<2147483647){break h}c=aa(8)|0;v[22640]=0;Q(1981,c|0,4467)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}v[22640]=0;U(223,c|0,89228,242);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18693;j:{if((b|0)<0){break j}if((Cc(d)|0)<=(b|0)){break j}a=Jb(xd(d,b))}b=ie(a);vd(d);break d}b=V(0)|0;O()|0;da(c|0)}vd(d)}Z(b|0)|0;b=0;v[22640]=0;Y(1911,9086,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function U9(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;R(1986,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break i}if(Cc(d)>>>0<2147483647){break h}c=aa(8)|0;v[22640]=0;Q(1981,c|0,4467)|0;b=v[22640];v[22640]=0;if((b|0)==1){break g}v[22640]=0;U(223,c|0,89228,242);b=v[22640];v[22640]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=18693;j:{if((b|0)<0){break j}if((Cc(d)|0)<=(b|0)){break j}a=Jb(xd(d,b))}b=ie(a);vd(d);break d}b=V(0)|0;O()|0;da(c|0)}vd(d)}Z(b|0)|0;b=0;v[22640]=0;Y(1911,9247,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break c}$()}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Bb()}L()}S(a|0);L()}function uH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;h=gb-1040|0;gb=h;i=v[b>>2];v[h+12>>2]=i;g=a?d:256;j=a?a:h+16|0;d=0;a:{b:{c:{if(!i|!g){break c}f=c>>>2|0;k=g>>>0<=f>>>0;if(f>>>0<g>>>0?c>>>0<=131:0){break b}while(1){f=k?g:f;c=c-f|0;f=sx(j,h+12|0,f,e);if((f|0)==-1){g=0;i=v[h+12>>2];d=-1;break c}i=(h+16|0)==(j|0);g=g-(i?0:f)|0;j=i?j:(f<<2)+j|0;d=d+f|0;i=v[h+12>>2];if(!i|!g){break c}f=c>>>2|0;k=g>>>0<=f>>>0;if(c>>>0>131|f>>>0>=g>>>0){continue}break}break b}if(!i){break a}}if(!g|!c){break a}f=d;while(1){d:{d=$p(j,i,c,e);e:{if(d+2>>>0<=2){f:{switch(d+1|0){case 1:v[h+12>>2]=0;break e;case 0:break a;default:break f}}v[e>>2]=0;break e}i=v[h+12>>2]+d|0;v[h+12>>2]=i;f=f+1|0;g=g-1|0;if(g){break d}}d=f;break a}j=j+4|0;c=c-d|0;d=f;if(c){continue}break}}if(a){v[b>>2]=v[h+12>>2]}gb=h+1040|0;return d|0}function Om(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-16|0;gb=f;if(e){v[e>>2]=0}i=a+484344|0;a:{if(!ke(i,b)){break a}d=Tc(_b(i,b),c,d);g=w[d+5|0];b:{c:{d:{e:{h=w[d+3|0];switch(h-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(h-35>>>0>=2){break a}}v[f+12>>2]=1;j=0;if((h|0)!=17){break b}j=v[a+480180>>2]==4;break b}v[f+12>>2]=2;j=0}m=f,n=v[_b(i,b)+12>>2]+(c^-1)|0,v[m+8>>2]=n;a=v[Fb(f+8|0,f+12|0)>>2];f:{g:{h:{i:{if(a){c=0;k=a;j:{while(1){d=B(Hi(_b(i,b)),6)+d|0;if(w[d+3|0]!=34){break j}l=g<<8;g=w[d+5|0]|(j?g>>>0<256?l+-8192|0:l:l);c=c+1|0;k=k-1|0;if(k){continue}break}c=a}if((h|0)!=35){break i}break h}c=0;if((h|0)==35){break g}}if((h|0)!=36){break f}}if(c){break f}}g=g<<8;c=0}if(!e){break a}v[e>>2]=c}gb=f+16|0;return g|0}function Mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;h=8;t[e+15|0]=8;t[e+14|0]=0;u[e+12>>1]=0;if(d){m=B(c,d);while(1){if((m|0)>=1){j=(l<<1)+b|0;p=j+(m<<1)|0;while(1){u[e+10>>1]=0;JV(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{if(!h){g=x[e+10>>1];break a}g=x[e+10>>1];c=x[e+12>>1];i=h;while(1){f=c<<1;c=f&254;u[e+12>>1]=c;if(c){k=(f&65534)>>>0>255}else{if(!kf(a,e+9|0)){break a}f=w[e+9|0];c=f<<1&254|1;u[e+12>>1]=c;k=f>>>7|0}g=k|g<<1;i=i-1|0;if(i&255){continue}break}u[e+10>>1]=g}k=e;f=g&65535;if(f>>>0<=3){c=h+1|0}else{c=15;while(1){i=c;n=c&255;if(!(f>>>n&1)){c=i-1|0;if(n>>>0>1){continue}}break}c=h+i|0}h=c>>>1&127;t[k+15|0]=h;c=g&1;t[e+14|0]=c;o=(c-1^(g&65534)>>>1)+o|0;u[j>>1]=o;j=(d<<1)+j|0;if(p>>>0>j>>>0){continue}break}}l=l+1|0;if((l|0)!=(d|0)){continue}break}}gb=e+16|0}function JL(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=gb+-64|0;gb=j;v[j+60>>2]=e;e=v[a+4>>2];k=v[a>>2];a=v[a+8>>2];v[j+40>>2]=b;v[j+52>>2]=a;v[j+44>>2]=k;v[j+48>>2]=e;v[22640]=0;v[j+20>>2]=d?d:1919;a=Q(1920,j+20|0,j+60|0)|0;b=v[22640];v[22640]=0;a:{b:{c:{d:{if((b|0)!=1){v[j+24>>2]=a;a=v[kq(j+32|0,j+24|0)>>2];b=v[j+52>>2];v[j+8>>2]=v[j+48>>2];v[j+12>>2]=b;v[22640]=0;b=v[j+44>>2];v[j>>2]=v[j+40>>2];v[j+4>>2]=b;c=+za(1921,j|0,+c,a|0);a=v[22640];v[22640]=0;if((a|0)==1){break d}Aj(j+24|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Aj(j+24|0)}Z(a|0)|0;v[22640]=0;ja(1922,12262,d|0,v[j+60>>2],f|0,g|0,h|0,i|0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();c=0}gb=j- -64|0;return+c}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Ew(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+60>>2]=d;a:{f=v[b>>2];b:{if(!(kb[v[v[f>>2]+36>>2]](f,c,d)|0)){Ih(a);break b}gj(e+40|0,b);v[22640]=0;b=v[b>>2];d=v[22640];v[22640]=0;if((d|0)==1){break a}d=v[v[b>>2]+24>>2];v[22640]=0;b=T(d|0,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break a}v[22640]=0;v[e+36>>2]=b-c;b=Fb(e+60|0,e+36|0);d=v[22640];v[22640]=0;if((d|0)==1){break a}g=v[b>>2];b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;b=gb-16|0;gb=b;d=e+16|0;f=gj(b+8|0,d);v[22640]=0;h=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=h;Y(258,e+48|0,b|0,c|0,g|0);c=v[22640];v[22640]=0;c:{if((c|0)!=1){pe(d);gb=b+16|0;break c}a=P()|0;O()|0;pe(d);S(a|0);L()}b=Sd(e+24|0);c=v[e+52>>2];v[e+8>>2]=v[e+48>>2];v[e+12>>2]=c;c=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=c;rF(a,e+8|0,e)}gb=e- -64|0;return}a=P()|0;O()|0;pe(e+40|0);S(a|0);L()}function zK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;v[f+12>>2]=c;a:{if(!b){a=a+120|0;ho(a);c=v[f+12>>2];b=a;d=mh(b);b:{if(!c){break b}v[22640]=0;R(2116,b|0,c|0);e=v[22640];v[22640]=0;if((e|0)!=1){v[22640]=0;ut(b,c);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;ty(d);S(a|0);L()}t[a+20|0]=0;break a}d=gb-16|0;gb=d;v[d+12>>2]=c;c:{if((b|0)==1){b=a+120|0;ho(b);fK(b,a,d+12|0);t[b+20|0]=1;break c}e=gb-16|0;gb=e;v[e+12>>2]=c;d:{if((b|0)==2){a=a+120|0;ho(a);c=v[e+12>>2];b=a;g=b;h=mh(b);e:{if(!c){break e}v[22640]=0;R(2118,g|0,c|0);i=v[22640];v[22640]=0;if((i|0)!=1){v[22640]=0;ut(g,c);c=v[22640];v[22640]=0;if((c|0)!=1){break e}}a=P()|0;O()|0;ty(h);S(a|0);L()}Sd(b+12|0);t[a+20|0]=2;break d}b=gb-16|0;gb=b;v[b+12>>2]=c;c=a+120|0;ho(c);fK(c,a,b+12|0);t[c+20|0]=3;gb=b+16|0}gb=e+16|0}gb=d+16|0}gb=f+16|0}function gk(a,b){var c=0,d=0,e=0,f=0;c=gb+-64|0;gb=c;d=v[v[a>>2]-12>>2]+a|0;f=v[d+16>>2]&-3;sp(d,f);a:{b:{if(w[rj(c+56|0,a,1)|0]){d=v[v[a>>2]-12>>2];v[22640]=0;d=v[(a+d|0)+24>>2];e=v[22640];v[22640]=0;c:{d:{if((e|0)==1){break d}v[22640]=0;e=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=e;e=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=e;Y(2290,c+40|0,d|0,c+8|0,8);b=v[22640];v[22640]=0;if((b|0)==1){break d}b=Bh(c+24|0,-1,-1);v[22640]=0;b=KY(c+40|0,b);d=v[22640];v[22640]=0;if((d|0)==1){break d}b=b?f|4:f;break c}b=V(0)|0;O()|0;Z(b|0)|0;b=f|1;qj(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22640]=0;X(2027);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){break b}S(a|0);L()}$()}fh(v[v[a>>2]-12>>2]+a|0,b)}gb=c- -64|0;return}V(0)|0;O()|0;Bb()}L()}function _ka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;td(c,2);t[d+16|0]=w[b+13|0];t[d|0]=64;f=c,g=w[ac(d+16|0,d)|0]<<2,u[f+30>>1]=g;e=b+14|0;v[c+24>>2]=(w[e|0]|w[e+1|0]<<8)<<1;Gk(d,2,b+1|0);Bc(d+16|0,d);v[22640]=0;Q(335,c+43|0,d+16|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){vb(d+16|0);e=Pc(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}a=b+22|0;v[c>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+26|0;v[c+4>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+30|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[c+8>>2]=a;if(a>>>0>y[c+4>>2]){v[c+8>>2]=a-1}if(w[b|0]&4){u[c+34>>1]=x[c+34>>1]|2}if(w[b|0]&8){u[c+34>>1]=x[c+34>>1]|4}if(!(w[b|0]&16)){break a}Vi(e,16);zf(e,9);v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function Tna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=gb-32|0;gb=g;i=g,j=$W(b),v[i+16>>2]=j;c=gb-32|0;gb=c;e=b;f=a;b=Vd(a);d=ec(a);a:{b:{if(b){f=wb(f);c:{while(1){d:{h=b+16|0;e:{if(BC(f,e,h)){if(!v[b>>2]){break b}d=b;break e}if(!AC(h,e)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d;d=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=d;break a}v[c+28>>2]=b;b=d;break a}b=ec(f)}v[c+28>>2]=b}d=b;b=v[b>>2];t[c+27|0]=0;if(!b){e=gb-16|0;gb=e;b=ec(a);h=Pj(c+8|0,ZW(),Qj(e+8|0,b));f=v[h>>2]+16|0;b=gb-16|0;gb=b;v[b+8>>2]=v[g+16>>2];u[f>>1]=x[v[b+8>>2]>>1];Kb(f+4|0);gb=b+16|0;i=ec(h),j=1,t[i+4|0]=j;gb=e+16|0;Ak(a,v[c+28>>2],d,v[c+8>>2]);b=$d(c+8|0);t[c+27|0]=1;d=c+8|0;e=d;a=v[e>>2];v[e>>2]=0;if(a){if(w[ec(d)+4|0]){zk(a+16|0)}if(a){YW(a)}}}Rj(g+24|0,yc(c+8|0,b),c+27|0);gb=c+32|0;a=ue(g+24|0);gb=g+32|0;return a+4|0}function dZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;td(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Lr(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=Lr(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+15|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}c=a+14|0;e=b,f=(B(Au(t[a+17|0],w[c|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[e+24>>2]=f;t[d+15|0]=w[a+18|0];t[d+14|0]=127;e=b,f=(((w[ac(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[e+30>>1]=f;if(w[c|0]>=16){c=w[c|0];u[b+34>>1]=32;u[b+28>>1]=c&240}a=a+19|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1}a:{if(!(w[a|0]&8)|y[b+4>>2]>=y[b+8>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(w[a|0]&16){u[b+34>>1]=x[b+34>>1]|4}if(!(w[a|0]&64)){break a}u[b+34>>1]=x[b+34>>1]|128}gb=d+16|0}function d8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb+-64|0;gb=d;a:{b:{if((b|0)>=0){e=a+24|0;if((Qi(Rb(v[e>>2]+484360|0))|0)>(b|0)){break b}}a=a+16|0;break a}f=x[rc(Rb(v[e>>2]+484360|0),b)>>1];c:{if(!$l(v[e>>2]+484344|0,f)){break c}if((c|0)>=0){g=c;if((c|0)<v[_b(v[e>>2]+484344|0,f)+12>>2]){break c}}a=a+16|0;break a}u[v[e>>2]+1074448>>1]=b;c=b&65535;_O(v[e>>2],c);v[v[e>>2]+1074428>>2]=g;v[v[e>>2]+1074392>>2]=-2;e=v[e>>2];f=w[a+64|0];b=d+24|0;t[b+6|0]=255;v[b+16>>2]=0;u[b+4>>1]=0;v[b>>2]=0;if(!((c|0)==65535|(g|0)==-1)){v[b+8>>2]=g;v[b+16>>2]=2;u[b+12>>1]=c}c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;mu(d+48|0,e,f?7:1,d);h=a,i=A[VO(d+48|0)>>3],A[h+16>>3]=i;en(d+48|0);a=a+16|0}gb=d- -64|0;return+A[a>>3]}function Lda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{if((Qf(a)|0)==(b|0)){if((Qf(a+12|0)|0)==(c|0)){break b}}v[22640]=0;R(1538,a|0,b|0);d=v[22640];v[22640]=0;c:{d:{if((d|0)==1){break d}v[22640]=0;e=a+12|0;R(1538,e|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break d}v[22640]=0;f=a+24|0;R(1539,f|0,b|0);d=v[22640];v[22640]=0;if((d|0)==1){break d}v[22640]=0;g=a+36|0;R(1539,g|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break d}if(b){d=0;while(1){h=Gn(a,d);i=Mb(f,d),j=h,v[i>>2]=j;d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break c}return 1}b=V(88880)|0;if((O()|0)!=(ea(88880)|0)){break a}Z(b|0)|0;eN(a);dN(a);b=a+12|0;eN(b);dN(b);b=a+24|0;Cg(b);cN(b);a=a+36|0;Cg(a);cN(a);$();return 0}a=0;while(1){b=Gn(e,a);i=Mb(g,a),j=b,v[i>>2]=j;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}S(b|0);L()}function qt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Hf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Gf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=v[Ug(a,c,f)>>2];i=sy(g,c,f),j=C(C(h|0)*C(7.450580596923828e-9)),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}ba(2959,6225,36,5969);L()}ba(2989,6225,35,5969);L()}ba(4217,6225,34,5969);L()}ba(4252,6225,33,5969);L()}gb=b- -64|0}function mW(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-48|0;gb=b;f=b,g=Xb(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788|0,v[f+8>>2]=g;v[b+12>>2]=0;f=b,g=Xb(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24)),v[f+16>>2]=g;v[b+20>>2]=0;d=b;c=b;if(Xb(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))){e=Xb(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))}else{e=52}v[c+24>>2]=e;v[d+28>>2]=0;a=Xb(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24));v[b+44>>2]=4;v[b+32>>2]=a+80;v[b+36>>2]=0;v[b+40>>2]=b+8;a=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=a;d=gb-16|0;gb=d;a=v[b>>2];e=v[b>>2]+(v[b+4>>2]<<3)|0;a:{if((a|0)==(e|0)){break a}c=a+8|0;if((e|0)==(c|0)){break a}while(1){a=iw(a,c)?c:a;c=c+8|0;if((e|0)!=(c|0)){continue}break}}gb=d+16|0;gb=b+48|0;b=v[a>>2];d=b-52|0;jb=v[a+4>>2]-(b>>>0<52)|0;return d}function pt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Hf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Gf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Ug(a,c,f);i=qy(g,c,f),j=C(C(v[h>>2])*C(7.450580596923828e-9)),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}ba(2959,6225,36,5969);L()}ba(2989,6225,35,5969);L()}ba(4217,6225,34,5969);L()}ba(4252,6225,33,5969);L()}gb=b- -64|0}function lfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;f=c+32|0;Xc(b,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));h=ad(a);f=c+28|0;a=f;e=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=0;v[22640]=0;R(1430,h|0,e|0);e=v[22640];v[22640]=0;if((e|0)!=1){a:{e=f;b:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break b}e=c+4|0;while(1){v[22640]=0;c=Q(228,b|0,4)|0;i=v[22640];v[22640]=0;if((i|0)==1){break a}if(!c){break b}c=w[e|0]|w[e+1|0]<<8;v[22640]=0;c=Q(1431,b|0,c|0)|0;i=v[22640];v[22640]=0;c:{if((i|0)!=1){v[g+12>>2]=c;if(Cc(d)>>>0<=c>>>0){break c}v[22640]=0;R(1432,h|0,g+12|0);c=v[22640];v[22640]=0;if((c|0)!=1){break c}}break a}a=a+1|0;c=f;if(a>>>0<(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){continue}break}}gb=g+16|0;return}}a=P()|0;O()|0;Lc(h);S(a|0);L()}function q$(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-192|0;gb=b;Vf(b+16|0,a);v[22640]=0;R(141,b+32|0,b+16|0);a=v[22640];v[22640]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22640]=0;a=W(142,b+48|0,b+32|0,8)|0;c=v[22640];v[22640]=0;if((c|0)==1){break e}vb(b+32|0);vb(b+16|0);c=v[v[a>>2]-12>>2];v[22640]=0;d=fa(121)|0;e=v[22640];v[22640]=0;if((e|0)==1){break c}v[22640]=0;U(122,b+8|0,c+(b+48|0)|0,d|0);c=v[22640];v[22640]=0;if((c|0)==1){break c}Vb(b+8|0);v[22640]=0;c=uJ(a);d=v[22640];v[22640]=0;if((d|0)==1){break c}v[22640]=0;c=Q(147,c|0,b+32|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}d=v[v[c>>2]-12>>2];v[22640]=0;c=_l(c+d|0);d=v[22640];v[22640]=0;if((d|0)==1){break c}d=v[b+32>>2];tf(a);gb=b+192|0;a=c?0:d;break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break b}c=P()|0;O()|0;tf(a)}S(c|0);L()}return a|0}function M3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=gb-32|0;gb=f;a:{b:{c:{if((b|0)!=(c|0)){j=v[115121];v[115121]=0;g=gb-16|0;gb=g;xe();h=gb-16|0;gb=h;e=gb-16|0;gb=e;Kx(e,b,f+28|0,2);b=v[e+4>>2];v[h>>2]=v[e>>2];v[h+4>>2]=b;b=h;h=v[e+12>>2];v[b+8>>2]=v[e+8>>2];v[b+12>>2]=h;gb=e+16|0;e=v[b+4>>2];v[g>>2]=v[b>>2];v[g+4>>2]=e;e=g;g=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=g;gb=b+16|0;b=v[e+4>>2];v[f>>2]=v[e>>2];v[f+4>>2]=b;b=v[e+12>>2];v[f+8>>2]=v[e+8>>2];v[f+12>>2]=b;gb=e+16|0;e=v[f+8>>2];g=v[f+12>>2];h=v[f>>2];i=v[f+4>>2];b=v[115121];if(!b){break c}if(v[f+28>>2]!=(c|0)){break b}k=h;l=i;m=e;n=g;if((b|0)!=68){break a}break b}v[d>>2]=4;break a}v[115121]=j;if(v[f+28>>2]==(c|0)){break a}}v[d>>2]=4;h=k;i=l;e=m;g=n}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=e;v[a+12>>2]=g;gb=f+32|0}function Yea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;td(b,4);u[b+30>>1]=w[a+12|0]<<2;sg(b+30|0,256);c=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=c;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=e;c=a+8|0;v[b+8>>2]=e+(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));a=a+14|0;if(w[a|0]&16){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}if(w[a|0]&32){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}a:{if(!(w[a|0]&3)|y[b+8>>2]<=y[b+4>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(!(w[a|0]&2)){break a}u[b+34>>1]=x[b+34>>1]|4}a=Tb(d,18693);v[22640]=0;Q(335,b+43|0,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){vb(a);gb=d+16|0;return}b=P()|0;O()|0;vb(a);S(b|0);L()}function O7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;e=nc(a);f=b+24|0;a=v[f>>2];v[22640]=0;a=sq(a+484344|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)==1){break c}v[22640]=0;R(1427,e|0,a|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}a=0;d:{e:{f:{g:{while(1){c=v[f>>2];v[22640]=0;c=sq(c+484344|0);g=v[22640];v[22640]=0;if((g|0)==1){break b}if(a>>>0>=c>>>0){break d}c=_b(v[f>>2]+484344|0,a);v[22640]=0;R(2098,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;U(2092,d+16|0,b|0,d|0);c=v[22640];v[22640]=0;if((c|0)==1){break g}v[22640]=0;R(1429,e|0,d+16|0);c=v[22640];v[22640]=0;if((c|0)==1){break f}a=a+1|0;vb(d+16|0);vb(d);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;vb(d+16|0)}vb(d);break a}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}vd(e);S(a|0);L()}function _fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];c=v[Fb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=i*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Wf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;h=a;f=re(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=h,k=Sc(g),u[j>>1]=k;z[e+12>>2]=i*(l(2,w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Wf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;h=a;f=re(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=h,k=Sc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return c<<3}function K8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=gb-16|0;gb=g;v[g+12>>2]=c;c=gb+-64|0;gb=c;m=c;j=c+16|0;k=gb-16|0;gb=k;n=xO(k+8|0);while(1){e=b;h=gb+-64|0;gb=h;d=n;f=v[d+4>>2]-v[d>>2]|0;a:{if(!f){d=v[d>>2];break a}f=f+1|0;if(!f){d=pK(qK(h+8|0,e,32));break a}i=e;e=E(f);e=qK(h+8|0,i,(f&-1>>>e+1?32:31)-e|0);while(1){i=pK(e);if(f>>>0<=i>>>0){continue}break}d=v[d>>2]+i|0}gb=h- -64|0;o=ci(j,l),p=d,v[o>>2]=p;l=l+1|0;if((l|0)!=12){continue}break}gb=k+16|0;d=IO(m,j,NO(j));v[22640]=0;b=a;Iz(b,d,0);e=v[22640];v[22640]=0;b:{if((e|0)!=1){Lc(d);gb=c- -64|0;break b}a=P()|0;O()|0;Lc(d);S(a|0);L()}c=b+120|0;oK(c,b,g+12|0);t[c+20|0]=1;v[22640]=0;R(2111,b|0,v[g+12>>2]);b=v[22640];v[22640]=0;c:{if((b|0)!=1){gb=g+16|0;break c}a=P()|0;O()|0;ho(c);S(a|0);L()}return a|0}function GM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-16|0;gb=g;ti(g+8|0,b);c=g;b=v[c+12>>2];f=v[c+8>>2];v[c>>2]=f;v[c+4>>2]=b;f=gb-32|0;gb=f;e=v[c+4>>2];b=f;c=v[c>>2];v[b+8>>2]=c;v[b+12>>2]=e;v[b+16>>2]=c;v[b+20>>2]=e;Lh(b+24|0,b+8|0);c=v[b+28>>2];v[b>>2]=v[b+24>>2];v[b+4>>2]=c;c=b;e=gb-16|0;gb=e;d=v[a+8>>2];b=v[a+12>>2];a:{if((b|0)<0){break a}if(j=1,k=(m=xb(a)>>>0<d>>>0,n=0,o=(b|0)>=0,o?m:n),l=(b|0)>0,l?j:k){break a}d=xb(a);h=v[a+8>>2];i=0-((d>>>0<h>>>0)+v[a+12>>2]|0)|0;b=e;v[b+8>>2]=d-h;v[b+12>>2]=i;j=b,k=xb(c),v[j>>2]=k;v[b+4>>2]=0;b=iv(b+8|0,b);b=jC(v[b>>2],v[b+4>>2]);if((b|0)!=(xb(c)|0)){break a}Bg(v[c>>2],v[c>>2]+b|0,zb(v[a>>2]+v[a+8>>2]|0));c=a;d=b+v[c+8>>2]|0;a=v[c+12>>2];v[c+8>>2]=d;v[c+12>>2]=b>>>0>d>>>0?a+1|0:a}gb=e+16|0;gb=f+32|0;gb=g+16|0}function yH(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=vx(11225);if(w[b|0]?b:0){break a}b=vx(B(a,12)+79232|0);if(w[b|0]?b:0){break a}b=vx(11472);if(w[b|0]?b:0){break a}b=11995}b:{while(1){e=w[b+c|0];if(!(!e|(e|0)==47)){e=15;c=c+1|0;if((c|0)!=15){continue}break b}break}e=c}d=11995;c:{d:{c=w[b|0];e:{f:{if(!(w[b+e|0]|(c|0)==46)){d=b;if((c|0)!=67){break f}}if(!w[d+1|0]){break e}}if(!uj(d,11995)){break e}if(uj(d,10880)){break d}}if(!a){c=74596;if(w[d+1|0]==46){break c}}return 0}c=v[115927];if(c){while(1){if(!uj(d,c+8|0)){break c}c=v[c+24>>2];if(c){continue}break}}c=v[115927];if(c){while(1){if(!uj(d,c+8|0)){return c}c=v[c+24>>2];if(c){continue}break}}c=Ad(28);g:{if(!c){c=0;break g}v[c+4>>2]=20;v[c>>2]=74576;b=c+8|0;hc(b,d,e);t[b+e|0]=0;v[c+24>>2]=v[115927];v[115927]=c}c=a|c?c:74596}return c}function fN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-16|0;gb=d;a:{if(Nb(a)>>>0>511){break a}if(!Tf(v[v[b>>2]-12>>2]+b|0)){break a}j=d;g=b;h=c;f=gb-16|0;gb=f;e=rf(64);v[22640]=0;i=T(1323,e|0)|0;k=v[22640];v[22640]=0;b:{c:{if((k|0)!=1){e=is(f,i);i=v[e>>2];v[22640]=0;g=W(1533,i|0,g|0,h|0)|0;h=v[22640];v[22640]=0;d:{e:{if((h|0)!=1){if((g|0)==1){break e}Rz(f+8|0);break d}a=P()|0;O()|0;Dg(e);break c}ni(f+8|0,e)}Dg(e);gb=f+16|0;g=v[f+8>>2];break b}a=P()|0;O()|0;Zb(e)}S(a|0);L()}v[j+8>>2]=g;f:{g:{if(!Bd(d+8|0)){v[22640]=0;b=Q(1531,b|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break g}v[d>>2]=b;bX(d+8|0,$d(d));Dg(d)}if(!Bd(d+8|0)){break f}l=v[d+8>>2];v[22640]=0;R(1532,a|0,d+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){break f}}a=P()|0;O()|0;Dg(d+8|0);S(a|0);L()}Dg(d+8|0)}gb=d+16|0;return l}function sma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-528|0;gb=d;c=-1;a:{if(!Rf(a,1468)){break a}Tl(a,1464);EV(a,d+524|0);if(!je(d+524|0,33570)){c=0;if(!je(d+524|0,12670)){break a}}Tl(a,20);b=1;while(1){c=-1;if(!BV(a,d)){break a}e=TB(d)+e|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}c=0;if(e>>>0>40){break a}e=d+520|0;c=gb-32|0;gb=c;b=a;b:{if(Rf(a,2)){Bn(c+24|0,e);e=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=e;LB(c+16|0,b,c+8|0);break b}t[c+16|0]=0;YD(e,c+16|0)}gb=c+32|0;e=md(d+520|0);c=0;if(w[d+520|0]>128){break a}b=d;c=gb-32|0;gb=c;c:{if(Rf(a,512)){qD(c+24|0,b);f=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=f;LB(c+16|0,a,c+8|0);break c}hV(b)}gb=c+32|0;a=d+512|0;c=w[e|0];d:{while(1){if(c>>>0<w[b|0]){break d}b=b+1|0;if((a|0)!=(b|0)){continue}break}c=1;break a}c=0}gb=d+528|0;return c|0}function By(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0);g=gb-96|0;gb=g;h=a+24|0;Bq(v[h>>2]);t[v[h>>2]+1298380|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=ig(g+32|0,g+80|0,hL(g+80|0),b);e=v[a+32>>2];j=z[a+48>>2];v[g+8>>2]=v[c+8>>2];d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[g+8>>2];c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;f=g+48|0;c=f;tt(c);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=56852;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=56056;gb=d+16|0;a:{if(!b){break a}while(1){c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;c=Dt(c,v[Qk(g+24|0,g+16|0)>>2],f);i=c+i|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|i)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=g+96|0;return i}function Ay(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0);g=gb-96|0;gb=g;h=a+24|0;Bq(v[h>>2]);t[v[h>>2]+1298380|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=ig(g+32|0,g+80|0,hL(g+80|0),b);e=v[a+32>>2];j=z[a+48>>2];v[g+8>>2]=v[c+8>>2];d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[g+8>>2];c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;f=g+48|0;c=f;tt(c);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=57696;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=56932;gb=d+16|0;a:{if(!b){break a}while(1){c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;c=Dt(c,v[Qk(g+24|0,g+16|0)>>2],f);i=c+i|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|i)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=g+96|0;return i}function zW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;t[g+14|0]=d;t[g+15|0]=c;t[g+13|0]=e;t[g+12|0]=f;if((d-1&255)>>>0<=5){t[g+14|0]=d+15}xW(g+15|0,g+13|0);xW(g+14|0,g+12|0);a:{if(w[g+15|0]==10){t[g+13|0]=w[g+13|0]&15?-1:w[g+12|0];if(w[g+14|0]!=10){break a}t[g+14|0]=0;break a}if(w[g+14|0]!=10){break a}t[g+12|0]=w[g+12|0]&15?-1:0}if(b){t[a+2|0]=1;t[a+4|0]=b+2>>>2}dz(g+15|0,g+13|0,g+14|0,g+12|0);c=w[g+15|0];b:{if(!c){break b}d=w[g+14|0];if(!d){t[g+14|0]=c;t[g+12|0]=w[g+13|0];t[g+15|0]=0;break b}if(!((c|0)==20|(c|0)!=(d|0))){t[g+15|0]=0;break b}if(!b){so(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);t[a+2|0]=w[g+15|0];t[a+4|0]=w[g+13|0];break b}if(to(c)>>>0<=to(w[g+14|0])>>>0){break b}Dh(g+15|0,g+14|0);Dh(g+13|0,g+12|0)}t[a+3|0]=w[g+14|0];t[a+5|0]=w[g+12|0];gb=g+16|0}function zj(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-48|0;gb=d;e=a+24|0;f=v[v[e>>2]+24620>>2];a:{if(!((f|0)!=(b|0)|v[v[e>>2]+24624>>2]!=(c|0))){if(w[a+29|0]){break a}DO(v[e>>2],1);break a}hc(d+8|0,v[e>>2]+24604|0,40);g=v[d+40>>2];h=v[d+44>>2];v[d+28>>2]=c;v[d+24>>2]=b;Ft(d+8|0,g);Ko(d+8|0,h);Jz(v[e>>2],d+8|0);if((b|0)==(f|0)){break a}b=v[e>>2];f=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];b:{if(!b){break b}if(!(kb[v[v[b>>2]+116>>2]](b)|0)){break b}kb[v[v[b>>2]+108>>2]](b,0);kb[v[v[b>>2]+96>>2]](b);kb[v[v[b>>2]+124>>2]](b)}c=c+160|0;if((f|0)!=(c|0)){continue}break}b=v[e>>2];e=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];c:{if(!b){break c}if(kb[v[v[b>>2]+116>>2]](b)|0){break c}kb[v[v[b>>2]+108>>2]](b,1);kb[v[v[b>>2]+120>>2]](b)}c=c+160|0;if((e|0)!=(c|0)){continue}break}}t[a+29|0]=1;gb=d+48|0}function Nn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;h=a;a=gb-16|0;gb=a;i=a;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);f=Jb(d);j=Ab(d);k=v[b>>2];v[22640]=0;Ht(e+8|0,c,f+j|0,k);c=v[22640];v[22640]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22640]=0;v[e+4>>2]=c;c=wf(e+4|0);f=v[22640];v[22640]=0;if((f|0)!=1){v[22640]=0;U(117,d|0,c|0,0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22640]=0;R(118,d|0,b-c|0);b=v[22640];v[22640]=0;if((b|0)!=1){v[22640]=0;R(128,i|0,d|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22640]=0;R(127,h|0,a|0);b=v[22640];v[22640]=0;d:{if((b|0)!=1){vb(a);gb=a+16|0;break d}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=g+16|0}function Vfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-32|0;gb=g;j=g,k=br(b),v[j+16>>2]=k;c=gb-32|0;gb=c;f=b;d=a;b=Vd(d);e=ec(d);a:{b:{if(b){wb(d);c:{while(1){d:{d=b+14|0;e:{if(qP(f,d)){if(!v[b>>2]){break b}e=b;break e}if(!qP(d,f)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=e;break a}v[c+28>>2]=b;b=e;break a}b=ec(d)}v[c+28>>2]=b}e=b;b=v[b>>2];t[c+27|0]=0;if(!b){d=gb-16|0;gb=d;b=ec(a);i=Pj(c+8|0,YB(),Qj(d+8|0,b));b=v[i>>2];f=gb-16|0;gb=f;v[f+8>>2]=v[g+16>>2];h=v[f+8>>2];h=x[h>>1]|x[h+2>>1]<<16;u[b+18>>1]=0;u[b+14>>1]=h;u[b+16>>1]=h>>>16;gb=f+16|0;j=ec(i),k=1,t[j+4|0]=k;gb=d+16|0;Ak(a,v[c+28>>2],e,v[c+8>>2]);b=$d(c+8|0);t[c+27|0]=1;ZB(c+8|0)}Rj(g+24|0,yc(c+8|0,b),c+27|0);gb=c+32|0;a=Vl(g+24|0);gb=g+32|0;return a+4|0}function R6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Hf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Gf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=Tg(a,c,f);i=qy(g,c,f),j=C(A[h>>3]),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}ba(2959,6225,80,5936);L()}ba(2989,6225,79,5936);L()}ba(4217,6225,78,5936);L()}ba(4252,6225,77,5936);L()}gb=b- -64|0}function $6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);b=gb+-64|0;gb=b;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[b+40>>2]=v[a+20>>2];c=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=c;Hf(b+48|0,b+32|0,e);a=v[d+4>>2];d=v[a+4>>2];e=v[a+8>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;g=b+16|0;a=b;a:{if(d>>>0<=y[b+4>>2]){if(d>>>0<=y[g+4>>2]){if(e>>>0<=y[a+8>>2]){if(Gf(g)>>>0>=e>>>0){if(e){while(1){c=0;if(d){while(1){h=A[Tg(a,c,f)>>3];i=sy(g,c,f),j=C(h),z[i>>2]=j;c=c+1|0;if((d|0)!=(c|0)){continue}break}}f=f+1|0;if((e|0)!=(f|0)){continue}break}}break a}ba(2959,6225,80,5936);L()}ba(2989,6225,79,5936);L()}ba(4217,6225,78,5936);L()}ba(4252,6225,77,5936);L()}gb=b- -64|0}function uV(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;d=b+20|0;while(1){f=c;c=t[b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}a:{if(c>>>0>5){break a}while(1){b=0;d=B(g,30)+a|0;e=d+20|0;j=e+22|0;while(1){f=b;b=t[e|0];b=f+((b&255)!=0&(b|0)<32)|0;e=e+1|0;if((j|0)!=(e|0)){continue}break}c=b+c|0;if(w[d+44|0]|(c>>>0>48|w[d+45|0]>64)){break a}if(Ib(w[d+42|0]|w[d+43|0]<<8)>>>0>32768){break a}h=Ib(w[d+42|0]|w[d+43|0]<<8)+h|0;i=w[d+45|0]|i;g=g+1|0;if((g|0)!=15){continue}break}if(!h|!(i&255)|w[a+470|0]>128|w[a+471|0]>220){break a}b=a+472|0;d=b+128|0;b:{if((b|0)==(d|0)){break b}c=b+1|0;if((d|0)==(c|0)){break b}while(1){b=w[b|0]<w[c|0]?c:b;c=c+1|0;if((d|0)!=(c|0)){continue}break}}b=w[b|0];if(b>>>0>63|!(b|w[a+470|0]?1:w[a+471|0])){break a}k=1}return k}function eja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){m=f>>>18|0;g=((((g&2147483647)<<1|f>>>31)&2147483646)<<1)+l|0;h=0;b=1;while(1){k=h<<1;f=u[k+g>>1];v[(e+8|0)+(h<<2)>>2]=f+((B(u[(k|4)+g>>1]-f|0,m)|0)/16384|0);f=b;b=0;h=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(h,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];g=v[e+28>>2];continue}break}f=v[e+24>>2];g=v[e+28>>2];break a}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=f;v[a+4>>2]=g;gb=e+32|0}function Qba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;h=f;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){g=Jb(d);i=Jb(d);j=Ab(d);k=v[b+4>>2];c=v[b>>2];v[22640]=0;Oa(120,e+8|0,g|0,i+j|0,c|0,k|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22640]=0;v[e+4>>2]=c;c=wf(e+4|0);g=v[22640];v[22640]=0;if((g|0)!=1){v[22640]=0;U(117,d|0,c|0,0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22640]=0;R(118,d|0,b-c|0);b=v[22640];v[22640]=0;if((b|0)!=1){v[22640]=0;R(119,h|0,d|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22640]=0;R(114,a|0,f|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(f);gb=f+16|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function Lma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=gb-16|0;gb=e;t[e+15|0]=0;u[e+12>>1]=0;if(d){f=4;l=B(c,d);o=(l|0)<1;while(1){if(!o){j=b+k|0;p=l+j|0;while(1){t[e+11|0]=0;IV(a,e+15|0,e+12|0,e+11|0);a:{if(!f){h=w[e+11|0];break a}h=w[e+11|0];c=x[e+12>>1];i=f;b:{while(1){g=c<<1;c=g&254;c:{if(c){g=(g&65534)>>>0>255;break c}if(!kf(a,e+10|0)){break b}c=w[e+10|0];g=c>>>7|0;c=c<<1&254|1}h=h<<1|g;i=i-1|0;if(i&255){continue}break}u[e+12>>1]=c;break a}u[e+12>>1]=0}g=h&255;if(g>>>0<=3){c=f+1|0}else{c=7;while(1){i=c;m=c&255;if(!(g>>>m&1)){c=i-1|0;if(m>>>0>1){continue}}break}c=f+i|0}f=h&1;t[e+15|0]=f;n=(f-1^(h&254)>>>1)+n|0;t[j|0]=n;f=(c&254)>>>1|0;j=d+j|0;if(p>>>0>j>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}gb=e+16|0}function hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-32|0;gb=d;v[d+24>>2]=c>>>3;v[d+16>>2]=v[a>>2];j=v[Fb(d+24|0,d+16|0)>>2];b=zb(b);if(j){a=v[a+20>>2];c=j;while(1){k=0;e=b;g=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);f=g<<24|h>>>8;e=0;l=f&65280;f=e;e=g<<8|h>>>24;f=f|k;k=e&255|l|(h<<24|h<<8&16711680);v[d+24>>2]=((g&255)<<24|h>>>8)&-16777216|((g&16777215)<<8|h>>>24)&16711680|(g>>>8&65280|g>>>24)|f;v[d+28>>2]=k;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;i=A[$g(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=i;e=a;i=fe(i);a:{if(D(i)<2147483648){f=~~i;break a}f=-2147483648}m=e,n=Sc(f),u[m>>1]=n;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+32|0;return j<<3}function Cea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;c=Hi(a);if(b){c=B(b,c);a:{b:{if(v[a+12>>2]!=(b|0)){break b}if((Eg(a)|0)!=(c|0)){break b}b=gb-16|0;gb=b;c=Sb(a);d=Wb(a);gi(b+8|0);a=gb-16|0;gb=a;v[a>>2]=d;v[a+8>>2]=c;d=St(a,a+8|0);g=gb-16|0;gb=g;v[g+8>>2]=c;if((d|0)>=1){while(1){c=v[g+8>>2];e=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[c|0]=e;t[c+1|0]=e>>>8;t[c+2|0]=e>>>16;t[c+3|0]=e>>>24;e=w[b+12|0]|w[b+13|0]<<8;t[c+4|0]=e;t[c+5|0]=e>>>8;c=(d|0)>1;Wj(g+8|0);d=d-1|0;if(c){continue}break}}gb=g+16|0;gb=a+16|0;gb=b+16|0;break a}gi(f+8|0);c=iX(f+16|0,c,f+8|0);IN(a);ip(a,c);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];d=v[wb(c)>>2];h=wb(a),i=d,v[h>>2]=i;h=wb(c),i=0,v[h>>2]=i;v[c>>2]=0;v[c+4>>2]=0;kn(c);v[a+12>>2]=b}a=1}else{a=0}gb=f+32|0;return a|0}function zO(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;g=-1;a:{if(!Bz(a,b,2)){break a}h=v[b+656>>2];f=a+1074312|0;Db(e+8|0,f,31);b:{if(Cb(e+8|0)){d=v[b+740>>2];if(d){break b}break a}d=v[b+740>>2]}Db(e+8|0,f,31);f=d-Cb(e+8|0)|0;d=v[a+480180>>2];d=(d|0)==4096?64:(d|0)==16384?192:512;d=Zq(h+88|0,f,d,v[a+480180>>2]==4096?255:64)-(d>>>1|0)|0;if(w[b+746|0]&16){g=Oq(a,b,!(v[b+88>>2]&32768),d);break a}if(Hj(b)){if((d|0)==u[b+772>>1]){break a}i=b,j=Sc(d),u[i+772>>1]=j;t[b+851|0]=w[b+851|0]|32;break a}b=qk(a);v[e+8>>2]=d;f=c;c:{if((d|0)<=-1){v[e+8>>2]=0-d;Zj(e+8|0,255);a=(v[e+8>>2]<<2)+(b?44976:43952)|0;break c}Zj(e+8|0,255);a=(v[e+8>>2]<<2)+(b?43952:44976)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];i=f,j=zc(nqa(mqa(b,d,a,a>>31),jb,65536,0),jb),v[i>>2]=j}gb=e+16|0;return g}function Rp(a){var b=C(0),c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=qi(+a);break a}if(d>>>0<=1081824209){f=+a;if(d>>>0>=1075235812){b=C(-qi(((e|0)>-1?-3.141592653589793:3.141592653589793)+f));break a}if((e|0)<=-1){b=ri(f+1.5707963267948966);break a}b=ri(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=qi(((e|0)>-1?-6.283185307179586:6.283185307179586)+ +a);break a}if((e|0)<=-1){b=ri(-4.71238898038469-+a);break a}b=ri(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(Vx(a,c+8|0)&3){case 0:b=qi(A[c+8>>3]);break a;case 1:b=ri(-A[c+8>>3]);break a;case 2:b=C(-qi(A[c+8>>3]));break a;default:break b}}b=ri(A[c+8>>3])}a=b;gb=c+16|0;return a}function sN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=C(0),l=0,m=C(0);f=gb-16|0;gb=f;g=u[d>>1];e=u[d+2>>1];if(!(!x[b>>1]|(g|0)>(e|0)|(!(z[c>>2]>C(0))|(e-g|0)>32766))){u[a>>1]=3;h=a+4|0;Cg(h);u[a+28>>1]=65472;v[f+12>>2]=1065353216;vN(h,f+12|0);v[a+32>>2]=0;u[a+30>>1]=0;Cg(a+16|0);u[a+28>>1]=x[d>>1];g=a;e=gb-16|0;gb=e;u[e+14>>1]=x[b>>1];v[22640]=0;u[e+12>>1]=32767;b=Oc(e+14|0,e+12|0);j=v[22640];v[22640]=0;a:{if((j|0)!=1){gb=e+16|0;b=u[b>>1];break a}V(0)|0;O()|0;Bb();L()}u[g+30>>1]=b;i=C(D(z[c>>2]));z[a+32>>2]=i;i=me(i,C(C(1)/C(u[a+30>>1])));j=1;El(h,(u[d+2>>1]-u[d>>1]|0)+1|0);b=u[d>>1];if((b|0)<=u[d+2>>1]){while(1){k=me(i,C(b|0));l=Mb(h,b-u[a+28>>1]|0),m=k,z[l>>2]=m;c=u[d+2>>1]>(b|0);b=b+1|0;if(c){continue}break}}rq(a)}gb=f+16|0;return j|0}function LL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;f=Jb(b);d=Ab(b);h=Jb(c);i=Ab(c);g=d+f|0;d=-1;a:{while(1){if((f|0)==(g|0)){break a}g=g-1|0;if(vp(h,i,g)){continue}break}d=g-f|0}b:{c:{if((d|0)!=-1){k=e,l=wd(b),v[k+16>>2]=l;k=e,l=we(e+16|0,d),v[k+24>>2]=l;k=e,l=we(e+24|0,1),v[k+32>>2]=l;c=Fd(e+40|0,e+32|0);k=e,l=df(b),v[k>>2]=l;d=Fd(e+8|0,e);dG(b,v[c>>2],v[d>>2]);break c}if(!Ab(b)){break c}i=Jb(b);f=Ab(b);d=Jb(c);c=Ab(c);if(!c|!f){c=-1}else{g=d;j=c+d|0;d=i;f=f+d|0;d:{if((d|0)==(f|0)){break d}c=f;while(1){h=g;if((j|0)!=(g|0)){while(1){if(kb[26](t[d|0],t[h|0])|0){break d}h=h+1|0;if((j|0)!=(h|0)){continue}break}}d=d+1|0;if((c|0)!=(d|0)){continue}break}d=c}c=(d|0)==(f|0)?-1:d-i|0}if(c){break c}Kb(a);break b}Dc(a,b)}gb=e+48|0}function fja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;i=v[a+40>>2];j=v[a+36>>2];k=v[a+16>>2];b=v[a+4>>2];h=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){l=f>>>10&4194048;h=(((h&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[h+g|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[e+12>>2]);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];h=v[e+28>>2];continue}break}f=v[e+24>>2];h=v[e+28>>2];break a}g=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=f;v[a+4>>2]=h;gb=e+32|0}function fZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-208|0;gb=e;d=a;if(!Rv(c,a)){t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0}ED(c,e+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}c=e;d=gb-16|0;gb=d;v[d+12>>2]=64;v[22640]=0;v[d+8>>2]=255;f=Fb(d+12|0,d+8|0);g=v[22640];v[22640]=0;b:{if((g|0)!=1){gb=d+16|0;d=w[f|0];break b}V(0)|0;O()|0;Bb();L()}t[c+12|0]=d;hh(b,w[ac(a+4|0,e+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;if(!Nb(b)){break a}a=0;while(1){if(a){c=x[Mb(b,a-1|0)>>1];v[e+12>>2]=1;d=(e+16|0)+B(a,3)|0;v[e+8>>2]=(t[d+1|0]&1)<<8|w[d|0];d=x[Nf(e+12|0,e+8|0)>>1];h=Mb(b,a),i=c+d|0,u[h>>1]=i}c=w[((e+16|0)+B(a,3)|0)+2|0];h=Mb(b,a),i=c,t[h+2|0]=i;a=a+1|0;if(Nb(b)>>>0>a>>>0){continue}break}}gb=e+208|0}function Bo(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=v[b+88>>2];c=e|2048;v[b+88>>2]=c;f=v[b+656>>2];if(!(!f|t[b+730|0]&1)){c=e|6144;v[b+88>>2]=c}a:{if(!v[b+76>>2]){break a}b:{if(!(c&8)){break b}d=v[b+104>>2];if(!d|e&2048){break b}e=x[d+34>>1];if(e&2){v[b+88>>2]=(e&4?c|4:c&-135)|2;c=v[d>>2];v[b+76>>2]=c;e=v[d+4>>2];v[b+80>>2]=e;d=v[d+8>>2];v[b+84>>2]=d;if(c>>>0>d>>>0){v[b+76>>2]=d;g=d}else{g=c}c=v[b+4>>2];if(g>>>0>=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=((c-e>>>0)%(d-e>>>0)|0)+e;break b}v[b+88>>2]=c&-135;v[b+76>>2]=v[d>>2]}if(!f){break a}if(!(!(v[a+480180>>2]&1064964?1:w[f+60|0]&2)|!v[f>>2])){v[b+88>>2]=v[b+88>>2]|4096}if(w[f+65|0]==255|x[b+728>>1]!=65535){break a}a=f+48|0;h=b,i=Sc(Zq(a,v[b+724>>2],256,64)),u[h+728>>1]=i;h=b,i=x[Mb(a,w[f+65|0])>>1],v[h+724>>2]=i}}function rG(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=ri(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<=-1){a=C(-qi(d+1.5707963267948966));break a}a=qi(d+-1.5707963267948966);break a}a=ri(-(((e|0)>-1?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){d=+a;if(c>>>0<=1085271519){if((e|0)<=-1){a=qi(d+4.71238898038469);break a}a=C(-qi(d+-4.71238898038469));break a}a=ri(((e|0)>-1?-6.283185307179586:6.283185307179586)+d);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(Vx(a,b+8|0)&3){case 0:a=ri(A[b+8>>3]);break a;case 1:a=qi(A[b+8>>3]);break a;case 2:a=ri(-A[b+8>>3]);break a;default:break b}}a=C(-qi(A[b+8>>3]))}gb=b+16|0;return a}function Uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){g=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;b=f>>>21&2040;l=u[b+46534>>1];m=u[b+46532>>1];n=u[b+46530>>1];o=u[b+46528>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+g>>1],n)+B(u[(f|-4)+g>>1],o)|0)+B(u[(f|4)+g>>1],m)|0)+B(u[(f|8)+g>>1],l)|0)/16384;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function nw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;t[f+15|0]=d;t[b+12|0]=w[b+12|0]&240|w[a|0]&15;g=a+1|0;hh(b,w[ac(g,f+15|0)|0]);d=w[ac(a+2|0,f+15|0)|0];t[b+13|0]=d;j=b,k=Jd(w[a+3|0],d,w[f+15|0]),t[j+14|0]=k;d=w[ac(a+4|0,f+15|0)|0];t[b+15|0]=d;j=b,k=Jd(w[a+5|0],d,w[f+15|0]),t[j+16|0]=k;t[f+14|0]=25;if(w[ac(f+14|0,g)|0]){d=0;while(1){e=B(d,3)+a|0;h=Lb(w[e+6|0]+c<<24>>24,0,64);j=Mb(b,d),k=h,t[j+2|0]=k;e=e+7|0;e=w[e|0]|w[e+1|0]<<8;j=Mb(b,d),k=e,u[j>>1]=k;a:{if(!d){break a}e=d-1|0;if(x[Mb(b,d)>>1]>=x[Mb(b,e)>>1]){break a}if(x[Mb(b,d)>>1]>255){break a}h=w[Mb(b,e)+1|0];i=Mb(b,d);u[i>>1]=x[i>>1]|h<<8;if(x[Mb(b,d)>>1]>=x[Mb(b,e)>>1]){break a}e=Mb(b,d);u[e>>1]=x[e>>1]+256}t[f+14|0]=25;d=d+1|0;if(d>>>0<w[ac(f+14|0,g)|0]){continue}break}}gb=f+16|0}function Pda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=Lz(c,a);wb(a);Vy(v[d+4>>2],b);v[d+4>>2]=v[d+4>>2]+4;$b(d);gb=c+16|0;return}f=gb-32|0;gb=f;d=wb(a);d=vo(f+8|0,kr(a,Nb(a)+1|0),Nb(a),d);Vy(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+4;b=a;tk(a);wb(a);c=d;h=c+4|0;e=h;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){g=v[e>>2];while(1){a=a-4|0;Vy(g-4|0,a);g=v[e>>2]-4|0;v[e>>2]=g;if((a|0)!=(i|0)){continue}break}}wc(b,h);wc(b+4|0,c+8|0);wc(wb(b),cc(c));v[c>>2]=v[c+4>>2];Lm(b,Nb(b));a=d;b=a;d=v[a+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-4|0;v[b+8>>2]=c;v[22640]=0;R(1333,e|0,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){Wh(v[a+16>>2],b,pk(a))}gb=f+32|0}function oJ(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);b=z[a+32>>2];c=z[a+8>>2];e=z[a+16>>2];f=C(C(b-c)+e);i=z[a>>2];j=z[a+24>>2];k=C(i-j);z[a+16>>2]=f+k;d=z[a+4>>2];g=z[a+20>>2];h=z[a+28>>2];l=C(C(d-C(g+h))*C(.8660253882408142));k=C(k-C(f*C(.5)));z[a+4>>2]=l+k;m=C(C(g+d)*C(.9848077297210693));f=C(z[a+12>>2]*C(.8660253882408142));n=C(C(h+d)*C(-.6427876353263855));o=C(C(m-f)+n);d=C(i+C(j*C(.5)));i=C(C(b+c)*C(.7660444378852844));b=C(C(e-b)*C(.1736481785774231));j=C(C(d-i)+b);z[a+12>>2]=o+j;z[a+20>>2]=j-o;z[a+28>>2]=k-l;g=C(C(g-h)*C(.3420201539993286));h=C(g-C(f+m));c=C(C(e+c)*C(.9396926164627075));b=C(C(d+c)-b);z[a+32>>2]=h+b;e=C(C(g+f)+n);c=C(C(d-c)+i);z[a+24>>2]=e+c;z[a+8>>2]=c-e;z[a>>2]=b-h}function iba(){var a=0,b=0,c=0,d=0,e=0;a=gb-48|0;gb=a;c=Kb(a+32|0);v[22640]=0;_(1916,a+16|0);b=v[22640];v[22640]=0;a:{b:{c:{d:{if((b|0)!=1){d=a,e=Sb(a+16|0),v[d+8>>2]=e;d=a,e=Wb(a+16|0),v[d>>2]=e;if(!Gb(a+8|0,a)){break c}while(1){e:{b=v[a+8>>2];v[22640]=0;Q(1183,c|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}sr(a+8|0);d=a,e=Wb(a+16|0),v[d>>2]=e;if(!Gb(a+8|0,a)){break c}v[22640]=0;Q(1917,c|0,11862)|0;b=v[22640];v[22640]=0;if((b|0)!=1){continue}}break}b=V(0)|0;O()|0;vd(a+16|0);break d}b=V(0)|0;O()|0}vb(c);Z(b|0)|0;b=0;v[22640]=0;Y(1911,4048,0,0,0);c=v[22640];v[22640]=0;if((c|0)==1){break a}$();break b}b=ie(Jb(c));vd(a+16|0);vb(c)}gb=a+48|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);c=v[22640];v[22640]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function QC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=a;a=gb-16|0;gb=a;h=a;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);f=Jb(d);i=Ab(d);j=v[b>>2];v[22640]=0;Cy(e+8|0,c,f+i|0,j);c=v[22640];v[22640]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22640]=0;v[e+4>>2]=c;c=wf(e+4|0);f=v[22640];v[22640]=0;if((f|0)!=1){v[22640]=0;U(117,d|0,c|0,0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22640]=0;R(118,d|0,b-c|0);b=v[22640];v[22640]=0;if((b|0)!=1){v[22640]=0;R(128,h|0,d|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22640]=0;R(127,g|0,a|0);b=v[22640];v[22640]=0;d:{if((b|0)!=1){vb(a);gb=a+16|0;break d}b=P()|0;O()|0;vb(a);S(b|0);L()}}function rs(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a=Kb(a);a:{b:{c:{switch(b|0){case 0:v[22640]=0;b=Q(2,d|0,12998)|0;c=v[22640];v[22640]=0;if((c|0)==1){break a}Eb(a,b);vb(b);break b;case 1:v[22640]=0;b=Q(2,d|0,13023)|0;c=v[22640];v[22640]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 2:v[22640]=0;b=Q(2,d|0,12971)|0;c=v[22640];v[22640]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 3:v[22640]=0;b=Q(2,d|0,12945)|0;c=v[22640];v[22640]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 4:v[22640]=0;b=Q(2,d|0,10361)|0;c=v[22640];v[22640]=0;if((c|0)!=1){Eb(a,b);vb(b);break b}break a;case 5:break c;default:break b}}v[22640]=0;b=Q(2,d|0,4286)|0;c=v[22640];v[22640]=0;if((c|0)==1){break a}Eb(a,b);vb(b)}gb=d+16|0;return}b=P()|0;O()|0;vb(a);S(b|0);L()}function v2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=ZG(c);b:{if(b){gl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;fl(k,a);break b}Es(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}jj(i,k);Hc(k);l=e,m=oj(a),v[l>>2]=m;l=f,m=nj(a),v[l>>2]=m;Qg(k,a);Eb(g,k);vb(k);Ph(k,a);jj(h,k);Hc(k);a=el(a);break a}a=YG(c);c:{if(b){gl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;fl(k,a);break c}Es(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}jj(i,k);Hc(k);l=e,m=oj(a),v[l>>2]=m;l=f,m=nj(a),v[l>>2]=m;Qg(k,a);Eb(g,k);vb(k);Ph(k,a);jj(h,k);Hc(k);a=el(a)}v[j>>2]=a;gb=k+16|0}function fla(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-192|0;gb=b;Vf(b+16|0,a);v[22640]=0;R(141,b+32|0,b+16|0);a=v[22640];v[22640]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22640]=0;a=W(142,b+48|0,b+32|0,8)|0;c=v[22640];v[22640]=0;if((c|0)==1){break e}vb(b+32|0);vb(b+16|0);c=v[v[a>>2]-12>>2];v[22640]=0;d=fa(121)|0;e=v[22640];v[22640]=0;if((e|0)==1){break c}v[22640]=0;U(122,b+8|0,c+(b+48|0)|0,d|0);c=v[22640];v[22640]=0;if((c|0)==1){break c}Vb(b+8|0);v[22640]=0;c=Q(143,a|0,b+32|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}d=v[v[c>>2]-12>>2];v[22640]=0;c=_l(c+d|0);d=v[22640];v[22640]=0;if((d|0)==1){break c}d=x[b+32>>1];tf(a);gb=b+192|0;a=(c?0:d)&65535;break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break b}c=P()|0;O()|0;tf(a)}S(c|0);L()}return a|0}function ega(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=C(0),h=C(0),i=0,j=C(0),k=0,m=0;f=gb-16|0;gb=f;k=f,m=B(v[a>>2],bd(a)),v[k>>2]=m;tc(f,c>>>2|0);c=zb(b);g=z[e+4>>2];e=v[f>>2];if(e){while(1){g=C(G(C(D((l(2,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),q()))),g));c=c+4|0;e=e-1|0;if(e){continue}break}}c=g==C(0);a:{if(c){break a}e=v[f>>2];if(!e){break a}j=c?C(1):C(C(1)/g);c=v[a+20>>2];while(1){z[f+12>>2]=j*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());v[f+8>>2]=-1082130432;v[f+4>>2]=1065353216;h=C(z[Wf(f+12|0,f+8|0,f+4|0)>>2]*C(32768));z[f+12>>2]=h;a=c;h=re(h);b:{if(C(D(h))<C(2147483648)){i=~~h;break b}i=-2147483648}k=a,m=Sc(i),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=g}gb=f+16|0;return v[f>>2]<<2}function pl(a){var b=0,c=0;b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[22640]=0;b=v[(b+c|0)+24>>2];c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[22640]=0;b=Tf(b+c|0);c=v[22640];v[22640]=0;if((c|0)==1){break a}if(!b){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(FH()){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[22640]=0;b=v[(b+c|0)+24>>2];c=v[22640];v[22640]=0;c:{if((c|0)==1){break c}v[22640]=0;b=T(2278,b|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[22640]=0;R(18,a+b|0,1);a=v[22640];v[22640]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;Z(a|0)|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function kga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];g=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(g){a=v[a+20>>2];c=g;while(1){v[d+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;e=C(z[Wf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=e;h=a;e=re(e);a:{if(C(D(e))<C(2147483648)){f=~~e;break a}f=-2147483648}i=h,j=Sc(f),u[i>>1]=j;v[d+12>>2]=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;e=C(z[Wf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=e;h=a;e=re(e);b:{if(C(D(e))<C(2147483648)){f=~~e;break b}f=-2147483648}i=h,j=Sc(f),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return g<<3}function ena(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-32|0;gb=f;j=f,k=$W(b),v[j+16>>2]=k;c=gb-32|0;gb=c;g=b;d=a;b=Vd(d);e=ec(d);a:{b:{if(b){d=wb(d);c:{while(1){d:{h=b+14|0;e:{if(BC(d,g,h)){if(!v[b>>2]){break b}e=b;break e}if(!AC(h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[c+28>>2]=b;b=e;break a}v[c+28>>2]=b;b=e;break a}b=ec(d)}v[c+28>>2]=b}e=b;b=v[b>>2];t[c+27|0]=0;if(!b){g=gb-16|0;gb=g;b=ec(a);h=Pj(c+8|0,YB(),Qj(g+8|0,b));d=v[h>>2];b=gb-16|0;gb=b;v[b+8>>2]=v[f+16>>2];i=x[v[b+8>>2]>>1];u[d+16>>1]=0;u[d+14>>1]=i;gb=b+16|0;j=ec(h),k=1,t[j+4|0]=k;gb=g+16|0;Ak(a,v[c+28>>2],e,v[c+8>>2]);b=$d(c+8|0);t[c+27|0]=1;ZB(c+8|0)}Rj(f+24|0,yc(c+8|0,b),c+27|0);gb=c+32|0;a=Vl(f+24|0);gb=f+32|0;return a+2|0}function Pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;td(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;d=a+40|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+44|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+151|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+49402|0]}t[c+39|0]=w[b+152|0];d=b+156|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+154|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+38|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}}function z2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=aH(c);b:{if(b){gl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;fl(k,a);break b}Es(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}Eb(i,k);vb(k);l=e,m=oj(a),t[l|0]=m;l=f,m=nj(a),t[l|0]=m;Qg(k,a);Eb(g,k);vb(k);Ph(k,a);Eb(h,k);vb(k);a=el(a);break a}a=$G(c);c:{if(b){gl(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;fl(k,a);break c}Es(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Oh(k,a)}Eb(i,k);vb(k);l=e,m=oj(a),t[l|0]=m;l=f,m=nj(a),t[l|0]=m;Qg(k,a);Eb(g,k);vb(k);Ph(k,a);Eb(h,k);vb(k);a=el(a)}v[j>>2]=a;gb=k+16|0}function nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0;g=gb-16|0;gb=g;j=a+44|0;if(ki(j)){p=g,q=Md(j,0),v[p+8>>2]=q;p=g,q=Md(j,1),v[p+12>>2]=q;p=g,q=kd(j,0),v[p>>2]=q;p=g,q=kd(j,1),v[p+4>>2]=q;if(d){k=d;while(1){e=0;l=1;while(1){h=e<<2;f=h+(g+8|0)|0;e=v[f>>2];v[f>>2]=e+4;f=a+h|0;m=f+4228|0;i=C(C(z[a+4236>>2]*z[m>>2])+C(z[a+4240>>2]*z[e>>2]));z[m>>2]=i;i=oM(C(i*C(1073741824)),w[a+4272|0],w[a+4273|0]);e=f+4244|0;n=z[a+4264>>2];f=f+4252|0;o=z[f>>2];i=C(C(i*z[a+4260>>2])-C(C(z[a+4268>>2]*z[e>>2])+C(n*o)));z[f>>2]=i;z[e>>2]=o+C(i*n);e=g+h|0;h=v[e>>2];v[e>>2]=h+4;z[h>>2]=i*C(9.313225746154785e-10);h=l;l=0;e=1;if(h){continue}break}k=k-1|0;if(k){continue}break}}Ci(a,b,c,kd(j,0),kd(j,1),d)}gb=g+16|0}function lq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;h=f;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);g=Jb(d);i=Ab(d);j=v[b>>2];v[22640]=0;Ht(e+8|0,c,g+i|0,j);c=v[22640];v[22640]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22640]=0;v[e+4>>2]=c;c=wf(e+4|0);g=v[22640];v[22640]=0;if((g|0)!=1){v[22640]=0;U(117,d|0,c|0,0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22640]=0;R(118,d|0,b-c|0);b=v[22640];v[22640]=0;if((b|0)!=1){v[22640]=0;R(119,h|0,d|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22640]=0;R(114,a|0,f|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(f);gb=f+16|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function kca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;h=f;e=gb-32|0;gb=e;d=Ge(e+16|0,1,0);a:{b:{c:{while(1){c=Jb(d);g=Jb(d);i=Ab(d);j=w[b|0];v[22640]=0;Ht(e+8|0,c,g+i|0,j);c=v[22640];v[22640]=0;if((c|0)==1){break b}if(!v[e+12>>2]){break c}c=Ab(d);v[22640]=0;v[e+4>>2]=c;c=wf(e+4|0);g=v[22640];v[22640]=0;if((g|0)!=1){v[22640]=0;U(117,d|0,c|0,0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}}break}break b}b=v[e+8>>2];c=Jb(d);v[22640]=0;R(118,d|0,b-c|0);b=v[22640];v[22640]=0;if((b|0)!=1){v[22640]=0;R(119,h|0,d|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}vb(d);gb=e+32|0;break a}}a=P()|0;O()|0;vb(d);S(a|0);L()}v[22640]=0;R(114,a|0,f|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(f);gb=f+16|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function VL(a){var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=uf(v[a+16>>2]);g=C(C(z[a+4220>>2]*C(.9980000257492065))+C(.0010000000474974513));d=-9965.784284662086/+C(C(C(z[a+4216>>2]*C(2999.9990234375))+C(.0010000000474974513))*C(c>>>0));m=a,n=C(Ag(d*+y[a+4288>>2])),z[m+4232>>2]=n;m=a+4236|0,n=C(Ag(d*+y[a+4292>>2])),z[m>>2]=n;l=(1/+g+-1)*d;c=0;h=a+4272|0;i=a+4232|0;while(1){j=v[(c<<2)+h>>2];e=c<<1&-4;f=Ag(l*+(j+v[(e+h|0)+16>>2]>>>0));b=Ag(d*+(j>>>0));g=z[e+i>>2];e=(c<<3)+i|0;f=f*.5;z[e+12>>2]=b*(.5-f);z[e+8>>2]=b*(f+.5);b=b*+g;b=(((b+1)*b+1)*b+1)*b+1;k=b*b+k;c=c+1|0;if((c|0)!=4){continue}break}d=Ag(+UL(z[a+4208>>2])*.16609640474436813);b=Ag(+UL(z[a+4212>>2])*.33219280948873625);z[a+4228>>2]=d*4*K(b)/K(k);z[a+4224>>2]=d*K(1-b)}function Kba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=Di(a,b,c,d);v[a+4260>>2]=0;v[a>>2]=52864;c=a+4960|0;e=a+4504|0;b=e;while(1){b=Ho(b)+24|0;if((c|0)!=(b|0)){continue}break}t[a+5046|0]=1;u[a+5044>>1]=0;v[a+4208>>2]=1063675494;v[a+4212>>2]=1065185444;v[a+4256>>2]=1059760811;b=a+4248|0;v[b>>2]=1065353216;v[b+4>>2]=1048525618;b=a+4240|0;v[b>>2]=1038174126;v[b+4>>2]=1065353216;b=a+4232|0;v[b>>2]=1047457519;v[b+4>>2]=1062836634;b=a+4224|0;v[b>>2]=1053079357;v[b+4>>2]=1059859440;b=a+4216|0;v[b>>2]=0;v[b+4>>2]=1032805417;v[22640]=0;W(1536,a+44|0,2,2)|0;b=v[22640];v[22640]=0;a:{if((b|0)!=1){v[22640]=0;Vh(d);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;while(1){c=c-24|0;Lc(c);if((c|0)!=(e|0)){continue}break}hf(d);S(a|0);L()}return a|0}function Ut(a){a=a|0;var b=0;a:{b:{c:{if(w[a+3|0]!=19){break c}t[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=w[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}t[a+3|0]=2;break a}t[a+3|0]=3;break a}t[a+5|0]=b&15|16;return}t[a+5|0]=b&3|48;return}t[a+5|0]=b&15|32;return}t[a+5|0]=b&15|176;return}t[a+5|0]=b&3|64;return}t[a+3|0]=15;t[a+5|0]=b&15;return}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;return}break b}if(b&15){t[a+3|0]=11;break a}break b}if((b|0)!=192){break c}t[a|0]=254;break b}if((b|0)!=208){break c}t[a+3|0]=0}return}t[a+3|0]=0;return}t[a+5|0]=b|240}function n$(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-192|0;gb=b;Vf(b+16|0,a);v[22640]=0;R(141,b+32|0,b+16|0);a=v[22640];v[22640]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[22640]=0;a=W(142,b+48|0,b+32|0,8)|0;c=v[22640];v[22640]=0;if((c|0)==1){break e}vb(b+32|0);vb(b+16|0);c=v[v[a>>2]-12>>2];v[22640]=0;d=fa(121)|0;e=v[22640];v[22640]=0;if((e|0)==1){break c}v[22640]=0;U(122,b+8|0,c+(b+48|0)|0,d|0);c=v[22640];v[22640]=0;if((c|0)==1){break c}Vb(b+8|0);v[22640]=0;c=Q(145,a|0,b+32|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}d=v[v[c>>2]-12>>2];v[22640]=0;c=_l(c+d|0);d=v[22640];v[22640]=0;if((d|0)==1){break c}d=v[b+32>>2];tf(a);gb=b+192|0;a=c?0:d;break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;vb(b+32|0)}vb(b+16|0);break b}c=P()|0;O()|0;tf(a)}S(c|0);L()}return a|0}function Y7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;h=Kb(a);a=Kb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!x[v[f>>2]+480192>>1]){break d}b=1;while(1){c=v[f>>2];v[22640]=0;c=Sz(c,b&65535);d=v[22640];v[22640]=0;if((d|0)==1){break c}v[22640]=0;c=Q(112,e|0,c|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}d=dd(c);v[22640]=0;Q(1183,a|0,c|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break b}v[22640]=0;Q(1917,a|0,18663)|0;g=v[22640];v[22640]=0;if((g|0)==1){break b}i=d^1|i;vb(c);b=b+1|0;if(x[v[f>>2]+480192>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}v[22640]=0;Q(408,h|0,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}vb(a);gb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(a);vb(h);S(b|0);L()}function X7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;h=Kb(a);a=Kb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!x[v[f>>2]+480190>>1]){break d}b=1;while(1){c=v[f>>2];v[22640]=0;c=Tz(c,b&65535);d=v[22640];v[22640]=0;if((d|0)==1){break c}v[22640]=0;c=Q(112,e|0,c|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}d=dd(c);v[22640]=0;Q(1183,a|0,c|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break b}v[22640]=0;Q(1917,a|0,18663)|0;g=v[22640];v[22640]=0;if((g|0)==1){break b}i=d^1|i;vb(c);b=b+1|0;if(x[v[f>>2]+480190>>1]>=(b&65535)>>>0){continue}break}if(!(i&1)){break d}v[22640]=0;Q(408,h|0,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}vb(a);gb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(a);vb(h);S(b|0);L()}function qha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;h=Zf(a,c);se(f+8|0,v[a+28>>2]);d=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=d;a:{if(!h){if(id(a,5)){break a}}g=v[a+28>>2];d=gb-16|0;gb=d;v[d+12>>2]=0;PI(g,d+12|0,1);e=v[d+12>>2];i=e>>>2&3;t[d+11|0]=i;if(i){t[d+4|0]=3;e=w[ac(d+4|0,d+11|0)|0];t[d+4|0]=0;t[d|0]=0;t[d+10|0]=0;b:{if(!e){break b}Rh(g,d+4|0);if((e|0)==1){break b}Rh(g,d);if(e>>>0<3){break b}Rh(g,d+10|0);j=w[d+10|0]<<24}e=w[d+12|0]|w[d+4|0]<<8|w[d|0]<<16|j;v[d+12>>2]=e}v[d+4>>2]=e>>>4;v[d>>2]=1e6;jq(b,v[Fb(d+4|0,d)>>2]);if(Ab(b)){e=0;while(1){ol(g,mc(b,e),1);e=e+1|0;if(Ab(b)>>>0>e>>>0){continue}break}}b=(v[d+12>>2]>>>4|0)-Ab(b)|0;v[d+12>>2]=b;if(b){tm(g,b,-1)}gb=d+16|0}Sf(a,h,c,f+24|0);gb=f+32|0}function Kka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=Cc(a);if(c>>>0<b>>>0){f=gb-32|0;gb=f;a:{b:{e=b-c|0;c:{if(e>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/12>>>0){c=gb-16|0;gb=c;d=Mp(c,a,e);a=v[d+4>>2];b=v[d+8>>2];if((a|0)!=(b|0)){while(1){VT(a);a=a+12|0;v[d+4>>2]=a;if((a|0)!=(b|0)){continue}break}}$b(d);gb=c+16|0;break c}b=wb(a);d=Nu(f+8|0,BB(a,Cc(a)+e|0),Cc(a),b);v[22640]=0;YT(d,e);b=v[22640];v[22640]=0;if((b|0)==1){break b}c=d;e=c+4|0;g=e;b=a;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){h=v[g>>2];while(1){a=a-12|0;AB(h-12|0,a);h=v[g>>2]-12|0;v[g>>2]=h;if((a|0)!=(i|0)){continue}break}}wc(b,e);wc(b+4|0,c+8|0);wc(wb(b),cc(c));v[c>>2]=v[c+4>>2];XT(d)}gb=f+32|0;break a}a=P()|0;O()|0;XT(d);S(a|0);L()}return}if(b>>>0<c>>>0){_T(a,v[a>>2]+B(b,12)|0)}}function g5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=v[b+44>>2];g=v[b+24>>2];if(i>>>0<g>>>0){v[b+44>>2]=g;i=g}l=-1;g=-1;m=f&24;a:{if(!m|((e|0)==1?(m|0)==24:0)){break a}if(i){h=i-Jb(b+32|0)|0;n=h;h=h>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;j=e;k=e>>31;break b}e=v[b+24>>2]-v[b+20>>2]|0;j=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}j=n;k=h}e=d+k|0;c=c+j|0;e=j>>>0>c>>>0?e+1|0:e;d=c;c=e;if((e|0)<0|((e|0)>(h|0)?1:(h|0)<=(e|0)?d>>>0>n>>>0:0)){break a}e=f&8;d:{if(!(c|d)){break d}if(v[b+12>>2]?0:e){break a}if(!(f&16)){break d}if(!v[b+24>>2]){break a}}if(e){e=v[b+8>>2];Zn(b,e,d+e|0,v[b+44>>2])}if(f&16){Fx(b,v[b+20>>2],v[b+28>>2]);Us(b,d)}l=d;g=c}Bh(a,l,g)}function sh(a,b,c){var d=0,e=0;a:{if((a|0)==(b|0)){break a}e=a+c|0;if(b-e>>>0<=0-(c<<1)>>>0){return hc(a,b,c)}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){d=a;break b}if(!(a&3)){d=a;break c}d=a;while(1){if(!c){break a}t[d|0]=w[b|0];b=b+1|0;c=c-1|0;d=d+1|0;if(d&3){continue}break}break c}d:{if(d){break d}if(e&3){while(1){if(!c){break a}c=c-1|0;d=c+a|0;t[d|0]=w[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c-4|0;v[c+a>>2]=v[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c-1|0;t[c+a|0]=w[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){v[d>>2]=v[b>>2];b=b+4|0;d=d+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function dL(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;b=v[a+4>>2];c=f;a=v[a>>2];v[c>>2]=a;v[c+4>>2]=b;v[c+8>>2]=a;v[c+12>>2]=b;b=gb+-64|0;gb=b;a:{b:{e=v[c+4>>2];if(!e){break b}d=38848;while(1){a=v[c+4>>2];v[b+56>>2]=v[c>>2];v[b+60>>2]=a;a=uc(b+48|0,v[d+8>>2]);g=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=g;g=v[a+4>>2];v[b+16>>2]=v[a>>2];v[b+20>>2]=g;if(mO(b+24|0,b+16|0)){break b}d=d+12|0;if((d|0)!=39412){continue}break}d=39424;while(1){c:{a=v[c+4>>2];v[b+40>>2]=v[c>>2];v[b+44>>2]=a;a=uc(b+32|0,v[d+8>>2]);e=v[b+44>>2];v[b+8>>2]=v[b+40>>2];v[b+12>>2]=e;e=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=e;a=mO(b+8|0,b);if(a){break c}d=d+12|0;if((d|0)!=39472){continue}}break}gb=b- -64|0;break a}gb=b- -64|0;a=(e|0)!=0}gb=f+16|0;return a|0}function gla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-32|0;gb=d;td(b,0);Yj(d,1,a);Bc(d+16|0,d);v[22640]=0;Q(335,b+43|0,d+16|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){vb(d+16|0);c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;No(b,+((w[a+60|0]^8)-120|0)*.005208333333333333);t[d+16|0]=w[a+61|0];t[d|0]=64;e=b,f=w[ac(d+16|0,d)|0]<<2,u[e+30>>1]=f;u[b+34>>1]=0;a=a+47|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1}if(w[a|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[a|0]<=-1){u[b+34>>1]=x[b+34>>1]|2}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function Via(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;b=f>>>21&2040;l=u[b+46534>>1];m=u[b+46532>>1];n=u[b+46530>>1];o=u[b+46528>>1];g=0;b=1;while(1){v[(e+8|0)+(g<<2)>>2]=(((B(t[g+h|0],n)+B(t[(g|-2)+h|0],o)|0)+B(t[(g|2)+h|0],m)|0)+B(t[(g|4)+h|0],l)<<8)/16384;f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function j7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-80|0;gb=d;a=v[a+4>>2];mz(d+16|0,b);v[22640]=0;b=Q(2,d|0,14831)|0;e=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[22640]=0;U(3,d+32|0,d+16|0,b|0);e=v[22640];v[22640]=0;if((e|0)==1){break h}v[22640]=0;U(671,d+48|0,d+32|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break g}v[22640]=0;R(2039,d- -64|0,d+48|0);c=v[22640];v[22640]=0;if((c|0)==1){break f}c=v[v[a>>2]+8>>2];v[22640]=0;R(c|0,a|0,d- -64|0);a=v[22640];v[22640]=0;if((a|0)==1){break e}vb(d- -64|0);vb(d+48|0);vb(d+32|0);vb(b);vb(d+16|0);gb=d+80|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;vb(d- -64|0)}vb(d+48|0)}vb(d+32|0)}vb(b)}vb(d+16|0);S(a|0);L()}function N7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;g=nc(a);f=b+24|0;a=x[v[f>>2]+480192>>1];v[22640]=0;R(1427,g|0,a|0);c=v[22640];v[22640]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480192>>1]){while(1){c=v[f>>2];v[22640]=0;c=Sz(c,a&65535);e=v[22640];v[22640]=0;if((e|0)==1){break e}v[22640]=0;c=Q(112,d|0,c|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break e}v[22640]=0;U(2092,d+16|0,b|0,c|0);e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;R(1429,g|0,d+16|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}vb(d+16|0);vb(c);a=a+1|0;if(x[v[f>>2]+480192>>1]>=(a&65535)>>>0){continue}break}}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+16|0)}vb(c);break a}a=P()|0;O()|0}vd(g);S(a|0);L()}function M7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;g=nc(a);f=b+24|0;a=x[v[f>>2]+480190>>1];v[22640]=0;R(1427,g|0,a|0);c=v[22640];v[22640]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480190>>1]){while(1){c=v[f>>2];v[22640]=0;c=Tz(c,a&65535);e=v[22640];v[22640]=0;if((e|0)==1){break e}v[22640]=0;c=Q(112,d|0,c|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break e}v[22640]=0;U(2092,d+16|0,b|0,c|0);e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;R(1429,g|0,d+16|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}vb(d+16|0);vb(c);a=a+1|0;if(x[v[f>>2]+480190>>1]>=(a&65535)>>>0){continue}break}}gb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+16|0)}vb(c);break a}a=P()|0;O()|0}vd(g);S(a|0);L()}function pO(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:zq(a,C(1));yq(a,C(3.725290298461914e-9));xq(a,C(268435456));wq(a,0);break b;case 1:zq(a,C(32));yq(a,C(4.656612873077393e-10));xq(a,C(2147483648));wq(a,0);break b;case 2:zq(a,C(2));yq(a,C(7.450580596923828e-9));xq(a,C(134217728));wq(a,1);break b;default:zq(a,C(1));yq(a,C(7.450580596923828e-9));xq(a,C(134217728));wq(a,1);xz(a,0);wz(a,1);vz(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}zq(a,C(.75));yq(a,C(7.450580596923828e-9));xq(a,C(134217728));wq(a,1);xz(a,0);b=(b|0)==4;wz(a,b?2:3);vz(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}xz(a,1);wz(a,0);vz(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function zoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb+-64|0;gb=c;a:{if(lv(a)){v[b>>2]=0;a=0;break a}MW(c+32|0,c+48|0);e=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=e;fc(c+40|0,a,c+16|0);g=xb(c+40|0);d=zb(w[c+48|0]);e=d&127;v[b>>2]=e;h=d<<24>>24;i=(h|0)<0;d=1;b:{if(!e){break b}f=1;while(1){if(e>>>0<2){break b}e=e>>>1|0;f=f+1|0;continue}}e=f;c:{if(g>>>0<2|(h|0)>-1){break c}while(1){f=zb(w[(c+48|0)+d|0]);v[b>>2]=f&127|v[b>>2]<<7;e=e+7|0;f=f<<24>>24;i=(f|0)<0;d=d+1|0;if((g|0)==(d|0)){Yb(a,g);MW(c+24|0,c+48|0);d=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=d;fc(c+40|0,a,c+8|0);g=xb(c+40|0);d=0}if(d>>>0>=g>>>0){break c}if((f|0)<0){continue}break}}Yb(a,d);if(e>>>0>=33){v[b>>2]=-1;a=0;break a}a=!i}gb=c- -64|0;return a|0}function fL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=C(0);e=gb-80|0;gb=e;f=a+24|0;Bq(v[f>>2]);t[v[f>>2]+1298380|0]=v[a+52>>2]!=0;c=ig(e+32|0,d,c,b);g=v[a+32>>2];j=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;i=e+48|0;c=i;tt(c);v[c+8>>2]=g;v[c+4>>2]=0;v[c>>2]=58524;g=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=g;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=57752;gb=d+16|0;a:{if(!b){break a}while(1){c=v[f>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;c=Dt(c,v[Qk(e+24|0,e+16|0)>>2],i);h=c+h|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|h)){a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=e+80|0;return h}function eL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=C(0);e=gb-80|0;gb=e;f=a+24|0;Bq(v[f>>2]);t[v[f>>2]+1298380|0]=v[a+52>>2]!=0;c=ig(e+32|0,d,c,b);g=v[a+32>>2];j=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=gb-16|0;gb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;i=e+48|0;c=i;tt(c);v[c+8>>2]=g;v[c+4>>2]=0;v[c>>2]=59352;g=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=g;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=j;v[c>>2]=58580;gb=d+16|0;a:{if(!b){break a}while(1){c=v[f>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;c=Dt(c,v[Qk(e+24|0,e+16|0)>>2],i);h=c+h|0;if(!c){break a}b=b-c|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|h)){a=v[f>>2];v[a+480208>>2]=v[a+480208>>2]&-513}gb=e+80|0;return h}function sfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=c;e=gb-32|0;gb=e;h=b;d=Vd(b);f=ec(b);a:{b:{if(d){c:{while(1){d:{b=d+16|0;e:{if(vA(c,b)){if(!v[d>>2]){break b}b=d;break e}if(!vA(b,c)){break c}b=d+4|0;if(!v[d+4>>2]){break d}d=b;b=d}f=b;d=v[d>>2];continue}break}v[e+28>>2]=d;break a}v[e+28>>2]=d;b=f;break a}d=ec(b)}v[e+28>>2]=d;b=d}d=v[b>>2];t[e+27|0]=0;if(!d){c=gb-16|0;gb=c;d=ec(h);d=Pj(e+8|0,Mc(28,4),Qj(c+8|0,d));f=v[d>>2];v[22640]=0;R(1423,f+16|0,i|0);f=v[22640];v[22640]=0;f:{if((f|0)!=1){j=ec(d),k=1,t[j+4|0]=k;gb=c+16|0;break f}a=P()|0;O()|0;gO(d);S(a|0);L()}Ak(h,v[e+28>>2],b,v[e+8>>2]);d=$d(e+8|0);t[e+27|0]=1;gO(e+8|0)}Rj(g+8|0,yc(e+8|0,d),e+27|0);gb=e+32|0;KS(a,g+8|0);gb=g+16|0}function IX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;v[e+24>>2]=b;k=e,l=wd(a),v[k+8>>2]=l;g=Xj(e+24|0,e+8|0);b=fi(c,d);a:{b:{if(!b){break b}if(RC(c,Jb(a),Jb(a)+Ab(a)|0)){b=Bj(e+8|0,c,d);c=v[e+24>>2];d=Jb(b);g=Jb(b);h=Ab(b);v[22640]=0;c=ca(563,a|0,c|0,d|0,g+h|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){vb(b);break a}a=P()|0;O()|0;vb(b);S(a|0);L()}h=Ab(a);f=Kc(a);c:{if(b>>>0<=f-h>>>0){f=Jb(a);i=h-g|0;if(!i){break c}j=g+f|0;bm(b+j|0,j,i);break c}Em(a,f,(b+h|0)-f|0,h,g,0,b);f=v[a>>2]}b=b+h|0;gh(a,b);t[e+8|0]=0;zd(b+f|0,e+8|0);if((c|0)==(d|0)){break b}b=g+f|0;while(1){zd(b,c);b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}k=e,l=wd(a),v[k+8>>2]=l;c=we(e+8|0,g)}gb=e+32|0;return c|0}function DJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;a:{b:{c:{d:{if((b|0)>=0){if((io(a+8|0)|0)>(b|0)){break d}}a=aa(8)|0;v[22640]=0;b=Q(112,f|0,8049)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}qc(a,b);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}d=a+32|0;a=(v[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;v[a>>2]=c|v[a>>2]&-134218753;a=(v[d>>2]+B(b,872)|0)+1075080|0;v[a>>2]=c|v[a>>2]&-134218753;a=x[v[d>>2]+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){e=B(a,872);if((b|0)==x[(e+v[d>>2]|0)+1075778>>1]){e=(e+v[d>>2]|0)+1075080|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}gb=f+16|0;return}c=P()|0;O()|0;da(a|0)}S(c|0)}L()}function ZU(a){var b=0,c=0;a:{b:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1196314451){break b}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<1108){break b}c=a+1104|0;if(((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-1108|0)!=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>262144){break b}b=a+1094|0;if(w[b|0]|w[b+1|0]<<8){break b}b=a+1096|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>4){break b}if(!Wu(a+8|0)){break b}c=a+1094|0;b=a+40|0;while(1){if(w[b+32|0]>15|w[b+33|0]>64){break b}if(!Wu(b)){break b}a=1;b=b+34|0;if((c|0)!=(b|0)){continue}break}break a}a=0}return a}function Up(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);e=j(1)|0;g=j(0)|0;a:{b:{c:{b=e;e=b;if(!((b|0)>-1?b>>>0>=1048576:0)){if(!(b&2147483647|g)){return-1/(a*a)}if((b|0)>-1){break c}return(a-a)/0}if(e>>>0>2146435071){break a}b=1072693248;h=-1023;if((e|0)!=1072693248){b=e;break b}if(g){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;g=j(0)|0;h=-1077}b=b+614242|0;d=+((b>>>20|0)+h|0);a=d*.6931471803691238;l(0,g|0);l(1,(b&1048575)+1072079006|0);f=+n()+-1;c=f/(f+2);i=a;k=d*1.9082149292705877e-10;m=c;a=f*(f*.5);d=c*c;c=d*d;a=i+(f+(k+m*(a+(c*(c*(c*.15313837699209373+.22222198432149784)+.3999999999940942)+d*(c*(c*(c*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))-a))}return a}function rfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-80|0;gb=d;g=QR(a,1<<b-1);v[a+12>>2]=b;c=1<<b;h=c>>>2|0;a:{if(b>>>0>=2){i=1/+(c>>>0);b=h;f=1;while(1){A[d+40>>3]=+(b>>>0)*-6.283185307179586*i;e=v[12147];c=d+48|0;v[c+8>>2]=v[12146];v[c+12>>2]=e;e=v[12145];v[c>>2]=v[12144];v[c+4>>2]=e;HA(c,A[d+40>>3]);v[22640]=0;GA(d- -64|0,d+48|0);c=v[22640];v[22640]=0;if((c|0)==1){break a}c=Qc(g,f);e=v[d+76>>2];v[c+8>>2]=v[d+72>>2];v[c+12>>2]=e;e=v[d+68>>2];v[c>>2]=v[d+64>>2];v[c+4>>2]=e;f=f<<1;c=b>>>0<2;b=b>>>1|0;if(!c){continue}break}}b=Vm(d+24|0,1,0);c=v[b+12>>2];v[d+16>>2]=v[b+8>>2];v[d+20>>2]=c;c=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=c;rz(a,0,h,d+8|0);gb=d+80|0;return a|0}a=P()|0;O()|0;Sq(g);S(a|0);L()}function f6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;e=b+c|0;j=2;b=d+16|0;a:{b:{c:{if(!ct(xa(v[a+60>>2],d+16|0,2,d+12|0)|0)){while(1){f=v[d+12>>2];if((f|0)==(e|0)){break c}if((f|0)<=-1){break b}g=v[b+4>>2];h=g>>>0<f>>>0;i=(h<<3)+b|0;g=f-(h?g:0)|0;v[i>>2]=g+v[i>>2];i=(h?12:4)+b|0;v[i>>2]=v[i>>2]-g;e=e-f|0;b=h?b+8|0:b;j=j-h|0;if(!ct(xa(v[a+60>>2],b|0,j|0,d+12|0)|0)){continue}break}}if((e|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((j|0)==2){break a}a=c-v[b+4>>2]|0}gb=d+32|0;return a|0}function WL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{f=gb-16|0;gb=f;g=f;d=gb-32|0;gb=d;c=Ge(d+16|0,1,0);wL(d+8|0,Jb(c),Jb(c)+Ab(c)|0,x[b>>1]);b:{c:{if(v[d+12>>2]){while(1){e=Ab(c);v[22640]=0;v[d+4>>2]=e;e=wf(d+4|0);h=v[22640];v[22640]=0;if((h|0)==1){break c}v[22640]=0;U(117,c|0,e|0,0);e=v[22640];v[22640]=0;if((e|0)==1){break c}wL(d+8|0,Jb(c),Jb(c)+Ab(c)|0,x[b>>1]);if(v[d+12>>2]){continue}break}}b=v[d+8>>2];e=Jb(c);v[22640]=0;R(118,c|0,b-e|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;R(128,g|0,c|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;vb(c);S(a|0);L()}vb(c);gb=d+32|0;v[22640]=0;R(127,a|0,f|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(f);gb=f+16|0;break a}a=P()|0;O()|0;vb(f);S(a|0);L()}}function vF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=of(a);if(c>>>0<b>>>0){g=gb-32|0;gb=g;a:{b:{e=b-c|0;c:{if(e>>>0<=v[wb(a)>>2]-v[a+4>>2]>>3>>>0){c=gb-16|0;gb=c;b=bs(c,a,e);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){ak(a);a=a+8|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0;break c}f=wb(a);b=cs(a,of(a)+e|0);i=of(a);c=0;h=gb-16|0;gb=h;v[h+12>>2]=0;d=g+8|0;ef(d+12|0,f);if(b){c=b;if(b>>>0>=536870912){nd(8513);L()}c=Mc(c<<3,1)}v[d>>2]=c;f=(i<<3)+c|0;v[d+8>>2]=f;v[d+4>>2]=f;j=cc(d),k=(b<<3)+c|0,v[j>>2]=k;gb=h+16|0;v[22640]=0;xw(d,e);b=v[22640];v[22640]=0;if((b|0)==1){break b}Uk(a,d);tF(d)}gb=g+32|0;break a}a=P()|0;O()|0;tF(d);S(a|0);L()}return}if(b>>>0<c>>>0){Vk(a,v[a>>2]+(b<<3)|0)}}function ZL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{f=gb-16|0;gb=f;g=f;d=gb-32|0;gb=d;c=Ge(d+16|0,1,0);BL(d+8|0,Jb(c),Jb(c)+Ab(c)|0,w[b|0]);b:{c:{if(v[d+12>>2]){while(1){e=Ab(c);v[22640]=0;v[d+4>>2]=e;e=wf(d+4|0);h=v[22640];v[22640]=0;if((h|0)==1){break c}v[22640]=0;U(117,c|0,e|0,0);e=v[22640];v[22640]=0;if((e|0)==1){break c}BL(d+8|0,Jb(c),Jb(c)+Ab(c)|0,w[b|0]);if(v[d+12>>2]){continue}break}}b=v[d+8>>2];e=Jb(c);v[22640]=0;R(118,c|0,b-e|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;R(128,g|0,c|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;vb(c);S(a|0);L()}vb(c);gb=d+32|0;v[22640]=0;R(127,a|0,f|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(f);gb=f+16|0;break a}a=P()|0;O()|0;vb(f);S(a|0);L()}}function Hea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=b+24|0;o=a+1298224|0;g=a+1074992|0;k=qk(a);p=b+4|0;q=b+12|0;r=b+8|0;s=b+16|0;while(1){if(v[g+104>>2]==(b|0)){if(v[g+16>>2]){v[g+16>>2]=c}if(y[g+4>>2]>d>>>0){v[g>>2]=0;v[g+4>>2]=0}if(v[g+76>>2]){tc(g+76|0,d)}h=bF(g);i=v[(h?q:p)>>2];v[g+84>>2]=v[(h?s:r)>>2];v[g+80>>2]=i;h=v[g+88>>2]|v[e>>2];v[g+88>>2]=h;v[g+88>>2]=h&(v[f>>2]^-1);h=g+704|0;a:{if(!v[g+704>>2]|!v[b+24>>2]){break a}if(fp(a)){break a}l=v[(k?h:j)>>2];m=mqa(v[(k?j:h)>>2],0,v[g+700>>2],0);n=m+(l>>>1|0)|0;i=jb;t=g,u=Uc(pqa(n,n>>>0<m>>>0?i+1|0:i,l,0),jb),v[t+700>>2]=u}v[h>>2]=v[j>>2]}g=g+872|0;if((o|0)!=(g|0)){continue}break}}function E9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[22640]=0;_(1934,a|0);e=v[22640];v[22640]=0;a:{b:{c:{if((e|0)==1){break c}v[22640]=0;_(1960,b|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}v[22640]=0;_(1960,c|0);f=v[22640];v[22640]=0;e=1;if((f|0)==1){break c}f=v[a+24>>2];b=uc(d+24|0,b);c=uc(d+16|0,c);v[22640]=0;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;Y(2004,f|0,d+8|0,d|0,1);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,2599,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();e=0}gb=d+32|0;return e|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Qb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}f=a+c|0;t[f-1|0]=b;t[a|0]=b;if(c>>>0<3){break a}t[f-2|0]=b;t[a+1|0]=b;t[f-3|0]=b;t[a+2|0]=b;if(c>>>0<7){break a}t[f-4|0]=b;t[a+3|0]=b;if(c>>>0<9){break a}f=0-a&3;e=f+a|0;d=B(b&255,16843009);v[e>>2]=d;b=c-f&-4;c=b+e|0;v[c-4>>2]=d;if(b>>>0<9){break a}v[e+8>>2]=d;v[e+4>>2]=d;v[c-8>>2]=d;v[c-12>>2]=d;if(b>>>0<25){break a}v[e+24>>2]=d;v[e+20>>2]=d;v[e+16>>2]=d;v[e+12>>2]=d;v[c-16>>2]=d;v[c-20>>2]=d;v[c-24>>2]=d;v[c-28>>2]=d;c=b;b=e&4|24;c=c-b|0;if(c>>>0<32){break a}d=mqa(d,0,1,1);f=jb;b=b+e|0;while(1){v[b+24>>2]=d;e=f;v[b+28>>2]=e;v[b+16>>2]=d;v[b+20>>2]=e;v[b+8>>2]=d;v[b+12>>2]=e;v[b>>2]=d;v[b+4>>2]=e;b=b+32|0;c=c-32|0;if(c>>>0>31){continue}break}}return a}function Ffa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;a:{b:{c:{d:{e:{if(nk(b)){break e}u[d+8>>1]=x[a+480190>>1];u[d+24>>1]=v[b+4>>2]-1;c=x[Oc(d+8|0,d+24|0)>>1];if(!c){break e}g=c;while(1){oe(d+8|0,b,c);if(!Cb(d+8|0)){v[22640]=0;e=Q(1321,a|0,c&65535)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}if(e){v[22640]=0;e=Q(112,d+8|0,18693)|0;f=v[22640];v[22640]=0;if((f|0)==1){break d}v[22640]=0;Q(333,((c<<5)+a|0)+946304|0,e|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break c}vb(e);h=h+1|0}if(!(x[a+480190>>1]!=(c|0)|c>>>0<2)){u[a+480190>>1]=x[a+480190>>1]-1}}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}gb=d+32|0;return h&65535}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(e);break a}c=P()|0;O()|0}S(c|0);L()}function tV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(Pb(a,1024)){MB(c+24|0,b);b=v[c+28>>2];v[c>>2]=v[c+24>>2];v[c+4>>2]=b;gd(c+8|0,a,c);break a}v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;a=64;while(1){d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);e=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;b=b+16|0;a=a-1|0;if(a){continue}break}}gb=c+32|0}function om(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0;k=gb-16|0;gb=k;t[k+15|0]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;m=a&255;if((m|0)!=w[j+24|0]){l=45;if(w[j+25|0]!=(m|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Ab(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=Dm(j,j+26|0,k+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+83184|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+83184|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}gb=k+16|0;return a}function nm(a,b,c,d,e,f,g,h,i,j){var k=0,l=0;k=gb-16|0;gb=k;v[k+12>>2]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Ab(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;g=gx(j,j+104|0,k+12|0)-j|0;if((g|0)>92){break a}f=g>>2;d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(g|0)<88){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+83184|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+83184|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}gb=k+16|0;return a}function fQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=gb-16|0;gb=h;v[h+12>>2]=c>>>4;v[h+8>>2]=v[a>>2];i=v[Fb(h+12|0,h+8|0)>>2];b=zb(b);if(i){a=v[a+20>>2];c=i;while(1){e=zb(w[b|0]);d=zb(w[b+1|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+2|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+3|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+4|0])|(f|g);j=a,k=Ic(d,zb(w[b+5|0])<<8|f|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,48),u[j>>1]=k;e=zb(w[b+8|0]);d=zb(w[b+9|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+10|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+11|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+12|0])|(f|g);j=a,k=Ic(d,zb(w[b+13|0])<<8|f|zb(w[b+14|0])<<16|zb(w[b+15|0])<<24,48),u[j+2>>1]=k;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=h+16|0;return i<<4}function eQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=gb-16|0;gb=h;v[h+12>>2]=c>>>4;v[h+8>>2]=v[a>>2];i=v[Fb(h+12|0,h+8|0)>>2];b=zb(b);if(i){a=v[a+20>>2];c=i;while(1){e=zb(w[b+7|0]);d=zb(w[b+6|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+5|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+4|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+3|0])|(f|g);j=a,k=Ic(d,zb(w[b+2|0])<<8|f|zb(w[b+1|0])<<16|zb(w[b|0])<<24,48),u[j>>1]=k;e=zb(w[b+15|0]);d=zb(w[b+14|0]);f=d>>>24|0;g=e|d<<8;e=zb(w[b+13|0]);d=e>>>16|0;e=g|e<<16;g=d|f;d=zb(w[b+12|0]);f=d>>>8|0;d=d<<24|e;f=zb(w[b+11|0])|(f|g);j=a,k=Ic(d,zb(w[b+10|0])<<8|f|zb(w[b+9|0])<<16|zb(w[b+8|0])<<24,48),u[j+2>>1]=k;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}gb=h+16|0;return i<<4}function Yna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;v[d+28>>2]=0;Bk(a,d+28|0);a:{b:{e=v[d+28>>2];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Kb(d+16|0);v[22640]=0;u[d+14>>1]=0;f=W(672,a|0,e|0,255)|0;g=v[22640];v[22640]=0;if((g|0)==1){break b}if(!f){break d}v[22640]=0;Q(666,a|0,d+14|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}v[22640]=0;U(13,d|0,c|0,e|0);f=v[22640];v[22640]=0;if((f|0)==1){break f}v[22640]=0;f=Q(673,b|0,d+14|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break e}Eb(f,d);vb(d);vb(e);h=h+1|0;if(h>>>0<y[d+28>>2]){continue}break}}Tf(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}vb(e)}gb=d+32|0;return}a=P()|0;O()|0}vb(e);S(a|0);L()}function Xna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;u[d+30>>1]=0;Xf(a,d+30|0);a:{b:{e=x[d+30>>1];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Kb(d+16|0);v[22640]=0;u[d+14>>1]=0;f=W(674,a|0,e|0,255)|0;g=v[22640];v[22640]=0;if((g|0)==1){break b}if(!f){break d}v[22640]=0;Q(666,a|0,d+14|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}v[22640]=0;U(13,d|0,c|0,e|0);f=v[22640];v[22640]=0;if((f|0)==1){break f}v[22640]=0;f=Q(673,b|0,d+14|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break e}Eb(f,d);vb(d);vb(e);h=h+1|0;if(h>>>0<x[d+30>>1]){continue}break}}Tf(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d);break a}vb(e)}gb=d+32|0;return}a=P()|0;O()|0}vb(e);S(a|0);L()}function DI(a,b,c,d,e,f){var g=0;g=gb-80|0;gb=g;a:{if((f|0)>=16384){Dd(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if((f|0)<32767){f=f-16383|0;break a}Dd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}Dd(g- -64|0,b,c,d,e,0,0,0,65536);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if((f|0)>-32765){f=f+16382|0;break a}Dd(g+48|0,b,c,d,e,0,0,0,65536);f=((f|0)>-49146?f:-49146)+32764|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}Dd(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;gb=g+80|0}function $z(a){var b=0,c=0,d=0,e=0;e=a+128e3|0;while(1){d=gb-32|0;gb=d;Yq(d);b=v[d+28>>2];c=v[d+24>>2];t[a+24|0]=c;t[a+25|0]=c>>>8;t[a+26|0]=c>>>16;t[a+27|0]=c>>>24;t[a+28|0]=b;t[a+29|0]=b>>>8;t[a+30|0]=b>>>16;t[a+31|0]=b>>>24;b=v[d+20>>2];c=v[d+16>>2];t[a+16|0]=c;t[a+17|0]=c>>>8;t[a+18|0]=c>>>16;t[a+19|0]=c>>>24;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[d+12>>2];c=v[d+8>>2];t[a+8|0]=c;t[a+9|0]=c>>>8;t[a+10|0]=c>>>16;t[a+11|0]=c>>>24;t[a+12|0]=b;t[a+13|0]=b>>>8;t[a+14|0]=b>>>16;t[a+15|0]=b>>>24;b=v[d+4>>2];c=v[d>>2];t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24;gb=d+32|0;a=a+32|0;if((e|0)!=(a|0)){continue}break}}function Sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;e=(e<<1)+k|0;f=f>>>21&2040;e=(((B(u[e>>1],u[f+46530>>1])+B(u[e-2>>1],u[f+46528>>1])|0)+B(u[e+2>>1],u[f+46532>>1])|0)+B(u[e+4>>1],u[f+46534>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(g,e);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function Gma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=C(0);c=gb-16|0;gb=c;if(v[b+8>>2]==v[a+8>>2]){if(v[b+4>>2]==v[a+4>>2]){v[c+12>>2]=v[b+8>>2];v[c+8>>2]=v[a+8>>2];h=v[Fb(c+12|0,c+8|0)>>2];v[c+12>>2]=v[b+4>>2];v[c+8>>2]=v[a+4>>2];d=Fb(c+12|0,c+8|0);if(h){i=v[d>>2];d=0;while(1){e=0;if(i){while(1){j=c,k=z[ir(b,e,d)>>2],z[j+12>>2]=k;v[c+8>>2]=-1082130432;v[c+4>>2]=1065353216;f=C(z[Wf(c+12|0,c+8|0,c+4|0)>>2]*C(128));z[c+12>>2]=f;f=re(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}g=GV(g);t[v[a>>2]+(B(v[a+4>>2],d)+e|0)|0]=g;e=e+1|0;if((i|0)!=(e|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}gb=c+16|0;return}ba(14365,6194,28,6685);L()}ba(14415,6194,27,6685);L()}function Co(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(c){t[b+809|0]=c;break a}c=w[b+809|0]}d=v[a+480180>>2]&202376205?c&240?c&-16:c&15:c;c=v[b+688>>2];b:{if(v[a+480180>>2]&69206029){break b}e=d&240;f=d&15;if((f|0)==15){if(e){Lq(a,b,(d&240)>>>4|0,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c-60|0;break b}if((e|0)!=240){break b}if(f){Kq(a,b,f,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c+60|0}c:{if(!(v[a+1074416>>2]!=1|v[a+480180>>2]!=524288?!(t[b+851|0]&1)|w[a+480208|0]&2:1)){break c}e=d&255;d=d&15;d:{if(d){if(e&240?v[a+480180>>2]&16777248:0){break d}c=c-(d<<2)|0;break d}c=(e>>>2&60)+c|0}if(v[a+480180>>2]!=1){break c}v[b+88>>2]=v[b+88>>2]|2097152}g=b,h=Lb(c,0,256),v[g+688>>2]=h}function qia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=(e<<1)+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function lC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=gb-32|0;gb=g;e=b;f=Nb(e);d=c;a:{if(f>>>0<d>>>0){j=gb-32|0;gb=j;b:{c:{h=d-f|0;d:{if(h>>>0<=v[wb(e)>>2]-v[e+4>>2]>>2>>>0){lr(e,h);break d}i=wb(e);k=kr(e,Nb(e)+h|0);m=Nb(e);f=0;l=gb-16|0;gb=l;v[l+12>>2]=0;d=j+8|0;ef(d+12|0,i);if(k){f=_V(k)}v[d>>2]=f;i=(m<<2)+f|0;v[d+8>>2]=i;v[d+4>>2]=i;n=cc(d),o=(k<<2)+f|0,v[n>>2]=o;gb=l+16|0;v[22640]=0;ev(d,h);f=v[22640];v[22640]=0;if((f|0)==1){break c}Uk(e,d);$V(d)}gb=j+32|0;break b}a=P()|0;O()|0;$V(d);S(a|0);L()}break a}if(d>>>0<f>>>0){Vk(e,v[e>>2]+(d<<2)|0)}}if(Pb(a,c<<2)){bc(g+24|0,v[b>>2],Nb(b)<<2);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0}function Hma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0,i=0,j=0,k=C(0),l=0;c=gb-16|0;gb=c;if(v[b+8>>2]==v[a+8>>2]){if(v[b+4>>2]==v[a+4>>2]){v[c+12>>2]=v[b+8>>2];v[c+8>>2]=v[a+8>>2];h=v[Fb(c+12|0,c+8|0)>>2];v[c+12>>2]=v[b+4>>2];v[c+8>>2]=v[a+4>>2];d=Fb(c+12|0,c+8|0);if(h){i=v[d>>2];d=0;while(1){e=0;if(i){while(1){j=c,k=z[ir(b,e,d)>>2],z[j+12>>2]=k;v[c+8>>2]=-1082130432;v[c+4>>2]=1065353216;f=C(z[Wf(c+12|0,c+8|0,c+4|0)>>2]*C(32768));z[c+12>>2]=f;f=re(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}g=Sc(g);j=HV(a,e,d),l=g,u[j>>1]=l;e=e+1|0;if((i|0)!=(e|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}gb=c+16|0;return}ba(14365,6194,28,6685);L()}ba(14415,6194,27,6685);L()}function YI(a,b,c,d){a:{if(b>>>0>20){break a}b:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 1:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return;case 4:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 5:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 6:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 8:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 9:break b;default:break a}}kb[d|0](a,c)}}function X5(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-48|0;gb=d;if(wa(1,d+32|0)|0){Ms(v[115121],10070);L()}c=bt(d+16|0,d+32|0);g=bt(d+8|0,d+32|4);e=gb-32|0;gb=e;b=gb-16|0;gb=b;h=gb-16|0;gb=h;a=gb-16|0;gb=a;i=a,j=mqa(v[c>>2],v[c+4>>2],1e9,0),v[i>>2]=j;v[a+4>>2]=jb;c=Jl(a+8|0,a);f=v[c+4>>2];c=v[c>>2];gb=a+16|0;gb=h+16|0;v[b+8>>2]=c;v[b+12>>2]=f;a=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=a;gb=b+16|0;f=v[e+8>>2];c=v[e+12>>2];a=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=a;a=e;c=v[a+4>>2]+c|0;b=v[a>>2];f=f+b|0;v[a+16>>2]=f;v[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=Jl(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];gb=e+32|0;v[d+24>>2]=a;v[d+28>>2]=b;a=Jl(d+40|0,d+24|0);b=v[a+4>>2];a=v[a>>2];gb=d+48|0;jb=b;return a|0}function VB(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;if(t[a|0]&1){t[b+12|0]=w[b+12|0]|1}if(w[a|0]&2){t[b+12|0]=w[b+12|0]|4}if(w[a|0]&4){t[b+12|0]=w[b+12|0]|2}if(w[a|0]&16){t[b+12|0]=w[b+12|0]|16}if(w[a|0]&32){t[b+12|0]=w[b+12|0]|8}t[g+15|0]=w[a+1|0];t[g+14|0]=25;hh(b,w[ac(g+15|0,g+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];if(Nb(b)){while(1){f=(d<<2)+a|0;e=f+6|0;e=w[e|0]|w[e+1|0]<<8;h=Mb(b,d),i=e,u[h>>1]=i;a:{if(!d){break a}e=d-1|0;if(x[Mb(b,d)>>1]>=x[Mb(b,e)>>1]){break a}e=x[Mb(b,e)>>1];h=Mb(b,d),i=e+1|0,u[h>>1]=i}f=f+8|0;f=Lb((w[f|0]|w[f+1|0]<<8)<<16>>16>>c,0,64);h=Mb(b,d),i=f,t[h+2|0]=i;d=d+1|0;if(Nb(b)>>>0>d>>>0){continue}break}}gb=g+16|0}function Tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+8>>2]=f;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;b=b+k|0;f=f>>>21&2040;b=(((B(t[b|0],u[f+46530>>1])+B(t[b-1|0],u[f+46528>>1])|0)+B(t[b+1|0],u[f+46532>>1])|0)+B(t[b+2|0],u[f+46534>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(g,b);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Ub(e+8|0,e);d=d-1|0;if(d){c=c+8|0;f=v[e+8>>2];b=v[e+12>>2];continue}break}f=v[e+8>>2];b=v[e+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=b;gb=e+16|0}function RN(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=gb-16|0;gb=h;t[h+15|0]=b;t[h+14|0]=10;hh(g,w[ac(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;if(Nb(g)){c=0;while(1){b=B(c,3)+f|0;d=w[b|0]|w[b+1|0]<<8;i=Mb(g,c),j=d>>>4|0,u[i>>1]=j;e=0;a:{if(c){d=c-1|0;if(x[Mb(g,c)>>1]>=x[Mb(g,d)>>1]){break a}e=x[Mb(g,d)>>1]+1|0}i=Mb(g,c),j=e,u[i>>1]=j}b=Jd(w[b+2|0],0,64);i=Mb(g,c),j=b,t[i+2|0]=j;c=c+1|0;if(Nb(g)>>>0>c>>>0){continue}break}}b=w[g+12|0]&-2|a&1;t[g+12|0]=b;c=g;if(a&2){b=w[g+15|0];d=Nb(g);b=w[g+12|0]&-5|(b>>>0<=d>>>0)<<2}else{b=b&251}t[c+12|0]=b;c=g;b:{c:{if(a&4){a=w[g+13|0];if(a>>>0<=w[g+14|0]){break c}}a=b&253;break b}b=Nb(g);a=w[g+12|0]&-3|(a>>>0<=b>>>0)<<1}t[c+12|0]=a;gb=h+16|0}function fba(a){a=a|0;var b=0;b=5229;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=14626;break a}switch(a-277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=18693;break a}b=5262;break a}b=2107;break a}b=5285;break a}b=5299;break a}b=2480;break a}b=2500;break a}b=5311;break a}b=5243;break a}b=10189;break a}b=9457;break a}b=3111;break a}if((a|0)!=357){break a}b=5196}return ie(b)|0}function cO(a){var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;v[b+12>>2]=B(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),5)+(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24));v[b+16>>2]=(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))+((w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))<<3);c=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);a=w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24);v[b+28>>2]=3;v[b+20>>2]=c+(a<<2);v[b+24>>2]=b+12;a=v[b+28>>2];v[b>>2]=v[b+24>>2];v[b+4>>2]=a;a=v[b>>2];d=UC(b);e=gb-16|0;gb=e;a:{if((a|0)==(d|0)){break a}c=a+4|0;if((d|0)==(c|0)){break a}while(1){a=Ed(a,c)?c:a;c=c+4|0;if((d|0)!=(c|0)){continue}break}}gb=e+16|0;gb=b+32|0;return v[a>>2]-36|0}function Xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=gb-32|0;gb=g;c=gb-16|0;gb=c;d=a;k=d;h=b;e=Vd(d);f=ec(d);i=gb-16|0;gb=i;if(e){while(1){j=ru(wb(k),e+16|0,h);f=j?f:e;e=v[(j?4:0)+e>>2];if(e){continue}break}}h=v[yc(i+8|0,f)>>2];gb=i+16|0;v[c+8>>2]=h;l=c,m=yh(d),v[l>>2]=m;a:{b:{if(!Xl(c+8|0,c)){break b}if(ru(wb(d),b,ue(c+8|0))){break b}b=v[c+8>>2];break a}b=yh(d)}gb=c+16|0;v[g+24>>2]=b;l=g,m=yh(a),v[l+16>>2]=m;if(!Jk(g+24|0,g+16|0)){b=v[yc(g+8|0,b)>>2];d=gb-16|0;gb=d;v[d+8>>2]=b;h=v[d+8>>2];e=h;c=gb-16|0;gb=c;f=yc(c+8|0,e);Oj(f);b=a;if((e|0)==v[b>>2]){v[b>>2]=v[f>>2]}f=wb(b);v[f>>2]=v[f>>2]-1;gN(v[ec(b)>>2],e);gb=c+16|0;ec(a);Rm(ue(d+8|0));tA(h);gb=d+16|0}gb=g+32|0}function gna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=gb-32|0;gb=g;d=b;f=sc(d);e=c;a:{if(f>>>0<e>>>0){h=gb-32|0;gb=h;b:{c:{f=e-f|0;d:{if(f>>>0<=v[wb(d)>>2]-v[d+4>>2]>>1>>>0){i=gb-16|0;gb=i;e=ji(i,d,f);d=v[e+4>>2];f=v[e+8>>2];if((d|0)!=(f|0)){while(1){Kk(d);d=d+2|0;v[e+4>>2]=d;if((d|0)!=(f|0)){continue}break}}$b(e);gb=i+16|0;break d}e=wb(d);e=lD(h+8|0,MY(d,sc(d)+f|0),sc(d),e);v[22640]=0;TV(e,f);f=v[22640];v[22640]=0;if((f|0)==1){break c}Uk(d,e);rp(e)}gb=h+32|0;break b}a=P()|0;O()|0;rp(e);S(a|0);L()}break a}if(e>>>0<f>>>0){Vk(d,v[d>>2]+(e<<1)|0)}}c=Pb(a,c<<1);if(c){bc(g+24|0,v[b>>2],sc(b)<<1);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function Gha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=c;e=gb-32|0;gb=e;h=b;f=b;b=Vd(b);d=ec(f);a:{b:{if(b){wb(f);c:{while(1){d:{f=b+14|0;e:{if(Fn(c,f)){if(!v[b>>2]){break b}d=b;break e}if(!Fn(f,c)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d;d=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=d;break a}v[e+28>>2]=b;b=d;break a}b=ec(f)}v[e+28>>2]=b}c=b;b=v[b>>2];t[e+27|0]=0;if(!b){b=gb-16|0;gb=b;d=ec(h);d=Pj(e+8|0,Mc(16,4),Qj(b+8|0,d));Qo(v[d>>2]+14|0,i);j=ec(d),k=1,t[j+4|0]=k;gb=b+16|0;HS(h,v[e+28>>2],c,v[e+8>>2]);b=$d(e+8|0);t[e+27|0]=1;d=e+8|0;c=v[d>>2];v[d>>2]=0;if(c){d=ec(d);if(c){On(v[d>>2],c,1)}}}Rj(g+8|0,yc(e+8|0,b),e+27|0);gb=e+32|0;KS(a,g+8|0);gb=g+16|0}function Y5(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=gb-48|0;gb=b;if(wa(0,b+32|0)|0){Ms(v[115121],10033);L()}d=bt(b+16|0,b+32|0);v[b+4>>2]=v[b+36>>2]/1e3;g=bt(b+8|0,b+4|0);e=gb-32|0;gb=e;c=gb-16|0;gb=c;a=gb-16|0;gb=a;h=a,i=mqa(v[d>>2],v[d+4>>2],1e6,0),v[h>>2]=i;v[a+4>>2]=jb;d=Jl(a+8|0,a);f=v[d+4>>2];d=v[d>>2];gb=a+16|0;v[c+8>>2]=d;v[c+12>>2]=f;a=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=a;gb=c+16|0;f=v[e+8>>2];d=v[e+12>>2];a=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=a;a=e;d=v[a+4>>2]+d|0;c=v[a>>2];f=f+c|0;v[a+16>>2]=f;v[a+20>>2]=c>>>0>f>>>0?d+1|0:d;a=Jl(a+24|0,a+16|0);c=v[a+4>>2];a=v[a>>2];gb=e+32|0;v[b+24>>2]=a;v[b+28>>2]=c;a=Jl(b+40|0,b+24|0);c=v[a+4>>2];a=v[a>>2];gb=b+48|0;jb=c;return a|0}function ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=gb-16|0;gb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=e+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Ub(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=g+16|0}function qaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[22640]=0;_(1960,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break f}e=v[a+24>>2];v[22640]=0;c=Q(112,d|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;U(1961,d+16|0,e|0,c|0);b=v[22640];v[22640]=0;if((b|0)==1){break d}b=ie(Jb(d+16|0));vb(d+16|0);vb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;vb(c)}Z(b|0)|0;b=0;v[22640]=0;Y(1911,10677,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$()}gb=d+32|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function L9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[22640]=0;_(1960,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break f}e=v[a+24>>2];v[22640]=0;c=Q(112,d|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break e}v[22640]=0;Y(1995,d+16|0,e|0,c|0,1);b=v[22640];v[22640]=0;if((b|0)==1){break d}b=ie(Jb(d+16|0));vb(d+16|0);vb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;vb(c)}Z(b|0)|0;b=0;v[22640]=0;Y(1911,3495,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$()}gb=d+32|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function tZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;td(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Lr(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=Lr(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+15|0]=127;t[d+14|0]=w[a+15|0];f=b,g=(((w[ac(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[f+30>>1]=g;e=a+12|0;if(w[e|0]>=16){c=w[e|0];u[b+34>>1]=32;u[b+28>>1]=c&240}c=a+13|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}f=b,g=(B(Au(0,w[e|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[f+24>>2]=g;if(y[b+4>>2]<y[b+8>>2]){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}gb=d+16|0}function NM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=gb-48|0;gb=c;v[c+8>>2]=542066252;d=c+8|4;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;d=v[b+4220>>2];t[c+16|0]=d;t[c+17|0]=d>>>8;t[c+18|0]=d>>>16;t[c+19|0]=d>>>24;d=v[b+4224>>2];t[c+20|0]=d;t[c+21|0]=d>>>8;t[c+22|0]=d>>>16;t[c+23|0]=d>>>24;d=v[b+4228>>2];t[c+24|0]=d;t[c+25|0]=d>>>8;t[c+26|0]=d>>>16;t[c+27|0]=d>>>24;d=v[b+4232>>2];t[c+28|0]=d;t[c+29|0]=d>>>8;t[c+30|0]=d>>>16;t[c+31|0]=d>>>24;d=v[b+4236>>2];t[c+32|0]=d;t[c+33|0]=d>>>8;t[c+34|0]=d>>>16;t[c+35|0]=d>>>24;t[c+36|0]=w[b+4240|0];t[c+37|0]=w[b+4241|0];t[c+38|0]=w[b+4242|0];t[c+39|0]=w[b+4243|0];t[c+40|0]=w[b+4244|0];b=b+4208|0;Fk(b,33);hc(v[b>>2],c+8|0,33);be(c,b);le(a,c);gb=c+48|0}function hh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Nb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){e=gb-16|0;gb=e;d:{b=yg(e,a,c);c=v[b+4>>2];f=v[b+8>>2];if((c|0)!=(f|0)){while(1){wb(a);v[22640]=0;Sr(c);g=v[22640];v[22640]=0;if((g|0)==1){break d}c=c+4|0;v[b+4>>2]=c;if((c|0)!=(f|0)){continue}break}}$b(b);gb=e+16|0;break c}a=P()|0;O()|0;$b(b);S(a|0);L()}b=wb(a);b=zp(d+8|0,_g(a,Nb(a)+c|0),Nb(a),b);v[22640]=0;R(331,b|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}v[22640]=0;R(332,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}cj(b)}gb=d+32|0;break a}a=P()|0;O()|0;cj(b);S(a|0);L()}return}if(b>>>0<c>>>0){dj(a,v[a>>2]+(b<<2)|0)}}function Vpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-48|0;gb=e;g=a+8|0;a:{c=v[a+8>>2];i=cc(a);b:{if((c|0)!=v[i>>2]){break b}h=a+4|0;d=v[a+4>>2];f=v[a>>2];if(d>>>0>f>>>0){f=((d-f>>1)+1|0)/-2<<1;a=f+d|0;if((c|0)!=(d|0)){while(1){CY(a,d);a=a+2|0;d=d+2|0;if((d|0)!=(c|0)){continue}break}}c=a;v[g>>2]=a;v[h>>2]=f+v[h>>2];break b}v[e+24>>2]=c-f;v[e+44>>2]=1;c=v[Jc(e+24|0,e+44|0)>>2];c=lD(e+24|0,c,c>>>2|0,v[a+16>>2]);d=yc(e+16|0,v[a+4>>2]);f=v[yc(e+8|0,v[a+8>>2])>>2];d=v[d>>2];v[22640]=0;DY(c,d,f);d=v[22640];v[22640]=0;if((d|0)==1){break a}wc(a,c);wc(h,c+4|0);wc(g,c+8|0);wc(i,cc(c));rp(c);c=v[a+8>>2]}Gr(c,b);v[g>>2]=v[g>>2]+2;gb=e+48|0;return}a=P()|0;O()|0;rp(c);S(a|0);L()}function n3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-48|0;gb=f;v[f+40>>2]=b;a:{b:{c:{d:{if(!(v[c+4>>2]&1)){b=kb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break d}Ec(f+24|0,c);v[22640]=0;a=T(2459,f+24|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}Vb(f+24|0);e:{if(e){Ph(f+24|0,a);break e}Oh(f+24|0,a)}g=f,h=wd(f+24|0),v[g+16>>2]=h;g=f,h=ui(f+24|0),v[g+8>>2]=h;if(Gb(f+16|0,f+8|0)){while(1){a=v[v[f+16>>2]>>2];v[22640]=0;Q(2478,f+40|0,a|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}Fg(f+16|0);g=f,h=ui(f+24|0),v[g+8>>2]=h;if(Gb(f+16|0,f+8|0)){continue}break}b=v[f+40>>2]}Hc(f+24|0)}gb=f+48|0;return b|0}b=P()|0;O()|0;Vb(f+24|0);break a}b=P()|0;O()|0;Hc(f+24|0)}S(b|0);L()}function _k(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=gb-32|0;gb=c;a:{d=v[a+32>>2];if((d|0)>=(b|0)){f=v[a+28>>2];break a}i=a+36|0;g=v[a+24>>2];e=v[a+20>>2];h=d;while(1){b:{if(e>>>0>=g>>>0){pd(c+16|0,i,i+1024|0);d=v[c+20>>2];v[c+8>>2]=v[c+16>>2];v[c+12>>2]=d;gd(c+24|0,a,c+8|0);g=xb(c+24|0);v[a+24>>2]=g;v[a+20>>2]=0;if(!g){break b}e=0;h=v[a+32>>2]}j=e+1|0;v[a+20>>2]=j;e=w[(a+e|0)+36|0];d=h+8|0;v[a+32>>2]=d;f=v[a+28>>2]|e<<h;v[a+28>>2]=f;h=d;e=j;if((b|0)>(d|0)){continue}break a}break}a=aa(8)|0;v[22640]=0;T(241,a|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){b=P()|0;O()|0;da(a|0);S(b|0);L()}ia(a|0,27860,242);L()}v[a+32>>2]=d-b;v[a+28>>2]=f>>>b;gb=c+32|0;return(-1<<b^-1)&f}function se(a,b){var c=0,d=0,e=0;d=gb-32|0;gb=d;a=Bh(a,-1,-1);a:{b:{if(w[rj(d+24|0,b,1)|0]){c=v[v[b>>2]-12>>2];v[22640]=0;c=v[(b+c|0)+24>>2];e=v[22640];v[22640]=0;c:{d:{if((e|0)==1){break d}v[22640]=0;Fa(2289,d+8|0,c|0,0,0,1,8);c=v[22640];v[22640]=0;if((c|0)==1){break d}c=v[d+12>>2];v[a>>2]=v[d+8>>2];v[a+4>>2]=c;c=v[d+20>>2];v[a+8>>2]=v[d+16>>2];v[a+12>>2]=c;a=0;break c}a=V(0)|0;O()|0;Z(a|0)|0;a=1;qj(v[v[b>>2]-12>>2]+b|0,1);if(v[(v[v[b>>2]-12>>2]+b|0)+20>>2]&1){v[22640]=0;X(2027);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){break b}S(a|0);L()}$()}fh(v[v[b>>2]-12>>2]+b|0,a)}gb=d+32|0;return}V(0)|0;O()|0;Bb()}L()}function fI(a){a=a|0;var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[22640]=0;c=Q(2292,d+8|0,a|0)|0;b=v[22640];v[22640]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[22640]=0;b=T(2293,b|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[22640]=0;_(2294,a+b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;eI(c);break c}eI(c);break b}b=V(0)|0;O()|0}Z(b|0)|0;c=v[v[a>>2]-12>>2];v[22640]=0;_(19,a+c|0);c=v[22640];v[22640]=0;if((c|0)==1){break a}$()}gb=d+16|0;return a|0}a=P()|0;O()|0;v[22640]=0;X(20);c=v[22640];v[22640]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Oz(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=gb-16|0;gb=c;if(!$c(a)){l=c,m=Sb(a),v[l+8>>2]=m;l=c,m=Wb(a),v[l>>2]=m;if(Gb(c+8|0,c)){while(1){b=v[c+8>>2];Gp(b,4194304,67108864);e=v[b>>2];f=e+f|0;b=g;b=f>>>0<e>>>0?b+1|0:b;g=b;Xg(c+8|0);if(Gb(c+8|0,c)){continue}break}}b=Nb(a);h=Nb(a);l=c,m=Sb(a),v[l+8>>2]=m;l=c,m=Wb(a),v[l>>2]=m;b=pqa(f,g,b,0);e=jb;f=h<<24;g=0;if(Gb(c+8|0,c)){h=b;e=((e&1)<<31|b>>>1)&2147483647;while(1){b=v[c+8>>2];i=b;d=v[b>>2];b=d>>>8|0;d=e+(d<<24)|0;b=b+j|0;b=Uc(pqa(d,e>>>0>d>>>0?b+1|0:b,h,k),jb);v[i>>2]=b;d=f;f=d-b|0;g=g-(b>>>0>d>>>0)|0;Xg(c+8|0);if(Gb(c+8|0,c)){continue}break}}if(!Nb(a)){Qx();L()}a=v[a>>2];v[a>>2]=f+v[a>>2]}gb=c+16|0}function y3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-48|0;gb=f;v[f+40>>2]=b;a:{b:{c:{d:{if(!(v[c+4>>2]&1)){b=kb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break d}Ec(f+24|0,c);v[22640]=0;a=T(2430,f+24|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break c}Vb(f+24|0);e:{if(e){Ph(f+24|0,a);break e}Oh(f+24|0,a)}g=f,h=wd(f+24|0),v[g+16>>2]=h;g=f,h=df(f+24|0),v[g+8>>2]=h;if(Gb(f+16|0,f+8|0)){while(1){a=t[v[f+16>>2]];v[22640]=0;Q(2297,f+40|0,a|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}Me(f+16|0);g=f,h=df(f+24|0),v[g+8>>2]=h;if(Gb(f+16|0,f+8|0)){continue}break}b=v[f+40>>2]}vb(f+24|0)}gb=f+48|0;return b|0}b=P()|0;O()|0;Vb(f+24|0);break a}b=P()|0;O()|0;vb(f+24|0)}S(b|0);L()}function qZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(Jg(a,d+8|0)){v[d+4>>2]=w[d+8|0];e=v[Fb(d+4|0,d+12|0)>>2];c=gb+-64|0;gb=c;Pe(c+40|0,a,e);a=v[c+40>>2];v[22640]=0;e=Rd(c+40|0);f=v[22640];v[22640]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22640]=0;Te(c+8|0,3,e,a);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;R(377,c+24|0,c+8|0);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;R(428,c|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}v[22640]=0;Q(429,c|0,c+24|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break c}vb(c+24|0);xc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}xc(c+40|0);S(a|0);L()}}gb=d+16|0}function h5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;a:{b:{if(!He(b,-1)){h=v[a+12>>2];i=v[a+8>>2];g=v[a+24>>2];if((g|0)==v[a+28>>2]){c=-1;if(!(w[a+48|0]&16)){break a}e=v[a+20>>2];j=v[a+44>>2];v[22640]=0;c=a+32|0;R(103,c|0,0);d=v[22640];v[22640]=0;if((d|0)==1){break b}d=Kc(c);v[22640]=0;R(118,c|0,d|0);d=v[22640];v[22640]=0;if((d|0)==1){break b}d=Jb(c);Fx(a,d,Ab(c)+d|0);Us(a,g-e|0);v[a+44>>2]=v[a+20>>2]+(j-e|0)}v[f+12>>2]=v[a+24>>2]+1;c=a+44|0;e=f+12|0;k=a,l=v[(Ed(e,c)?c:e)>>2],v[k+44>>2]=l;if(w[a+48|0]&8){c=Jb(a+32|0);Zn(a,c,c+(h-i|0)|0,v[a+44>>2])}c=gI(a,oh(b));break a}c=Ss(b);break a}a=V(0)|0;O()|0;Z(a|0)|0;$();c=-1}gb=f+16|0;return c|0}function $la(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;c=b;d=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=d;d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=fV(e);c=a;Br(c);t[c+8|0]=0;v[c+4>>2]=d;v[c>>2]=18824;d=nc(c+12|0);t[c+24|0]=0;v[22640]=0;Q(37,c+28|0,0)|0;f=v[22640];v[22640]=0;a:{if((f|0)!=1){d=c+40|0;f=d+192|0;while(1){v[d>>2]=0;v[d+4>>2]=0;t[d+8|0]=0;d=d+12|0;if((f|0)!=(d|0)){continue}break}if(w[c+24|0]){c=c+232|0;d=0;while(1){g=ci(c,d),h=d,v[g>>2]=h;d=d+1|0;if((d|0)!=16){continue}break}}break a}a=P()|0;O()|0;gc(d);S(a|0);L()}v[a>>2]=18932;c=v[b+4>>2];v[a+296>>2]=v[b>>2];v[a+300>>2]=c;c=v[b+12>>2];v[a+304>>2]=v[b+8>>2];v[a+308>>2]=c;gb=e+16|0;return a|0}function Fka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=gb-112|0;gb=h;a:{if(!Ld(a)){break a}if(Cc(b)>>>0<2){break a}f=Zo(h+8|0,a);v[f+20>>2]=0;v[f>>2]=0;c=Cc(b);b:{if(!c){break b}e=v[a>>2];while(1){d=xd(b,g);j=v[d>>2];if(e>>>0<=j>>>0){break b}d=v[d+4>>2];if(d>>>0>e-j>>>0|268435456-d>>>0<i>>>0){break b}i=d+i|0;v[f>>2]=i;g=g+1|0;if((c|0)!=(g|0)){continue}break}g=c}if(!_m(f)){break a}if(g){c=0;e=0;while(1){d=xd(b,c);hc(zb(v[f+20>>2])+e|0,zb(v[a+20>>2])+v[d>>2]|0,v[d+4>>2]);v[d>>2]=e;if(!(!c|c>>>0>9)){v[((c<<2)+f|0)- -64>>2]=e}e=v[d+4>>2]+e|0;c=c+1|0;if((g|0)!=(c|0)){continue}break}}Ol(a);Zo(a,f);v[a+4>>2]=0;v[a+8>>2]=v[a>>2];u[a+34>>1]=x[a+34>>1]|2}gb=h+112|0}function $p(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-16|0;gb=h;f=d?d:463692;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}a=t[b|0];if(!v[v[22545]>>2]){v[i>>2]=a&57343;e=1;break a}a=(a&255)-194|0;if(a>>>0>50){break c}d=v[(a<<2)+76576>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[115121]=25;e=-1;break a}v[f>>2]=d}gb=h+16|0;return e|0}function nN(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-48|0;gb=e;f=Kb(e+32|0);v[22640]=0;Q(1521,a|0,e+24|0)|0;d=v[22640];v[22640]=0;a:{b:{if((d|0)!=1){g=v[e+28>>2];d=v[e+24>>2];Ye(f);v[22640]=0;g=!g&d>>>0<255?d:255;R(118,f|0,g|0);d=v[22640];v[22640]=0;if((d|0)==1){break a}if(g){d=0;while(1){h=mc(f,d);v[22640]=0;Q(1522,a|0,h|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break a}d=d+1|0;if((g|0)!=(d|0)){continue}break}}if((xI(f)|0)!=-1){a=xI(f);v[22640]=0;R(118,f|0,a|0);a=v[22640];v[22640]=0;if((a|0)==1){break a}}v[22640]=0;U(13,e+8|0,c|0,f|0);a=v[22640];v[22640]=0;if((a|0)!=1){break b}break a}break a}Eb(b,e+8|0);vb(e+8|0);vb(f);gb=e+48|0;return}a=P()|0;O()|0;vb(f);S(a|0);L()}function eA(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;a:{if(!d){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}c=v[a+480180>>2]&1048580?c&240?c&-16:c&15:c;b:{c:{d:{if(!(v[a+480180>>2]&1048580)){d=c&240;c=c&15;if(!(!d|(c|0)!=15)){if(!(w[a+480209|0]&16)){break b}c=0-(d>>>2|0)|0;break d}f=v[a+480208>>2]&4096;if(!(!c|(d|0)!=240)){if(!f){break b}c=c<<2;break c}if(f){break b}if(c){c=c<<2;if(!(v[a+480180>>2]&16777248)|!d){break c}break b}c=0-(d>>>2|0)|0;break d}if(w[a+480209|0]&16){break b}Db(e+8|0,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;c=a;if(!Cb(e+8|0)){break d}c=(a|0)/4<<24>>24}if(!c){break b}}a=Lb(v[b+692>>2]+c|0,0,256);u[b+784>>1]=0;v[b+692>>2]=a}gb=e+16|0}function oq(a,b,c){var d=0,e=0,f=0;d=Kb(a);a=Ab(b);v[22640]=0;R(102,d|0,a|0);a=v[22640];v[22640]=0;if((a|0)!=1){a:{if(Ab(b)){while(1){f=v[kk(b,e)>>2];a=32;b:{c:{while(1){if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;if(a>>>0<256){continue}break c}break}v[22640]=0;R(103,d|0,a<<24>>24);a=v[22640];v[22640]=0;if((a|0)!=1){break b}break a}a=0;while(1){d:{if(v[(a<<2)+c>>2]==(f|0)){v[22640]=0;R(103,d|0,a<<24>>24);a=v[22640];v[22640]=0;if((a|0)!=1){break b}break a}if(a>>>0>30){break d}a=a+1|0;if(a>>>0<256){continue}}break}v[22640]=0;R(103,d|0,63);a=v[22640];v[22640]=0;if((a|0)!=1){break b}break a}e=e+1|0;if(Ab(b)>>>0>e>>>0){continue}break}}return}}a=P()|0;O()|0;vb(d);S(a|0);L()}function WP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=gb-112|0;gb=f;v[f+108>>2]=0;d=Om(a,x[d+70>>1],v[d+48>>2],c,f+108|0);c=w[b+790|0];if(!v[f+108>>2]){e=!w[b+792|0]&(c|0)==15;d=d<<8;a:{if(d){v[b+664>>2]=d;break a}d=0;if(e){break a}d=v[b+664>>2]}d=(e?0:w[b+836|0]<<16)+d|0}b:{if((c|0)!=15){break b}c=w[b+792|0];if(!c){c=v[b+76>>2];v[f>>2]=1;e=v[Jc(f,f+108|0)>>2]<<3;g=mqa(c,0,d,0);d=(256<<e>>>1|0)+g|0;c=jb;c=d>>>0<g>>>0?c+1|0:c;g=d;e=e+8|0;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}d=Uc(c,e);break b}eU(f,0);if(c>>>0>9){break b}c=v[b+104>>2];if(!c){break b}d=v[(c+(w[b+792|0]<<2)|0)- -64>>2]+d|0}Mm(a,b,d);gb=f+112|0}function Jha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-48|0;gb=d;a:{b:{if(v[a+8>>2]!=v[cc(a)>>2]){break b}g=a+8|0;h=a+4|0;c=v[a+4>>2];e=v[a>>2];if(c>>>0>e>>>0){f=c;c=((c-e>>2)+1|0)/-2<<2;i=g,j=Bg(f,v[g>>2],f+c|0),v[i>>2]=j;v[h>>2]=c+v[h>>2];break b}i=d,j=v[cc(a)>>2]-v[a>>2]>>1,v[i+24>>2]=j;v[d+44>>2]=1;c=v[Jc(d+24|0,d+44|0)>>2];c=zp(d+24|0,c,c>>>2|0,v[a+16>>2]);e=yc(d+16|0,v[a+4>>2]);f=v[yc(d+8|0,v[a+8>>2])>>2];e=v[e>>2];v[22640]=0;U(1091,c|0,e|0,f|0);e=v[22640];v[22640]=0;if((e|0)==1){break a}jc(a,c);jc(h,c+4|0);jc(g,c+8|0);jc(cc(a),cc(c));cj(c)}gn(v[a+16>>2],v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+4;gb=d+48|0;return}a=P()|0;O()|0;cj(c);S(a|0);L()}function Gga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+7;TQ(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+7;$b(c);gb=c+16|0;return}g=gb-32|0;gb=g;h=wb(a);i=g+8|0;j=a;f=wA(a)+1|0;d=gb-16|0;gb=d;v[d+12>>2]=f;e=gb-16|0;gb=e;v[e+12>>2]=613566756;v[22640]=0;v[e+8>>2]=2147483647;k=Fb(e+12|0,e+8|0);c=v[22640];v[22640]=0;a:{if((c|0)!=1){gb=e+16|0;c=v[k>>2];break a}V(0)|0;O()|0;Bb();L()}b:{if(c>>>0>=f>>>0){f=sA(j);if(f>>>0<c>>>1>>>0){v[d+8>>2]=f<<1;c=v[Jc(d+8|0,d+12|0)>>2]}gb=d+16|0;break b}Rc();L()}c=dR(i,c,wA(a),h);TQ(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+7;cR(a,c);bR(c);gb=g+32|0}function $2(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;f=RF(v[v[a>>2]-12>>2]+a|0,10);e=gb-16|0;gb=e;v[22640]=0;c=a;d=Q(15,e+8|0,c|0)|0;b=v[22640];v[22640]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!w[d|0]){break e}b=_i(e,c);v[22640]=0;Q(2297,b|0,f|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){if(!Wv(b)){break e}b=v[v[c>>2]-12>>2];v[22640]=0;R(18,b+c|0,1);b=v[22640];v[22640]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;pl(d);break d}pl(d);break c}b=V(0)|0;O()|0}Z(b|0)|0;d=v[v[c>>2]-12>>2];v[22640]=0;_(19,c+d|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}$()}gb=e+16|0;break a}a=P()|0;O()|0;v[22640]=0;X(20);c=v[22640];v[22640]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}Ws(a);return a|0}function R2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;c=gb-416|0;gb=c;v[c+12>>2]=c+416;d=gb-144|0;gb=d;v[d+28>>2]=d+132;dH(a+8|0,d+32|0,d+28|0,e,f,g);v[d+16>>2]=0;v[d+20>>2]=0;v[d+12>>2]=d+32;f=c+16|0;h=WV(f,v[c+12>>2]);e=gb-16|0;gb=e;v[e+12>>2]=v[a+8>>2];g=vi(e+8|0,e+12|0);v[22640]=0;a=sx(f,d+12|0,h,d+16|0);h=v[22640];v[22640]=0;a:{if((h|0)!=1){ff(g);gb=e+16|0;break a}a=P()|0;O()|0;ff(g);S(a|0);L()}if((a|0)==-1){Gs(9912);L()}v[c+12>>2]=f+(a<<2);gb=d+144|0;e=v[c+12>>2];a=gb-16|0;gb=a;v[a+8>>2]=b;d=c+16|0;if((e|0)!=(d|0)){while(1){ZH(a+8|0,v[d>>2]);d=d+4|0;if((e|0)!=(d|0)){continue}break}b=v[a+8>>2]}gb=a+16|0;gb=c+416|0;return b|0}function U8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=Zp(c,a,1);wy(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+16;$b(a);gb=c+16|0;return}e=gb-32|0;gb=e;c=wb(a);c=WG(e+8|0,fx(a,qf(a)+1|0),qf(a),c);wy(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+16;b=c;h=c+4|0;f=h;d=a;i=v[a>>2];a=v[a+4>>2];if((i|0)!=(a|0)){g=v[f>>2];while(1){a=a-16|0;wy(g-16|0,a);g=v[f>>2]-16|0;v[f>>2]=g;if((a|0)!=(i|0)){continue}break}}wc(d,h);wc(d+4|0,b+8|0);wc(wb(d),cc(b));v[b>>2]=v[b+4>>2];a=c;b=a;d=v[a+8>>2];c=v[a+4>>2];if((d|0)!=(c|0)){while(1){d=d-16|0;v[b+8>>2]=d;zk(d);d=v[b+8>>2];if((c|0)!=(d|0)){continue}break}}b=v[a>>2];if(b){sK(b,_w(a))}gb=e+32|0}function uma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=gb-608|0;gb=g;c=gb-32|0;gb=c;f=g+8|0;kV(c+24|0,f);e=xb(c+24|0);b=v[c+28>>2];d=v[c+24>>2];v[c+8>>2]=d;v[c+12>>2]=b;v[c>>2]=d;v[c+4>>2]=b;b=a;qd(c+16|0,b,c);d=xb(c+16|0);if((d|0)==(e|0)){cd(b,xb(c+24|0))}gb=c+32|0;c=(d|0)==(e|0);if(!c){iV(f)}b=-1;a:{if(!c){break a}b=0;if(!uV(g+8|0)){break a}b=-1;if(!Rf(a,1024)){break a}b=0;e=gb-1024|0;gb=e;c=gb-32|0;gb=c;MB(c+24|0,e);f=xb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(f|0)){cd(a,xb(c+24|0))}gb=c+32|0;if((d|0)==(f|0)){b=OB(e,0)>>>0<17}gb=e+1024|0}gb=g+608|0;return b|0}function ija(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=gb-32|0;gb=e;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];g=v[a+4>>2];f=g;b=v[a>>2];v[e+24>>2]=b;v[e+28>>2]=f;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){m=b>>>18|0;h=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;g=0;b=1;while(1){i=g<<1;f=u[i+h>>1];v[(e+8|0)+(g<<2)>>2]=f+((B(u[(i|4)+h>>1]-f|0,m)|0)/16384|0);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],j);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;b=v[e+24>>2];f=v[e+28>>2];continue}break}b=v[e+24>>2];f=v[e+28>>2]}v[a>>2]=b;v[a+4>>2]=f;gb=e+32|0}function FJ(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=gb-16|0;gb=d;a:{b:{c:{d:{if((b|0)>=0){if((io(a+8|0)|0)>(b|0)){break d}}a=aa(8)|0;v[22640]=0;d=Q(112,d|0,8049)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}qc(a,d);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(d);break b}if(c<=1?c<0:1){a=aa(8)|0;v[22640]=0;d=Q(112,d|0,9056)|0;b=v[22640];v[22640]=0;if((b|0)!=1){qc(a,d);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(d);break b}b=P()|0;O()|0;da(a|0);break b}e=Oo(c*64);v[(v[a+32>>2]+B(b,872)|0)+1075740>>2]=e;gb=d+16|0;return}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function tn(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;j=1;i=d&2147483647;m=i;k=c;a:{if(!c&(i|0)==2147418112?a|b:(i|0)==2147418112&(c|0)!=0|i>>>0>2147418112){break a}l=h&2147483647;n=l;i=g;if(!g&(l|0)==2147418112?e|f:(l|0)==2147418112&(g|0)!=0|l>>>0>2147418112){break a}if(!(a|e|(i|k)|(b|f|(m|n)))){return 0}k=d&h;if((k|0)>0?1:(k|0)>=0){j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:(d|0)<(h|0)?1:(d|0)<=(h|0)?c>>>0<g>>>0:0){break a}return(a^e|c^g)!=0|(b^f|d^h)!=0}j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:(d|0)>(h|0)?1:(d|0)>=(h|0)?c>>>0>g>>>0:0){break a}j=(a^e|c^g)!=0|(b^f|d^h)!=0}return j}function C$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=gb+-64|0;gb=g;Jh(g+16|0,c);v[22640]=0;R(181,g+28|0,d|0);d=v[22640];v[22640]=0;c=1;b:{c:{if((d|0)==1){break c}v[22640]=0;R(181,g+40|0,e|0);c=v[22640];v[22640]=0;if((c|0)==1){c=2;break c}v[22640]=0;R(181,g+52|0,f|0);c=v[22640];v[22640]=0;if((c|0)==1){c=3;break c}c=g+16|0;v[g+8>>2]=c;v[g+12>>2]=c+48;v[22640]=0;c=v[g+12>>2];v[g>>2]=v[g+8>>2];v[g+4>>2]=c;U(183,a|0,b|0,g|0);a=v[22640];v[22640]=0;if((a|0)==1){c=P()|0;O()|0;aG(g+16|0);break b}aG(g+16|0);gb=g- -64|0;break a}a=(g+16|0)+B(c,12)|0;c=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(g+16|0)){continue}break}}S(c|0);L()}}function oea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{d=gb-16|0;gb=d;c=b;wb(b);e=a;h=xN(a,d+8|0);b:{f=Eg(b);if(!f){break b}v[22640]=0;R(637,e|0,f|0);g=v[22640];v[22640]=0;if((g|0)!=1){g=v[c+4>>2];c=v[c>>2];v[22640]=0;Y(1501,e|0,c|0,g|0,f|0);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}a=P()|0;O()|0;nv(h);S(a|0);L()}gb=d+16|0;v[a+20>>2]=v[b+20>>2];c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;v[22640]=0;c=Q(1500,a+24|0,b+24|0)|0;d=v[22640];v[22640]=0;c:{d:{if((d|0)!=1){v[22640]=0;Q(111,a+36|0,b+36|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}v[a+48>>2]=v[b+48>>2];break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;Lc(c)}kn(e);S(a|0);L()}}function lla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-32|0;gb=d;td(b,0);NC(d,a+1|0);Bc(d+16|0,d);v[22640]=0;Q(335,b+43|0,d+16|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){vb(d+16|0);c=a+73|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+54|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+58|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){v[b+8>>2]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;tc(b+8|0,v[b>>2]);tc(b+4|0,v[b+8>>2]);gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function MI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;d=1;a:{b:{switch(b-a>>2){case 2:b=b-4|0;if(!Ed(b,a)){break a}jc(a,b);break a;case 3:ao(a,a+4|0,b-4|0);break a;case 4:Sx(a,a+4|0,a+8|0,b-4|0);break a;case 5:Rx(a,a+4|0,a+8|0,a+12|0,b-4|0);break a;case 0:case 1:break a;default:break b}}e=a+8|0;ao(a,a+4|0,e);c=a+12|0;if((c|0)==(b|0)){break a}c:{while(1){g=c;if(Ed(c,e)){v[f+12>>2]=v[g>>2];d=g;while(1){d:{c=e;v[d>>2]=v[c>>2];if((a|0)==(c|0)){c=a;break d}d=c;e=c-4|0;if(Ed(f+12|0,e)){continue}}break}v[c>>2]=v[f+12>>2];h=h+1|0;if((h|0)==8){break c}}e=g;c=g+4|0;if((c|0)!=(b|0)){continue}break}d=1;break a}d=(g+4|0)==(b|0)}gb=f+16|0;return d}function YA(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+798|0]=0;return}t[a+798|0]=1;return}t[a+798|0]=2;return}t[a+798|0]=3;return}t[a+730|0]=w[a+730|0]&254;return}t[a+730|0]=w[a+730|0]|1;return}t[a+738|0]=w[a+738|0]&254;return}t[a+738|0]=w[a+738|0]|1;return}t[a+746|0]=w[a+746|0]&254;return}t[a+746|0]=w[a+746|0]|1;return}if(v[c+480180>>2]!=16777216){break a}c=a;a=w[a+746|0];t[c+746|0]=(b|0)==13?a&238|1:a|17}}function m4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-32|0;gb=e;a:{if(xH(c)){while(1){if(a>>>d&1){i=(d<<2)+c|0,j=yH(d,b),v[i>>2]=j}d=d+1|0;if((d|0)!=6){continue}break}break a}while(1){h=(e+8|0)+(d<<2)|0;f=1<<d&a;if(f|!c){f=yH(d,f?b:18693)}else{f=v[(d<<2)+c>>2]}v[h>>2]=f;g=((f|0)!=0)+g|0;d=d+1|0;if((d|0)!=6){continue}break}c=74624;b:{c:{switch(g|0){case 0:break a;case 1:break c;default:break b}}if(v[e+8>>2]!=74596){break b}c=74648;break a}c=Ad(24);if(!c){break a}a=v[e+12>>2];v[c>>2]=v[e+8>>2];v[c+4>>2]=a;a=v[e+28>>2];v[c+16>>2]=v[e+24>>2];v[c+20>>2]=a;a=v[e+20>>2];v[c+8>>2]=v[e+16>>2];v[c+12>>2]=a}gb=e+32|0;return c|0}function jd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{c=v[a+112>>2];d=v[a+116>>2];b:{if(c|d){b=c>>>0<=y[a+120>>2];c=v[a+124>>2];if((d|0)<(c|0)?1:(d|0)<=(c|0)?b:0){break b}}g=Mx(a);if((g|0)>-1){break a}}v[a+104>>2]=0;return-1}h=v[a+4>>2];j=a;b=v[a+116>>2];e=b;d=v[a+8>>2];c=d;f=v[a+112>>2];c:{if(!(b|f)){break c}c=d;i=v[a+120>>2]^-1;f=i+f|0;b=(v[a+124>>2]^-1)+e|0;b=f>>>0<i>>>0?b+1|0:b;e=d-h|0;i=f>>>0>=e>>>0;e=e>>31;if((b|0)>(e|0)?1:(e|0)<=(b|0)?i:0){break c}c=f+h|0}v[j+104>>2]=c;if(d){c=a;j=(d-h|0)+1|0;b=j;d=b+v[a+120>>2]|0;a=v[a+124>>2]+(b>>31)|0;v[c+120>>2]=d;v[c+124>>2]=d>>>0<b>>>0?a+1|0:a}a=h-1|0;if(w[a|0]!=(g|0)){t[a|0]=g}return g}function ph(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0);d=aM(a);c=C(C(z[a+4224>>2]*C(1.899999976158142))+C(.10000000149011612));f=z[a+4268>>2];e=me(C(10),C(C(C(v[((b<<2)+a|0)+4292>>2])*C(-3))/C(C(C(z[a+4220>>2]*C(19.899999618530273))+C(.10000000149011612))*f)));c=C(C(me(e,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-Rp(c>C(1)?C(3.1415927410125732):C(C(d*C(6.2831854820251465))/f))));a:{if(c==C(0)){break a}f=C(c+c);d=C(C(-2)-f);c=C(K(C(C(d*d)+C(C(c*c)*C(-4)))));g=C(C(c-d)/f);if(C(D(g))<=C(1)){break a}g=C(C(-C(c+d))/f)}b=(b<<3)+a|0;z[b+4404>>2]=g;z[b+4400>>2]=e;c=z[a+4272>>2];c=C(c*c);d=C(C(1)-c);e=C(e*e);return C(C(C(C(d*d)*e)/C(C(1)-C(c*e)))+c)}function m$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-32|0;gb=c;a:{b:{c:{d:{if(i=dd(b),j=1,k=v[b+12>>2],k?i:j){Kb(a);break d}f=gb-16|0;gb=f;e=Kb(c+16|0);d=Ab(b);g=Lf(11562);h=Jb(b);v[22640]=0;Y(158,e|0,h|0,d|0,d+g|0);d=v[22640];v[22640]=0;e:{if((d|0)!=1){v[22640]=0;W(159,e|0,11562,g|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;vb(e);S(a|0);L()}gb=f+16|0;v[22640]=0;R(190,c|0,b+12|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;U(3,a|0,c+16|0,c|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}vb(c);vb(c+16|0)}gb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;vb(c)}vb(c+16|0);S(b|0);L()}function Di(a,b,c,d){var e=0,f=0,g=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=50492;c=a+24|0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;b=a+44|0;g=ad(b);e=ad(b+12|0);f=ad(b+24|0);d=ad(b+36|0);v[22640]=0;W(1536,b|0,2,0)|0;b=v[22640];v[22640]=0;if((b|0)==1){a=P()|0;O()|0;Lc(d);Lc(f);Lt(e);Lt(g);S(a|0);L()}v[a+4196>>2]=1065353216;v[a+4200>>2]=0;b=0;u[a+4204>>1]=0;e=v[a+16>>2];v[e+946300>>2]=v[e+946300>>2]+1;v[c>>2]=a+99&-8;f=v[a+20>>2];if((f|0)!=(e+906300|0)){d=a+4200|0;while(1){a:{c=b+1|0;if(b>>>0>247){break a}b=c;if((f|0)!=((e+B(b,160)|0)+906300|0)){continue}}break}t[d|0]=c}return a}function Sda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{d=gb+-64|0;gb=d;e=v[a+28>>2];sp(v[v[e>>2]-12>>2]+e|0,0);e=v[v[b>>2]+4>>2];if(e){h=v[a+28>>2];f=v[a+12>>2];g=e;e=v[a+8>>2]+e|0;f=g>>>0>e>>>0?f+1|0:f;e=Bh(d+48|0,e,f);f=v[e+12>>2];v[d+16>>2]=v[e+8>>2];v[d+20>>2]=f;g=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=g;gk(h,d+8|0)}se(d+24|0,v[a+28>>2]);e=v[d+36>>2];v[d+40>>2]=v[d+32>>2];v[d+44>>2]=e;sS(v[a+28>>2],c,v[v[b>>2]+8>>2]);c=v[b>>2];b=Xn(d+24|0,kc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[22640]=0;ca(1530,a|0,c|0,b|0,d+40|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){Hb(b);gb=d- -64|0;break a}a=P()|0;O()|0;Hb(b);S(a|0);L()}}function jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-32|0;gb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){l=f>>>10&4194048;h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[g+h|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Ub(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;gb=e+32|0}function hja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=e+l|0;e=t[k|0];h=v[a+28>>2]+h|0;f=h>>12;e=((B(t[k+1|0]-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;gb=b+16|0}function A8(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=gb-96|0;gb=d;v[d+88>>2]=c;c=v[a>>2];e=v[a+4>>2];f=v[a+12>>2];v[d+56>>2]=v[a+8>>2];v[d+60>>2]=f;v[d+48>>2]=c;v[d+52>>2]=e;a=Sd(d+40|0);c=v[d+60>>2];v[d+24>>2]=v[d+56>>2];v[d+28>>2]=c;v[22640]=0;c=v[d+52>>2];v[d+16>>2]=v[d+48>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;U(2073,d- -64|0,d+16|0,d+8|0);a=v[22640];v[22640]=0;a:{b:{if((a|0)!=1){a=v[ni(d+32|0,d+88|0)>>2];v[22640]=0;b=+za(2074,d- -64|0,+b,a|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}yb(d- -64|0);bg(d+88|0);gb=d+96|0;return+b}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d- -64|0)}bg(d+88|0);S(a|0);L()}function gU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;f=b,g=Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)),v[f>>2]=g;t[d+15|0]=w[a+4|0];t[d+14|0]=64;f=b,g=w[ac(d+15|0,d+14|0)|0]<<2,u[f+30>>1]=g;c=a+6|0;f=b,g=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),v[f+4>>2]=g;a=a+10|0;a=Xb(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0;v[b+8>>2]=a;e=v[b+4>>2];c=v[b>>2];if(e>>>0>=c>>>0){e=c-1|0;v[b+4>>2]=e}if(a>>>0>c>>>0){v[b+8>>2]=c;a=c}a:{if(a>>>0<e>>>0){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(a>>>0<=e>>>0){break a}v[b+68>>2]=e;u[b+34>>1]=x[b+34>>1]|2}gb=d+16|0}function ol(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;v[a+4>>2]=0;d=4;a:{b:{c:{if(!w[rj(e+8|0,a,1)|0]){break c}d=v[v[a>>2]-12>>2];v[22640]=0;d=v[(a+d|0)+24>>2];f=v[22640];v[22640]=0;d:{if((f|0)==1){break d}v[22640]=0;b=W(2288,d|0,b|0,c|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break d}v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;Z(b|0)|0;d=1;qj(v[v[a>>2]-12>>2]+a|0,1);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[22640]=0;X(2027);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)==1){break b}S(a|0);L()}$()}fh(v[v[a>>2]-12>>2]+a|0,d);gb=e+16|0;return}V(0)|0;O()|0;Bb()}L()}function Tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+56>>2]=d;d=v[a+28>>2];sp(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){h=v[a+28>>2];g=v[a+12>>2];f=v[a+8>>2]+d|0;g=f>>>0<d>>>0?g+1|0:g;f=Bh(e+40|0,f,g);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;gk(h,e)}se(e+16|0,v[a+28>>2]);d=v[e+28>>2];v[e+32>>2]=v[e+24>>2];v[e+36>>2]=d;nN(v[a+28>>2],c,v[e+56>>2]);c=v[b>>2];b=Xn(e+16|0,kc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[22640]=0;ca(1530,a|0,c|0,b|0,e+32|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){Hb(b);gb=e- -64|0;return}a=P()|0;O()|0;Hb(b);S(a|0);L()}function Rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;v[e+56>>2]=d;d=v[a+28>>2];sp(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){h=v[a+28>>2];g=v[a+12>>2];f=v[a+8>>2]+d|0;g=f>>>0<d>>>0?g+1|0:g;f=Bh(e+40|0,f,g);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;gk(h,e)}se(e+16|0,v[a+28>>2]);d=v[e+28>>2];v[e+32>>2]=v[e+24>>2];v[e+36>>2]=d;fN(c,v[a+28>>2],v[e+56>>2]);c=v[b>>2];b=Xn(e+16|0,kc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[22640]=0;ca(1530,a|0,c|0,b|0,e+32|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){Hb(b);gb=e- -64|0;return}a=P()|0;O()|0;Hb(b);S(a|0);L()}function Ofa(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+872|0;if((c|0)!=(b|0)){continue}break}GN(a+484344|0);Ye(a+1298268|0);Ye(a+1298280|0);Ye(a+1298292|0);cD(a+1298368|0);c=a+900380|0;b=a+484380|0;while(1){Ol(b);b=b+104|0;if((c|0)!=(b|0)){continue}break}c=a+901404|0;b=a+900380|0;while(1){d=v[b>>2];if(d){Zb(hv(d))}v[b>>2]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){FM(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0;return 1}function gja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=(e<<1)+l|0;e=u[k>>1];h=v[a+28>>2]+h|0;f=h>>12;e=e+((B(u[k+2>>1]-e|0,i>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;gb=b+16|0}function vpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-32|0;gb=d;td(b,0);Yj(d,1,a);Bc(d+16|0,d);v[22640]=0;Q(335,b+43|0,d+16|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){vb(d+16|0);c=a+32|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+13|0;u[b+34>>1]=x[b+34>>1]&65533|(w[c|0]|w[c+1|0]<<8)<<1&2;c=a+16|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+20|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+24|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+16|0]=w[a+15|0];t[d|0]=64;e=b,f=w[ac(d+16|0,d)|0]<<2,u[e+30>>1]=f;gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function mY(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=w[e|0];if(!i|!b){break a}g=d-6|0;j=35>>>g&(g&255)>>>0<6;h=B(0-c|0,6);k=(d-2&255)>>>0>2;while(1){g=a+h|0;f=w[g+3|0];b:{if(!((f-2&255)>>>0>2|k)){c=1;if(w[(a+h|0)+5|0]<224){break b}break a}c=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}c=1}c:{if(k){break c}f=a+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=a+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}e:{if(!c){break e}c=i;a=w[(a+h|0)+5|0];if(a?(c|0)!=(a|0):0){break a}if((a|0)!=(c|0)){break e}t[e|0]=0;return}a=g;b=b-1|0;if(b){continue}break}}}function gG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-48|0;gb=e;f=Jb(b);g=Ab(b);i=Jb(c);j=Ab(c);h=-1;a:{if(!g){break a}d=f;g=g+d|0;while(1){if(vp(i,j,d)){d=d+1|0;if((g|0)!=(d|0)){continue}break a}break}h=d-f|0}b:{c:{if((h|0)!=-1){k=e,l=wd(b),v[k+32>>2]=l;c=Fd(e+40|0,e+32|0);k=e,l=wd(b),v[k+8>>2]=l;k=e,l=we(e+8|0,h),v[k+16>>2]=l;d=Fd(e+24|0,e+16|0);dG(b,v[c>>2],v[d>>2]);break c}if(!Ab(b)){break c}f=Jb(b);h=Ab(b);g=Jb(c);d=-1;i=Ab(c);if(i){c=f+h|0;d:{while(1){if((c|0)==(f|0)){break d}c=c-1|0;if(!vp(g,i,c)){continue}break}d=c-f|0}}if((Ab(b)-1|0)!=(d|0)){break c}Kb(a);break b}Dc(a,b)}gb=e+48|0}function vja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;g=u[f+2>>1];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+B(e,u[f>>1]);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(g,j);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;gb=b+16|0}function JA(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=gb-16|0;gb=g;h=Nl(a,b);a:{if((h|0)==255){break a}if(vk(a)){break a}b:{if(c>>>0>6208431){i=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}i=f;c=mqa(1<<20-f,0,c,0)+24858e3|0;f=jb;c=Uc(pqa(c,c>>>0<24858e3?f+1|0:f,49716e3,0),jb)}if(e){u[g+14>>1]=(b&3)+c;u[g+12>>1]=1023;c=x[Oc(g+14|0,g+12|0)>>1]}e=xu(h);b=lc(a+4|0,h);t[b|0]=(i<<10|c)>>>8|(d?0:32);Yh(v[a>>2],e|160,c&255);Yh(v[a>>2],e|176,w[b|0]);t[a+530|0]=1}gb=g+16|0}function BJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=gb-16|0;gb=e;a:{b:{c:{d=a+8|0;d:{if(!xl(d)){if((b|0)<0|(gq(d)|0)<=(b|0)){break d}a=Sl(v[a+32>>2],b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}d=xl(d);if((b|0)<0){break d}if((b|0)<(d|0)){break c}}b=aa(8)|0;v[22640]=0;c=Q(112,e|0,3092)|0;a=v[22640];v[22640]=0;e:{if((a|0)!=1){qc(b,c);v[22640]=0;U(223,b|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break e}a=P()|0;O()|0;da(b|0)}S(a|0);L()}b=b+1<<2;a=a+32|0;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}a=v[(b+v[a>>2]|0)+900380>>2];t[a+15|0]=w[a+15|0]&253|(c?2:0)}gb=e+16|0;return}L()}function zI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;gb=d+16|0;e=0;a:{if(!b){break a}b:{if(!c){break b}a=a?a:d+12|0;d=w[b|0];e=d<<24>>24;if((e|0)>=0){v[a>>2]=d;e=(e|0)!=0;break a}d=t[b|0];if(!v[v[22545]>>2]){v[a>>2]=d&57343;e=1;break a}d=(d&255)-194|0;if(d>>>0>50){break b}d=v[(d<<2)+76576>>2];if(d<<B(c,6)-6<0?c>>>0<=3:0){break b}c=w[b+1|0];e=c>>>3|0;if((e-16|e+(d>>26))>>>0>7){break b}c=c-128|d<<6;if((c|0)>=0){v[a>>2]=c;e=2;break a}d=w[b+2|0]-128|0;if(d>>>0>63){break b}c=d|c<<6;if((c|0)>=0){v[a>>2]=c;e=3;break a}b=w[b+3|0]-128|0;if(b>>>0>63){break b}v[a>>2]=b|c<<6;e=4;break a}v[115121]=25;e=-1}return e|0}function ZI(a,b,c,d,e){var f=0,g=0,h=0;f=gb-208|0;gb=f;v[f+204>>2]=c;Qb(f+160|0,0,40);v[f+200>>2]=v[f+204>>2];a:{if((Xx(0,b,f+200|0,f+80|0,f+160|0,d,e)|0)<0){b=-1;break a}g=v[a+76>>2]>=0;c=v[a>>2];if(t[a+74|0]<=0){v[a>>2]=c&-33}h=c&32;b:{if(v[a+48>>2]){b=Xx(a,b,f+200|0,f+80|0,f+160|0,d,e);break b}v[a+48>>2]=80;v[a+16>>2]=f+80;v[a+28>>2]=f;v[a+20>>2]=f;c=v[a+44>>2];v[a+44>>2]=f;d=Xx(a,b,f+200|0,f+80|0,f+160|0,d,e);b=d;if(!c){break b}kb[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=c;v[a+28>>2]=0;v[a+16>>2]=0;b=v[a+20>>2];v[a+20>>2]=0;b=b?d:-1}c=a;a=v[a>>2];v[c>>2]=a|h;b=a&32?-1:b;if(!g){break a}}gb=f+208|0;return b}function zV(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;while(1){m=x[rc(b,l)>>1];n=m+1|0;i=(h&65535)>>>0>m>>>0|m>>>0>127;j=i?j:c>>>0>l>>>0?n:j;k=(k&65535)>>>0>m>>>0?k:n;h=i?h:n;l=l+1|0;if((l|0)!=128){continue}break}yf(b,c);i=v[a+8>>2];a:{b:{c:{if(!f){break c}c=h&65535;if((i+((c<<11)+f|0)|0)!=(hm(a)&-2)){break c}Xc(a,i+(c<<10)|0);if(!RB(a,16,1)){break b}u[e>>1]=8;break b}if(!g|(h&65535)==(j&65535)){break a}Xc(a,i+((j&65535)<<10)|0);h=RB(a,64,1)?h:j}Xc(a,i)}c=k&65535;d:{if(c>>>0>(h&65535)>>>0){if(((d+i|0)+(B(c,x[e>>1])<<8)|0)==(hm(a)|0)){break d}}if(c>>>0>=255){Zu(b,254,65534);Zu(b,255,65535)}k=h}return k&65535}function wja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=(((f&2147483647)<<1|g>>>31)&-2)+k|0;g=t[f+1|0];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+(B(e,t[f|0])<<8);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+(B(g,j)<<8);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;gb=b+16|0}function I$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;l=gb-32|0;gb=l;n=v[c>>2];m=v[c+8>>2];k=l;c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=m;v[k+24>>2]=c;v[k+28>>2]=m;v[k+20>>2]=n;v[k+16>>2]=d;v[22640]=0;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=Ja(1927,a|0,b|0,k|0)|0;b=v[22640];v[22640]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22640]=0;ja(1922,7741,e|0,f|0,g|0,h|0,i|0,j|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}$();a=-255}gb=l+32|0;break a}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function fJ(a){var b=0,c=0,d=0,e=0,f=0,g=0;if(Le(a)){dc(a,31);return 0}f=a,g=Le(a),t[f+1375|0]=g;e=wj(a);b=wj(a);wj(a);f=a,g=wj(a),v[f+1112>>2]=g;wj(a);c=Le(a);v[a+1116>>2]=c;if(!by(a,a+1120|0,c)){dc(a,10);return 0}v[a+1404>>2]=-2;a:{if((b|0)==-1?(e|0)==-1:0){break a}b=v[a+1116>>2];while(1){if((b|0)<1){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=e;v[a+1404>>2]=b}if(w[a+1377|0]){c=0;d=v[a+1116>>2];b:{if((d|0)>0){b=0;while(1){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}b=(c+d|0)+27|0;break b}b=d+27|0}v[a- -64>>2]=e;v[a+60>>2]=b+v[a+56>>2]}v[a+1380>>2]=0;return 1}function Eoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Tj(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/48>>>0){e=gb-16|0;gb=e;c=gY(e,a,c);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){wb(a);OW(b);b=b+48|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(c);gb=e+16|0;break c}b=wb(a);b=eY(d+8|0,fY(a,Tj(a)+c|0),Tj(a),b);v[22640]=0;PW(b,c);c=v[22640];v[22640]=0;if((c|0)==1){break b}v[22640]=0;R(510,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}yv(b)}gb=d+32|0;break a}a=P()|0;O()|0;yv(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,48)|0;Tj(a);hY(a,b);qY(a)}}function I9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;v[22640]=0;_(1934,a|0);d=v[22640];v[22640]=0;a:{b:{c:{if((d|0)==1){break c}v[22640]=0;_(1960,b|0);d=v[22640];v[22640]=0;if((d|0)==1){break c}d=v[a+24>>2];b=uc(c+8|0,b);v[22640]=0;e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;Y(1999,c+16|0,d|0,c|0,1);b=v[22640];v[22640]=0;if((b|0)==1){break c}b=ie(Jb(c+16|0));vb(c+16|0);break b}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22640]=0;Y(1911,2627,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$()}gb=c+32|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function joa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-48|0;gb=c;d=c+24|0;f=nc(d+8|0);v[22640]=0;e=T(492,b|0)|0;g=v[22640];v[22640]=0;a:{b:{if((g|0)==1){break b}v[22640]=0;U(383,d|0,b|0,e|0);e=v[22640];v[22640]=0;if((e|0)==1){break b}d=v[d>>2];v[22640]=0;Q(350,b|0,d|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;gc(f);S(a|0);L()}v[22640]=0;Nr(c+16|0,c+24|0);b=v[22640];v[22640]=0;c:{if((b|0)==1){break c}v[22640]=0;b=v[c+20>>2];v[c+8>>2]=v[c+16>>2];v[c+12>>2]=b;R(659,a|0,c+8|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}xc(c+24|0);gb=c+48|0;return}a=P()|0;O()|0;xc(c+24|0);S(a|0);L()}function G$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[22640]=0;_(1934,a|0);f=v[22640];v[22640]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[22640]=0;_(1960,b|0);f=v[22640];v[22640]=0;if((f|0)==1){break d}f=v[a+24>>2];b=uc(e+8|0,b);v[22640]=0;g=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=g;Ha(2002,f|0,e|0,c|0,d|0,1);c=v[22640];v[22640]=0;b=1;if((c|0)!=1){break c}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,5853,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break b}$();b=0}gb=e+16|0;break a}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return b|0}function rj(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-32|0;gb=e;t[a|0]=0;f=Tf(v[v[b>>2]-12>>2]+b|0);d=v[v[b>>2]-12>>2]+b|0;a:{b:{if(f){d=v[d+72>>2];if(d){Ws(d)}c:{if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&4096)|c){break c}Ec(e+24|0,v[v[b>>2]-12>>2]+b|0);v[22640]=0;f=T(21,e+24|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break a}Vb(e+24|0);c=_i(e+16|0,b);d=Ui(e+8|0);d:{if(!ik(c,d)){break d}while(1){if(!jh(f,8192,rl(c))){break d}ql(c);if(ik(c,d)){continue}break}}if(!hk(c,d)){break c}fh(v[v[b>>2]-12>>2]+b|0,6)}g=a,h=Tf(v[v[b>>2]-12>>2]+b|0),t[g|0]=h;break b}fh(d,4)}gb=e+32|0;return a}a=P()|0;O()|0;Vb(e+24|0);S(a|0);L()}function hX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Pe(d+40|0,a,c);a=v[d+40>>2];v[22640]=0;e=Rd(d+40|0);f=v[22640];v[22640]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22640]=0;Te(d+8|0,2,e,a);e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;R(377,d+24|0,d+8|0);e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;R(471,d|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}v[22640]=0;Q(429,d|0,d+24|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}vb(d+24|0);xc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}xc(d+40|0);S(a|0);L()}return a|0}function sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=Di(a,b,c,d);v[a>>2]=50260;c=nc(a+4208|0);v[a+4236>>2]=2147483647;v[a+4240>>2]=0;v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;t[a+4244|0]=0;Qb(a+4248|0,0,48);v[22640]=0;d=fa(1292)|0;e=v[22640];v[22640]=0;a:{if((e|0)==1){break a}v[22640]=0;d=T(1293,d|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break a}v[a+4296>>2]=d;Nt(a);Mt(a);v[22640]=0;W(1536,a+44|0,2,2)|0;d=v[22640];v[22640]=0;if((d|0)==1){break a}v[22640]=0;Vh(b);d=v[22640];v[22640]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;gc(c);hf(b);S(a|0);L()}function F2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=ZG(b);gl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;fl(k,a);jj(i,k);Hc(k);Oh(k,a);jj(h,k);Hc(k);l=d,m=oj(a),v[l>>2]=m;l=e,m=nj(a),v[l>>2]=m;Qg(k,a);Eb(f,k);vb(k);Ph(k,a);jj(g,k);Hc(k);a=el(a);break a}a=YG(b);gl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;fl(k,a);jj(i,k);Hc(k);Oh(k,a);jj(h,k);Hc(k);l=d,m=oj(a),v[l>>2]=m;l=e,m=nj(a),v[l>>2]=m;Qg(k,a);Eb(f,k);vb(k);Ph(k,a);jj(g,k);Hc(k);a=el(a)}v[j>>2]=a;gb=k+16|0}function xfa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=gb-32|0;gb=g;a:{if(x[a+480192>>1]<b>>>0){break a}b=v[((b<<2)+a|0)+900380>>2];if(!b){break a}LS(g+16|0,b);i=g,j=gC(g+16|0),v[i+8>>2]=j;i=g,j=yh(g+16|0),v[i>>2]=j;while(1){b:{v[22640]=0;b=Xl(g+8|0,g);h=v[22640];v[22640]=0;if((h|0)==1){break b}if(!b){nr(g+16|0);break a}v[22640]=0;b=Vl(g+8|0);h=v[22640];v[22640]=0;if((h|0)==1){break b}b=x[b>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}Oj(g+8|0);continue}break}a=P()|0;O()|0;nr(g+16|0);S(a|0);L()}gb=g+32|0}function QM(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;Ty(a);Fi(d+12|0);a:{b:{switch(b|0){case 0:z[a+4220>>2]=z[d+12>>2];break a;case 1:z[a+4224>>2]=z[d+12>>2];break a;case 2:z[a+4228>>2]=z[d+12>>2];Nt(a);break a;case 3:t[a+4240|0]=z[d+12>>2]>=C(.5);Nt(a);break a;case 4:b=a;a=Xh(C(z[d+12>>2]*C(32)));v[b+4232>>2]=(a|0)<5?a:5;gb=d+16|0;return;case 5:t[a+4241|0]=z[d+12>>2]>=C(.5);break a;case 6:t[a+4242|0]=z[d+12>>2]>=C(.5);break a;case 7:t[a+4244|0]=z[d+12>>2]>=C(.5);break a;case 8:break b;default:break a}}b=a;c=z[d+12>>2];if(c==C(0)){Ry(a);c=z[d+12>>2]}A[b+4256>>3]=c}gb=d+16|0}function KC(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;d=(c<<3)+a|0;f=w[d+356|0];t[b+12|0]=w[b+12|0]&248|f&1|f<<1&4|f>>>1&2;hh(b,Jd(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;if(Nb(b)){f=((c|0)!=0)<<1;a=(c<<6)+a|0;while(1){c=a+(d<<2)|0;g=c+160|0;u[e+12>>1]=w[g|0]|w[g+1|0]<<8;g=x[Ie(e+14|0,e+12|0)>>1];u[e+14>>1]=g;h=Mb(b,d),i=g,u[h>>1]=i;u[e+14>>1]=x[e+14>>1]+1;c=c+162|0;v[e+8>>2]=(w[c|0]|w[c+1|0]<<8)>>>f;v[e+4>>2]=64;c=v[ld(e+8|0,e+4|0)>>2];h=Mb(b,d),i=c,t[h+2|0]=i;d=d+1|0;if(Nb(b)>>>0>d>>>0){continue}break}}gb=e+16|0}function yR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-32|0;gb=d;k=d,l=br(b),v[k+16>>2]=l;c=gb-32|0;gb=c;h=nR(a,c+28|0,b);b=v[h>>2];t[c+27|0]=0;if(!b){f=gb-16|0;gb=f;b=ec(a);g=Pj(c+8|0,mR(),Qj(f+8|0,b));b=v[g>>2];v[22640]=0;b=b+16|0;e=v[22640];v[22640]=0;a:{if((e|0)!=1){e=gb-16|0;gb=e;v[e+8>>2]=v[d+16>>2];i=v[e+8>>2];j=v[i+4>>2];v[b>>2]=v[i>>2];v[b+4>>2]=j;ad(b+8|0);gb=e+16|0;k=ec(g),l=1,t[k+4|0]=l;gb=f+16|0;break a}a=P()|0;O()|0;zA(g);S(a|0);L()}Ak(a,v[c+28>>2],h,v[c+8>>2]);b=$d(c+8|0);t[c+27|0]=1;zA(c+8|0)}Rj(d+24|0,yc(c+8|0,b),c+27|0);gb=c+32|0;a=ue(d+24|0);gb=d+32|0;return a+8|0}function nt(a,b,c){var d=0,e=0;d=a,e=xj(C(C(C(C(C(C(C(C(C(z[c+3328>>2]+z[c+256>>2])*C(213))+C(C(z[c+3584>>2]-z[c>>2])*C(29)))+C(C(z[c+3072>>2]-z[c+512>>2])*C(459)))+C(C(z[c+2816>>2]+z[c+768>>2])*C(2037)))+C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153)))+C(C(z[c+2304>>2]+z[c+1280>>2])*C(6574)))+C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489)))+C(z[c+1792>>2]*C(75038)))),u[d>>1]=e;d=(b<<5)+a|0,e=xj(C(C(C(C(C(C(C(C(z[c+3080>>2]*C(1567))+C(z[c+3592>>2]*C(104)))+C(z[c+2568>>2]*C(9727)))+C(z[c+2056>>2]*C(64019)))+C(z[c+1544>>2]*C(-9975)))+C(z[c+1032>>2]*C(-45)))+C(z[c+520>>2]*C(146)))+C(z[c+8>>2]*C(-5)))),u[d>>1]=e}function N2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=gb-16|0;gb=k;a:{if(a){a=aH(b);gl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;fl(k,a);Eb(i,k);vb(k);Oh(k,a);Eb(h,k);vb(k);l=d,m=oj(a),t[l|0]=m;l=e,m=nj(a),t[l|0]=m;Qg(k,a);Eb(f,k);vb(k);Ph(k,a);Eb(g,k);vb(k);a=el(a);break a}a=$G(b);gl(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;fl(k,a);Eb(i,k);vb(k);Oh(k,a);Eb(h,k);vb(k);l=d,m=oj(a),t[l|0]=m;l=e,m=nj(a),t[l|0]=m;Qg(k,a);Eb(f,k);vb(k);Ph(k,a);Eb(g,k);vb(k);a=el(a)}v[j>>2]=a;gb=k+16|0}function zga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;bc(c+24|0,b,24);gb=d+16|0;d=xb(c+24|0);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;fc(c+16|0,a,c);e=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;gb=c+16|0}return a|0}function Vka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb+-64|0;gb=f;Jh(f+24|0,c);v[22640]=0;R(197,f+36|0,d|0);c=v[22640];v[22640]=0;a:{b:{c:{d=f+24|0;if((c|0)!=1){v[22640]=0;R(181,f+48|0,e|0);c=v[22640];v[22640]=0;if((c|0)!=1){break c}a=2}else{a=1}a=d+B(a,12)|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}v[22640]=0;os(f+16|0,f+24|0);c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(183,a|0,b|0,f+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}}b=P()|0;O()|0;bl(f+24|0)}S(b|0);L()}bl(f+24|0);gb=f- -64|0}function Loa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb+-64|0;gb=f;Jh(f+24|0,c);v[22640]=0;R(181,f+36|0,d|0);c=v[22640];v[22640]=0;a:{b:{c:{d=f+24|0;if((c|0)!=1){v[22640]=0;R(181,f+48|0,e|0);c=v[22640];v[22640]=0;if((c|0)!=1){break c}a=2}else{a=1}a=d+B(a,12)|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}v[22640]=0;os(f+16|0,f+24|0);c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(183,a|0,b|0,f+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}}b=P()|0;O()|0;bl(f+24|0)}S(b|0);L()}bl(f+24|0);gb=f- -64|0}function i$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb+-64|0;gb=f;Nn(f+24|0,c);v[22640]=0;R(197,f+36|0,d|0);c=v[22640];v[22640]=0;a:{b:{c:{d=f+24|0;if((c|0)!=1){v[22640]=0;R(197,f+48|0,e|0);c=v[22640];v[22640]=0;if((c|0)!=1){break c}a=2}else{a=1}a=d+B(a,12)|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}v[22640]=0;os(f+16|0,f+24|0);c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(183,a|0,b|0,f+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}}b=P()|0;O()|0;bl(f+24|0)}S(b|0);L()}bl(f+24|0);gb=f- -64|0}function qh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb+-64|0;gb=e;a:{b:{if(c-1>>>0>1023){break b}if(ke(a,b)){break b}c:{d:{if(Of(a)>>>0<=b>>>0){d=$y(e+8|0,a);v[22640]=0;U(1494,a|0,b+1|0,d|0);f=v[22640];v[22640]=0;if((f|0)==1){break d}Hm(d)}d=$e(a,b);v[22640]=0;Q(1495,d|0,c|0)|0;c=v[22640];v[22640]=0;e:{if((c|0)!=1){c=$e(a,b);v[c+16>>2]=0;v[c+20>>2]=0;c=$e(a,b);v[22640]=0;_(1496,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){break e}}a=V(88880)|0;b=O()|0;break c}g=hi($e(a,b));break b}a=V(88880)|0;b=O()|0;Hm(d)}if((ea(88880)|0)!=(b|0)){break a}Z(a|0)|0;$()}gb=e- -64|0;return g|0}S(a|0);L()}function H$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[22640]=0;_(1960,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break d}c=v[a+24>>2];e=uc(d+8|0,b);v[22640]=0;b=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=b;b=oG(c,d,1);e=v[22640];v[22640]=0;c=jb;if((e|0)!=1){break c}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,5884,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break b}$();b=0;c=0}gb=d+16|0;a=c;break a}b=P()|0;O()|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Bb();L()}ma(a|0);return b|0}function oZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=gb-32|0;gb=g;d=b;f=pc(d);e=c;a:{if(f>>>0<e>>>0){h=gb-32|0;gb=h;b:{c:{f=e-f|0;d:{if(f>>>0<=v[wb(d)>>2]-v[d+4>>2]>>>0){yr(d,f);break d}e=wb(d);e=dh(h+8|0,vh(d,pc(d)+f|0),pc(d),e);v[22640]=0;R(327,e|0,f|0);f=v[22640];v[22640]=0;if((f|0)==1){break c}v[22640]=0;R(328,d|0,e|0);d=v[22640];v[22640]=0;if((d|0)==1){break c}ae(e)}gb=h+32|0;break b}a=P()|0;O()|0;ae(e);S(a|0);L()}break a}if(e>>>0<f>>>0){jn(d,e+v[d>>2]|0)}}c=Pb(a,c);if(c){uD(g+24|0,b);b=v[g+28>>2];v[g+8>>2]=v[g+24>>2];v[g+12>>2]=b;gd(g+16|0,a,g+8|0)}gb=g+32|0;return c|0}function hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=gb-16|0;gb=d;b=x[b>>1];e=d;f=x[a+30>>1];if(f){b=qo(b<<16>>16,f<<16>>16)}u[e+14>>1]=b;a:{if(!dd(c)){dk(rN(a+52|0,d+14|0),c);break a}a=a+52|0;b=Yy(a,d+14|0);v[d+8>>2]=b;l=d,m=zh(a),v[l>>2]=m;if(!kg(d+8|0,d)){break a}e=gb-16|0;gb=e;k=e+8|0;b=v[yc(e,b)>>2];c=gb-16|0;gb=c;v[c+8>>2]=b;f=gb-16|0;gb=f;j=v[c+8>>2];h=j;i=yc(f+8|0,h);Oj(i);b=a;g=b;if(v[b>>2]==(h|0)){v[g>>2]=v[i>>2]}g=wb(b);v[g>>2]=v[g>>2]-1;gN(v[ec(b)>>2],h);b=v[i>>2];gb=f+16|0;a=ec(a);zk(ue(c+8|0));Tk(a,j,1);gb=c+16|0;yc(k,b);gb=e+16|0}gb=d+16|0}function VS(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=gb-16|0;gb=f;v[f+8>>2]=e;v[f+12>>2]=d;a:{if(!d){break a}Ye(a);Kt(a,c);if(!c){break a}e=0;while(1){j=c-g|0;v[f+4>>2]=j;h=v[Fb(f+12|0,f+4|0)>>2];Dp(a,zb(b)+g|0,h);qs(a,1,13);i=e+h|0;if(i>>>0>e>>>0){while(1){b:{c:{d:{k=t[mc(a,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}l=mc(a,e),m=32,t[l|0]=m}e=e+1|0;if((i|0)!=(e|0)){continue}break}}v[f+4>>2]=j-h;e=i+1|0;g=v[Fb(f+8|0,f+4|0)>>2]+(h+g|0)|0;if(g>>>0<c>>>0){continue}break}}gb=f+16|0;return(d|0)!=0|0}function G9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[22640]=0;_(1934,a|0);e=v[22640];v[22640]=0;a:{b:{c:{if((e|0)==1){break c}v[22640]=0;_(1960,b|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}e=v[a+24>>2];b=uc(d+8|0,b);v[22640]=0;f=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=f;Y(2001,e|0,d|0,(c|0)!=0|0,1);c=v[22640];v[22640]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,7331,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function AJ(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a:{b:{c:{c=a+8|0;d:{if(!xl(c)){if((b|0)<0|(gq(c)|0)<=(b|0)){break d}c=(w[Sl(v[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}c=xl(c);if((b|0)<0){break d}if((b|0)<(c|0)){break c}}b=aa(8)|0;v[22640]=0;c=Q(112,d|0,3092)|0;a=v[22640];v[22640]=0;e:{if((a|0)!=1){qc(b,c);v[22640]=0;U(223,b|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break e}a=P()|0;O()|0;da(b|0)}S(a|0);L()}b=b+1<<2;a=a+32|0;c=1;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}c=(w[v[(b+v[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}gb=d+16|0;return c|0}L()}function dfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-48|0;gb=c;Sm(c+24|0,b,1819307379);od(a+40|0,c+24|0);yb(c+24|0);Sm(c+24|0,b,1953721961);od(a+60|0,c+24|0);yb(c+24|0);Sm(c+24|0,b,543520099);od(a+120|0,c+24|0);yb(c+24|0);Sm(c,b,1414744396);d=c+24|0;Wk(d,c);yb(c);v[22640]=0;e=Q(575,d|0,11155)|0;f=v[22640];v[22640]=0;a:{if((f|0)!=1){b:{if(e){v[22640]=0;U(1435,c|0,d|0,2);e=v[22640];v[22640]=0;if((e|0)==1){break b}$N(a+140|0,c);an(c)}v[22640]=0;U(1436,c|0,b|0,1634890872);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}}a=P()|0;O()|0;yb(d);S(a|0);L()}od(a+80|0,c);yb(c);yb(d);gb=c+48|0}function Nm(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;f=a+1074312|0;Db(e+8|0,f,84);a:{if(Cb(e+8|0)){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){Db(e+8|0,f,10);if(!Cb(e+8|0)){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+784>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;Db(e+8|0,f,10);if(!Cb(e+8|0)){break a}t[b+831|0]=0;u[b+778>>1]=0}gb=e+16|0}function Dpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;td(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+8|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+12|0;c=w[c|0]|w[c+1|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;e=b;c=a+14|0;if(w[c|0]){d=w[c|0]+1|0}else{d=256}u[e+30>>1]=d;u[b+34>>1]=x[b+34>>1]&32767|!w[c|0]<<15;a=a+15|0;if(!(!(t[a|0]&1)|y[b+16>>2]<=y[b+12>>2])){u[b+34>>1]=x[b+34>>1]|8}if(w[a|0]&2){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;v[b+12>>2]=v[b+12>>2]>>>1;v[b+16>>2]=v[b+16>>2]>>>1}}function ix(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;Ec(f+8|0,b);v[22640]=0;b=T(2458,f+8|0)|0;g=v[22640];v[22640]=0;a:{if((g|0)==1){break a}v[22640]=0;Y(2470,b|0,83184,83216,c|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}v[22640]=0;b=T(2459,f+8|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break a}v[22640]=0;c=T(2471,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break a}v[d>>2]=c;v[22640]=0;c=T(2468,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break a}v[e>>2]=c;v[22640]=0;R(2469,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break a}Vb(f+8|0);gb=f+16|0;return}a=P()|0;O()|0;Vb(f+8|0);S(a|0);L()}function iga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;v[d+24>>2]=c>>>3;v[d+16>>2]=v[a>>2];f=v[Fb(d+24|0,d+16|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){g=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[d+24>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+28>>2]=g;v[d+16>>2]=0;v[d+20>>2]=-1074790400;v[d+8>>2]=0;v[d+12>>2]=1072693248;e=A[$g(d+24|0,d+16|0,d+8|0)>>3]*32768;A[d+24>>3]=e;g=a;e=fe(e);a:{if(D(e)<2147483648){h=~~e;break a}h=-2147483648}i=g,j=Sc(h),u[i>>1]=j;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+32|0;return f<<3}function S$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(Og(a,v[b+8>>2],f)){Sw(b,c,d,e);return}h=w[b+53|0];g=v[a+12>>2];t[b+53|0]=0;i=w[b+52|0];t[b+52|0]=0;j=a+16|0;Qw(j,b,c,d,e,f);k=w[b+53|0];h=h|k;l=w[b+52|0];i=i|l;a:{if((g|0)<2){break a}j=j+(g<<3)|0;g=a+24|0;while(1){if(w[b+54|0]){break a}b:{if(l){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!k){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;Qw(g,b,c,d,e,f);k=w[b+53|0];h=k|h;l=w[b+52|0];i=l|i;g=g+8|0;if(j>>>0>g>>>0){continue}break}}t[b+53|0]=(h&255)!=0;t[b+52|0]=(i&255)!=0}function F9(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=gb-16|0;gb=e;v[22640]=0;_(1934,a|0);d=v[22640];v[22640]=0;a:{b:{c:{if((d|0)==1){break c}v[22640]=0;_(1960,b|0);d=v[22640];v[22640]=0;if((d|0)==1){break c}d=v[a+24>>2];b=uc(e+8|0,b);v[22640]=0;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;Wa(2003,d|0,e|0,+c,1);d=v[22640];v[22640]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,3018,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}gb=e+16|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Qea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;Hk(d,2,a+2|0);Bc(d+16|0,d);v[22640]=0;Q(333,b+492|0,d+16|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){vb(d+16|0);f=b+236|0;c=c+1|0;while(1){g=w[(a+e|0)+31|0];h=sd(f,e),i=c+g|0,u[h>>1]=i;e=e+1|0;if(e>>>0<120){continue}break}v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;c=a+1|0;e=a+2|0;f=a+3|0;g=a+4|0;RN(w[a|0]&15,w[c|0]&15,w[e|0]&15,w[f|0]&15,w[g|0]&15,a+5|0,b+48|0);RN(w[a|0]>>>4|0,w[c|0]>>>4|0,w[e|0]>>>4|0,w[f|0]>>>4|0,w[g|0]>>>4|0,a+35|0,b+68|0);gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function $fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];g=v[Fb(e+12|0,e+8|0)>>2];i=z[d>>2];b=zb(b);if(g){d=v[a+20>>2];c=g;while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Wf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;a=d;f=re(f);a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}j=a,k=Sc(h),u[j>>1]=k;d=d+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return g<<2}function JS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;tc(a,65536);tc(a+4|0,64);tc(a+8|0,256);sg(a+28|0,16384);vf(a+30|0,128);vf(a+31|0,17);if(w[a+16|0]>=4){t[a+16|0]=0}if(w[a+17|0]>=5){t[a+17|0]=0}if(w[a+18|0]>=3){t[a+18|0]=0}vf(a+19|0,64);vf(a+20|0,100);c=224;d=t[a+26|0];a:{if((d|0)>=-32){c=32;if((d|0)<33){break a}}t[a+26|0]=c}vf(a+23|0,64);vf(a+24|0,64);XA(a+48|0,64);XA(a+68|0,64);XA(a+88|0,(b|0)==4096?255:64);c=a+108|0;b=0;while(1){b:{if(w[lc(c,b)|0]){if(w[lc(c,b)|0]<121){break b}}e=lc(c,b),f=b+1|0,t[e|0]=f}b=b+1|0;if(b>>>0<128){continue}break}if(!wp(w[a+14|0])){t[a+14|0]=5}}function lx(a,b,c,d,e){var f=0,g=0;f=gb-16|0;gb=f;Ec(f+8|0,b);v[22640]=0;b=T(21,f+8|0)|0;g=v[22640];v[22640]=0;a:{if((g|0)==1){break a}v[22640]=0;Y(2450,b|0,83184,83216,c|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}v[22640]=0;b=T(2430,f+8|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break a}v[22640]=0;c=T(2451,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break a}t[d|0]=c;v[22640]=0;c=T(2442,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break a}t[e|0]=c;v[22640]=0;R(2443,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break a}Vb(f+8|0);gb=f+16|0;return}a=P()|0;O()|0;Vb(f+8|0);S(a|0);L()}function Nk(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=gb-48|0;gb=d;v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+28>>2]=c;a:{if(c){while(1){v[d+16>>2]=16;f=v[Fb(d+16|0,d+28|0)>>2];e=Wd(d+8|0,d+32|0,f);g=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=g;e=gb-16|0;gb=e;g=v[a>>2];k=v[a+8>>2];i=v[d+4>>2];j=v[d>>2];v[e+8>>2]=j;v[e+12>>2]=i;l=v[v[g>>2]+28>>2];v[e>>2]=j;v[e+4>>2]=i;kb[l|0](d+16|0,g,h+k|0,e);gb=e+16|0;e=0;if((xb(d+16|0)|0)!=(f|0)){break a}if(yd(d+32|0,b+h|0,f)){break a}e=v[d+28>>2]-f|0;v[d+28>>2]=e;h=f+h|0;if(e){continue}break}}Yb(a,c);e=1}gb=d+48|0;return e}function sY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=gY(c,a,1);a=wb(a);e=v[d+4>>2];v[22640]=0;U(509,a|0,e|0,b|0);a=v[22640];v[22640]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+48;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=eY(c+8|0,fY(a,Tj(a)+1|0),Tj(a),e);f=v[a+8>>2];v[22640]=0;U(509,e|0,f|0,b|0);b=v[22640];v[22640]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+48;v[22640]=0;R(510,d|0,a|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}yv(a);gb=c+32|0;break b}b=P()|0;O()|0;yv(a);S(b|0);L()}}function z8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;v[22640]=0;e=v[b+12>>2];v[d+24>>2]=v[b+8>>2];v[d+28>>2]=e;e=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=e;e=T(2075,d+16|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){a:{b:{if(e){v[22640]=0;R(2076,d+40|0,b|0);break b}v[22640]=0;R(2077,d+40|0,b|0)}b=v[22640];v[22640]=0;if((b|0)==1){break a}qF(d+48|0,d+40|0);b=bk(d+56|0,d+48|0);e=bk(d+32|0,c);f=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=f;b=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=b;rF(a,d+8|0,d);pe(d+48|0);pe(d+40|0);pe(c);gb=d- -64|0;return}}a=P()|0;O()|0;pe(c);S(a|0);L()}function xna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;Pe(c+40|0,a,16);a=v[c+40>>2];v[22640]=0;d=Rd(c+40|0);e=v[22640];v[22640]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22640]=0;Te(c+8|0,3,d,a);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;R(377,c+24|0,c+8|0);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;R(705,c|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}v[22640]=0;Q(429,c|0,c+24|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break c}vb(c+24|0);xc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}xc(c+40|0);S(a|0);L()}}function n_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=yw(c,a,1);a=wb(a);e=v[d+4>>2];v[22640]=0;U(310,a|0,e|0,b|0);a=v[22640];v[22640]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+36;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=FF(c+8|0,GF(a,Zk(a)+1|0),Zk(a),e);f=v[a+8>>2];v[22640]=0;U(310,e|0,f|0,b|0);b=v[22640];v[22640]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+36;v[22640]=0;R(246,d|0,a|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}fs(a);gb=c+32|0;break b}b=P()|0;O()|0;fs(a);S(b|0);L()}}function dqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;Pe(c+40|0,a,44);a=v[c+40>>2];v[22640]=0;d=Rd(c+40|0);e=v[22640];v[22640]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22640]=0;Te(c+8|0,2,d,a);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;R(377,c+24|0,c+8|0);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;R(477,c|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}v[22640]=0;Q(429,c|0,c+24|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break c}vb(c+24|0);xc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}xc(c+40|0);S(a|0);L()}}function M4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-32|0;gb=c;d=He(b,-1);e=w[a+52|0];f=a;a:{b:{if(d){d=b;if(e){break a}b=v[a+48>>2];a=He(b,-1)^1;break b}if(e){g=c,h=oh(v[a+48>>2]),t[g+19|0]=h;c:{d:{switch(Rs(v[a+36>>2],v[a+40>>2],c+19|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)-1|0){case 2:d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d;default:while(1){d=v[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break c}d=d-1|0;v[c+20>>2]=d;if((Os(t[d|0],v[a+32>>2])|0)!=-1){continue}break};break;case 0:case 1:break d}}d=-1;e=0}if(!e){break a}}v[a+48>>2]=b;a=1}t[f+52|0]=a;d=b}gb=c+32|0;return d|0}function Lo(a){var b=0,c=0,d=0,e=0,f=0,g=0;e=x[a+24>>1];c=v[a+4>>2];d=!w[a+77|0]<<1;b=(e<<2)+(x[c+28>>1]>>>d|0)|0;v[a+40>>2]=((b&3)<<4)+34496;f=b>>>2|0;b=b>>>0<48;g=b?12-f|0:0;u[a+32>>1]=g;u[a+36>>1]=b?1:1<<f-12;u[a+34>>1]=-1<<g^-1;if((e|0)==15){u[a+36>>1]=4095}b=(x[a+26>>1]<<2)+(x[c+28>>1]>>>d|0)|0;v[a+52>>2]=((b&3)<<4)+34496;e=b>>>2|0;b=b>>>0<48;f=b?12-e|0:0;u[a+44>>1]=f;u[a+48>>1]=b?1:1<<e-12;u[a+46>>1]=-1<<f^-1;c=(x[a+30>>1]<<2)+(x[c+28>>1]>>>d|0)|0;v[a+64>>2]=((c&3)<<4)+34496;d=c>>>2|0;c=c>>>0<48;b=c?12-d|0:0;u[a+56>>1]=b;u[a+60>>1]=c?1:1<<d-12;u[a+58>>1]=-1<<b^-1}function tea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;v[e+12>>2]=b;a:{if(mk(a)>>>0>=b>>>0){h=e,i=Of(a),v[h+8>>2]=i;d=v[a>>2];b=c;f=v[Fb(e+12|0,e+8|0)>>2];if(f){while(1){MN(d,b);d=d+52|0;f=f-1|0;if(f){continue}break}}b=v[e+12>>2];d=v[e+8>>2];if(b>>>0>d>>>0){_y(a,b-d|0,c);break a}FN(a,v[a>>2]+B(b,52)|0);break a}d=a;if(v[d>>2]){Of(d);OO(d);CN(d);Nz(wb(d),v[d>>2],mk(d));h=wb(d),i=0,v[h>>2]=i;v[d>>2]=0;v[d+4>>2]=0}f=EN(a,b);if(AN()>>>0<f>>>0){Rc();L()}wb(d);g=zN(f);v[d>>2]=g;v[d+4>>2]=g;h=wb(d),i=B(f,52)+g|0,v[h>>2]=i;yN(d,0);_y(a,b,c)}gb=e+16|0}function J9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[22640]=0;_(1934,a|0);d=v[22640];v[22640]=0;a:{b:{c:{if((d|0)==1){break c}v[22640]=0;_(1960,b|0);d=v[22640];v[22640]=0;if((d|0)==1){break c}d=v[a+24>>2];b=uc(c+8|0,b);v[22640]=0;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;e=+oa(1998,d|0,c|0,1);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,3055,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();e=0}gb=c+16|0;return+e}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function yha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{d=gb+-64|0;gb=d;k=d;g=d+16|0;h=gb-16|0;gb=h;l=xO(h+8|0);while(1){e=gb-48|0;gb=e;b=l;c=v[b+4>>2]-v[b>>2]|0;b:{if(!c){b=v[b>>2];break b}c=c+1|0;if(!c){b=oO(sO(e+8|0,32));break b}f=E(c);f=sO(e+8|0,(c&-1>>>f+1?32:31)-f|0);while(1){j=oO(f);if(c>>>0<=j>>>0){continue}break}b=v[b>>2]+j|0}gb=e+48|0;m=ci(g,i),n=b,v[m>>2]=n;i=i+1|0;if((i|0)!=12){continue}break}gb=h+16|0;b=IO(k,g,NO(g));v[22640]=0;Iz(a,b,0);a=v[22640];v[22640]=0;if((a|0)!=1){Lc(b);gb=d- -64|0;break a}a=P()|0;O()|0;Lc(b);S(a|0);L()}}function qq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;ti(e+16|0,b);c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;d=gb-32|0;gb=d;c=v[e+4>>2];f=v[e>>2];v[d+8>>2]=f;v[d+12>>2]=c;v[d+16>>2]=f;v[d+20>>2]=c;f=gb-16|0;gb=f;g=v[d+12>>2];c=f;h=v[d+8>>2];v[c>>2]=h;v[c+4>>2]=g;v[c+8>>2]=h;v[c+12>>2]=g;g=gb-16|0;gb=g;h=v[c>>2];i=v[c>>2];c=xb(c);v[22640]=0;Sn(d+24|0,h,c+i|0);c=v[22640];v[22640]=0;a:{if((c|0)!=1){gb=g+16|0;break a}V(0)|0;O()|0;Bb();L()}gb=f+16|0;c=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=c;AY(e+24|0,a,d);gb=d+32|0;xb(e+24|0);ti(e+8|0,b);xb(e+8|0);gb=e+32|0}function Zq(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=gb-16|0;gb=f;g=Nb(a)-1|0;a:{if((Nb(a)|0)==1){break a}while(1){if(x[Ac(a,e)>>1]>=(b|0)){g=e;break a}e=e+1|0;if(e>>>0<Nb(a)-1>>>0){continue}break}}h=x[Ac(a,g)>>1];v[f+12>>2]=0;b:{if((b|0)>=(h|0)){j=f,k=(w[Ac(a,g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break b}e=0;if(g){e=g-1|0;i=(w[Ac(a,e)+2|0]<<16)/(d|0)|0;v[f+12>>2]=i;e=x[Ac(a,e)>>1]}if((b|0)<=(e|0)|e>>>0>=h>>>0){break b}j=f,k=((B(((w[Ac(a,g)+2|0]<<16)/(d|0)|0)-i|0,b-e|0)|0)/(h-e|0)|0)+i|0,v[j+12>>2]=k}Qd(f+12|0,0,65536);gb=f+16|0;return(B(v[f+12>>2],c)+32768|0)/65536|0}function Wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=(e<<1)+j|0;f=f>>>21&2040;e=(((B(u[e>>1],u[f+46530>>1])+B(u[e-2>>1],u[f+46528>>1])|0)+B(u[e+2>>1],u[f+46532>>1])|0)+B(u[e+4>>1],u[f+46534>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function K9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{c:{if((c|0)==1){break c}v[22640]=0;_(1960,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break c}c=v[a+24>>2];b=uc(d+8|0,b);v[22640]=0;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=W(1996,c|0,d|0,1)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,7362,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}gb=d+16|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function F4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb-32|0;gb=c;a:{b:{c:{if(He(b,-1)){break c}h=c,i=oh(b),t[h+23|0]=i;if(w[a+44|0]){if((Ek(c+23|0,1,1,v[a+32>>2])|0)!=1){break b}break c}v[c+16>>2]=c+24;f=c+32|0;g=c+24|0;d=c+23|0;while(1){e=Rs(v[a+36>>2],v[a+40>>2],d,g,c+12|0,c+24|0,f,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Ek(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=v[c+16>>2]-(c+24|0)|0;if((Ek(c+24|0,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=Ss(b);break a}a=-1}gb=c+32|0;return a|0}function Ag(a){var b=0,c=0,d=0,e=0;a:{o(+a);b=j(1)|0;j(0)|0;c=b;b=b&2147483647;b:{if(b>>>0>=1083174912){if(!((c|0)<0|b>>>0<1083179008)){return a*8.98846567431158e307}if(b>>>0>=2146435072){return-1/a}if(!(a<=-1075)){break a}d=0;if((c|0)<-1?1:(c|0)<=-1){break b}break a}if(b>>>0>1016070143){break a}d=a+1}return d}e=a+26388279066624;o(+e);j(1)|0;c=(j(0)|0)+128|0;b=c<<4&4080;d=A[b+29408>>3];a=a-(e+-26388279066624)-A[(b|8)+29408>>3];return $i(d+d*a*(a*(a*(a*(a*.0013333559164630223+.009618129842126066)+.0555041086648214)+.2402265069591)+.6931471805599453),(c&-256)/256|0)}function zQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;f=v[Fb(e+8|0,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-f;i=f>>>1|0;j=v[Fb(e+8|0,e+4|0)>>2];c=zb(b);if(f>>>0>=2){g=v[a+20>>2];f=i;h=d;while(1){h=(zb(w[c|0])+h|0)+(zb(w[c+1|0])<<8)|0;u[g>>1]=h;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}h=j>>>1|0;b=zb(b);if(j>>>0>=2){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;f=h;while(1){d=(zb(w[c|0])+d|0)+(zb(w[c+1|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}gb=e+16|0;return h+i<<1}function xQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Fb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=e>>>1|0;h=v[Fb(d+8|0,d+4|0)>>2];c=zb(b);if(e>>>0>=2){f=v[a+20>>2];e=g;while(1){j=f,k=(zb(w[c+1|0])|zb(w[c|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=i;while(1){j=f,k=(zb(w[c+1|0])|zb(w[c|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=d+16|0;return g+i<<1}function wQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;f=v[Fb(e+8|0,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-f;i=f>>>1|0;j=v[Fb(e+8|0,e+4|0)>>2];c=zb(b);if(f>>>0>=2){g=v[a+20>>2];f=i;h=d;while(1){h=(zb(w[c+1|0])+h|0)+(zb(w[c|0])<<8)|0;u[g>>1]=h;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}h=j>>>1|0;b=zb(b);if(j>>>0>=2){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;f=h;while(1){d=(zb(w[c+1|0])+d|0)+(zb(w[c|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}gb=e+16|0;return h+i<<1}function dka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb+-64|0;gb=f;Jh(f+24|0,c);v[22640]=0;R(793,f+36|0,d|0);c=v[22640];v[22640]=0;a:{b:{c:{d=f+24|0;if((c|0)!=1){v[22640]=0;R(793,f+48|0,e|0);c=v[22640];v[22640]=0;if((c|0)!=1){break c}a=2}else{a=1}a=d+B(a,12)|0;b=P()|0;O()|0;while(1){a=vb(a-12|0);if((a|0)!=(f+24|0)){continue}break}break b}c=f+24|0;v[f+16>>2]=c;v[f+20>>2]=c+36;v[22640]=0;c=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=c;U(480,a|0,b|0,f+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}b=P()|0;O()|0;bl(f+24|0)}S(b|0);L()}bl(f+24|0);gb=f- -64|0}function AQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Fb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=e>>>1|0;h=v[Fb(d+8|0,d+4|0)>>2];c=zb(b);if(e>>>0>=2){f=v[a+20>>2];e=g;while(1){j=f,k=(zb(w[c|0])|zb(w[c+1|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=i;while(1){j=f,k=(zb(w[c|0])|zb(w[c+1|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=d+16|0;return g+i<<1}function RE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;g=w[a+8|0];f=v[a>>2];a=v[a+4>>2];d=Jb(b);b=Ab(b);c=gb-16|0;gb=c;v[c+8>>2]=b;v[c+12>>2]=a;e=v[Fb(c+12|0,c+8|0)>>2];a:{b:{if(!e){a=f;break b}b=e;a=f;while(1){h=w[d|0];t[a|0]=h;if(!h){break a}d=d+1|0;a=a+1|0;b=b-1|0;if(b){continue}break}}b=0}c:{d:{e:{switch(g-1|0){case 0:case 1:d=v[c+12>>2];t[c+7|0]=0;no(a,((a+d|0)-e|0)+b|0,c+7|0);break d;case 2:case 3:break e;default:break c}}d=v[c+12>>2];t[c+6|0]=32;no(a,((a+d|0)-e|0)+b|0,c+6|0)}f:{switch(g-1|0){case 0:case 3:break f;default:break c}}t[(v[c+12>>2]+f|0)-1|0]=0}gb=c+16|0}function G7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=gb-32|0;gb=b;e=nc(a);Kd(b+24|0);a=0;c=v[b+28>>2];d=v[b+24>>2];v[22640]=0;R(1427,e|0,yy(d,c)|0);c=v[22640];v[22640]=0;a:{if((c|0)!=1){b:{c:{c=v[b+24>>2];if((yy(c,v[b+28>>2])|0)>0){while(1){c=v[(a<<3)+c>>2];v[22640]=0;c=Q(112,b+8|0,c|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}v[22640]=0;R(1429,e|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break b}vb(c);c=v[b+24>>2];a=a+1|0;if((yy(c,v[b+28>>2])|0)>(a|0)){continue}break}}gb=b+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(c);break a}a=P()|0;O()|0}vd(e);S(a|0);L()}function VC(a,b,c){var d=0,e=0,f=0,g=0;g=b;d=v[c+16>>2];a:{if(!d){d=0;e=c;f=w[c+74|0];t[c+74|0]=f-1|f;f=v[c>>2];b:{if(f&8){v[e>>2]=f|32;e=-1;break b}v[e+4>>2]=0;v[e+8>>2]=0;f=v[e+44>>2];v[e+28>>2]=f;v[e+20>>2]=f;v[e+16>>2]=f+v[e+48>>2];e=0}if(e){break a}d=v[c+16>>2]}f=v[c+20>>2];if(d-f>>>0<g>>>0){return kb[v[c+36>>2]](c,a,b)|0}c:{if(t[c+75|0]>-1){d=b;while(1){g=d;d=b;if(!g){break c}d=g-1|0;if(w[d+a|0]!=10){continue}break}d=kb[v[c+36>>2]](c,a,g)|0;if(g>>>0>d>>>0){break a}a=a+g|0;f=v[c+20>>2];d=b-g|0;break c}d=b}e=d;hc(f,a,e);v[c+20>>2]=e+v[c+20>>2];d=b}return d}function Pv(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-48|0;gb=d;v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+28>>2]=c;a:{if(c){while(1){v[d+16>>2]=16;f=v[Fb(d+16|0,d+28|0)>>2];e=Wd(d+8|0,d+32|0,f);g=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=g;e=gb-16|0;gb=e;j=v[a+12>>2];g=v[d+4>>2];i=v[d>>2];v[e+8>>2]=i;v[e+12>>2]=g;k=v[v[a>>2]+28>>2];v[e>>2]=i;v[e+4>>2]=g;kb[k|0](d+16|0,a,h+j|0,e);gb=e+16|0;e=0;if((xb(d+16|0)|0)!=(f|0)){break a}if(yd(d+32|0,b+h|0,f)){break a}e=v[d+28>>2]-f|0;v[d+28>>2]=e;h=f+h|0;if(e){continue}break}}cd(a,c);e=1}gb=d+48|0;return e}function kla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-32|0;gb=d;td(b,0);NC(d,a+1|0);Bc(d+16|0,d);v[22640]=0;Q(335,b+43|0,d+16|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){vb(d+16|0);c=a+78|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;c=a+58|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+66|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;tc(b+8|0,v[b>>2]);tc(b+4|0,v[b+8>>2]);gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function Xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=e+j|0;f=f>>>21&2040;e=(((B(t[e|0],u[f+46530>>1])+B(t[e-1|0],u[f+46528>>1])|0)+B(t[e+1|0],u[f+46532>>1])|0)+B(t[e+2|0],u[f+46534>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function eI(a){var b=0,c=0;a:{b=v[a+4>>2];b:{if(!v[(v[v[b>>2]-12>>2]+b|0)+24>>2]){break b}b=v[a+4>>2];if(!Tf(v[v[b>>2]-12>>2]+b|0)){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(FH()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[22640]=0;b=T(2293,b|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[22640]=0;_(2294,a+b|0);a=v[22640];v[22640]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;Z(a|0)|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function R7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;f=nc(a);a:{b:{c:{d:{e:{e=b+24|0;if(x[v[e>>2]+480188>>1]){a=0;while(1){d=v[e>>2];v[22640]=0;R(2099,c|0,(d+(a<<5)|0)+480289|0);d=v[22640];v[22640]=0;if((d|0)==1){break e}v[22640]=0;U(2092,c+16|0,b|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break d}v[22640]=0;R(1429,f|0,c+16|0);d=v[22640];v[22640]=0;if((d|0)==1){break c}vb(c+16|0);vb(c);a=a+1|0;if(a>>>0<x[v[e>>2]+480188>>1]){continue}break}}gb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+16|0)}vb(c)}vd(f);S(a|0);L()}function GU(a,b){var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;Pe(c+40|0,a,4);a=v[c+40>>2];v[22640]=0;d=Rd(c+40|0);e=v[22640];v[22640]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22640]=0;Te(c+8|0,3,d,a);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;R(377,c+24|0,c+8|0);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;R(888,c|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}v[22640]=0;Q(429,c|0,c+24|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break c}vb(c+24|0);xc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}xc(c+40|0);S(a|0);L()}}function hy(a,b,c){var d=0,e=0,f=C(0),g=0,h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0);e=gb-32|0;gb=e;mJ(C(-z[a>>2]),C(z[a+12>>2]+z[a+24>>2]),C(z[a+36>>2]+z[a+48>>2]),e+20|0);mJ(z[a+60>>2],C(z[a+48>>2]-z[a+36>>2]),C(z[a+24>>2]-z[a+12>>2]),e+8|0);z[e+12>>2]=-z[e+12>>2];a=0;while(1){d=a<<2;g=d+c|0;h=z[g>>2];f=z[d+68032>>2];i=z[d+(e+20|0)>>2];j=z[d+(e+8|0)>>2];k=z[d+68044>>2];z[g>>2]=C(f*i)-C(j*k);g=b+d|0;l=z[(0-a<<2)+68040>>2];d=5-a<<2;m=z[d+68032>>2];f=C(C(f*j)+C(k*i));z[g>>2]=C(h*l)-C(m*f);z[b+d>>2]=C(m*h)+C(f*l);a=a+1|0;if((a|0)!=3){continue}break}gb=e+32|0}function et(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=gb-240|0;gb=g;h=v[c>>2];v[g+232>>2]=h;c=v[c+4>>2];v[g>>2]=a;v[g+236>>2]=c;a:{b:{c:{d:{if((h|0)!=1){h=a;i=1;break d}h=a;i=1;if(c){break d}c=a;break c}while(1){c=h-v[(d<<2)+f>>2]|0;if((kb[b|0](c,a)|0)<1){c=h;break c}e:{if(!((d|0)<2|e)){e=v[((d<<2)+f|0)-8>>2];j=h-4|0;if((kb[b|0](j,c)|0)>-1){break e}if((kb[b|0](j-e|0,c)|0)>-1){break e}}v[(i<<2)+g>>2]=c;e=OI(g+232|0);ft(g+232|0,e);i=i+1|0;d=d+e|0;e=0;h=c;if(v[g+236>>2]|v[g+232>>2]!=1){continue}break b}break}c=h;break b}if(e){break a}}NI(g,i);Ux(c,b,d,f)}gb=g+240|0}function xja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=u[(f<<1)+k>>1];h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;gb=b+16|0}function _da(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=yg(c,a,1);a=wb(a);e=v[d+4>>2];v[22640]=0;pq(a,e,b);a=v[22640];v[22640]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=Pm(c+8|0,_g(a,Nb(a)+1|0),Nb(a),e);f=v[a+8>>2];v[22640]=0;pq(e,f,b);b=v[22640];v[22640]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[22640]=0;R(1505,d|0,a|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}Zg(a);gb=c+32|0;break b}b=P()|0;O()|0;Zg(a);S(b|0);L()}}function Wna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=Mp(c,a,1);wb(a);a=v[d+4>>2];v[22640]=0;R(676,a|0,b|0);a=v[22640];v[22640]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+12;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=ns(c+8|0,Mw(a,Cc(a)+1|0),Cc(a),e);e=v[a+8>>2];v[22640]=0;R(676,e|0,b|0);b=v[22640];v[22640]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+12;v[22640]=0;Ln(d,a);b=v[22640];v[22640]=0;if((b|0)==1){break c}ms(a);gb=c+32|0;break b}b=P()|0;O()|0;ms(a);S(b|0);L()}}function Jw(a){var b=0,c=0,d=0,e=0,f=0;a:{if(y[a+4>>2]<y[wb(a)>>2]){b=gb-16|0;gb=b;c=yw(b,a,1);d=wb(a);e=v[c+4>>2];v[22640]=0;R(245,d|0,e|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[c+4>>2]=v[c+4>>2]+36;$b(c);gb=b+16|0;break a}a=P()|0;O()|0;$b(c);S(a|0);L()}d=gb-32|0;gb=d;c=a;e=wb(a);b=FF(d+8|0,GF(a,Zk(a)+1|0),Zk(a),e);f=v[b+8>>2];v[22640]=0;R(245,e|0,f|0);e=v[22640];v[22640]=0;b:{c:{if((e|0)==1){break c}v[b+8>>2]=v[b+8>>2]+36;v[22640]=0;R(246,c|0,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break c}fs(b);gb=d+32|0;break b}a=P()|0;O()|0;fs(b);S(a|0);L()}}hj(a)}function I4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=He(b,-1);e=w[a+52|0];f=a;a:{b:{if(d){d=b;if(e){break a}b=v[a+48>>2];a=He(b,-1)^1;break b}if(e){v[c+16>>2]=v[a+48>>2];c:{d:{switch(Rs(v[a+36>>2],v[a+40>>2],c+16|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)-1|0){case 2:d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d;default:while(1){d=v[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break c}d=d-1|0;v[c+20>>2]=d;if((Os(t[d|0],v[a+32>>2])|0)!=-1){continue}break};break;case 0:case 1:break d}}d=-1;e=0}if(!e){break a}}v[a+48>>2]=b;a=1}t[f+52|0]=a;d=b}gb=c+32|0;return d|0}function FD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=ji(c,a,1);a=wb(a);e=v[d+4>>2];v[22640]=0;yn(a,e,b);a=v[22640];v[22640]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+2;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=En(c+8|0,Rk(a,sc(a)+1|0),sc(a),e);f=v[a+8>>2];v[22640]=0;yn(e,f,b);b=v[22640];v[22640]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+2;v[22640]=0;R(345,d|0,a|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}Gh(a);gb=c+32|0;break b}b=P()|0;O()|0;Gh(a);S(b|0);L()}}function yja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gb-16|0;gb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=t[f+k|0]<<8;h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;gb=b+16|0}function ama(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,26);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function X_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>=c>>>0){break a}d=a+4|0;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0>c>>>0|c-(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0){break a}e=1;if(pc(b)>>>0>=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0){break a}mx(b,(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))|0)}return e|0}function LA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;d=yg(c,a,1);a=wb(a);e=v[d+4>>2];v[22640]=0;Go(a,e,b);a=v[22640];v[22640]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=Pm(c+8|0,_g(a,Nb(a)+1|0),Nb(a),e);f=v[a+8>>2];v[22640]=0;Go(e,f,b);b=v[22640];v[22640]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[22640]=0;R(95,d|0,a|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}Zg(a);gb=c+32|0;break b}b=P()|0;O()|0;Zg(a);S(b|0);L()}}function Gz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;a:{if(w[b+791|0]!=27){a=t[b+831|0];break a}e=a+1074312|0;Db(c+8|0,e,21);d=Cb(c+8|0);f=a;a=w[b+821|0];a=Cz(f,w[b+828|0],d?a:a+16>>>2|0);Db(c+8|0,e,45);b:{if(!(!Cb(c+8|0)|w[b+828|0]!=3)){f=b;d=w[b+821|0];c:{if(!(!d|d>>>0>=w[b+829|0])){a=w[b+832|0];d=d+1|0;break c}t[b+832|0]=a;d=1}t[f+821|0]=d;a=a<<24>>24;break b}t[b+821|0]=w[b+821|0]+w[b+829|0]}Db(c+8|0,e,47);if(!Cb(c+8|0)){break a}t[b+831|0]=a}if(a){g=b,h=Lb(v[b+684>>2]+((B(w[b+830|0],a)+2|0)/8|0)|0,0,256),v[g+684>>2]=h}gb=c+16|0}function E0(){var a=0;a:{if(t[465168]&1){break a}if(!Pd(465168)){break a}a=464880;while(1){a=Kb(a)+12|0;if((a|0)!=465168){continue}break}Od(465168)}hd(464880,88184);hd(464892,88216);hd(464904,88252);hd(464916,88276);hd(464928,88300);hd(464940,88316);hd(464952,88336);hd(464964,88356);hd(464976,88384);hd(464988,88424);hd(465e3,88456);hd(465012,88492);hd(465024,88528);hd(465036,88544);hd(465048,88560);hd(465060,88576);hd(465072,88300);hd(465084,88592);hd(465096,88608);hd(465108,88624);hd(465120,88640);hd(465132,88656);hd(465144,88672);hd(465156,88688)}function yQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Fb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=e>>>1|0;h=v[Fb(d+8|0,d+4|0)>>2];c=zb(b);if(e>>>0>=2){f=v[a+20>>2];e=g;while(1){j=f,k=zb(w[c+1|0])|zb(w[c|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=i;while(1){j=f,k=zb(w[c+1|0])|zb(w[c|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=d+16|0;return g+i<<1}function sj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;f=gb-16|0;gb=f;o(+b);h=j(1)|0;e=j(0)|0;g=h&2147483647;c=g;d=e;g=c+-1048576|0;a:{if((g|0)==2145386495|g>>>0<2145386495){i=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){i=e<<28;c=h;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e|2147418112;break a}if(!(c|d)){c=0;d=0;break a}g=c;c=c>>>0<1?E(e)+32|0:E(c);If(f,d,g,0,0,c+49|0);k=v[f>>2];i=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=k;v[a+4>>2]=i;v[a+8>>2]=c;v[a+12>>2]=h&-2147483648|d;gb=f+16|0}function Yoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;d=RD(c,a,1);a=wb(a);e=v[d+4>>2];v[22640]=0;TC(a,e,b);a=v[22640];v[22640]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+20;$b(d);gb=c+16|0;break a}a=P()|0;O()|0;$b(d);S(a|0);L()}return}c=gb-32|0;gb=c;d=a;e=wb(a);a=LX(c+8|0,MX(a,Ze(a)+1|0),Ze(a),e);f=v[a+8>>2];v[22640]=0;TC(e,f,b);b=v[22640];v[22640]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+20;v[22640]=0;SC(d,a);b=v[22640];v[22640]=0;if((b|0)==1){break c}tv(a);gb=c+32|0;break b}b=P()|0;O()|0;tv(a);S(b|0);L()}}function LP(a,b){var c=0,d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;a:{if(!w[b+846|0]|v[a+480180>>2]!=1){break a}c=v[b+104>>2];if(!c){break a}if(!Ld(c)){break a}d=x[c+34>>1];if(!(d&10)){break a}e=w[b+847|0]+w[(w[b+846|0]&15)+40048|0]|0;t[b+847|0]=e;if(e<<24>>24>-1){break a}t[b+847|0]=0;e=d&2;d=v[(e?4:12)+c>>2];g=v[b+760>>2]+1|0;v[b+760>>2]=g>>>0<v[(e?8:16)+c>>2]-d>>>0?g:0;e=fj(c);bc(f+8|0,zb(zb(v[c+20>>2]))+B(e,v[b+760>>2]+d|0)|0,e);b=v[f+8>>2];d=v[f+12>>2];if((b|0)!=(d|0)){while(1){t[b|0]=w[b|0]^-1;b=b+1|0;if((d|0)!=(b|0)){continue}break}}Zh(c,a,0)}gb=f+16|0}function BQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Fb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=e>>>1|0;h=v[Fb(d+8|0,d+4|0)>>2];c=zb(b);if(e>>>0>=2){f=v[a+20>>2];e=g;while(1){j=f,k=zb(w[c|0])|zb(w[c+1|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}i=h>>>1|0;b=zb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=i;while(1){j=f,k=zb(w[c|0])|zb(w[c+1|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}gb=d+16|0;return g+i<<1}function nW(a){var b=0;a:{if(yd(a,11534,3)){break a}b=a+3|0;if(w[b|0]<48|w[b|0]>51){break a}b=a+8|0;if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>4294966507){break a}b=a+16|0;if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}b=a+24|0;if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<52){break a}}a=a+32|0;return Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<4294967216}return 0}function Cna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=gb-48|0;gb=e;v[22640]=0;c=Q(228,a|0,1)|0;d=v[22640];v[22640]=0;a:{if((d|0)==1){break a}b:{c:{if(!c){break c}v[22640]=0;_(702,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break a}v[22640]=0;c=T(353,a|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}if(!c){break c}while(1){v[22640]=0;d=Q(703,a|0,e+8|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}c=c-1|0;d:{if(!d){break d}d=w[e+8|0];if(d>>>0>63){break d}hc(yW(b,d),e+8|0,33)}if(c&255){continue}break}}yb(a);gb=e+48|0;return}}b=P()|0;O()|0;yb(a);S(b|0);L()}function B4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;a:{b:{c:{if(He(b,-1)){break c}v[c+20>>2]=b;if(w[a+44|0]){if((Ek(c+20|0,4,1,v[a+32>>2])|0)!=1){break b}break c}v[c+16>>2]=c+24;f=c+32|0;g=c+24|0;d=c+20|0;while(1){e=Rs(v[a+36>>2],v[a+40>>2],d,g,c+12|0,c+24|0,f,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Ek(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=v[c+16>>2]-(c+24|0)|0;if((Ek(c+24|0,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=Ss(b);break a}a=-1}gb=c+32|0;return a|0}function Kt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=b;if(b>>>0<=4294967279){i=d,j=Ab(a),v[i+8>>2]=j;e=Xk(v[Jc(d+12|0,d+8|0)>>2]);if((e|0)!=(Kc(a)|0)){a:{f=Kc(a);g=Ab(a);b:{if((e|0)==10){h=1;b=a;c=v[a>>2];break b}c=e+1|0;b=a;c:{if(e>>>0>f>>>0){b=mi(b,c);break c}v[22640]=0;b=Q(109,b|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break c}a=V(0)|0;O()|0;Z(a|0)|0;$();break a}h=De(a);c=Jb(a)}Ng(b,c,Ab(a)+1|0);if(h){al(a,c,f+1|0)}d:{if((e|0)!=10){ng(a,e+1|0);ee(a,g);bf(a,b);break d}Ve(a,g)}}}gb=d+16|0;return}_f();L()}function oka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=mh(a);a:{if(b){v[22640]=0;R(952,a|0,b|0);d=v[22640];v[22640]=0;if((d|0)==1){break a}e=gb-16|0;gb=e;d=yw(e,a,b);b=v[d+4>>2];f=v[d+8>>2];if((b|0)!=(f|0)){while(1){c=Qb(b,0,36);v[c>>2]=0;v[c+4>>2]=0;u[c+22>>1]=0;u[c+24>>1]=0;u[c+26>>1]=0;u[c+28>>1]=0;t[c+21|0]=64;t[c+19|0]=64;t[c+20|0]=100;t[c+15|0]=0;t[c+16|0]=0;t[c+17|0]=0;t[c+18|0]=0;v[c+8>>2]=0;v[c+12>>2]=0;u[c+30>>1]=0;u[c+32>>1]=0;b=b+36|0;v[d+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(d);gb=e+16|0}return a|0}a=P()|0;O()|0;xB(c);S(a|0);L()}function S5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=b;if(b>>>0<=1073741807){i=d,j=Ab(a),v[i+8>>2]=j;e=vm(v[Jc(d+12|0,d+8|0)>>2]);if((e|0)!=(cq(a)|0)){a:{f=1;g=cq(a);h=Ab(a);b:{if((e|0)==1){b=a;c=v[a>>2];break b}c=e+1|0;b=a;c:{if(e>>>0>g>>>0){b=Li(b,c);break c}v[22640]=0;b=Q(2275,b|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break c}a=V(0)|0;O()|0;Z(a|0)|0;$();break a}f=De(a);c=Jb(a)}wi(b,c,Ab(a)+1|0);if(f){Wh(a,c,g+1|0)}d:{if((e|0)!=1){ng(a,e+1|0);ee(a,h);bf(a,b);break d}Ve(a,h)}}}gb=d+16|0;return}_f();L()}function zt(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+12>>2]=b;u[f+10>>1]=0;u[f+8>>1]=65535;a:{if(!At(f+12|0,f+10|0,f+8|0)){break a}a=a+24|0;if(!ke(v[a>>2]+484344|0,b&65535)){break a}b=_b(v[a>>2]+484344|0,b);if((d|0)<0|v[b+12>>2]<=(c|0)|(c|0)<0|(x[v[a>>2]+480188>>1]<=(d|0)|e>>>0>5)){break a}a=Tc(b,c,d&65535);b:{switch(e|0){case 0:g=w[a|0];break a;case 1:g=w[a+1|0];break a;case 2:g=w[a+2|0];break a;case 3:g=w[a+3|0];break a;case 4:g=w[a+4|0];break a;case 5:break b;default:break a}}g=w[a+5|0]}gb=f+16|0;return g|0}function lga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];g=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(g){c=v[a+20>>2];a=g;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;f=C(z[Wf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=f;e=c;f=re(f);a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}i=e,j=Sc(h),u[i>>1]=j;c=c+2|0;b=b+4|0;a=a-1|0;if(a){continue}break}}gb=d+16|0;return g<<2}function kz(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;j=gb-16|0;gb=j;v[j+12>>2]=d;d=a+12|0;i=d;a:{if(!(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))){break a}i=a+8|0;v[j+8>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);k=b,l=v[Fb(j+8|0,j+12|0)>>2],v[k>>2]=l;b=Jd(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24),v[b>>2],v[j+12>>2]);v[c>>2]=b;if(!(b>>>0>=y[j+12>>2]|h)){v[c>>2]=b+1}u[e>>1]=x[e>>1]|f;a=a+4|0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1){break a}u[e>>1]=x[e>>1]|g}gb=j+16|0}function yf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[Oc(28768,d+14|0)>>1];c=sc(a);a:{if(b>>>0>c>>>0){e=gb-32|0;gb=e;b:{c:{c=b-c|0;d:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>1>>>0){up(a,c,f);break d}b=wb(a);b=En(e+8|0,Rk(a,sc(a)+c|0),sc(a),b);v[22640]=0;U(344,b|0,c|0,f|0);c=v[22640];v[22640]=0;if((c|0)==1){break c}v[22640]=0;R(345,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}Gh(b)}gb=e+32|0;break b}a=P()|0;O()|0;Gh(b);S(a|0);L()}break a}if(b>>>0<c>>>0){zn(a,v[a>>2]+(b<<1)|0)}}gb=d+16|0}function xka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;bn(c- -64|0,b);v[22640]=0;be(c+32|0,c- -64|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)==1){break b}b=Sd(c+24|0);v[22640]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(239,c+40|0,c+16|0,c+8|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}a=ad(a);d=pc(c- -64|0);v[22640]=0;U(942,b|0,a|0,d>>>5|0);d=v[22640];v[22640]=0;if((d|0)==1){d=P()|0;O()|0;Ku(a);yb(b);break a}yb(b);gc(c- -64|0);gb=c+80|0;return}d=P()|0;O()|0}gc(c- -64|0);S(d|0);L()}function uka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;bn(c- -64|0,b);v[22640]=0;be(c+32|0,c- -64|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)==1){break b}b=Sd(c+24|0);v[22640]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(239,c+40|0,c+16|0,c+8|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}a=ad(a);d=pc(c- -64|0);v[22640]=0;U(943,b|0,a|0,d>>>2|0);d=v[22640];v[22640]=0;if((d|0)==1){d=P()|0;O()|0;ai(a);yb(b);break a}yb(b);gc(c- -64|0);gb=c+80|0;return}d=P()|0;O()|0}gc(c- -64|0);S(d|0);L()}function tka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;bn(c- -64|0,b);v[22640]=0;be(c+32|0,c- -64|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)==1){break b}b=Sd(c+24|0);v[22640]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(239,c+40|0,c+16|0,c+8|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}a=ad(a);d=pc(c- -64|0);v[22640]=0;U(944,b|0,a|0,d>>>8|0);d=v[22640];v[22640]=0;if((d|0)==1){d=P()|0;O()|0;Iu(a);yb(b);break a}yb(b);gc(c- -64|0);gb=c+80|0;return}d=P()|0;O()|0}gc(c- -64|0);S(d|0);L()}function ska(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-80|0;gb=c;bn(c- -64|0,b);v[22640]=0;be(c+32|0,c- -64|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)==1){break b}b=Sd(c+24|0);v[22640]=0;d=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;b=W(239,c+40|0,c+16|0,c+8|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}a=ad(a);d=pc(c- -64|0);v[22640]=0;U(945,b|0,a|0,d>>>4|0);d=v[22640];v[22640]=0;if((d|0)==1){d=P()|0;O()|0;Hu(a);yb(b);break a}yb(b);gc(c- -64|0);gb=c+80|0;return}d=P()|0;O()|0}gc(c- -64|0);S(d|0);L()}function g_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[d+8>>2]=16384;e=v[Fb(d+12|0,d+8|0)>>2];v[a+1072>>2]=e;c=17;v[d+4>>2]=17;a:{if(!e){break a}while(1){f=1<<c-1;e=_k(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}Yr(d+4|0,_k(a,4));break b}if((c|0)>16){break c}c=f-8|0;if((c|0)>(e|0)|(e|0)>(f+7|0)){break d}Yr(d+4|0,e-c|0);break b}YE(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}YE(a,c,0,b)}if(!v[a+1072>>2]){break a}c=v[d+4>>2];if((c|0)<18){continue}break}}gb=d+16|0}function mma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-80|0;gb=d;Ye(b);Pe(d+56|0,a,c);a=v[d+56>>2];v[22640]=0;c=Rd(d+56|0);e=v[22640];v[22640]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[22640]=0;Te(d+8|0,2,c,a);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;R(377,d+24|0,d+8|0);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;U(13,d+40|0,2,d+24|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}Eb(b,d+40|0);vb(d+40|0);vb(d+24|0);xc(d+56|0);gb=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}xc(d+56|0);S(a|0);L()}}function Fma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb-80|0;gb=d;Ye(b);Pe(d+56|0,a,c);a=v[d+56>>2];v[22640]=0;c=Rd(d+56|0);e=v[22640];v[22640]=0;b:{c:{d:{if((e|0)==1){break d}c=zb(c);v[22640]=0;Te(d+8|0,3,c,a);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;R(377,d+24|0,d+8|0);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;U(13,d+40|0,5,d+24|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}Eb(b,d+40|0);vb(d+40|0);vb(d+24|0);xc(d+56|0);gb=d+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}xc(d+56|0);S(a|0);L()}}function uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Pe(d+40|0,a,c);a=v[d+40>>2];v[22640]=0;e=Rd(d+40|0);f=v[22640];v[22640]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22640]=0;Te(d+8|0,1,e,a);e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;R(377,d+24|0,d+8|0);e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;Q(333,b|0,d+24|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}vb(d+24|0);xc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}xc(d+40|0);S(a|0);L()}return a|0}function Cpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Pe(d+40|0,a,c);a=v[d+40>>2];v[22640]=0;e=Rd(d+40|0);f=v[22640];v[22640]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22640]=0;Te(d+8|0,3,e,a);e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;R(377,d+24|0,d+8|0);e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;Q(335,b|0,d+24|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}vb(d+24|0);xc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}xc(d+40|0);S(a|0);L()}return a|0}function Coa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Pe(d+40|0,a,c);a=v[d+40>>2];v[22640]=0;e=Rd(d+40|0);f=v[22640];v[22640]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22640]=0;Te(d+8|0,2,e,a);e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;R(377,d+24|0,d+8|0);e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;Q(427,b|0,d+24|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}vb(d+24|0);xc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}xc(d+40|0);S(a|0);L()}return a|0}function mE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Pe(d+40|0,a,c);a=v[d+40>>2];v[22640]=0;e=Rd(d+40|0);f=v[22640];v[22640]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22640]=0;Te(d+8|0,2,e,a);e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;R(377,d+24|0,d+8|0);e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;Q(333,b|0,d+24|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}vb(d+24|0);xc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}xc(d+40|0);S(a|0);L()}return a|0}function f_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[d+8>>2]=32768;e=v[Fb(d+12|0,d+8|0)>>2];v[a+1072>>2]=e;c=9;v[d+4>>2]=9;a:{if(!e){break a}while(1){f=1<<c-1;e=_k(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}Yr(d+4|0,_k(a,3));break b}if((c|0)>8){break c}c=f-4|0;if((c|0)>(e|0)|(e|0)>(f+3|0)){break d}Yr(d+4|0,e-c|0);break b}XE(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}XE(a,c,0,b)}if(!v[a+1072>>2]){break a}c=v[d+4>>2];if((c|0)<10){continue}break}}gb=d+16|0}function aga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];c=v[Fb(e+12|0,e+8|0)>>2];h=z[d>>2];b=zb(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=h*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());v[e+8>>2]=-1082130432;v[e+4>>2]=1065353216;f=C(z[Wf(e+12|0,e+8|0,e+4|0)>>2]*C(32768));z[e+12>>2]=f;i=a;f=re(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=i,k=Sc(g),u[j>>1]=k;a=a+2|0;b=b+4|0;d=d-1|0;if(d){continue}break}}gb=e+16|0;return c<<2}function SR(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=vq(b);d=a;e=mh(a);v[22640]=0;R(1126,a|0,2048);a=v[22640];v[22640]=0;a:{if((a|0)!=1){v[22640]=0;LR(d);a=v[22640];v[22640]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Jf(e);S(a|0);L()}a=0;b:{while(1){c=1;if((a|0)!=1024){v[22640]=0;c=+(a-1024|0);g=vq(K(c*c*-9.5367431640625e-7+1)*b);e=v[22640];v[22640]=0;if((e|0)==1){break b}c=c*.0372006759294457;c=g*pi(c)/(c*f)}h=ze(d,a),i=c*.011841342921061943,A[h>>3]=i;a=a+1|0;if((a|0)!=2048){continue}break}return}a=P()|0;O()|0;Jf(d);S(a|0);L()}function KZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb+-64|0;gb=d;Pe(d+40|0,a,c);a=v[d+40>>2];v[22640]=0;e=Rd(d+40|0);f=v[22640];v[22640]=0;a:{b:{c:{d:{if((f|0)==1){break d}e=zb(e);v[22640]=0;Te(d+8|0,1,e,a);e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;R(377,d+24|0,d+8|0);e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;Q(335,b|0,d+24|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}vb(d+24|0);xc(d+40|0);gb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(d+24|0)}xc(d+40|0);S(a|0);L()}return a|0}function xha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=gb-16|0;gb=c;f=x[bj(a,b)>>1];a:{if(!Mo(a,b)){break a}d=v[a+24>>2]+484360|0;j=c,k=Sb(d),v[j+8>>2]=k;j=c,k=Wb(d),v[j>>2]=k;if(!Gb(c+8|0,c)){break a}h=f&65535;while(1){b:{g=v[c+8>>2];i=Yl(g);if(i){e=0;while(1){if(!(x[rc(g,e)>>1]!=(h|0)|((a|0)==(g|0)?(b|0)==(e|0):0))){d=DN(v[a+24>>2]+484344|0,h,0);if((d|0)!=65535){break b}}e=e+1|0;if((i|0)!=(e|0)){continue}break}}vS(c+8|0);if(Gb(c+8|0,c)){continue}break a}break}j=bj(a,b),k=d,u[j>>1]=k;f=d}gb=c+16|0;return f&65535}function jl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=gb-16|0;gb=d;v[b>>2]=0;v[b+4>>2]=0;t[d+15|0]=0;i=Qh(a,d+15|0);e=w[d+15|0];v[b>>2]=(e&252)>>>2;v[b+4>>2]=0;a:{c=e&3;if(!c){break a}c=-1<<c;k=(c>>>0<4294967294?c:-2)^-1;h=1;c=0;while(1){t[d+15|0]=0;l=Qh(a,d+15|0);m=v[b+4>>2];j=w[d+15|0];g=(h<<3)-2|0;f=g&31;e=b;n=b;if((g&63)>>>0>=32){g=j<<f;f=0}else{g=(1<<f)-1&j>>>32-f;f=j<<f}v[n>>2]=f|v[b>>2];v[e+4>>2]=g|m;i=i&l;if(!c&(h|0)==(k|0)){break a}e=h+1|0;c=e>>>0<1?c+1|0:c;h=e;continue}}gb=d+16|0;return i|0}function H0(){var a=0;a:{if(t[464864]&1){break a}if(!Pd(464864)){break a}a=464576;while(1){a=Kb(a)+12|0;if((a|0)!=464864){continue}break}Od(464864)}Vc(464576,2130);Vc(464588,2121);Vc(464600,8164);Vc(464612,7933);Vc(464624,2357);Vc(464636,8956);Vc(464648,2214);Vc(464660,2701);Vc(464672,6097);Vc(464684,6080);Vc(464696,6088);Vc(464708,6107);Vc(464720,7399);Vc(464732,10633);Vc(464744,6170);Vc(464756,4858);Vc(464768,2357);Vc(464780,6922);Vc(464792,7804);Vc(464804,8176);Vc(464816,6424);Vc(464828,3526);Vc(464840,2584);Vc(464852,10542)}function cF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;c=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=c;a:{if(!c){break a}d=b+80|0;f=a;c=v[b+84>>2];if(c>>>0<=15){c=v[d>>2]}else{v[e+12>>2]=c-16;c=v[Jc(d,e+12|0)>>2]}v[f+8>>2]=c;if(!(w[b+88|0]&2)|!w[b+794|0]){break a}b:{c:{d:{if(!bF(b)){c=v[b+104>>2];break d}c=v[b+104>>2];if(v[b+80>>2]!=v[c+12>>2]){break d}d=v[b+84>>2];if((d|0)==v[c+16>>2]){break c}}b=v[b+84>>2];if((b|0)!=v[c+8>>2]){break a}b=(v[c>>2]-b|0)+48|0;break b}b=(v[c>>2]-d|0)+112|0}g=a,h=v[a>>2]+B(fj(c),b)|0,v[g+4>>2]=h}gb=e+16|0}function m3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83221]|w[83222]<<8;v[a+24>>2]=w[83217]|w[83218]<<8|(w[83219]<<16|w[83220]<<24);il(a+24|1,8097,1,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;gb=f;h=xe();v[a>>2]=e;e=g>>>9&1;g=Ff(f,e+13|0,h,a+24|0,a)+f|0;h=Pg(f,g,c);e=f-((e<<3)+107&112)|0;gb=e;Ec(a+8|0,c);v[22640]=0;ja(2479,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22640];v[22640]=0;if((f|0)!=1){Vb(a+8|0);b=Tn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Vb(a+8|0);S(b|0);L()}function bea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-32|0;gb=e;f=Zf(a,c);se(e+8|0,v[a+28>>2]);d=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=d;a:{b:{if(!f){d=-1;if(!id(a,5)){break b}break a}d=v[f+8>>2]}h=d;g=v[a+28>>2];c:{d:{switch(d+1|0){case 0:case 3:PA(g,b);break c;default:break d}}d=gb-32|0;gb=d;v[d+28>>2]=h;u[d+26>>1]=0;v[d+12>>2]=2;kj(d+16|0,g,d+26|0,v[Fb(d+28|0,d+12|0)>>2]);xb(d+16|0);v[d+16>>2]=2;Fb(d+28|0,d+16|0);u[d+16>>1]=x[d+26>>1];u[b>>1]=w[d+16|0]|w[d+17|0]<<8;gb=d+32|0}}Sf(a,f,c,e+24|0);gb=e+32|0}function _3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{c:{d:{e:{if((a|0)!=(b|0)){g=v[115121];v[115121]=0;a=rH(a,e+12|0,d,xe());d=jb;f=v[115121];f:{if(f){if(v[e+12>>2]!=(b|0)){break f}if((f|0)==68){break d}break e}v[115121]=g;if(v[e+12>>2]==(b|0)){break e}}}v[c>>2]=4;a=0;break a}if((d|0)<-1?1:(d|0)<=-1?a>>>0<=2147483647:0){v[c>>2]=4;break c}if((d|0)<0?1:(d|0)<=0?a>>>0<=2147483647:0){break a}}v[c>>2]=4;if((d|0)>0?1:(d|0)>=0?a>>>0>=1:0){break b}}a=-2147483648;break a}a=2147483647}gb=e+16|0;return a|0}function Vw(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;f=v[a>>2];e=v[f-4>>2];f=v[f-8>>2];v[d+20>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;b=0;Qb(d+24|0,0,39);a=a+f|0;a:{if(Og(e,c,0)){v[d+56>>2]=1;kb[v[v[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=v[d+32>>2]==1?a:0;break a}kb[v[v[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:b=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}b=v[d+24>>2]}gb=d- -64|0;return b}function IP(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}b=v[a+480180>>2]&1048580?b&240?b&-16:b&15:b;c=b&240;e=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=e>>>3&30;break d}f=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(c){if(b?v[a+480180>>2]&59314208:0){break b}b=e>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}c=a+1074456|0;v[d+12>>2]=v[c>>2]+(b<<!(v[a+480180>>2]&59314208));Qd(d+12|0,0,256);v[c>>2]=v[d+12>>2]}gb=d+16|0}function _W(a,b){var c=0,d=0;c=(a|0)==(b|0);t[b+12|0]=c;a:{if(c){break a}while(1){if(w[v[b+8>>2]+12|0]){break a}d=jg(v[b+8>>2]);c=v[b+8>>2];b:{if(d){c=v[v[c+8>>2]+4>>2];if(!(!c|w[c+12|0])){break b}if(!jg(b)){b=v[b+8>>2];ur(b)}a=v[b+8>>2];t[a+12|0]=1;a=v[a+8>>2];t[a+12|0]=0;tr(a);return}c=v[v[c+8>>2]>>2];if(!(!c|w[c+12|0])){break b}if(jg(b)){b=v[b+8>>2];tr(b)}a=v[b+8>>2];t[a+12|0]=1;a=v[a+8>>2];t[a+12|0]=0;ur(a);break a}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=(a|0)==(b|0);t[c+12|0]=1;if((a|0)!=(b|0)){continue}break}}}function dk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){if(!De(a)){if(!De(b)){v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;return a|0}e=Jb(b);b=Ab(b);d=gb-16|0;gb=d;a:{if(b>>>0<=10){Ve(a,b);Ng(a,e,b);t[d+15|0]=0;zd(a+b|0,d+15|0);break a}c=w[a+11|0];Ap(a,10,b-10|0,c,0,c,b,e)}gb=d+16|0;return a|0}e=Jb(b);b=Ab(b);d=gb-16|0;gb=d;c=ck(a);b:{if(c>>>0>b>>>0){c=v[a>>2];ee(a,b);Ng(c,e,b);t[d+15|0]=0;zd(b+c|0,d+15|0);break b}f=c-1|0;g=(b-c|0)+1|0;c=v[a+4>>2];Ap(a,f,g,c,0,c,b,e)}gb=d+16|0}return a|0}function xga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-32|0;gb=e;g=e;k=b;d=gb-32|0;gb=d;BY(d+24|0,e+24|0);i=xb(d+24|0);h=v[d+28>>2];f=v[d+24>>2];v[d+8>>2]=f;v[d+12>>2]=h;v[d>>2]=f;v[d+4>>2]=h;h=b;fc(d+16|0,b,d);f=xb(d+16|0);if((f|0)==(i|0)){Yb(h,xb(d+24|0))}gb=d+32|0;if((f|0)==(i|0)){j=dn(e+24|0)}rd(g,k,j);a=Zl(a,e+24|0,e);yb(e);a:{if(!c){break a}g=(j>>>0)%(c>>>0)|0;if(!g){break a}v[22640]=0;Q(350,b|0,c-g|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break a}b=P()|0;O()|0;Xd(a);S(b|0);L()}gb=e+32|0}function jba(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;a:{b:{if(!a){a=ie(18693);break b}v[22640]=0;c=Q(112,b|0,a|0)|0;a=v[22640];v[22640]=0;c:{d:{if((a|0)!=1){v[22640]=0;R(1915,b+16|0,c|0);a=v[22640];v[22640]=0;if((a|0)==1){break d}a=ie(Jb(b+16|0));vb(b+16|0);vb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;vb(c)}Z(a|0)|0;a=0;v[22640]=0;Y(1911,8316,0,0,0);c=v[22640];v[22640]=0;if((c|0)==1){break a}$()}gb=b+32|0;return a|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function O9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-16|0;gb=g;v[22640]=0;_(1934,a|0);h=v[22640];v[22640]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[22640]=0;ja(1992,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}b=ie(Jb(g));vb(g);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22640]=0;Y(1911,8007,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$()}gb=g+16|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function N9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-16|0;gb=g;v[22640]=0;_(1934,a|0);h=v[22640];v[22640]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[22640]=0;ja(1993,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}b=ie(Jb(g));vb(g);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22640]=0;Y(1911,7962,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$()}gb=g+16|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function x3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83221]|w[83222]<<8;v[a+24>>2]=w[83217]|w[83218]<<8|(w[83219]<<16|w[83220]<<24);il(a+24|1,8097,1,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;gb=f;h=xe();v[a>>2]=e;g=Ff(f,(g>>>9&1)+13|0,h,a+24|0,a)+f|0;h=Pg(f,g,c);e=f-32|0;gb=e;Ec(a+8|0,c);v[22640]=0;ja(2472,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22640];v[22640]=0;if((f|0)!=1){Vb(a+8|0);b=wn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Vb(a+8|0);S(b|0);L()}function XA(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;a:{if($c(a)){break a}u[v[a>>2]>>1]=0;vf(v[a>>2]+2|0,b);e=c,f=Sb(a),v[e>>2]=f;e=c,f=Xo(c,1),v[e+8>>2]=f;e=c,f=Wb(a),v[e>>2]=f;if(!Gb(c+8|0,c)){break a}while(1){d=v[c+8>>2];e=c,f=Xo(c+8|0,-1),v[e>>2]=f;d=Ie(d,v[c>>2]);u[v[c+8>>2]>>1]=x[d>>1];vf(v[c+8>>2]+2|0,b);iE(c+8|0);e=c,f=Wb(a),v[e>>2]=f;if(Gb(c+8|0,c)){continue}break}}vf(a+14|0,Nb(a)-1&255);vf(a+13|0,w[a+14|0]);vf(a+16|0,Nb(a)-1&255);vf(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){vf(a+17|0,Nb(a)-1&255)}gb=c+16|0}function Vea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=gb-32|0;gb=f;a=eh(a);a:{b:{c:{d:{while(1){v[22640]=0;e=Q(228,b|0,8)|0;g=v[22640];v[22640]=0;if((g|0)==1){break b}if(e){v[22640]=0;U(1472,f|0,b|0,c|0);e=v[22640];v[22640]=0;if((e|0)==1){break d}v[22640]=0;R(1473,a|0,f|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}Xd(f);e=HU(a);if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=(d|0)){continue}}break}gb=f+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Xd(f);break a}b=P()|0;O()|0}Cd(a);S(b|0);L()}function U$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Og(a,v[b+8>>2],e)){Rw(b,c,d);return}a:{if(Og(a,v[b>>2],e)){if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];kb[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];kb[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function nha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-32|0;gb=e;f=Zf(a,c);se(e+8|0,v[a+28>>2]);d=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=d;a:{b:{if(!f){d=-1;if(!id(a,5)){break b}break a}d=v[f+8>>2]}h=d;g=v[a+28>>2];c:{d:{switch(d+1|0){case 0:case 2:Rh(g,b);break c;default:break d}}d=gb-32|0;gb=d;v[d+28>>2]=h;t[d+27|0]=0;v[d+12>>2]=1;kj(d+16|0,g,d+27|0,v[Fb(d+28|0,d+12|0)>>2]);xb(d+16|0);v[d+16>>2]=1;Fb(d+28|0,d+16|0);t[d+16|0]=w[d+27|0];t[b|0]=w[d+16|0];gb=d+32|0}}Sf(a,f,c,e+24|0);gb=e+32|0}function u3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83221]|w[83222]<<8;v[a+24>>2]=w[83217]|w[83218]<<8|(w[83219]<<16|w[83220]<<24);il(a+24|1,8097,0,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;gb=f;h=xe();v[a>>2]=e;g=Ff(f,g>>>9&1|12,h,a+24|0,a)+f|0;h=Pg(f,g,c);e=f-32|0;gb=e;Ec(a+8|0,c);v[22640]=0;ja(2472,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22640];v[22640]=0;if((f|0)!=1){Vb(a+8|0);b=wn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Vb(a+8|0);S(b|0);L()}function j3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=gb-32|0;gb=a;u[a+28>>1]=w[83221]|w[83222]<<8;v[a+24>>2]=w[83217]|w[83218]<<8|(w[83219]<<16|w[83220]<<24);il(a+24|1,8097,0,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;gb=f;h=xe();v[a>>2]=e;g=Ff(f,g>>>9&1|12,h,a+24|0,a)+f|0;h=Pg(f,g,c);e=f-96|0;gb=e;Ec(a+8|0,c);v[22640]=0;ja(2479,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22640];v[22640]=0;if((f|0)!=1){Vb(a+8|0);b=Tn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Vb(a+8|0);S(b|0);L()}function lm(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}h=e;i=d;j=64-f|0;g=j&31;if((j&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|h<<g;j=i<<g}i=b;g=f;b=g&31;if((g&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function e3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-208|0;gb=a;u[a+204>>1]=w[83227]|w[83228]<<8;v[a+200>>2]=w[83223]|w[83224]<<8|(w[83225]<<16|w[83226]<<24);f=xe();v[a>>2]=e;h=Ff(a+176|0,20,f,a+200|0,a);e=h+(a+176|0)|0;f=Pg(a+176|0,e,c);Ec(a+8|0,c);v[22640]=0;g=T(2458,a+8|0)|0;i=v[22640];v[22640]=0;if((i|0)!=1){Vb(a+8|0);mH(g,a+176|0,e,a+16|0);g=b;b=(a+16|0)+(h<<2)|0;b=Tn(g,a+16|0,(e|0)==(f|0)?b:((f-a<<2)+a|0)-688|0,b,c,d);gb=a+208|0;return b|0}b=P()|0;O()|0;Vb(a+8|0);S(b|0);L()}function kZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{if(!Rf(a,7)){break b}d=0;if(!ND(a,14880)){break a}if(!Rf(a,1)){break b}d=-1;if(!cd(a,Kr(a))){break a}c=gb-32|0;gb=c;g=e+8|0;un(c+24|0,g);h=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;qd(c+16|0,a,c);f=xb(c+16|0);if((f|0)==(h|0)){cd(d,xb(c+24|0))}gb=c+32|0;c=(f|0)==(h|0);if(!c){Ov(g)}d=-1;if(!c){break a}d=0;if(!JD(e+8|0)){break a}d=Ne(a,b,ID(e+8|0),jb);break a}d=-1}gb=e+16|0;return d|0}function Lka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=gb+-64|0;gb=c;Pe(c+40|0,a,31);a=v[c+40>>2];v[22640]=0;d=Rd(c+40|0);e=v[22640];v[22640]=0;b:{c:{d:{if((e|0)==1){break d}d=zb(d);v[22640]=0;Te(c+8|0,2,d,a);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;R(377,c+24|0,c+8|0);a=v[22640];v[22640]=0;if((a|0)==1){break d}v[22640]=0;Q(335,b|0,c+24|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break c}vb(c+24|0);xc(c+40|0);gb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;vb(c+24|0)}xc(c+40|0);S(a|0);L()}}function HC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c;g=e+12|0;c=a;d=Nb(c);a:{if(d>>>0<b>>>0){f=gb-32|0;gb=f;b:{d=b-d|0;c:{if(d>>>0<=v[wb(c)>>2]-v[c+4>>2]>>2>>>0){gE(c,d,g);break c}b=wb(c);b=Pm(f+8|0,_g(c,Nb(c)+d|0),Nb(c),b);v[22640]=0;U(679,b|0,d|0,g|0);d=v[22640];v[22640]=0;if((d|0)==1){break b}v[22640]=0;R(95,c|0,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}Zg(b)}gb=f+32|0;break a}a=P()|0;O()|0;Zg(b);S(a|0);L()}if(b>>>0<d>>>0){dj(c,v[c>>2]+(b<<2)|0)}}Oz(a);gb=e+16|0}function Cz(a,b,c){var d=0,e=0;e=gb-16|0;gb=e;Db(e+8|0,a+1074312|0,21);a:{if(Cb(e+8|0)){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+40256|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=vO(Ao(a))+-64|0;break a}d=t[(c>>>1&31)+38752|0];if(v[a+480180>>2]&67633152){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+40128|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+40192|0]}a=d;gb=e+16|0;return a}function yz(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=gb-16|0;gb=h;a:{if((c|0)<2){break a}j=c-2>>>1|0;f=d-a|0;if((j|0)<f>>1){break a}g=f+1|0;e=(g<<1)+a|0;f=f+2|0;if((f|0)<(c|0)){i=Aq(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?f:g}if(Aq(b,x[e>>1],x[d>>1])){break a}u[h+14>>1]=x[d>>1];while(1){b:{f=e;u[d>>1]=x[e>>1];if((g|0)>(j|0)){break b}d=g<<1;g=d|1;e=(g<<1)+a|0;d=d+2|0;if((d|0)<(c|0)){i=Aq(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?d:g}d=f;if(!Aq(b,x[e>>1],x[h+14>>1])){continue}}break}u[f>>1]=x[h+14>>1]}gb=h+16|0}function una(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=jD(c,a);nC(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;$b(a);gb=c+16|0;return}f=gb-32|0;gb=f;c=wb(a);d=gD(f+8|0,hD(a,Ch(a)+1|0),Ch(a),c);nC(v[d+8>>2],b);v[d+8>>2]=v[d+8>>2]+28;c=d;h=c+4|0;g=h;b=a;e=v[a+4>>2];i=v[a>>2];if((e|0)!=(i|0)){a=v[g>>2];while(1){e=e-28|0;nC(a-28|0,e);a=v[g>>2]-28|0;v[g>>2]=a;if((e|0)!=(i|0)){continue}break}}wc(b,h);wc(b+4|0,c+8|0);wc(wb(b),cc(c));v[c>>2]=v[c+4>>2];fD(d);gb=f+32|0}function mga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];f=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){v[d+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+8>>2]=-1082130432;v[d+4>>2]=1065353216;e=C(z[Wf(d+12|0,d+8|0,d+4|0)>>2]*C(32768));z[d+12>>2]=e;h=a;e=re(e);a:{if(C(D(e))<C(2147483648)){g=~~e;break a}g=-2147483648}i=h,j=Sc(g),u[i>>1]=j;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return f<<2}function DS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=b?33:32;c=w[a+16|0];k=c?-1:1;l=c?1:-1;e=v[a+8>>2]-1|0;m=c?e-(w[a+17|0]!=0&(e|0)!=0)|0:0;n=c?0:e;f=v[a+12>>2];h=v[a>>2]+B(f,62)|0;d=b?1:-1;o=B(f,d)<<1;c=e;while(1){if((f|0)>0){g=B(c,f);p=v[a+4>>2];b=0;while(1){u[(b<<1)+h>>1]=x[p+(b+g<<1)>>1];b=b+1|0;if((f|0)!=(b|0)){continue}break}}h=h+o|0;a:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break a}}b=c+d|0;c=!c&(d|0)<0;b=c?n:b;g=c?l:d}d=g;c=b;i=i+1|0;if((j|0)!=(i|0)){continue}break}}function vka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-4112|0;gb=d;bn(a,b);if(pc(a)>>>0>4095){while(1){f=e<<12;b=0;c=0;while(1){b=zb(w[kc(a,c+f|0)|0])+b|0;g=zb(b&255);i=lc(d+16|0,c<<1|1),j=g,t[i|0]=j;c=c+1|0;if((c|0)!=2048){continue}break}g=f|2048;c=0;while(1){b=zb(w[kc(a,c+g|0)|0])+b|0;h=zb(b&255);i=lc(d+16|0,c<<1),j=h,t[i|0]=j;c=c+1|0;if((c|0)!=2048){continue}break}i=d,j=Sb(a),v[i+8>>2]=j;Ju(d+16|0,d+4112|0,we(d+8|0,f));e=e+1|0;if(e>>>0<pc(a)>>>12>>>0){continue}break}}gb=d+4112|0}function cea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=C(0);e=gb-32|0;gb=e;g=Zf(a,c);se(e+8|0,v[a+28>>2]);d=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=d;a:{if(!g){if(id(a,5)){break a}}d=gb-32|0;gb=d;h=v[a+28>>2];jl(h,d+24|0);j=d,k=Uc(v[d+24>>2],v[d+28>>2]),v[j+16>>2]=k;v[d+12>>2]=256;El(b,v[Fb(d+16|0,d+12|0)>>2]);if(Nb(b)){while(1){v[d+16>>2]=0;qq(h,d+16|0);i=z[d+16>>2];j=Mb(b,f),l=i,z[j>>2]=l;f=f+1|0;if(Nb(b)>>>0>f>>>0){continue}break}}gb=d+32|0}Sf(a,g,c,e+24|0);gb=e+32|0}function CS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=b?33:32;f=v[a+8>>2];c=f-1|0;d=v[a+12>>2];g=v[a>>2]+B(d,31)|0;h=b?1:-1;e=h;while(1){b=0;if((d|0)>0){while(1){t[b+g|0]=w[v[a+4>>2]+(B(c,d)+b|0)|0];b=b+1|0;d=v[a+12>>2];if((b|0)<(d|0)){continue}break}f=v[a+8>>2]}b=B(d,h);i=f-1|0;a:{if(!((i|0)!=(c|0)|(e|0)<=0)){if(!w[a+16|0]){e=1;c=0;break a}e=-1;c=c-(w[a+17|0]!=0&(c|0)!=0)|0;break a}if(!((e|0)>-1|c)){c=w[a+16|0];e=c?1:-1;c=c?0:i;break a}c=c+e|0}g=b+g|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}}function wD(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;Pe(d+40|0,a,c);a=v[d+40>>2];v[22640]=0;e=Rd(d+40|0);f=v[22640];v[22640]=0;a:{b:{c:{if((f|0)==1){break c}e=zb(e);v[22640]=0;Te(d+8|0,3,e,a);e=v[22640];v[22640]=0;if((e|0)==1){break c}v[22640]=0;R(377,d+24|0,d+8|0);e=v[22640];v[22640]=0;if((e|0)==1){break c}v[22640]=0;Q(333,b|0,d+24|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break b}vb(d+24|0);xc(d+40|0);gb=d- -64|0;return!c|(a|0)!=0}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+24|0)}xc(d+40|0);S(c|0);L()}function f8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-32|0;gb=b;a:{b:{if(yj(a)){th(b+24|0);break b}mo(b+8|0,a);v[22640]=0;c=T(2084,b+8|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break a}v[b+24>>2]=c;Uf(b+8|0)}if(yj(a)){c=a+36|0}else{c=v[b+24>>2]}a=v[a+8>>2];c:{if((a|0)==-1){f=b,g=Sb(c),v[f+8>>2]=g;f=b,g=Wb(c),v[f>>2]=g;if(!Gb(b+8|0,b)){break c}while(1){d=A[v[b+8>>2]>>3]+d;aL(b+8|0);if(Gb(b+8|0,b)){continue}break}break c}d=A[Ul(c,a)>>3]}yl(b+24|0);gb=b+32|0;return+d}a=P()|0;O()|0;Uf(b+8|0);S(a|0);L()}function Po(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[a+34>>1];if(!b){b=a;if(d&512){GS(a);d=x[a+34>>1]}u[b+34>>1]=d&65023;return}v[a>>2]=4;u[a+34>>1]=d&64958|512;_m(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}function Aga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;bc(c+24|0,b,16);gb=d+16|0;d=xb(c+24|0);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;fc(c+16|0,a,c);e=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;gb=c+16|0}return a|0}function Q9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[22640]=0;_(1934,a|0);g=v[22640];v[22640]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[22640]=0;ka(1990,f|0,g|0,b|0,c|0,d|0,e|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}b=ie(Jb(f));vb(f);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22640]=0;Y(1911,9753,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$()}gb=f+16|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function P9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[22640]=0;_(1934,a|0);g=v[22640];v[22640]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[22640]=0;ka(1991,f|0,g|0,b|0,c|0,d|0,e|0);b=v[22640];v[22640]=0;if((b|0)==1){break c}b=ie(Jb(f));vb(f);break b}}b=V(0)|0;O()|0;Z(b|0)|0;b=0;v[22640]=0;Y(1911,9653,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$()}gb=f+16|0;return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function B2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;d=Ab(a);e=cq(a);g=jr(b,c);a:{if(!g){break a}if(RC(b,Jb(a),Jb(a)+(Ab(a)<<2)|0)){d=gb-16|0;gb=d;qH(f,b,c);gb=d+16|0;b=f;c=Jb(b);d=Ab(b);v[22640]=0;W(2499,a|0,c|0,d|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){Hc(b);break a}a=P()|0;O()|0;Hc(b);S(a|0);L()}if(e-d>>>0<g>>>0){tI(a,e,(d+g|0)-e|0,d,d)}e=Jb(a)+(d<<2)|0;if((b|0)!=(c|0)){while(1){Fe(e,b);e=e+4|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}v[f>>2]=0;Fe(e,f);gh(a,d+g|0)}gb=f+16|0}function qoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Eg(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/6>>>0){GC(a,d,c);break c}b=wb(a);b=JW(e+8|0,qC(a,Eg(a)+d|0),Eg(a),b);v[22640]=0;U(662,b|0,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}EC(a);c=b+4|0;HW(wb(a),v[a>>2],v[a+4>>2],c);jc(a,c);jc(a+4|0,b+8|0);jc(wb(a),cc(b));v[b>>2]=v[b+4>>2];sC(a,Eg(a));kv(b)}gb=e+32|0;break a}a=P()|0;O()|0;kv(b);S(a|0);L()}return}if(b>>>0<d>>>0){FC(a,v[a>>2]+B(b,6)|0)}}function o3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=gb-96|0;gb=a;u[a+92>>1]=w[83227]|w[83228]<<8;v[a+88>>2]=w[83223]|w[83224]<<8|(w[83225]<<16|w[83226]<<24);f=xe();v[a>>2]=e;h=Ff(a- -64|0,20,f,a+88|0,a);e=h+(a- -64|0)|0;f=Pg(a- -64|0,e,c);Ec(a+8|0,c);v[22640]=0;g=T(21,a+8|0)|0;i=v[22640];v[22640]=0;if((i|0)!=1){Vb(a+8|0);nH(g,a- -64|0,e,a+16|0);g=b;b=(a+16|0)+h|0;b=wn(g,a+16|0,(e|0)==(f|0)?b:((f-a|0)+a|0)-48|0,b,c,d);gb=a+96|0;return b|0}b=P()|0;O()|0;Vb(a+8|0);S(b|0);L()}function Nea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-32|0;gb=d;_e(d,2,a+6|0);Bc(d+16|0,d);v[22640]=0;Q(333,b+492|0,d+16|0)|0;e=v[22640];v[22640]=0;if((e|0)!=1){e=b+236|0;c=c+1|0;vb(d+16|0);while(1){g=w[(a+f|0)+38|0];h=sd(e,f),i=c+g|0,u[h>>1]=i;f=f+1|0;if((f|0)!=128){continue}break}c=a+226|0;v[b>>2]=(w[c|0]|w[c+1|0]<<8)<<5;jz(a+180|0,b+48|0,0);jz(a+228|0,b+88|0,2);jz(a+276|0,b+68|0,1);a=a+324|0;if(!(w[a|0]|w[a+1|0]<<8)){nB(e)}gb=d+32|0;return}a=P()|0;O()|0;vb(d+16|0);S(a|0);L()}function qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;f=Kb(a);a:{b:{c:{if(Cc(b)){a=0;while(1){d:{if(!a){break d}v[22640]=0;Q(1183,f|0,c|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=xd(b,a);v[22640]=0;R(1184,e|0,d|0);d=v[22640];v[22640]=0;if((d|0)==1){break c}v[22640]=0;Q(1183,f|0,e|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}vb(e);a=a+1|0;if(Cc(b)>>>0>a>>>0){continue}break}}gb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e)}vb(f);S(a|0);L()}function S3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[115121];v[115121]=0;a=rx(a,e+12|0,d,xe());d=jb;e:{g=v[115121];if(g){if(v[e+12>>2]!=(b|0)){break c}if((g|0)==68){break e}break b}v[115121]=h;if(v[e+12>>2]==(b|0)){break b}break c}v[c>>2]=4;a=-1;b=-1;break a}}v[c>>2]=4;a=0;b=0;break a}b=a;c=(f|0)==45;a=c?0-a|0:a;b=c?0-(d+((b|0)!=0)|0)|0:d}gb=e+16|0;jb=b;return a|0}function ula(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-32|0;gb=d;a=eh(a);a:{b:{c:{d:{while(1){v[22640]=0;c=Q(228,b|0,8)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}if(c){v[22640]=0;R(881,d|0,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break d}v[22640]=0;R(882,a|0,d|0);c=v[22640];v[22640]=0;if((c|0)==1){break c}Xd(d);c=HU(a);if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1413891155){continue}}break}gb=d+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Xd(d);break a}b=P()|0;O()|0}Cd(a);S(b|0);L()}function If(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;i=f;d=f&31;if((f&63)>>>0>=32){h=g<<d;j=0}else{h=(1<<d)-1&g>>>32-d|e<<d;j=g<<d}d=c;g=b;f=64-f|0;e=f&31;if((f&63)>>>0>=32){f=0;d=d>>>e|0}else{f=d>>>e|0;d=((1<<e)-1&d)<<32-e|g>>>e}d=j|d;e=f|h;f=b;b=i&31;if((i&63)>>>0>=32){h=f<<b;b=0}else{h=(1<<b)-1&f>>>32-b|c<<b;b=f<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function EP(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=d+c^d;if(d>>>0<224){break c}Db(e+8|0,a+1074312|0,3);if(Cb(e+8|0)){break c}if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,872)+a|0)+1075843|0]&1){Db(e+8|0,a+1074312|0,3);if(!Cb(e+8|0)){break a}}c=c<<2}if(!c){break a}d=gu(a,b);if(!d){break a}f=d;a=v[(B(b,872)+a|0)+1075648>>2];if(a){a=w[a+33|0]}else{a=13}kb[v[v[d>>2]+84>>2]](f,c,a<<24>>24,b)}gb=e+16|0}function uy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=b;m=e,n=wd(a),v[m+16>>2]=n;j=Xj(e+24|0,e+16|0);h=j;i=gb-16|0;gb=i;a:{b=a;g=Ab(b);if(g>>>0>=h>>>0){if(c){f=Kc(b);b:{if(f-g>>>0>=c>>>0){f=Jb(b);k=g-h|0;if(!k){break b}l=f+h|0;bm(l+c|0,l,k);break b}Em(b,f,(c+g|0)-f|0,g,h,0,c);f=v[b>>2]}Ir(f+h|0,c,d);d=b;b=c+g|0;gh(d,b);t[i+15|0]=0;zd(b+f|0,i+15|0)}gb=i+16|0;break a}_n();L()}m=e,n=wd(a),v[m+8>>2]=n;a=we(e+8|0,j);gb=e+32|0;return a|0}function e$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;f=Kb(a);a:{b:{c:{if(Cc(b)){a=0;while(1){d:{if(!a){break d}v[22640]=0;Q(155,f|0,c|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=xd(b,a);v[22640]=0;R(212,e|0,d|0);d=v[22640];v[22640]=0;if((d|0)==1){break c}v[22640]=0;Q(155,f|0,e|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break b}vb(e);a=a+1|0;if(Cc(b)>>>0>a>>>0){continue}break}}gb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(e)}vb(f);S(a|0);L()}function Lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[wb(a)>>2]){d=gb-16|0;gb=d;c=yg(d,a,1);wb(a);bT(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+4;$b(c);gb=d+16|0;return}f=gb-32|0;gb=f;e=wb(a);d=_g(a,Nb(a)+1|0);i=Nb(a);g=gb-16|0;gb=g;v[g+12>>2]=0;c=f+8|0;ef(c+12|0,e);if(d){h=QW(d)}v[c>>2]=h;e=(i<<2)+h|0;v[c+8>>2]=e;v[c+4>>2]=e;j=cc(c),k=(d<<2)+h|0,v[j>>2]=k;gb=g+16|0;bT(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;aT(a,c);a=c;$S(c);b=v[c>>2];if(b){vC(v[a+16>>2],b,pk(a))}gb=f+32|0}function Vx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;f=(p(a),j(2));c=f&2147483647;a:{if(c>>>0<=1305022426){g=+a;d=g*.6366197723675814+6755399441055744+-6755399441055744;A[b>>3]=g+d*-1.5707963109016418+d*-1.5893254773528196e-8;if(D(d)<2147483648){c=~~d;break a}c=-2147483648;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}h=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,h-(c<<23)|0),q());c=SI(e+8|0,e,c,1,0);d=A[e>>3];if((f|0)<=-1){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}gb=e+16|0;return c}function pv(a,b){a=a|0;b=b|0;var c=0,d=0;d=w[a+3|0];a:{if(d>>>0>18){break a}d=1<<d;b:{if(!(d&126991)){if(d&396800){break b}break a}if(!w[a|0]){break a}}c:{d:{e:{f:{g:{switch(w[a+3|0]){case 9:c=2;break d;case 10:case 17:case 18:c=1;break d;case 11:break f;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:break g;default:break e}}c=w[a|0];if(c&7){break f}c=c>>>3|0;break d}c=b+1>>>1|0;b=(w[a+3|0]==11)<<4;break c}c=0}c=B(c,b);b=(w[a+3|0]==11)<<4}c=b+B(dp(a),c)|0}return c|0}function lja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=e+j|0;e=t[f|0];e=((B(t[f+1|0]-e|0,g>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;gb=b+16|0}function Tn(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=gb-16|0;gb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>=1){g=g>>2;if((vn(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>=1){f=rI(i,b,f);h=Jb(f);v[22640]=0;h=W(2481,a|0,h|0,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break a}Hc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>=1){b=b>>2;if((vn(a,c,b)|0)!=(b|0)){break b}}DB(e);j=a}gb=i+16|0;return j|0}a=P()|0;O()|0;Hc(f);S(a|0);L()}function Eaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22640]=0;_(1934,a|0);d=v[22640];v[22640]=0;a:{if((d|0)==1){break a}v[22640]=0;_(1945,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break a}d=v[a+24>>2];v[22640]=0;b=Q(1946,d|0,b|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,7679,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function hp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;v[f+28>>2]=c;g=Pb(b,c);a:{if(!g){break a}tc(f+28|0,65535);yf(a,x[f+28>>1]);i=f,j=Sb(a),v[i+16>>2]=j;i=f,j=Wb(a),v[i+8>>2]=j;if(!Gb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+27|0;if(!Jg(b,c)){h=gb-16|0;gb=h;Kf(c);gb=h+16|0}c=w[f+27|0];u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}mf(f+16|0);if(Gb(f+16|0,f+8|0)){continue}break}}gb=f+32|0;return g|0}function vD(a,b,c){var d=0,e=0;d=gb+-64|0;gb=d;Pe(d+40|0,a,c);a=v[d+40>>2];v[22640]=0;c=Rd(d+40|0);e=v[22640];v[22640]=0;a:{b:{c:{if((e|0)==1){break c}c=zb(c);v[22640]=0;Te(d+8|0,3,c,a);a=v[22640];v[22640]=0;if((a|0)==1){break c}v[22640]=0;R(377,d+24|0,d+8|0);a=v[22640];v[22640]=0;if((a|0)==1){break c}v[22640]=0;Q(427,b|0,d+24|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}vb(d+24|0);xc(d+40|0);gb=d- -64|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+24|0)}xc(d+40|0);S(c|0);L()}function u$(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;c=Tb(b,13880);v[22640]=0;U(175,b+16|0,a|0,c|0);a=v[22640];v[22640]=0;a:{b:{c:{if((a|0)!=1){vb(c);if(Cc(b+16|0)){break c}a=0;break a}d=P()|0;O()|0;vb(c);break b}a=0;while(1){d:{c=xd(b+16|0,d);v[22640]=0;c=T(176,c|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break d}a=(c&255)<<24-(d<<3)|a;c=Cc(b+16|0);if(d>>>0>2){break a}d=d+1|0;if(c>>>0>d>>>0){continue}break a}break}d=P()|0;O()|0;jm(b+16|0)}S(d|0);L()}jm(b+16|0);gb=b+32|0;return a|0}function kja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=(e<<1)+j|0;e=u[f>>1];e=e+((B(u[f+2>>1]-e|0,g>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;gb=b+16|0}function k3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;il(a+24|1,7930,1,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;gb=g;i=xe();v[a>>2]=e;v[a+4>>2]=f;e=h>>>9&1;f=Ff(g,e+23|0,i,a+24|0,a)+g|0;h=Pg(g,f,c);e=g-((e<<3)+187&240)|0;gb=e;Ec(a+8|0,c);v[22640]=0;ja(2479,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22640];v[22640]=0;if((f|0)!=1){Vb(a+8|0);b=Tn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Vb(a+8|0);S(b|0);L()}function i3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;il(a+24|1,7930,0,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;gb=g;i=xe();v[a>>2]=e;v[a+4>>2]=f;e=h>>>9&1;f=Ff(g,e+23|0,i,a+24|0,a)+g|0;h=Pg(g,f,c);e=g-((e<<3)+187&240)|0;gb=e;Ec(a+8|0,c);v[22640]=0;ja(2479,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22640];v[22640]=0;if((f|0)!=1){Vb(a+8|0);b=Tn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Vb(a+8|0);S(b|0);L()}function W3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[115121];v[115121]=0;a=rx(a,e+12|0,d,xe());d=jb;g=v[115121];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[115121]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535){break b}}v[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}gb=e+16|0;return a&65535}function m_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-48|0;gb=d;f=-1;c=gb-32|0;gb=c;g=d+8|0;_r(c+24|0,g);h=xb(c+24|0);e=v[c+28>>2];i=v[c+24>>2];v[c+8>>2]=i;v[c+12>>2]=e;v[c>>2]=i;v[c+4>>2]=e;qd(c+16|0,a,c);e=xb(c+16|0);if((e|0)==(h|0)){cd(a,xb(c+24|0))}gb=c+32|0;a=(e|0)==(h|0);if(!a){tw(g)}a:{if(!a){break a}f=0;if(!fF(d+8|0)){break a}if(b){c=v[b>>2];a=d+12|0;if(!v[b+4>>2]&c>>>0<Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))-8>>>0){break a}}f=1}gb=d+48|0;return f|0}function pK(a){var b=0,c=0,d=0,e=0,f=0;if(v[a+16>>2]){while(1){c=Mz(v[a>>2]);d=jb;e=v[a+28>>2];if((d|0)==(e|0)&y[a+24>>2]<=c>>>0|d>>>0>e>>>0){continue}d=b;b=v[a+8>>2];b=(c&v[a+40>>2])+(b>>>0<32?d<<b:0)|0;c=v[a+16>>2];f=f+1|0;if(c>>>0>f>>>0){continue}break}}if(y[a+12>>2]>c>>>0){while(1){d=Mz(v[a>>2]);f=jb;e=v[a+36>>2];if((f|0)==(e|0)&y[a+32>>2]<=d>>>0|f>>>0>e>>>0){continue}e=b;b=v[a+8>>2];b=(d&v[a+48>>2])+(b>>>0<31?e<<b+1:0)|0;c=c+1|0;if(c>>>0<y[a+12>>2]){continue}break}}return b}function zja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;f=u[e+2>>1];v[c>>2]=v[c>>2]+B(u[e>>1],h);v[c+4>>2]=v[c+4>>2]+B(f,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function Aja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){g=g<<8;h=h<<8;while(1){e=(((e&2147483647)<<1|f>>>31)&-2)+i|0;f=t[e+1|0];v[c>>2]=v[c>>2]+B(h,t[e|0]);v[c+4>>2]=v[c+4>>2]+B(f,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function T_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d>>2]=b;v[d+4>>2]=e;v[d+8>>2]=b;v[d+12>>2]=e;f=gb-16|0;gb=f;g=f+8|0;h=gb-16|0;gb=h;e=gb-16|0;gb=e;c=gb-16|0;gb=c;b=e;v[b+4>>2]=1;i=b,j=Mc(24,4),v[i+8>>2]=j;gb=c+16|0;c=v[b+8>>2];v[22640]=0;Q(249,c|0,d|0)|0;c=v[22640];v[22640]=0;a:{if((c|0)!=1){c=g;g=Kp(b);Bw(c,cc(g),g);OF(b);gb=e+16|0;break a}a=P()|0;O()|0;OF(b);S(a|0);L()}gb=h+16|0;bk(a,f+8|0);pe(f+8|0);gb=f+16|0;gb=d+16|0}function KE(a,b){a=a|0;b=b|0;var c=0,d=0;Qb(b,0,44);if(w[a+2|0]|w[a+3|0]<<8?1:w[a|0]|w[a+1|0]<<8){v[b+20>>2]=((w[a|0]|w[a+1|0]<<8)>>>9|0)+80;c=b,d=Lb((w[a|0]|w[a+1|0]<<8)>>>5&15,1,12)-1|0,v[c+16>>2]=d;c=b,d=Lb((w[a|0]|w[a+1|0]<<8)&31,1,31),v[c+12>>2]=d;c=b,d=Lb((w[a+2|0]|w[a+3|0]<<8)>>>11|0,0,23),v[c+8>>2]=d;c=b,d=Lb((w[a+2|0]|w[a+3|0]<<8)>>>5&63,0,59),v[c+4>>2]=d;c=b,d=Lb((w[a+2|0]|w[a+3|0]<<8)<<1&62,0,59),v[c>>2]=d}v[b+44>>2]=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24)}function I2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-32|0;gb=f;d=Ab(a);e=Kc(a);g=fi(b,c);a:{if(!g){break a}if(RC(b,Jb(a),Jb(a)+Ab(a)|0)){b=Bj(f+16|0,b,c);c=Jb(b);d=Ab(b);v[22640]=0;W(2277,a|0,c|0,d|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){vb(b);break a}a=P()|0;O()|0;vb(b);S(a|0);L()}if(e-d>>>0<g>>>0){Em(a,e,(d+g|0)-e|0,d,d,0,0)}e=Jb(a)+d|0;if((b|0)!=(c|0)){while(1){zd(e,b);e=e+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;zd(e,f+15|0);gh(a,d+g|0)}gb=f+32|0}function hQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=zb(w[b|0]);d=zb(w[b+1|0]);g=d>>>24|0;i=f|d<<8;f=zb(w[b+2|0]);d=f>>>16|0;f=i|f<<16;i=d|g;d=zb(w[b+3|0]);g=d>>>8|0;d=d<<24|f;g=zb(w[b+4|0])|(g|i);j=a,k=Ic(d,zb(w[b+5|0])<<8|g|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,48),u[j>>1]=k;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function gQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(h){a=v[a+20>>2];c=h;while(1){f=zb(w[b+7|0]);d=zb(w[b+6|0]);g=d>>>24|0;i=f|d<<8;f=zb(w[b+5|0]);d=f>>>16|0;f=i|f<<16;i=d|g;d=zb(w[b+4|0]);g=d>>>8|0;d=d<<24|f;g=zb(w[b+3|0])|(g|i);j=a,k=Ic(d,zb(w[b+2|0])<<8|g|zb(w[b+1|0])<<16|zb(w[b|0])<<24,48),u[j>>1]=k;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return h<<3}function aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=gb-32|0;gb=f;g=Zf(a,c);se(f+8|0,v[a+28>>2]);d=v[f+20>>2];v[f+24>>2]=v[f+16>>2];v[f+28>>2]=d;a:{b:{if(!g){d=-1;if(!id(a,5)){break b}break a}d=v[g+8>>2]}h=v[a+28>>2];c:{if(!((d|0)!=-1?(d|0)!=4:0)){d=gb-16|0;gb=d;v[d+8>>2]=0;qq(h,d+8|0);z[b>>2]=z[d+8>>2];gb=d+16|0;break c}e=gb-32|0;gb=e;v[e+28>>2]=0;v[e+24>>2]=d;v[e+20>>2]=4;kj(e+8|0,h,e+28|0,v[Fb(e+24|0,e+20|0)>>2]);v[b>>2]=0;gb=e+32|0}}Sf(a,g,c,f+24|0);gb=f+32|0}function O6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;v[e+40>>2]=c;c=v[b+12>>2];v[e+32>>2]=v[b+8>>2];v[e+36>>2]=c;c=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=c;b=v[ni(e+16|0,e+40|0)>>2];c=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=c;v[22640]=0;c=v[e+28>>2];v[e>>2]=v[e+24>>2];v[e+4>>2]=c;ca(1932,a+8|0,e|0,b|0,d|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){QJ(a);b=PJ(a+88|0);v[a>>2]=59472;v[b>>2]=59560;bg(e+40|0);gb=e+48|0;return a|0}a=P()|0;O()|0;bg(e+40|0);S(a|0);L()}function MQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];g=v[Fb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Fb(d+8|0,d+4|0)>>2];c=zb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=zb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=zb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=zb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}gb=d+16|0;return g+h|0}function LQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];h=v[Fb(e+8|0,e+12|0)>>2];v[e+8>>2]=v[a>>2];v[e+4>>2]=v[e+12>>2]-h;i=v[Fb(e+8|0,e+4|0)>>2];c=zb(b);if(h){f=v[a+20>>2];g=h;j=d;while(1){j=zb(w[c|0])+j|0;t[f|0]=j;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}b=zb(b);if(i){c=b+v[a>>2]|0;f=v[a+20>>2]+1|0;g=i;while(1){d=zb(w[c|0])+d|0;t[f|0]=d;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}gb=e+16|0;return h+i|0}function KO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;jb=v[e+4>>2];return v[e>>2]}function nZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=gb-32|0;gb=f;v[f+28>>2]=c;g=Pb(b,c<<1);a:{if(!g){break a}tc(f+28|0,65535);yf(a,x[f+28>>1]);h=f,i=Sb(a),v[h+16>>2]=i;h=f,i=Wb(a),v[h+8>>2]=i;if(!Gb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+24|0;if(!Ep(b,c)){tD(c)}c=w[f+24|0]|w[f+25|0]<<8;u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}mf(f+16|0);if(Gb(f+16|0,f+8|0)){continue}break}}gb=f+32|0;return g|0}function d1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(!(!e|(c|0)==(d|0))){while(1){a:{g=1;f=gb-16|0;gb=f;v[f+12>>2]=v[a+8>>2];h=vi(f+8|0,f+12|0);v[22640]=0;i=sH(c,d-c|0,b);l=v[22640];v[22640]=0;b:{if((l|0)!=1){ff(h);gb=f+16|0;break b}a=P()|0;O()|0;ff(h);S(a|0);L()}c:{switch(i+2|0){default:g=i;break;case 0:case 1:break a;case 2:break c}}j=g+j|0;k=k+1|0;if(k>>>0>=e>>>0){break a}c=c+g|0;if((d|0)!=(c|0)){continue}}break}return j|0}return 0}function wn(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=gb-16|0;gb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>=1){if((vn(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>=1){f=Ge(i,b,f);g=Jb(f);v[22640]=0;g=W(28,a|0,g|0,b|0)|0;h=v[22640];v[22640]=0;if((h|0)==1){break a}vb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>=1){if((vn(a,c,b)|0)!=(b|0)){break b}}DB(e);j=a}gb=i+16|0;return j|0}a=P()|0;O()|0;vb(f);S(a|0);L()}function vma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=gb-32|0;gb=f;WB(b,c,xb(d));e=v[b+16>>2];a:{if(e>>>0<=c>>>0){Uj(a,d,0);break a}v[f+28>>2]=e-c;i=f,j=xb(d),v[i+24>>2]=j;g=v[Fb(f+28|0,f+24|0)>>2];QB(f+16|0,d,0,g);e=v[f+20>>2];v[f+8>>2]=v[f+16>>2];v[f+12>>2]=e;e=gb-32|0;gb=e;b=b+4|0;i=e,j=Sb(b),v[i+24>>2]=j;h=we(e+24|0,c);i=e,j=Sb(b),v[i+8>>2]=j;i=e,j=we(e+8|0,c),v[i+16>>2]=j;b=f+8|0;Ti(h,we(e+16|0,xb(b)),v[b>>2]);gb=e+32|0;QB(a,d,0,g)}gb=f+32|0}function vU(a){var b=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1179472976|w[a+28|0]!=26|w[a+30|0]>2){break a}b=a+40|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+38|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>32){break a}b=a+32|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+34|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+36|0;if(!(w[a|0]|w[a+1|0]<<8)){break a}return(w[a|0]|w[a+1|0]<<8)>>>0<129}return 0}function jt(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==w[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}d:{if(w[a|0]==(b&255)|c>>>0<4){break d}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break d}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==w[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function Efa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-32|0;gb=c;a:{if((b-1&65535)>>>0>3998){break a}f=1;e=(B(b,104)+a|0)+484380|0;if(!Ld(e)){break a}g=a+1298224|0;d=a+1074992|0;while(1){if(v[d+104>>2]==(e|0)){v[d+76>>2]=0;v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0}d=d+872|0;if((g|0)!=(d|0)){continue}break}Ol(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[c+24>>2]=0;v[c+8>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Po(e,0,c)}gb=c+32|0;return f|0}function v3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;il(a+24|1,7930,1,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;gb=g;i=xe();v[a>>2]=e;v[a+4>>2]=f;f=Ff(g,(h>>>9&1)+23|0,i,a+24|0,a)+g|0;h=Pg(g,f,c);e=g-48|0;gb=e;Ec(a+8|0,c);v[22640]=0;ja(2472,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22640];v[22640]=0;if((f|0)!=1){Vb(a+8|0);b=wn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Vb(a+8|0);S(b|0);L()}function ufa(a,b){a=a|0;b=b|0;var c=0;b=38848;a=ad(a);a:{while(1){b:{if(!$c(a)){if(!uj(v[b+8>>2],v[uo(a)>>2])){break b}}v[22640]=0;R(1419,a|0,b+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){break b}break a}b=b+12|0;if((b|0)!=39412){continue}break}b=39424;while(1){c:{if(!$c(a)){if(!uj(v[b+8>>2],v[uo(a)>>2])){break c}}v[22640]=0;R(1419,a|0,b+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){break c}break a}b=b+12|0;if((b|0)!=39472){continue}break}return}b=P()|0;O()|0;Lc(a);S(b|0);L()}function t3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=gb-32|0;gb=a;v[a+24>>2]=37;v[a+28>>2]=0;il(a+24|1,7930,0,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;gb=g;i=xe();v[a>>2]=e;v[a+4>>2]=f;f=Ff(g,(h>>>9&1)+23|0,i,a+24|0,a)+g|0;h=Pg(g,f,c);e=g-48|0;gb=e;Ec(a+8|0,c);v[22640]=0;ja(2472,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[22640];v[22640]=0;if((f|0)!=1){Vb(a+8|0);b=wn(b,e,v[a+20>>2],v[a+16>>2],c,d);gb=a+32|0;return b|0}b=P()|0;O()|0;Vb(a+8|0);S(b|0);L()}function vI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;if((b^-1)+1073741807>>>0>=c>>>0){j=Jb(a);l=a;a:{if(b>>>0<536870887){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=vm(v[Jc(i+12|0,i+8|0)>>2]);break a}c=1073741806}k=c+1|0;c=Li(l,k);if(e){wi(c,j,e)}if(g){wi(c+(e<<2)|0,h,g)}d=d-(e+f|0)|0;if(d){h=e<<2;wi((h+c|0)+(g<<2)|0,(h+j|0)+(f<<2)|0,d)}b=b+1|0;if((b|0)!=2){Wh(a,j,b)}bf(a,c);ng(a,k);b=a;a=d+(e+g|0)|0;ee(b,a);v[i+4>>2]=0;Fe(c+(a<<2)|0,i+4|0);gb=i+16|0;return}_f();L()}function dG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-32|0;gb=d;v[d+16>>2]=c;v[d+24>>2]=b;j=d,k=wd(a),v[j+8>>2]=k;h=Xj(d+24|0,d+8|0);f=h;b=Xj(d+16|0,d+24|0);a:{if(Ab(a)>>>0>=f>>>0){if((b|0)==-1){rE(a,f);break a}e=gb-16|0;gb=e;v[e+12>>2]=b;if(b){c=Ab(a);i=Jb(a);g=c-f|0;v[e+8>>2]=g;b=v[Fb(e+12|0,e+8|0)>>2];v[e+12>>2]=b;g=g-b|0;if(g){f=f+i|0;bm(f,b+f|0,g);b=v[e+12>>2]}f=a;a=c-b|0;gh(f,a);t[e+7|0]=0;zd(a+i|0,e+7|0)}gb=e+16|0;break a}_n();L()}we(d+8|0,h);gb=d+32|0}function Qi(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-48|0;gb=b;if(!$c(a)){wS(b+32|0,Wb(a));wS(b+24|0,Sb(a));c=v[b+36>>2];v[b+16>>2]=v[b+32>>2];v[b+20>>2]=c;c=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=c;c=b+16|0;e=b+8|0;a:{if(!xS(c,e)){break a}while(1){d=gb-16|0;gb=d;v[d+8>>2]=v[c+4>>2];f=pS(d+8|0);gb=d+16|0;if(x[v[f>>2]>>1]!=65535){break a}pS(c+4|0);if(xS(c,e)){continue}break}}d=v[c+4>>2];v[b+40>>2]=v[c>>2];v[b+44>>2]=d;c=eD(Sb(a),v[b+44>>2])}gb=b+48|0;return c&65535}function NQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];g=v[Fb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Fb(d+8|0,d+4|0)>>2];c=zb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=oh(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=zb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=oh(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}gb=d+16|0;return g+h|0}function zaa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[22640]=0;_(1934,a|0);h=v[22640];v[22640]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[22640]=0;b=sa(1951,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,10336,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function waa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[22640]=0;_(1934,a|0);h=v[22640];v[22640]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[22640]=0;b=sa(1954,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,10268,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function IV(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;e=x[c>>1];while(1){a:{e=e<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!kf(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!kf(a,f+14|0)){break a}e=w[f+14|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;e=w[c|0];u[c>>1]=e;if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}gb=f+16|0}function sl(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[22545]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344?b>>>0>=55296:0)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[115121]=25;a=-1}else{a=1}return a|0}t[a|0]=b;return 1}function pf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=mqa(b,c,h,i);i=jb;j=h;h=mqa(d,e,f,g);e=j+h|0;d=jb+i|0;i=e;h=e>>>0<h>>>0?d+1|0:d;j=g;e=0;g=e;k=i;l=c;d=0;i=mqa(j,e,c,d);e=k+i|0;c=jb+h|0;k=e;e=e>>>0<i>>>0?c+1|0:c;h=f;c=0;i=b;f=mqa(h,c,i,0);b=jb;d=mqa(h,c,l,d);b=b+d|0;c=jb;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+k|0;d=c>>>0<h>>>0?e+1|0:e;h=c;c=d;d=mqa(i,m,j,g)+b|0;e=jb;e=b>>>0>d>>>0?e+1|0:e;b=h;h=e;e=b+e|0;v[a+8>>2]=e;v[a+12>>2]=e>>>0<h>>>0?c+1|0:c;v[a>>2]=f;v[a+4>>2]=d}function oH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[115121];v[115121]=0;a=rx(a,e+12|0,d,xe());d=jb;g=v[115121];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[115121]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d){break b}}v[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}gb=e+16|0;return a|0}function Hka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=mh(a);a:{if(b){v[22640]=0;R(915,a|0,b|0);d=v[22640];v[22640]=0;if((d|0)==1){break a}d=gb-16|0;gb=d;c=d;v[c>>2]=a;e=v[a+4>>2];v[c+4>>2]=e;v[c+8>>2]=e+B(b,9);e=c;b=v[c+4>>2];c=v[c+8>>2];if((b|0)!=(c|0)){while(1){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;b=b+9|0;v[e+4>>2]=b;if((b|0)!=(c|0)){continue}break}}$b(e);gb=d+16|0}return a|0}a=P()|0;O()|0;CB(c);S(a|0);L()}function cba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;f=v[c+12>>2];a:{if(!f){break a}g=t[c+16|0];e=Ab(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(w[mc(b,0)|0]==(ag(43)&255)){break b}if(w[mc(b,0)|0]==(ag(45)&255)){break b}}i=d,j=wd(b),v[i+8>>2]=j;i=d,j=we(d+8|0,e-c|0),v[i+16>>2]=j;Fd(d+24|0,d+16|0);uy(b,v[d+24>>2],1,ag(g))}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Dc(a,b);gb=d+32|0}function Jna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;e=-1;a:{if(!_j(a,d+8|0)){break a}b:{c:{c=d+8|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(An(6189)|0)){break c}c=c+4|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0<256){break c}c=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0<260;break b}c=0}e=0;if(!c){break a}c=a;a=d+12|0;e=Ne(c,b,(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<259?80:76,0)}c=e;gb=d+16|0;return c|0}function v9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[22640]=0;_(2007,a|0);f=v[22640];v[22640]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[22640]=0;b=Ta(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,8638,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function UJ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=gb-32|0;gb=e;v[e+24>>2]=b;m=e,n=wd(a),v[m+16>>2]=n;j=Xj(e+24|0,e+16|0);h=j;i=gb-16|0;gb=i;a:{b=a;g=Ab(b);if(g>>>0>=h>>>0){if(c){f=Kc(b);b:{if(f-g>>>0>=c>>>0){f=Jb(b);k=g-h|0;if(!k){break b}l=f+h|0;bm(l+c|0,l,k);break b}Em(b,f,(c+g|0)-f|0,g,h,0,c);f=v[b>>2]}Ir(f+h|0,c,d);d=b;b=c+g|0;gh(d,b);t[i+15|0]=0;zd(b+f|0,i+15|0)}gb=i+16|0;break a}_n();L()}m=e,n=wd(a),v[m+8>>2]=n;we(e+8|0,j);gb=e+32|0}function Raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-32|0;gb=d;f=v[c+12>>2];a:{if(!f){break a}g=t[c+16|0];e=Ab(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(w[Jb(b)|0]==(ag(43)&255)){break b}if(w[Jb(b)|0]==(ag(45)&255)){break b}}i=d,j=wd(b),v[i+8>>2]=j;i=d,j=we(d+8|0,e-c|0),v[i+16>>2]=j;Fd(d+24|0,d+16|0);UJ(b,v[d+24>>2],1,ag(g))}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Dc(a,b);gb=d+32|0}function zna(a,b){a=a|0;b=b|0;var c=0,d=0;c=Ze(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[wb(a)>>2]-v[a+4>>2]|0)/20>>>0){fE(a,c);break c}b=wb(a);b=LX(d+8|0,MX(a,Ze(a)+c|0),Ze(a),b);v[22640]=0;R(704,b|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}v[22640]=0;SC(a,b);a=v[22640];v[22640]=0;if((a|0)==1){break b}tv(b)}gb=d+32|0;break a}a=P()|0;O()|0;tv(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,20)|0;Ze(a);PD(a,b);am(a);Ze(a)}}function kY(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a+1064>>2];if((b|0)>255){break a}while(1){f=(B(b,6)+a|0)+1072|0,g=_k(a,7),t[f|0]=g;d=_k(a,1);e=_k(a,1);c=v[a+1060>>2];if((c|0)>255){break a}b=v[a+1064>>2]+1|0;v[a+1060>>2]=b;v[a+1064>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1068>>1]=b;kY(a);b=v[a+1064>>2];break b}u[(B(c,6)+a|0)+1068>>1]=65535}v[a+1060>>2]=b;if(e){u[(B(c,6)+a|0)+1070>>1]=b;if((b|0)<=255){continue}break a}break}u[(B(c,6)+a|0)+1070>>1]=65535}}function gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Di(a,b,c,d);v[a>>2]=52144;d=nc(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=uf(c);v[a+4260>>2]=0;v[a+4256>>2]=c;v[a+4236>>2]=0;c=a+4228|0;v[c>>2]=1048576e3;v[c+4>>2]=1048576e3;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[22640]=0;W(1536,a+44|0,2,2)|0;c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}v[22640]=0;Vh(b);c=v[22640];v[22640]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(d);hf(b);S(a|0);L()}function y9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22640]=0;_(2007,a|0);e=v[22640];v[22640]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[22640]=0;b=ca(f|0,e|0,b|0,c|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,8783,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function x9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[22640]=0;_(2007,a|0);e=v[22640];v[22640]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[22640]=0;b=ca(f|0,e|0,b|0,c|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,8819,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function cL(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=gb-48|0;gb=b;v[b+40>>2]=e;v[b+44>>2]=f;c=Wd(b+32|0,c,d);d=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=d;a:{a=Vz(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=aa(8)|0;v[22640]=0;b=Q(112,b+16|0,5270)|0;c=v[22640];v[22640]=0;b:{if((c|0)!=1){qc(a,b);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}c=P()|0;O()|0;da(a|0)}S(c|0);L()}gb=b+48|0;return a|0}L()}function oc(a,b){var c=0,d=0,e=0;a:{b:{c=v[a+1396>>2];if((c|0)>=0){c:{if((b|0)>(c|0)){if((b|0)>=25){break b}if(!c){v[a+1392>>2]=0}while(1){c=-1;e=mt(a);d=0;if((e|0)==-1){break c}d=v[a+1396>>2];c=d+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(e<<d);if((b|0)>(c|0)){continue}break}}if((b|0)>(c|0)){break a}d=v[a+1392>>2];v[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}v[a+1396>>2]=c}return d}return oc(a,24)+(oc(a,b-24|0)<<24)|0}ba(7403,10568,1617,3893);L()}function XF(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1129474426|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=1634291279){break a}b=a+8|0;if((w[b|0]|w[b+1|0]<<8)!=14){break a}b=a+12|0;if(!(w[b|0]|w[b+1|0]<<8)){break a}b=a+14|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))<0){break a}a=a+18|0;c=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>23}return c}function t9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[22640]=0;_(2007,a|0);d=v[22640];v[22640]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[22640]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,3723,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function r9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[22640]=0;_(2007,a|0);d=v[22640];v[22640]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[22640]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,3777,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function zP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[a+480180>>2]==4){e=w[b+813|0];if(c){t[b+813|0]=e&240|c&15;break a}c=e&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}ok(a,b,b+700|0,0-(c<<2)|0,0);if(v[b+700>>2]<65536){break b}Db(d+8|0,a+1074312|0,7);if(Cb(d+8|0)|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}gb=d+16|0}function MN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=a;d=b;if((c|0)!=(d|0)){e=gb-16|0;gb=e;g=v[d+4>>2];d=v[d>>2];f=(g-d|0)/6|0;a:{if(f>>>0<=Sj(c)>>>0){if(Eg(c)>>>0<f>>>0){v[e+12>>2]=d;h=Eg(c);v[e+12>>2]=v[e+12>>2]+B(h,6);h=d;d=v[e+12>>2];cz(h,d,v[c>>2]);az(c,d,g,f-Eg(c)|0);break a}FC(c,cz(d,g,v[c>>2]));break a}IN(c);fX(c,qC(c,f));az(c,d,g,f)}gb=e+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];LN(a+24|0,b+24|0);dk(a+36|0,b+36|0)}function M5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;a:{if((c|0)<1){break a}while(1){d=v[a+16>>2];g=v[a+12>>2];b:{if(d>>>0>g>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=d-g;v[e+4>>2]=c-f;d=v[ld(e+12|0,ld(e+8|0,e+4|0))>>2];Ng(b,v[a+12>>2],d);v[a+12>>2]=d+v[a+12>>2];f=d+f|0;b=b+d|0;break b}d=kb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=oh(d),t[h|0]=i;f=f+1|0;b=b+1|0}if((c|0)>(f|0)){continue}break}}gb=e+16|0;return f|0}function zM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Di(a,b,c,d);v[a>>2]=51280;c=nc(a+4260|0);v[a+4232>>2]=1061997773;d=a+4224|0;v[d>>2]=1061158912;v[d+4>>2]=1059082943;d=a+4216|0;v[d>>2]=1038174126;v[d+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1036831949;v[22640]=0;W(1536,a+44|0,2,2)|0;d=v[22640];v[22640]=0;a:{if((d|0)==1){break a}v[22640]=0;Vh(b);d=v[22640];v[22640]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(c);hf(b);S(a|0);L()}function vN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Nb(a);if(c>>>0<=127){e=gb-32|0;gb=e;a:{b:{d=128-c|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){Wy(a,d,b);break c}c=wb(a);c=Pm(e+8|0,_g(a,Nb(a)+d|0),Nb(a),c);v[22640]=0;U(1504,c|0,d|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}v[22640]=0;R(1505,a|0,c|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Zg(c)}gb=e+32|0;break a}a=P()|0;O()|0;Zg(c);S(a|0);L()}return}if((c|0)!=128){dj(a,v[a>>2]+512|0)}}function bB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;h=-1;f=d&2147483647;i=f;g=c;a:{if(!c&(f|0)==2147418112?a|b:(f|0)==2147418112&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;j=f;if((f|0)==2147418112?0:f>>>0>2147418112){break a}if(!(a|g|(i|j|b))){return 0}g=d&e;if((g|0)>0?1:(g|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c)!=0|(d^e|b)!=0}if(!c&(d|0)==(e|0)?a|b:(d|0)>(e|0)?1:(d|0)>=(e|0)?c:0){break a}h=(a|c)!=0|(d^e|b)!=0}return h}function SN(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1163089229){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=-1095062050?(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=-1346458146:0){break a}b=a+16|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+8|0;c=((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+24|0)==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}return c}function GP(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[a+480180>>2]==4){e=w[b+814|0];if(c){t[b+814|0]=e&240|c&15;break a}c=e&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}ok(a,b,b+700|0,0-c|0,0);if(v[b+700>>2]<65536){break b}Db(d+8|0,a+1074312|0,7);if(Cb(d+8|0)|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}gb=d+16|0}function BN(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=v[a+4>>2];v[c+8>>2]=v[b+4>>2];a:{b:{if(!v[Fb(c+12|0,c+8|0)>>2]){break b}while(1){e=tq(t[kc(a,d)|0]);f=tq(t[kc(b,d)|0]);if((e|0)!=(f|0)){d=(e&255)>>>0<(f&255)>>>0?-1:1;break a}if(e){v[c+12>>2]=v[a+4>>2];v[c+8>>2]=v[b+4>>2];d=d+1|0;if(d>>>0>=y[Fb(c+12|0,c+8|0)>>2]){break b}continue}break}d=0;break a}d=0;if(v[a+4>>2]==v[b+4>>2]){break a}d=y[a+4>>2]<y[b+4>>2]?-1:1}gb=c+16|0;return d}function xaa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22640]=0;_(1934,a|0);f=v[22640];v[22640]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22640]=0;b=ga(1953,f|0,b|0,c|0,d|0,e|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,6786,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function voa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=pc(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){Cn(a,d,c);break c}b=wb(a);b=dh(e+8|0,vh(a,pc(a)+d|0),pc(a),b);v[22640]=0;U(657,b|0,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}v[22640]=0;R(328,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}ae(b)}gb=e+32|0;break a}a=P()|0;O()|0;ae(b);S(a|0);L()}return}if(b>>>0<d>>>0){jn(a,v[a>>2]+b|0)}}function Goa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-32|0;gb=d;v[d+28>>2]=c;c=Pb(b,c<<2);a:{if(!c){break a}tc(d+28|0,65535);yf(a,x[d+28>>1]);g=d,h=Sb(a),v[g+16>>2]=h;g=d,h=Wb(a),v[g+8>>2]=h;if(!Gb(d+16|0,d+8|0)){break a}while(1){a=v[d+16>>2];e=d+24|0;if(!ds(b,e)){f=gb-16|0;gb=f;Ik(e);gb=f+16|0}e=w[d+24|0]|w[d+25|0]<<8;u[a>>1]=e;if((e|0)==65535){u[a>>1]=65535}mf(d+16|0);if(Gb(d+16|0,d+8|0)){continue}break}}gb=d+32|0;return c|0}function Aaa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22640]=0;_(1934,a|0);f=v[22640];v[22640]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22640]=0;b=ga(1950,f|0,b|0,c|0,d|0,e|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,6858,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function p9(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[22640]=0;_(2007,a|0);d=v[22640];v[22640]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[22640]=0;Va(f|0,d|0,b|0,+c);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,8982,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function I5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{if((c|0)<1){break a}while(1){d=v[a+16>>2];g=v[a+12>>2];b:{if(d>>>0>g>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=d-g>>2;v[e+4>>2]=c-f;d=v[ld(e+12|0,ld(e+8|0,e+4|0))>>2];wi(b,v[a+12>>2],d);v[a+12>>2]=v[a+12>>2]+(d<<2);f=d+f|0;b=(d<<2)+b|0;break b}d=kb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;f=f+1|0;b=b+4|0}if((c|0)>(f|0)){continue}break}}gb=e+16|0;return f|0}function vu(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[b+40>>2]=0;v[b+44>>2]=0;e=b- -64|0;v[e>>2]=0;v[e+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;e=1;a:{while(1){b:{NR(b,A[ze(c,0)>>3]);if((e|0)==1e4){f=d,g=Sb(c),v[f+8>>2]=g;f=d,g=Wb(c),v[f>>2]=g;if(Gb(d+8|0,d)){break b}break a}else{e=e+1|0;continue}}break}while(1){e=v[d+8>>2];f=e,h=NR(b,A[e>>3]),A[f>>3]=h;uu(d+8|0);if(Gb(d+8|0,d)){continue}break}}AB(a,c);gb=d+16|0}function Ne(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;g=wo(a);f=e;i=e;a:{if(b){j=v[b+4>>2];h=v[b>>2];break a}h=wo(a)}v[i+8>>2]=h;v[f+12>>2]=j;f=v[a+12>>2];a=1;b:{if(!b){break b}a=c+f|0;d=c>>>0>a>>>0?d+1|0:d;b=a;v[e>>2]=2048;v[e+4>>2]=0;a=Qk(e+8|0,e);c=v[a>>2];a=v[a+4>>2];c:{if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break c}break b}a=0;c=v[e+12>>2];if((c|0)==(d|0)&b>>>0>y[e+8>>2]|c>>>0<d>>>0){break b}}a=1}gb=e+16|0;return a}function i7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;c=Xh(C(z[a+24>>2]*C(65536)));if(!((c|0)==65536|!v[b+8>>2])){g=c;h=c>>31;while(1){e=0;if(v[b+4>>2]){while(1){c=v[Ug(b,e,f)>>2];c=zc(nqa(mqa(c,c>>31,g,h),jb,65536,0),jb);i=Ug(b,e,f),j=c,v[i>>2]=j;e=e+1|0;if(e>>>0<y[b+4>>2]){continue}break}}f=f+1|0;if(f>>>0<y[b+8>>2]){continue}break}}v[d+8>>2]=v[b+8>>2];g=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=g;dK(a,d);gb=d+16|0}function _6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;c=Xh(C(z[a+24>>2]*C(65536)));if(!((c|0)==65536|!v[b+8>>2])){g=c;h=c>>31;while(1){e=0;if(v[b+4>>2]){while(1){c=v[Ug(b,e,f)>>2];c=zc(nqa(mqa(c,c>>31,g,h),jb,65536,0),jb);i=Ug(b,e,f),j=c,v[i>>2]=j;e=e+1|0;if(e>>>0<y[b+4>>2]){continue}break}}f=f+1|0;if(f>>>0<y[b+8>>2]){continue}break}}v[d+8>>2]=v[b+8>>2];g=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=g;XJ(a,d);gb=d+16|0}function Uea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;a=eh(a);a:{b:{c:{d:{while(1){v[22640]=0;e=Q(228,b|0,8)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}if(!e){break c}v[22640]=0;U(1472,d|0,b|0,c|0);e=v[22640];v[22640]=0;if((e|0)!=1){v[22640]=0;R(1473,a|0,d|0);e=v[22640];v[22640]=0;if((e|0)==1){break d}Xd(d);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Xd(d);break a}gb=d+32|0;return}b=P()|0;O()|0}Cd(a);S(b|0);L()}
function Jda(a,b){a=a|0;b=b|0;var c=0,d=0;c=Nb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){mN(a,c);break c}b=wb(a);b=Pm(d+8|0,_g(a,Nb(a)+c|0),Nb(a),b);v[22640]=0;R(1546,b|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}v[22640]=0;R(1543,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Zg(b)}gb=d+32|0;break a}a=P()|0;O()|0;Zg(b);S(a|0);L()}return}if(b>>>0<c>>>0){dj(a,v[a>>2]+(b<<2)|0)}}function yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;a=Ho(a);a:{b:{c:{d:{while(1){v[22640]=0;e=Q(228,b|0,8)|0;f=v[22640];v[22640]=0;if((f|0)==1){break b}if(!e){break c}v[22640]=0;U(1176,d|0,b|0,c|0);e=v[22640];v[22640]=0;if((e|0)!=1){v[22640]=0;R(1177,a|0,d|0);e=v[22640];v[22640]=0;if((e|0)==1){break d}Xd(d);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Xd(d);break a}gb=d+32|0;return}b=P()|0;O()|0}an(a);S(b|0);L()}function ie(a){var b=0,c=0,d=0;d=Xp(Lf(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}b=w[a|0];t[c|0]=b;if(!b){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function P5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[d+16>>2]=b;e=v[a+48>>2];v[d+20>>2]=c-((e|0)!=0);f=v[a+44>>2];v[d+28>>2]=e;v[d+24>>2]=f;e=-1;a:{b:{if(!ct(eb(v[a+60>>2],d+16|0,2,d+12|0)|0)){e=v[d+12>>2];if((e|0)>0){break b}}v[a>>2]=v[a>>2]|e&48^16;break a}g=v[d+20>>2];if(g>>>0>=e>>>0){break a}f=v[a+44>>2];v[a+4>>2]=f;v[a+8>>2]=f+(e-g|0);if(v[a+48>>2]){v[a+4>>2]=f+1;t[(b+c|0)-1|0]=w[f|0]}e=c}gb=d+32|0;return e|0}function nE(a,b){a=a|0;b=b|0;var c=0,d=0;c=sc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>1>>>0){XD(a,c);break c}b=wb(a);b=En(d+8|0,Rk(a,sc(a)+c|0),sc(a),b);v[22640]=0;R(373,b|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}v[22640]=0;R(345,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Gh(b)}gb=d+32|0;break a}a=P()|0;O()|0;Gh(b);S(a|0);L()}return}if(b>>>0<c>>>0){zn(a,v[a>>2]+(b<<1)|0)}}function n8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-16|0;gb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=aa(8)|0;v[22640]=0;c=Q(112,h|0,5413)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}zj(a,b,4);c=By(a,c,d,e,f,g);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=h+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function k8(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-16|0;gb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=aa(8)|0;v[22640]=0;c=Q(112,h|0,5413)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}zj(a,b,4);c=Ay(a,c,d,e,f,g);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=h+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function cpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,15);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0}}function Bna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,14);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0}}function xZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;d=-1;a:{if(!Rf(a,7)){break a}d=0;if(!ND(a,9078)){break a}c=gb-32|0;gb=c;d=f;CD(c+24|0,f);h=xb(c+24|0);e=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=e;v[c>>2]=g;v[c+4>>2]=e;e=a;qd(c+16|0,e,c);g=xb(c+16|0);if((g|0)==(h|0)){cd(e,xb(c+24|0))}gb=c+32|0;e=(g|0)==(h|0);if(!e){BD(d)}d=-1;if(!e){break a}d=0;if(!MD(f)){break a}d=Ne(a,b,LD(f),jb)}gb=f+16|0;return d|0}function US(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;a=Kb(a);d=Ab(b);v[22640]=0;R(102,a|0,d|0);d=v[22640];v[22640]=0;if((d|0)!=1){a:{e=c,f=wd(b),v[e+8>>2]=f;e=c,f=df(b),v[e>>2]=f;if(Gb(c+8|0,c)){while(1){b=w[v[c+8>>2]];b:{if((b|0)==13){v[22640]=0;R(103,a|0,10);break b}v[22640]=0;R(103,a|0,b<<24>>24)}b=v[22640];v[22640]=0;if((b|0)==1){break a}Me(c+8|0);if(Gb(c+8|0,c)){continue}break}}gb=c+16|0;return}}b=P()|0;O()|0;vb(a);S(b|0);L()}function LT(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;g=v[c>>2];v[d+8>>2]=6553600;e=b+4|0;h=d,i=Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24)),v[h+4>>2]=i;f=+(g>>>0)*1.52587890625e-7;e=hr(f*+y[Fb(d+8|0,d+4|0)>>2]);v[d+12>>2]=e;v[d+4>>2]=6553600;b=b+8|0;h=d,i=Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),v[h>>2]=i;h=d,i=hr(f*+y[Fb(d+4|0,d)>>2]),v[h+8>>2]=i;v[d+4>>2]=v[c>>2]-e;Fu(a,d+12|0,Fb(d+4|0,d+8|0));gb=d+16|0}function uaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22640]=0;_(1934,a|0);e=v[22640];v[22640]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22640]=0;b=ca(1956,e|0,b|0,c|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,10299,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function saa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22640]=0;_(1934,a|0);e=v[22640];v[22640]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22640]=0;b=ca(1958,e|0,b|0,c|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,10225,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function h9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22640]=0;_(2007,a|0);c=v[22640];v[22640]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[22640]=0;R(e|0,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,10138,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function dN(a){var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a:{b:{if(Cl(a)>>>0<=Qf(a)>>>0){break b}b=wb(a);d=Qf(a);e=Qf(a);v[22640]=0;b=ca(1540,c+8|0,d|0,e|0,b|0)|0;d=v[22640];v[22640]=0;c:{d:{if((d|0)!=1){v[22640]=0;R(1541,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break d}Pt(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Pt(b)}Z(a|0)|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)==1){break a}}gb=c+32|0;return}V(0)|0;O()|0;Bb();L()}function cN(a){var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a:{b:{if(ye(a)>>>0<=Nb(a)>>>0){break b}b=wb(a);d=Nb(a);e=Nb(a);v[22640]=0;b=ca(1542,c+8|0,d|0,e|0,b|0)|0;d=v[22640];v[22640]=0;c:{d:{if((d|0)!=1){v[22640]=0;R(1543,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break d}Zg(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Zg(b)}Z(a|0)|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)==1){break a}}gb=c+32|0;return}V(0)|0;O()|0;Bb();L()}function yaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22640]=0;_(1934,a|0);e=v[22640];v[22640]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22640]=0;b=ca(1952,e|0,b|0,c|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,6595,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function w9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22640]=0;_(2007,a|0);c=v[22640];v[22640]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[22640]=0;R(e|0,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,8648,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function vaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22640]=0;_(1934,a|0);e=v[22640];v[22640]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22640]=0;b=ca(1955,e|0,b|0,c|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,6819,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function taa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22640]=0;_(1934,a|0);e=v[22640];v[22640]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22640]=0;b=ca(1957,e|0,b|0,c|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,6741,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function i9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22640]=0;_(2007,a|0);c=v[22640];v[22640]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[22640]=0;R(e|0,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,6487,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Baa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[22640]=0;_(1934,a|0);e=v[22640];v[22640]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[22640]=0;b=ca(1949,e|0,b|0,c|0,d|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,6626,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function sla(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;t[b+15|0]=128;d=Dv(a,127,b+15|0);v[22640]=0;t[b+14|0]=64;e=W(796,a+12|0,127,b+14|0)|0;c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){v[22640]=0;t[b+13|0]=0;W(883,a+24|0,127,b+13|0)|0;c=v[22640];v[22640]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;v[a+44>>2]=0;v[a+48>>2]=0;u[a+52>>1]=0;gb=b+16|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;gc(e)}gc(d);S(a|0);L()}function pba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;t[a+4202|0]=1;b=Gj(C(C(uf(v[a+16>>2])>>>0)*C(.04500000178813934)));c=Gj(C(C(b>>>0)*C(1.1892070770263672)));d=Gj(C(C(c>>>0)*C(1.1892070770263672)));g=Gj(C(C(d>>>0)*C(1.1892070770263672)));e=Gj(C(C(b+d>>>0)*C(.11546666920185089)));f=Gj(C(C(c+g>>>0)*C(.11546666920185089)));v[a+4292>>2]=f;v[a+4288>>2]=e;v[a+4276>>2]=d-e;v[a+4272>>2]=b-e;v[a+4284>>2]=g-f;v[a+4280>>2]=c-f;VL(a);TL(a)}function n9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22640]=0;_(2007,a|0);c=v[22640];v[22640]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[22640]=0;ta(e|0,c|0,+b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[22640]=0;Y(1911,9020,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22640]=0;X(20);d=v[22640];v[22640]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function l9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22640]=0;_(2007,a|0);c=v[22640];v[22640]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[22640]=0;ta(e|0,c|0,+b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[22640]=0;Y(1911,4921,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22640]=0;X(20);d=v[22640];v[22640]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function j9(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[22640]=0;_(2007,a|0);c=v[22640];v[22640]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[22640]=0;ta(e|0,c|0,+b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;Z(d|0)|0;v[22640]=0;Y(1911,4869,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22640]=0;X(20);d=v[22640];v[22640]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function H8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;Ec(a,b);v[22640]=0;U(139,d+8|0,b|0,c|0);e=v[22640];v[22640]=0;a:{if((e|0)==1){break a}Vb(d+8|0);v[22640]=0;e=v[b+24>>2];f=v[22640];v[22640]=0;if((f|0)==1){break a}if(e){v[22640]=0;b=v[b+24>>2];e=v[22640];v[22640]=0;if((e|0)==1){break a}v[22640]=0;U(140,d|0,b|0,c|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}Vb(d)}gb=d+16|0;return}b=P()|0;O()|0;Vb(a);S(b|0);L()}function q9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[22640]=0;_(2007,a|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[22640]=0;d=+Ua(e|0,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,9001,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function mx(a,b){a=a|0;b=b|0;var c=0,d=0;c=pc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){yr(a,c);break c}b=wb(a);b=dh(d+8|0,vh(a,pc(a)+c|0),pc(a),b);v[22640]=0;R(165,b|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}v[22640]=0;R(162,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}ae(b)}gb=d+32|0;break a}a=P()|0;O()|0;ae(b);S(a|0);L()}return}if(b>>>0<c>>>0){jn(a,v[a>>2]+b|0)}}
function l$(a,b){a=a|0;b=b|0;var c=0;a=Kb(a);a:{if(w[b+16|0]){v[22640]=0;Q(191,a|0,2041)|0;c=v[22640];v[22640]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[22640]=0;Q(191,a|0,9828)|0;c=v[22640];v[22640]=0;if((c|0)==1){break a}}if(dd(a)){v[22640]=0;Q(191,a|0,7393)|0;c=v[22640];v[22640]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[22640]=0;Q(191,a|0,8388)|0;b=v[22640];v[22640]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;vb(a);S(b|0);L()}function gr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=(w[lc(a,0)|0]&15)<<8|w[lc(a,1)|0];a:{if((d|0)==4095|!d){break a}e=108;while(1){f=x[(c<<1)+39488>>1];if(f>>>0<=d>>>0){if(!(!c|(d|0)==(f|0)|(x[(c<<1)+39486>>1]-d|0)>=(d-f|0))){e=c+24|0;break a}e=c+25|0;break a}c=c+1|0;if(c>>>0<84){continue}break}}t[b|0]=e;c=w[lc(a,2)|0];g=b,h=w[lc(a,0)|0]&16|c>>>4,t[g+1|0]=h;g=b,h=w[lc(a,2)|0]&15,t[g+3|0]=h;g=b,h=w[lc(a,3)|0],t[g+5|0]=h}function yoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;Nn(e+24|0,c);v[22640]=0;R(181,e+36|0,d|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){v[22640]=0;oi(e+16|0,e+24|0);c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(183,a|0,b|0,e+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function woa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;QC(e+24|0,c);v[22640]=0;R(656,e+36|0,d|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){v[22640]=0;oi(e+16|0,e+24|0);c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(183,a|0,b|0,e+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function u9(a,b){a=a|0;b=b|0;var c=0,d=0;v[22640]=0;_(2007,a|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[22640]=0;b=Q(d|0,c|0,b|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,3750,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function s9(a,b){a=a|0;b=b|0;var c=0,d=0;v[22640]=0;_(2007,a|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[22640]=0;b=Q(d|0,c|0,b|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,3801,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function nX(a){var b=0,c=0,d=0,e=0;c=gb-32|0;gb=c;a:{b:{if(hg(a)>>>0<=pc(a)>>>0){break b}b=wb(a);d=pc(a);e=pc(a);v[22640]=0;b=ca(42,c+8|0,d|0,e|0,b|0)|0;d=v[22640];v[22640]=0;c:{d:{if((d|0)!=1){v[22640]=0;R(43,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break d}ae(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;ae(b)}Z(a|0)|0;v[22640]=0;X(20);a=v[22640];v[22640]=0;if((a|0)==1){break a}}gb=c+32|0;return}V(0)|0;O()|0;Bb();L()}function iP(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){a=gb-16|0;gb=a;f=a,g=Sb(c),v[f+8>>2]=g;f=a,g=Wb(c),v[f>>2]=g;if(Gb(a+8|0,a)){while(1){e=v[a+8>>2];a:{while(1){b=v[e>>2];d=v[b>>2];if(!d){break a}b=v[v[d>>2]+8>>2];v[22640]=0;_(b|0,d|0);b=v[22640];v[22640]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Gl(c);Bb();L()}Hb(b+20|0);Hb(b+8|0);Zb(b);Fg(a+8|0);if(Gb(a+8|0,a)){continue}break}}Gl(c);gb=a+16|0;Zb(c)}}}function Zoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;QC(e+24|0,c);v[22640]=0;R(560,e+36|0,d|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){v[22640]=0;oi(e+16|0,e+24|0);c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(183,a|0,b|0,e+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function Uma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;Jh(e+24|0,c);v[22640]=0;R(793,e+36|0,d|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){v[22640]=0;oi(e+16|0,e+24|0);c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(480,a|0,b|0,e+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function Qpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;Nn(e+24|0,c);v[22640]=0;R(197,e+36|0,d|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){v[22640]=0;oi(e+16|0,e+24|0);c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(183,a|0,b|0,e+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function K$(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;v[22640]=0;a=pG(1925,a,b,c,d,e,f);b=v[22640];v[22640]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22640]=0;ja(1922,6054,g|0,h|0,i|0,j|0,k|0,l|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function Ap(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=gb-16|0;gb=i;if((b^-1)-17>>>0>=c>>>0){j=Jb(a);l=a;a:{if(b>>>0<2147483623){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=Xk(v[Jc(i+12|0,i+8|0)>>2]);break a}c=-18}k=c+1|0;c=mi(l,k);if(e){Ng(c,j,e)}if(g){Ng(c+e|0,h,g)}d=d-(e+f|0)|0;if(d){Ng((c+e|0)+g|0,(e+j|0)+f|0,d)}b=b+1|0;if((b|0)!=11){al(a,j,b)}bf(a,c);ng(a,k);b=a;a=d+(e+g|0)|0;ee(b,a);t[i+7|0]=0;zd(a+c|0,i+7|0);gb=i+16|0;return}_f();L()}function vZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;_v(e+24|0,c);v[22640]=0;R(405,e+36|0,d|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){v[22640]=0;oi(e+16|0,e+24|0);c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(183,a|0,b|0,e+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function Uv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;sD(e+24|0,c);v[22640]=0;R(181,e+36|0,d|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){v[22640]=0;oi(e+16|0,e+24|0);c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(183,a|0,b|0,e+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function L$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-48|0;gb=e;Jh(e+24|0,c);v[22640]=0;R(181,e+36|0,d|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){v[22640]=0;oi(e+16|0,e+24|0);c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;c=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=c;U(183,a|0,b|0,e+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(e+24|0);break b}a=P()|0;O()|0;vb(e+24|0)}S(a|0);L()}Cf(e+24|0);gb=e+48|0}function Kga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=eh(a);a:{b:{c:{d:{while(1){v[22640]=0;d=Q(228,b|0,8)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}if(!d){break c}v[22640]=0;R(1167,c|0,b|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;R(1168,a|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break d}Xd(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Xd(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Cd(a);S(b|0);L()}function K5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=gb-16|0;gb=e;a:{if((c|0)<1){break a}while(1){d=v[a+28>>2];g=v[a+24>>2];b:{if(d>>>0<=g>>>0){if(((i=a,j=Ig(t[b|0]),h=v[v[a>>2]+52>>2],kb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0;break b}v[e+12>>2]=d-g;v[e+8>>2]=c-f;d=v[ld(e+12|0,e+8|0)>>2];Ng(v[a+24>>2],b,d);v[a+24>>2]=d+v[a+24>>2];f=d+f|0;b=b+d|0}if((c|0)>(f|0)){continue}break}}gb=e+16|0;return f|0}function Fk(a,b){a=a|0;b=b|0;var c=0,d=0;c=pc(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>>0){yr(a,c);break c}b=wb(a);b=dh(d+8|0,vh(a,pc(a)+c|0),pc(a),b);v[22640]=0;R(44,b|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}v[22640]=0;R(43,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}ae(b)}gb=d+32|0;break a}a=P()|0;O()|0;ae(b);S(a|0);L()}return}if(b>>>0<c>>>0){jn(a,v[a>>2]+b|0)}}function El(a,b){var c=0,d=0;c=Nb(a);if(c>>>0<b>>>0){d=gb-32|0;gb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[wb(a)>>2]-v[a+4>>2]>>2>>>0){mN(a,c);break c}b=wb(a);b=Pm(d+8|0,_g(a,Nb(a)+c|0),Nb(a),b);v[22640]=0;R(1506,b|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}v[22640]=0;R(1505,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Zg(b)}gb=d+32|0;break a}a=P()|0;O()|0;Zg(b);S(a|0);L()}return}if(b>>>0<c>>>0){dj(a,v[a>>2]+(b<<2)|0)}}function Dga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=eh(a);a:{b:{c:{d:{while(1){v[22640]=0;d=Q(228,b|0,8)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}if(!d){break c}v[22640]=0;R(1174,c|0,b|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;R(1175,a|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break d}Xd(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Xd(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Cd(a);S(b|0);L()}function gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;NW(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;gb=c+16|0}return a|0}function R9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[22640]=0;_(1934,a|0);f=v[22640];v[22640]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[22640]=0;b=zt(f,b,c,d,e);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,9706,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Di(a,b,c,d);v[a>>2]=51540;c=nc(a+4256|0);d=a+4224|0;v[d>>2]=1017370378;v[d+4>>2]=1065353216;d=a+4216|0;v[d>>2]=1028670828;v[d+4>>2]=1059760811;v[a+4208>>2]=1056964608;v[a+4212>>2]=1017370378;v[22640]=0;W(1536,a+44|0,2,2)|0;d=v[22640];v[22640]=0;a:{if((d|0)==1){break a}v[22640]=0;Vh(b);d=v[22640];v[22640]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(c);hf(b);S(a|0);L()}function tla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=eh(a);a:{b:{c:{d:{while(1){v[22640]=0;d=Q(228,b|0,8)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}if(!d){break c}v[22640]=0;R(881,c|0,b|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;R(882,a|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break d}Xd(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Xd(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Cd(a);S(b|0);L()}function gqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=eh(a);a:{b:{c:{d:{while(1){v[22640]=0;d=Q(228,b|0,8)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}if(!d){break c}v[22640]=0;R(472,c|0,b|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;R(473,a|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break d}Xd(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Xd(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Cd(a);S(b|0);L()}function gpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=eh(a);a:{b:{c:{d:{while(1){v[22640]=0;d=Q(228,b|0,8)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}if(!d){break c}v[22640]=0;R(554,c|0,b|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;R(555,a|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break d}Xd(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Xd(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Cd(a);S(b|0);L()}function Rla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=eh(a);a:{b:{c:{d:{while(1){v[22640]=0;d=Q(228,b|0,8)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}if(!d){break c}v[22640]=0;R(841,c|0,b|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;R(842,a|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break d}Xd(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Xd(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Cd(a);S(b|0);L()}function Gna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;a=eh(a);a:{b:{c:{d:{while(1){v[22640]=0;d=Q(228,b|0,6)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}if(!d){break c}v[22640]=0;R(700,c|0,b|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;R(701,a|0,c|0);d=v[22640];v[22640]=0;if((d|0)==1){break d}Xd(c);continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;Xd(c);break a}gb=c+32|0;return}b=P()|0;O()|0}Cd(a);S(b|0);L()}function rz(a,b,c,d){var e=0,f=0,g=0;f=gb-48|0;gb=f;a:{if(!c){c=Qc(a,b);a=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=a;a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;break a}e=v[d+12>>2];v[f+24>>2]=v[d+8>>2];v[f+28>>2]=e;g=v[d+4>>2];e=f;v[e+16>>2]=v[d>>2];v[e+20>>2]=g;g=c>>>1|0;rz(a,b,g,e+16|0);Ji(e+32|0,d,Qc(a,c));d=v[e+44>>2];v[e+8>>2]=v[e+40>>2];v[e+12>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;rz(a,b|c,g,e)}gb=f+48|0}function k5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;dk(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){d=a,e=Jb(c)+Ab(c)|0,v[d+44>>2]=e;Zn(a,Jb(c),Jb(c),v[a+44>>2]);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=Ab(c);d=a,e=b+Jb(c)|0,v[d+44>>2]=e;jq(c,Kc(c));Fx(a,Jb(c),Jb(c)+Ab(c)|0);if(!(w[a+48|0]&3)){break a}b:{if((b|0)<=-1){c=b-2147483647|0;while(1){b=c;Us(a,2147483647);c=1;if((b|0)<0){continue}break}break b}if(!b){break a}}Us(a,b)}}function jQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=ed(f|zb(w[b+1|0])<<8|zb(w[b+2|0])<<16|zb(w[b+3|0])<<24,16),u[g>>1]=h;f=zb(w[b+4|0]);g=a,h=ed(f|zb(w[b+5|0])<<8|zb(w[b+6|0])<<16|zb(w[b+7|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<3}function iQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+3|0]);g=a,h=ed(f|zb(w[b+2|0])<<8|zb(w[b+1|0])<<16|zb(w[b|0])<<24,16),u[g>>1]=h;f=zb(w[b+7|0]);g=a,h=ed(f|zb(w[b+6|0])<<8|zb(w[b+5|0])<<16|zb(w[b+4|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<3}function rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-48|0;gb=d;tC(d+24|0,c);v[22640]=0;R(656,d+36|0,49420);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){v[22640]=0;oi(d+16|0,d+24|0);c=v[22640];v[22640]=0;if((c|0)!=1){v[22640]=0;c=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=c;U(183,a|0,b|0,d+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Cf(d+24|0);break b}a=P()|0;O()|0;vb(d+24|0)}S(a|0);L()}Cf(d+24|0);gb=d+48|0}function Caa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[22640]=0;_(1934,a|0);d=v[22640];v[22640]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[22640]=0;U(1948,d|0,b|0,c|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,7647,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function bJ(a){var b=C(0),c=0,d=C(0),e=C(0),f=C(0),g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;j=a-24|0;b=z[j>>2];c=a-8|0;d=z[c>>2];e=C(b+d);k=a-16|0;f=z[k>>2];l=z[a>>2];g=C(f+l);z[a>>2]=e+g;z[c>>2]=g-e;c=a-28|0;g=z[c>>2];h=a-12|0;m=z[h>>2];e=C(g+m);p=h;h=a-20|0;i=z[h>>2];a=a-4|0;n=z[a>>2];o=C(i+n);z[p>>2]=o-e;i=C(n-i);b=C(d-b);z[c>>2]=i+b;d=C(m-g);f=C(l-f);z[k>>2]=d+f;z[j>>2]=f-d;z[a>>2]=o+e;z[h>>2]=i-b}function Faa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[22640]=0;_(1934,a|0);d=v[22640];v[22640]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[22640]=0;e=+oa(1944,d|0,b|0,c|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,2442,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Aha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;u[e+12>>1]=c;u[e+14>>1]=b;sg(e+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);c=e+12|0;b=gb-16|0;gb=b;d=x[e+14>>1];v[b+12>>2]=d;a:{if(Lg(a)>>>0>=d>>>0){g=b,h=sc(a),v[g+8>>2]=h;fv(v[a>>2],v[Fb(b+12|0,b+8|0)>>2],c);f=v[b+8>>2];d=v[b+12>>2];if(f>>>0<d>>>0){up(a,d-f|0,c);break a}zn(a,v[a>>2]+(d<<1)|0);break a}yS(a);JB(a,Rk(a,d));up(a,d,c)}gb=b+16|0;gb=e+16|0}function td(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;Ol(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;c=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?c|32:c;b=Tb(d,18693);v[22640]=0;Q(335,a+43|0,b|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){vb(b);GS(a);gb=d+16|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function Fha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=b;d=gb-16|0;gb=d;v[d>>2]=c;v[d+8>>2]=b;b=gv(d,d+8|0);gb=d+16|0;a:{b=Pk(e+8|0,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];d=v[b>>2];f=v[e+24>>2];v[22640]=0;gn(c,d,f);c=v[22640];v[22640]=0;if((c|0)==1){break a}v[b>>2]=v[b>>2]+4;Fg(e+24|0);if(v[b>>2]!=v[b+4>>2]){continue}break}}Yc(b);gb=e+32|0;return}a=P()|0;O()|0;Yc(b);S(a|0);L()}function JC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Pb(a,b)){break a}if(b>>>0<=3){c=gb-16|0;gb=c;if(Pb(a,b)){while(1){t[c+11|0]=0;b:{if(b>>>0>d>>>0){Jg(a,c+11|0);e=t[c+11|0];g=e>>>31|0;break b}e=0-g|0}t[(c+12|0)+d|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=c+16|0;c=d;break a}c=og(a);Yb(a,b-4|0)}t[f|0]=c}function J$(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[22640]=0;a=Ka(1926,a|0,b|0,c|0,d|0)|0;b=v[22640];v[22640]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22640]=0;ja(1922,8423,e|0,f|0,g|0,h|0,i|0,j|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}return a|0}function Bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=u[(e<<1)+i>>1];v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function o9(a){a=a|0;var b=0,c=0,d=0;v[22640]=0;_(2007,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[22640]=0;c=+pa(d|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,9038,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function m9(a){a=a|0;var b=0,c=0,d=0;v[22640]=0;_(2007,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[22640]=0;c=+pa(d|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,4938,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function k9(a){a=a|0;var b=0,c=0,d=0;v[22640]=0;_(2007,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[22640]=0;c=+pa(d|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,4886,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function bfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=gb+-64|0;gb=d;Ye(b);Pe(d+40|0,a,c);a=v[d+40>>2];v[22640]=0;c=Rd(d+40|0);e=v[22640];v[22640]=0;b:{if((e|0)==1){break b}c=zb(c);v[22640]=0;Te(d+8|0,1,c,a);a=v[22640];v[22640]=0;if((a|0)==1){break b}v[22640]=0;R(377,d+24|0,d+8|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Eb(b,d+24|0);vb(d+24|0);xc(d+40|0);gb=d- -64|0;break a}a=P()|0;O()|0;xc(d+40|0);S(a|0);L()}}function Mka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=gb-32|0;gb=d;e=gb-16|0;gb=e;f=e,g=Ib(w[c|0]|w[c+1|0]<<8),u[f+14>>1]=g;WL(d+16|0,e+14|0);gb=e+16|0;v[22640]=0;ij(d+8|0,d+16|0);c=v[22640];v[22640]=0;b:{if((c|0)==1){break b}v[22640]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(183,a|0,b|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function Fna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;e=Sb(b);f=Wb(b);c=gb-32|0;gb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;if(Gb(c+24|0,c+16|0)){while(1){e=v[c+24>>2];if(v[v[c+8>>2]>>2]!=(w[e|0]|w[e+1|0]<<8)){pp(c+24|0);if(Gb(c+24|0,c+16|0)){continue}}break}e=v[c+24>>2]}gb=c+32|0;v[d+8>>2]=e;g=d,h=Wb(b),v[g>>2]=h;a:{if(Gb(d+8|0,d)){Je(a,wb(v[d+8>>2]));break a}Ih(a)}gb=d+16|0}function Ez(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;t[e+15|0]=(d?y[c+20>>2]>=2:0)?v[b+480180>>2]==1:0;d=!v[c+52>>2]|d;t[e+14|0]=d;if(!(!x[b+480188>>1]|((d|0)!=1|v[b+480180>>2]!=2))){d=0;while(1){v[(B(d,872)+c|0)+1380>>2]=0;d=d+1|0;if(d>>>0<x[b+480188>>1]){continue}break}}v[c+24>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+48>>2]=v[c+52>>2];u[c+72>>1]=x[c+74>>1];t[a|0]=w[e+15|0];t[a+1|0]=w[e+14|0];gb=e+16|0}function kna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=v[b>>2];f=UC(b);d=gb-16|0;gb=d;e=jr(c,f);a:{if(e>>>0<=ye(a)>>>0){if(Nb(a)>>>0<e>>>0){v[d+12>>2]=c;ZV(d+12|0,Nb(a));b=v[d+12>>2];Bg(c,b,v[a>>2]);YV(a,b,f,e-Nb(a)|0);break a}dj(a,Bg(c,f,v[a>>2]));break a}XV(a);b=a;g=_g(a,e);if(g>>>0>lA(a)>>>0){Rc();L()}h=JE(wb(b),g);v[b>>2]=h;v[b+4>>2]=h;i=wb(b),j=(g<<2)+h|0,v[i>>2]=j;Lm(b,0);YV(a,c,f,e)}gb=d+16|0}function Sm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;e=Sb(b);f=Wb(b);c=gb-32|0;gb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;a:{if(!Gb(c+24|0,c+16|0)){break a}while(1){if(aY(c+8|0,v[c+24>>2])){break a}v[c+24>>2]=v[c+24>>2]+28;if(Gb(c+24|0,c+16|0)){continue}break}}gb=c+32|0;v[d+8>>2]=v[c+24>>2];g=d,h=Wb(b),v[g>>2]=h;b:{if(Gb(d+8|0,d)){Je(a,wb(v[d+8>>2]));break b}Ih(a)}gb=d+16|0}function Cja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=gb-16|0;gb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=t[e+i|0]<<8;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Ub(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;gb=b+16|0}function rga(a){a=a|0;var b=0;a=Kb(a);v[22640]=0;R(102,a|0,4);b=v[22640];v[22640]=0;a:{b:{if((b|0)==1){break b}v[22640]=0;R(103,a|0,32);b=v[22640];v[22640]=0;if((b|0)==1){break b}v[22640]=0;R(103,a|0,10);b=v[22640];v[22640]=0;if((b|0)==1){break b}v[22640]=0;R(103,a|0,13);b=v[22640];v[22640]=0;if((b|0)==1){break b}v[22640]=0;R(103,a|0,9);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}}function mj(a,b,c,d,e){var f=0,g=0,h=0;g=gb-16|0;gb=g;v[g+8>>2]=b;b=0;f=6;a:{b:{if(hk(a,g+8|0)){break b}f=4;h=rl(a);if(!jh(d,2048,h)){break b}b=Rn(d,h);ql(a);b=b-48|0;c:{if(!ik(a,g+8|0)|(e|0)<2){break c}while(1){f=rl(a);if(!jh(d,2048,f)){break a}f=Rn(d,f);ql(a);b=(f+B(b,10)|0)-48|0;if(!ik(a,g+8|0)){break c}f=(e|0)>2;e=e-1|0;if(f){continue}break}}f=2;if(!hk(a,g+8|0)){break a}}v[c>>2]=v[c>>2]|f}gb=g+16|0;return b}function lj(a,b,c,d,e){var f=0,g=0,h=0;g=gb-16|0;gb=g;v[g+8>>2]=b;b=0;f=6;a:{b:{if(ll(a,g+8|0)){break b}f=4;h=rm(a);if(!ml(d,2048,h)){break b}b=Qn(d,h);qm(a);b=b-48|0;c:{if(!sm(a,g+8|0)|(e|0)<2){break c}while(1){f=rm(a);if(!ml(d,2048,f)){break a}f=Qn(d,f);qm(a);b=(f+B(b,10)|0)-48|0;if(!sm(a,g+8|0)){break c}f=(e|0)>2;e=e-1|0;if(f){continue}break}}f=2;if(!ll(a,g+8|0)){break a}}v[c>>2]=v[c>>2]|f}gb=g+16|0;return b}function Y3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;a:{b:{if((a|0)!=(b|0)){g=v[115121];v[115121]=0;d=rH(a,e+12|0,d,xe());a=jb;f=v[115121];c:{if(f){if(v[e+12>>2]!=(b|0)){break c}if((f|0)==68){break b}break a}v[115121]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0;break a}v[c>>2]=4;if((a|0)>0?1:(a|0)>=0?d>>>0>=1:0){d=-1;a=2147483647;break a}d=0;a=-2147483648}gb=e+16|0;jb=a;return d|0}function WB(a,b,c){var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;a:{if(w[a+20|0]){break a}b=(-1-b>>>0<c>>>0?-1-b|0:c)+b|0;c=v[a+16>>2];if(b>>>0<=c>>>0){break a}b=cC(b,4096);aW(a,b-c|0);b=Wd(d+16|0,kc(a+4|0,v[a+16>>2]),b-v[a+16>>2]|0);c=v[v[a>>2]+44>>2];e=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=e;kb[c|0](d+24|0,a,d+8|0);f=a,g=xb(d+24|0)+v[a+16>>2]|0,v[f+16>>2]=g;if(!(kb[v[v[a>>2]+40>>2]](a)|0)){break a}t[a+20|0]=1}gb=d+32|0}function Qfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=gb-880|0;gb=d;b=Qb(a,0,76);v[b+84>>2]=0;v[b+88>>2]=0;v[b+80>>2]=256;u[b+76>>1]=65535;v[b+92>>2]=0;v[b+96>>2]=0;t[b+100|0]=1;e=b+223848|0;c=b+616|0;a=c;while(1){a=vB(a)+872|0;if((e|0)!=(a|0)){continue}break}Qb(d+8|0,0,872);e=vB(d+8|0);a=c;c=((a+223232|0)-a|0)/872|0;if((c|0)>=1){while(1){hu(a,e);a=a+872|0;f=(c|0)>1;c=c-1|0;if(f){continue}break}}gb=d+880|0;return b|0}function p8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;a:{b:{c:{if(!(e?d:0)){a=aa(8)|0;v[22640]=0;c=Q(112,f|0,5413)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}zj(a,b,2);c=By(a,c,d,e,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=f+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function l8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;a:{b:{c:{if(!(e?d:0)){a=aa(8)|0;v[22640]=0;c=Q(112,f|0,5413)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}zj(a,b,2);c=Ay(a,c,d,e,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=f+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function d$(a){a=a|0;var b=0;a=Kb(a);v[22640]=0;R(107,a|0,4);b=v[22640];v[22640]=0;a:{b:{if((b|0)==1){break b}v[22640]=0;R(108,a|0,32);b=v[22640];v[22640]=0;if((b|0)==1){break b}v[22640]=0;R(108,a|0,10);b=v[22640];v[22640]=0;if((b|0)==1){break b}v[22640]=0;R(108,a|0,13);b=v[22640];v[22640]=0;if((b|0)==1){break b}v[22640]=0;R(108,a|0,9);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}}function _x(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!lt(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}dc(a,32);return 0}ba(12893,10568,1549,3128);L()}function Du(a,b){var c=0;c=gb-32|0;gb=c;sT(c+16|0,a,a+1|0,a+2|0,a+3|0);sT(c,b,b+1|0,b+2|0,b+3|0);gb=c+32|0;b=c+16|0;a=c;c=1;a:{if(w[v[b>>2]]<w[v[a>>2]]){break a}c=0;if(w[v[a>>2]]<w[v[b>>2]]){break a}c=1;b:{if(t[v[b+4>>2]]<t[v[a+4>>2]]){break b}c=0;if(t[v[a+4>>2]]<t[v[b+4>>2]]){break b}c=1;c:{if(w[v[b+8>>2]]<w[v[a+8>>2]]){break c}c=0;if(w[v[a+8>>2]]<w[v[b+8>>2]]){break c}c=w[v[b+12>>2]]<w[v[a+12>>2]]}}}return c}function Sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c=Di(a,b,c,d);v[a>>2]=51048;d=nc(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=1056964608;b=a+4228|0;t[b+4|0]=0;t[b+5|0]=4;t[b|0]=69;t[b+1|0]=99;t[b+2|0]=104;t[b+3|0]=111;t[b+6|0]=1;v[22640]=0;W(1536,a+44|0,2,2)|0;b=v[22640];v[22640]=0;a:{if((b|0)==1){break a}v[22640]=0;Vh(c);b=v[22640];v[22640]=0;if((b|0)==1){break a}Jt(a);return a|0}a=P()|0;O()|0;Lc(d);hf(c);S(a|0);L()}function Q3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=C(0);e=gb-16|0;gb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115121];v[115121]=0;xe();d=gb-16|0;gb=d;Kx(d,a,e+12|0,0);f=AI(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);gb=d+16|0;a=v[115121];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115121]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}gb=e+16|0;return C(f)}function nq(a,b,c){var d=0,e=0;a=Kb(a);d=Ab(b);v[22640]=0;R(104,a|0,d|0);d=v[22640];v[22640]=0;if((d|0)!=1){a:{if(Ab(b)){while(1){d=w[mc(b,e)|0];b:{if(d>>>0<256){d=v[(d<<2)+c>>2];v[22640]=0;R(105,a|0,d|0);d=v[22640];v[22640]=0;if((d|0)!=1){break b}break a}v[22640]=0;R(105,a|0,65533);d=v[22640];v[22640]=0;if((d|0)==1){break a}}e=e+1|0;if(Ab(b)>>>0>e>>>0){continue}break}}return}}b=P()|0;O()|0;Hc(a);S(b|0);L()}function hba(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;a:{b:{if(!a){break b}a=uc(b+8|0,a);v[22640]=0;c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=dL(b);c=v[22640];v[22640]=0;if((c|0)!=1){break a}a=V(0)|0;O()|0;Z(a|0)|0;v[22640]=0;Y(1911,9835,0,0,0);a=v[22640];v[22640]=0;if((a|0)!=1){$();break b}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}a=0}gb=b+16|0;return a|0}function Maa(a,b){a=a|0;b=b|0;var c=0,d=0;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;R(1937,c|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,8189,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function D2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-16|0;gb=e;d=v[ec(a)>>2];i=v[b>>2];g=v[a>>2];f=(d|0)==2485;j=f?0:g;d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}h=d?d:4;d=Wp(j,h);if(d){if(!f){$d(a)}v[e+4>>2]=2434;d=ge(e+8|0,d,e+4|0);Ee(a,$d(d));f=v[ec(d)>>2];k=ec(a),l=f,v[k>>2]=l;Gc(d);v[b>>2]=v[a>>2]+(i-g|0);v[c>>2]=v[a>>2]+(h&-4);gb=e+16|0;return}Ns();L()}function kka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;d=Pc(c+8|0,16,1,1,0);v[c+4>>2]=0;td(a,0);vc(b);a:{b:{if(Mr(b,11147)){Xc(b,12);if(!Jv(b)){Bp(d,2)}Xc(b,24);break b}if(Fh(b,11029)){vc(b);v[c+4>>2]=4;e=1;break a}Vi(d,8)}e=0}f=a,g=(xf(b)>>>0)/(B(dp(d),w[d|0])>>>3>>>0)|0,v[f>>2]=g;b=zg(d,a,b);if(!(!e|!b)){d=v[a+20>>2];f=c,g=Yi(a),v[f>>2]=g;Qb(d,0,v[Fb(c+4|0,c)>>2])}gb=c+16|0;return(b|0)!=0|0}function doa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;v[e+24>>2]=d;g=Zf(a,c);se(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!g){if(id(a,5)){break a}}h=v[a+28>>2];i=v[e+24>>2];f=gb-16|0;gb=f;d=Kb(f);v[22640]=0;ca(649,b|0,h|0,d|0,i|0)|0;b=v[22640];v[22640]=0;b:{if((b|0)!=1){vb(d);gb=f+16|0;break b}a=P()|0;O()|0;vb(d);S(a|0);L()}}Sf(a,g,c,e+16|0);gb=e+32|0}function Xz(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;t[a+1074368|0]=b;pO(a+1074332|0,b);f=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;d=b;if(kb[v[v[b>>2]+136>>2]](b)|0){e=v[b+16>>2];b=e+1074332|0;c=C(C(c*C(y[e+480232>>2]))/C(z[b+8>>2]*z[b+20>>2]))}z[d+4196>>2]=c}a=a+160|0;if((f|0)!=(a|0)){continue}break}}function xD(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;Ye(b);Pe(d+40|0,a,c);a=v[d+40>>2];v[22640]=0;e=Rd(d+40|0);f=v[22640];v[22640]=0;a:{if((f|0)==1){break a}e=zb(e);v[22640]=0;Te(d+8|0,3,e,a);e=v[22640];v[22640]=0;if((e|0)==1){break a}v[22640]=0;R(377,d+24|0,d+8|0);e=v[22640];v[22640]=0;if((e|0)==1){break a}Eb(b,d+24|0);vb(d+24|0);xc(d+40|0);gb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;xc(d+40|0);S(a|0);L()}function iaa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;d=PK(c,b);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,6552,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function haa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;d=OK(c,b);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,3292,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function gaa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;d=NK(c,b);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,3193,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function faa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;d=MK(c,b);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,3335,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function eaa(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;d=LK(c,b);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,3237,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function NY(a,b,c){var d=0,e=0,f=0;d=gb+-64|0;gb=d;Ye(b);Pe(d+40|0,a,c);a=v[d+40>>2];v[22640]=0;e=Rd(d+40|0);f=v[22640];v[22640]=0;a:{if((f|0)==1){break a}e=zb(e);v[22640]=0;Te(d+8|0,2,e,a);e=v[22640];v[22640]=0;if((e|0)==1){break a}v[22640]=0;R(377,d+24|0,d+8|0);e=v[22640];v[22640]=0;if((e|0)==1){break a}Eb(b,d+24|0);vb(d+24|0);xc(d+40|0);gb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;xc(d+40|0);S(a|0);L()}function Kx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=gb-160|0;gb=e;Qb(e+16|0,0,144);v[e+92>>2]=-1;v[e+60>>2]=b;v[e+24>>2]=-1;v[e+20>>2]=b;xi(e+16|0,0,0);CI(e,e+16|0,d,1);d=v[e+8>>2];g=v[e+12>>2];h=v[e>>2];i=v[e+4>>2];if(c){j=c;f=b;b=v[e+20>>2]-v[e+24>>2]|0;k=b;c=b+v[e+136>>2]|0;b=v[e+140>>2]+(b>>31)|0;b=c>>>0<k>>>0?b+1|0:b;v[j>>2]=!(b|c)?f:f+c|0}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=g;gb=e+160|0}function ZY(){var a=0,b=0;a=gb-16|0;gb=a;a:{if(bb(a+12|0,a+8|0)|0){break a}b=Ad((v[a+12>>2]<<2)+4|0);v[115924]=b;if(!b){break a}b=Ad(v[a+8>>2]);if(b){v[v[115924]+(v[a+12>>2]<<2)>>2]=0;if(!(ab(v[115924],b|0)|0)){break a}}v[115924]=0}gb=a+16|0;b:{if(t[463680]&1){break b}if(!Pd(463680)){break b}v[22640]=0;X(2379);a=v[22640];v[22640]=0;if((a|0)!=1){Od(463680);break b}a=P()|0;O()|0;We(463680);S(a|0);L()}iO()}function B9(a){a=a|0;var b=0;v[22640]=0;_(2007,a|0);b=v[22640];v[22640]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){kb[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){Zb(b);v[a+20>>2]=0}Zb(a);return}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,2147,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function nQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/6;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=ed(zb(w[b+1|0])<<16|f<<8|zb(w[b+2|0])<<24,16),u[g>>1]=h;f=zb(w[b+3|0]);g=a,h=ed(zb(w[b+4|0])<<16|f<<8|zb(w[b+5|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,6)|0}function mQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/6;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+2|0]);g=a,h=ed(zb(w[b+1|0])<<16|f<<8|zb(w[b|0])<<24,16),u[g>>1]=h;f=zb(w[b+5|0]);g=a,h=ed(zb(w[b+4|0])<<16|f<<8|zb(w[b+3|0])<<24,16),u[g+2>>1]=h;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,6)|0}function EJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{d:{if((b|0)>=0){if((io(a+8|0)|0)>(b|0)){break d}}b=aa(8)|0;v[22640]=0;c=Q(112,c|0,8049)|0;a=v[22640];v[22640]=0;if((a|0)==1){break c}qc(b,c);v[22640]=0;U(223,b|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}gb=c+16|0;return+(+v[(v[a+32>>2]+B(b,872)|0)+1075740>>2]*.015625)}a=P()|0;O()|0;da(b|0)}S(a|0)}L()}function gV(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808604749){break a}b=a+8|0;if((w[b|0]|w[b+1|0]<<8)>>>0<512|(w[b|0]|w[b+1|0]<<8)>>>0>767){break a}b=a+112|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>64){break a}b=a+106|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+124|0;return(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return 0}function cJ(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){dc(a,21);return-1}if(v[a+1396>>2]<=9){tl(a)}c=v[a+1392>>2];e=u[(((c&1023)<<1)+b|0)+36>>1];a:{if((e|0)>=0){d=c;c=w[e+v[b+8>>2]|0];v[a+1392>>2]=d>>>c;c=v[a+1396>>2]-c|0;d=(c|0)<0;v[a+1396>>2]=d?0:c;c=d?-1:e;break a}c=zm(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!(!(v[a+1384>>2]?w[a+1376|0]:1)|(c|0)>-1)){dc(a,21)}return c}ba(4604,10568,1778,2842);L()}
function O3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115121];v[115121]=0;xe();d=gb-16|0;gb=d;Kx(d,a,e+12|0,1);f=Yx(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);gb=d+16|0;a=v[115121];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115121]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}gb=e+16|0;return+f}function Ke(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Sp(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(qG(a,b)&3){case 0:c=Sp(A[b>>3],A[b+8>>3]);break a;case 1:c=-Tp(A[b>>3],A[b+8>>3],1);break a;case 2:c=-Sp(A[b>>3],A[b+8>>3]);break a;default:break b}}c=Tp(A[b>>3],A[b+8>>3],1)}a=c;gb=b+16|0;return a}function Kaa(a,b){a=a|0;b=b|0;var c=0,d=0;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;_K(c,b);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,2876,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Haa(a,b){a=a|0;b=+b;var c=0;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;b=+Xa(1942,c|0,+b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;Z(c|0)|0;v[22640]=0;Y(1911,4644,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[22640]=0;X(20);c=v[22640];v[22640]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function G5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;a:{if((c|0)<1){break a}while(1){e=v[a+24>>2];g=v[a+28>>2];b:{if(e>>>0>=g>>>0){if((kb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}f=f+1|0;b=b+4|0;break b}v[d+12>>2]=g-e>>2;v[d+8>>2]=c-f;e=v[ld(d+12|0,d+8|0)>>2];wi(v[a+24>>2],b,e);g=e<<2;v[a+24>>2]=g+v[a+24>>2];f=f+e|0;b=b+g|0}if((c|0)>(f|0)){continue}break}}gb=d+16|0;return f|0}function CJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{d:{if((b|0)>=0){if((io(a+8|0)|0)>(b|0)){break d}}b=aa(8)|0;v[22640]=0;c=Q(112,c|0,8049)|0;a=v[22640];v[22640]=0;if((a|0)==1){break c}qc(b,c);v[22640]=0;U(223,b|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}gb=c+16|0;return(w[(v[a+32>>2]+B(b,872)|0)+1075081|0]&4)>>>2|0}a=P()|0;O()|0;da(b|0)}S(a|0)}L()}function OQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=gb-16|0;gb=d;v[d+8>>2]=c;v[d+4>>2]=v[a>>2];e=v[Fb(d+8|0,d+4|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){j=d,k=oh(w[b|0]),t[j+15|0]=k;t[d+14|0]=192;t[d+13|0]=63;h=d+13|0;i=gb-16|0;gb=i;f=d+15|0;g=d+14|0;if(!Jj(f,g)){g=Jj(h,f)?h:f}gb=i+16|0;t[a|0]=w[g|0]<<1;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function Mv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;e=Sb(b);f=Wb(b);c=gb-32|0;gb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;if(Gb(c+24|0,c+16|0)){while(1){if((FY(v[c+24>>2])|0)!=v[v[c+8>>2]>>2]){pp(c+24|0);if(Gb(c+24|0,c+16|0)){continue}}break}e=v[c+24>>2]}gb=c+32|0;v[d+8>>2]=e;g=d,h=Wb(b),v[g>>2]=h;a:{if(Gb(d+8|0,d)){Je(a,wb(v[d+8>>2]));break a}Ih(a)}gb=d+16|0}function q8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22640]=0;c=Q(112,e|0,5413)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}zj(a,b,1);c=By(a,c,d,0,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function m8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22640]=0;c=Q(112,e|0,5413)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}zj(a,b,1);c=Ay(a,c,d,0,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function bqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;v[d+28>>2]=c;a:{if(!Pb(b,c<<1)){break a}tc(d+28|0,65535);yf(a,x[d+28>>1]);e=d,f=Sb(a),v[e+16>>2]=f;e=d,f=Wb(a),v[e+8>>2]=f;if(!Gb(d+16|0,d+8|0)){break a}while(1){a=v[d+16>>2];c=d+24|0;if(!Ep(b,c)){tD(c)}c=Ib(w[d+24|0]|w[d+25|0]<<8);u[a>>1]=c;if((c|0)==65535){u[a>>1]=65535}mf(d+16|0);if(Gb(d+16|0,d+8|0)){continue}break}}gb=d+32|0}function Qt(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);v[a+4228>>2]=(B(v[a+4232>>2],w[a+4264|0])+250>>>0)/500;z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16)}function dla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=AU(a,b);v[22640]=0;e=Q(889,a+12|0,b+12|0)|0;d=v[22640];v[22640]=0;b:{c:{if((d|0)!=1){v[22640]=0;Q(890,a+24|0,b+24|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}c=v[b+40>>2];v[a+36>>2]=v[b+36>>2];v[a+40>>2]=c;u[a+52>>1]=x[b+52>>1];c=v[b+48>>2];v[a+44>>2]=v[b+44>>2];v[a+48>>2]=c;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;gc(e)}gc(c);S(a|0);L()}}function daa(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;b=T(1974,b|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,4328,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function w8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=gb-32|0;gb=b;c=Wd(b+24|0,c,d);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;a:{a=Vz(a,b,0);if(a+1>>>0>=3){a=aa(8)|0;v[22640]=0;b=Q(112,b+8|0,5270)|0;c=v[22640];v[22640]=0;b:{if((c|0)!=1){qc(a,b);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}c=P()|0;O()|0;vb(b);break b}c=P()|0;O()|0;da(a|0)}S(c|0);L()}gb=b+32|0;return a|0}L()}function Ih(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;f=gb-16|0;gb=f;e=gb-16|0;gb=e;b=gb-16|0;gb=b;c=e;v[c+4>>2]=1;g=d+8|0;h=c,i=Mc(16,4),v[h+8>>2]=i;gb=b+16|0;b=v[c+8>>2];v[22640]=0;DF(b);b=v[22640];v[22640]=0;a:{if((b|0)!=1){b=Kp(c);Bw(g,cc(b),b);CF(c);gb=e+16|0;break a}a=P()|0;O()|0;CF(c);S(a|0);L()}gb=f+16|0;bk(a,d+8|0);pe(d+8|0);gb=d+16|0;v[a+8>>2]=0;Sd(a+12|0);return a|0}function us(a){var b=0,c=0;ko(a,1,10940);v[22640]=0;b=fa(184)|0;c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[22640]=0;b=fa(185)|0;c=v[22640];v[22640]=0;if((c|0)==1){break a}t[a+16|0]=b;v[22640]=0;b=fa(186)|0;c=v[22640];v[22640]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[22640]=0;_(187,a+20|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;vb(a);S(b|0);L()}function Yfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;v[a>>2]=b;d=gb-16|0;gb=d;g=d+8|0;e=b+1074376|0;c=hc(rf(223848),e,614);b=0;while(1){f=B(b,872);hu((c+f|0)+616|0,(e+f|0)+616|0);b=b+1|0;if((b|0)!=256){continue}break}b=v[Ni(g,c)>>2];gb=d+16|0;v[a+4>>2]=b;b=Ck(a+8|0);d=ad(a+20|0);v[22640]=0;_(1262,a|0);c=v[22640];v[22640]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;wP(d);vP(b);uP(a+4|0);S(c|0);L()}function Iaa(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;c=+pa(1941,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,4716,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function pna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb+-64|0;gb=e;c=gb-32|0;gb=c;g=e+8|0;fW(c+24|0,g);h=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;qd(c+16|0,d,c);f=xb(c+16|0);if((f|0)==(h|0)){cd(d,xb(c+24|0))}gb=c+32|0;c=(f|0)==(h|0);if(!c){eW(g)}d=-1;a:{if(!c){break a}d=0;if(!nW(e+8|0)){break a}d=Ne(a,b,mW(e+8|0),jb)}gb=e- -64|0;return d|0}function j8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22640]=0;c=Q(112,e|0,5413)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}zj(a,b,2);c=fL(a,c,2,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function i8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22640]=0;c=Q(112,e|0,5413)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}zj(a,b,4);c=fL(a,c,4,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function h8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22640]=0;c=Q(112,e|0,5413)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}zj(a,b,2);c=eL(a,c,2,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function gda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;NM(c+8|0,a,0);if(xb(c+8|0)){a=v[a+20>>2];v[a+148>>2]=-1;d=gb-16|0;gb=d;b=v[c+8>>2];f=v[c+12>>2];e=fi(b,f);a=a+4|0;a:{if(e>>>0<=hg(a)>>>0){if(pc(a)>>>0<e>>>0){v[d+12>>2]=b;HO(d+12|0,pc(a));g=b;b=v[d+12>>2];Bg(g,b,v[a>>2]);rr(a,b,f,e-pc(a)|0);break a}jn(a,Bg(b,f,v[a>>2]));break a}vv(a);gp(a,vh(a,e));rr(a,b,f,e)}gb=d+16|0}gb=c+16|0}function g8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a:{b:{c:{if(!d){a=aa(8)|0;v[22640]=0;c=Q(112,e|0,5413)|0;b=v[22640];v[22640]=0;if((b|0)==1){break c}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}b=P()|0;O()|0;vb(c);break b}zj(a,b,4);c=eL(a,c,4,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];gb=e+16|0;return c|0}b=P()|0;O()|0;da(a|0)}S(b|0)}L()}function T9(a,b){a=a|0;b=b|0;var c=0;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;b=FK(c,b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,6961,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function S9(a,b){a=a|0;b=b|0;var c=0;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[22640]=0;b=EK(c,b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,3687,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Laa(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;b=v[b+8>>2];c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,8219,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Woa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-112|0;gb=e;c=gb-32|0;gb=c;g=e+8|0;EX(c+24|0,g);h=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;qd(c+16|0,d,c);f=xb(c+16|0);if((f|0)==(h|0)){cd(d,xb(c+24|0))}gb=c+32|0;c=(f|0)==(h|0);if(!c){DX(g)}d=-1;a:{if(!c){break a}d=0;if(!HX(e+8|0)){break a}d=Ne(a,b,GX(e+8|0),jb)}gb=e+112|0;return d|0}function UZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-512|0;gb=e;c=gb-32|0;gb=c;g=e+8|0;xE(c+24|0,g);h=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;qd(c+16|0,d,c);f=xb(c+16|0);if((f|0)==(h|0)){cd(d,xb(c+24|0))}gb=c+32|0;c=(f|0)==(h|0);if(!c){wE(g)}d=-1;a:{if(!c){break a}d=0;if(!CE(e+8|0)){break a}d=Ne(a,b,BE(e+8|0),jb)}gb=e+512|0;return d|0}
function ER(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[a+4>>2]=0;a:{if(b){b:{if(Uu(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}wb(a);e=Vu(d+16|0);v[22640]=0;f=Q(847,a|0,b|0)|0;g=v[22640];v[22640]=0;if((g|0)==1){break a}v[22640]=0;R(848,e|0,f|0);f=v[22640];v[22640]=0;if((f|0)==1){break a}v[e+4>>2]=b;GB(a,e);Ce(e)}yk(d,a);xp(d,b,w[c|0])}gb=d+32|0;return}a=P()|0;O()|0;Ce(e);S(a|0);L()}function h1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[e>>2]=c;c=2;a=bx(f+12|0,0,b,v[a+8>>2]);a:{if(a+1>>>0<2){break a}c=1;b=v[e>>2];g=d-b|0;d=a-1|0;if(g>>>0<d>>>0){break a}c=0;if(!d){break a}d=w[f+12|0];v[e>>2]=b+1;t[b|0]=d;a=a-2|0;if(!a){break a}b=f+12|0;while(1){d=w[b+1|0];g=v[e>>2];v[e>>2]=g+1;t[g|0]=d;b=b+1|0;a=a-1|0;if(a){continue}break}}gb=f+16|0;return c|0}function Yy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=gb-16|0;gb=f;i=f+8|0;d=gb-16|0;gb=d;c=a;j=b;e=Vd(a);g=ec(a);h=gb-16|0;gb=h;if(e){wb(c);while(1){c=iN(e+16|0,j);g=c?g:e;e=v[(c?4:0)+e>>2];if(e){continue}break}}c=v[yc(h+8|0,g)>>2];gb=h+16|0;v[d+8>>2]=c;k=d,l=yh(a),v[k>>2]=l;a:{if(Xl(d+8|0,d)){if(!jN(wb(a),b,ue(d+8|0))){break a}}c=yh(a)}gb=d+16|0;a=v[yc(i,c)>>2];gb=f+16|0;return a}function Gaa(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;c=A[b+16>>3];b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,4680,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function pi(a){var b=0,c=0;b=gb-16|0;gb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Tp(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(qG(a,b)&3){case 0:a=Tp(A[b>>3],A[b+8>>3],1);break a;case 1:a=Sp(A[b>>3],A[b+8>>3]);break a;case 2:a=-Tp(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-Sp(A[b>>3],A[b+8>>3])}gb=b+16|0;return a}function pga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;f=c;d=b;if(qp(b,c+24|0)){if(Xb(w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))){e=Xb(w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))}else{e=-1}}rd(f,d,e);d=Zl(a,c+24|0,c);yb(c);a:{a=e&1;if(!a){break a}v[22640]=0;Q(350,b|0,2-a|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Xd(d);S(a|0);L()}gb=c+32|0}function oaa(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;b=WK(b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,10156,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function mha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Ae(a);if(d>>>0<b>>>0){e=gb-32|0;gb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[wb(a)>>2]-v[a+4>>2]>>5>>>0){TA(a,d,c);break c}b=wb(a);b=jS(e+8|0,$q(a,Ae(a)+d|0),Ae(a),b);v[22640]=0;U(1111,b|0,d|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}iS(a,b);QA(b)}gb=e+32|0;break a}a=P()|0;O()|0;QA(b);S(a|0);L()}return}if(b>>>0<d>>>0){tS(a,v[a>>2]+(b<<5)|0)}}function b7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=gb-16|0;gb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;_J(a,c);if(!(!v[b+8>>2]|z[a+24>>2]==C(1))){h=a+12|0;while(1){if(v[b+4>>2]){i=e+g|0;d=0;while(1){j=z[a+24>>2];f=ir(h,d,i);z[f>>2]=j*z[f>>2];d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}gb=c+16|0}function RZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=gb-48|0;gb=e;c=gb-32|0;gb=c;g=e+8|0;aE(c+24|0,g);h=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;qd(c+16|0,d,c);f=xb(c+16|0);if((f|0)==(h|0)){cd(d,xb(c+24|0))}gb=c+32|0;c=(f|0)==(h|0);if(!c){$D(g)}d=-1;a:{if(!c){break a}d=0;if(!tE(e+8|0)){break a}d=Ne(a,b,sE(e+8|0),jb)}gb=e+48|0;return d|0}function so(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-16|0;gb=f;a:{while(1){g=h&255;if(ez(b,c,g>>>0>1)){t[f+15|0]=0;t[f+14|0]=0;VA(a,f+15|0,f+14|0);break a}Dh(b,d);Dh(c,e);h=h+1|0;if(g>>>0<3){continue}break}h=f;g=w[b|0];if(to(g)>>>0>to(w[d|0])>>>0){Dh(b,d);Dh(c,e);g=w[b|0]}t[h+11|0]=g;VA(f+12|0,f+11|0,c);t[b|0]=0;t[c|0]=0;b=x[f+12>>1];t[a|0]=b;t[a+1|0]=b>>>8}gb=f+16|0}function naa(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;b=VK(b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,6505,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function maa(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;b=UK(b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,6007,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function laa(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;b=SK(b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,6926,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function kaa(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;b=RK(b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,2411,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function jaa(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;b=QK(b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,4173,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function caa(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;b=io(b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,4141,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function baa(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;b=KK(b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,3948,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function aaa(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;b=JK(b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,4016,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Jaa(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;b=ZK(b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,2908,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function _Y(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-1968|0;gb=f;c=gb-32|0;gb=c;g=f+8|0;VY(c+24|0,g);h=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=a;qd(c+16|0,d,c);e=xb(c+16|0);if((e|0)==(h|0)){cd(d,xb(c+24|0))}gb=c+32|0;c=(e|0)==(h|0);if(!c){UY(g)}d=-1;a:{if(!c){break a}d=0;if(!rD(f+8|0)){break a}d=Ne(a,b,1024,0)}gb=f+1968|0;return d|0}function _9(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;b=gq(b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,4518,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function HB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=nc(a);f=d,g=Sb(b),v[f+8>>2]=g;f=d,g=Wb(b),v[f>>2]=g;a:{if(Gb(d+8|0,d)){while(1){a=v[d+8>>2];if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(c|0)){v[22640]=0;R(556,e|0,wb(a)|0);a=v[22640];v[22640]=0;if((a|0)==1){break a}}pp(d+8|0);if(Gb(d+8|0,d)){continue}break}}gb=d+16|0;return}a=P()|0;O()|0;fd(e);S(a|0);L()}function $9(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;b=xl(b);c=v[22640];v[22640]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,3850,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function paa(a){a=a|0;var b=0,c=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[22640]=0;c=XK(b);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,7475,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function cB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-32|0;gb=f;v[f+8>>2]=c;g=f,h=xf(b),v[g+28>>2]=h;Pe(f+8|0,b,v[Fb(f+8|0,f+28|0)>>2]);v[22640]=0;b=Rd(f+8|0);c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}c=v[f+8>>2];v[22640]=0;a=ga(401,a|0,b|0,c|0,d|0,e|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break a}xc(f+8|0);gb=f+32|0;return a|0}a=P()|0;O()|0;xc(f+8|0);S(a|0);L()}function pV(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Oy(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(uf(v[a+16>>2])>>>0);c=C(C(kb[v[v[a>>2]+204>>2]](a))*b);d=a,e=C(C(c*C(2.0480000972747803))*C(kb[v[v[a>>2]+196>>2]](a))),z[d+4248>>2]=e;d=a,f=Xh(C(C(c*C(4.0960001945495605))+C(8192))),v[d+4256>>2]=f;c=C(kb[v[v[a>>2]+208>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(kb[v[v[a>>2]+192>>2]](a)|0)){b=rG(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function IB(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+30|0]=0;t[a+31|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function K0(){var a=0;a:{if(t[464568]&1){break a}if(!Pd(464568)){break a}a=464400;while(1){a=Kb(a)+12|0;if((a|0)!=464568){continue}break}Od(464568)}hd(464400,87844);hd(464412,87872);hd(464424,87900);hd(464436,87932);hd(464448,87972);hd(464460,88008);hd(464472,88036);hd(464484,88072);hd(464496,88088);hd(464508,88104);hd(464520,88120);hd(464532,88136);hd(464544,88152);hd(464556,88168)}function upa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-32|0;gb=f;c=gb-32|0;gb=c;g=f+8|0;zD(c+24|0,g);h=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;d=a;qd(c+16|0,d,c);e=xb(c+16|0);if((e|0)==(h|0)){cd(d,xb(c+24|0))}gb=c+32|0;d=(e|0)==(h|0);if(!d){yD(g)}c=-1;a:{if(!d){break a}c=0;if(!TX(f+8|0)){break a}c=Ne(a,b,72,0)}gb=f+32|0;return c|0}function Hda(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[22640]=0;R(467,b+4|0,8);b=v[22640];v[22640]=0;if((b|0)!=1){c=v[v[a+20>>2]+4>>2];b=v[a+4264>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(88880)|0;if((O()|0)==(ea(88880)|0)){Z(b|0)|0;zr(v[a+20>>2]+4|0);$();return}S(b|0);L()}function rI(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;h=c;d=gb-16|0;gb=d;c=a;a:{if(b>>>0<=1073741807){b:{if(b>>>0<=1){Ve(c,b);e=c;break b}f=vm(b)+1|0;e=Li(c,f);bf(c,e);ng(c,f);ee(c,b)}c=e;f=b;c:{d:{if(b){v[22640]=0;HI(c,h,f);c=v[22640];v[22640]=0;if((c|0)==1){break d}}break c}V(0)|0;O()|0;Bb();L()}v[d+12>>2]=0;Fe((b<<2)+e|0,d+12|0);gb=d+16|0;break a}_f();L()}gb=g+16|0;return a}function iha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=b;wb(b);d=a;f=mh(a);b:{c:{e=sc(b);if(e){v[22640]=0;R(830,d|0,e|0);g=v[22640];v[22640]=0;if((g|0)==1){break c}kS(d,v[c>>2],v[c+4>>2],e)}break b}a=P()|0;O()|0;Zr(f);S(a|0);L()}v[22640]=0;Q(4,a+12|0,b+12|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){v[a+24>>2]=v[b+24>>2];u[a+28>>1]=x[b+28>>1];break a}a=P()|0;O()|0;Ue(d);S(a|0);L()}}function WF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-48|0;gb=d;f=v[b>>2];g=v[b+8>>2];e=v[c+4>>2];c=v[c>>2];v[d+16>>2]=c;v[d+20>>2]=e;v[d+24>>2]=c;v[d+28>>2]=e;Lh(d+32|0,d+16|0);c=v[v[f>>2]+28>>2];e=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=e;kb[c|0](d+40|0,f,g,d+8|0);c=v[d+44>>2];v[d>>2]=v[d+40>>2];v[d+4>>2]=c;Lh(a,d);h=b,i=xb(a)+v[b+8>>2]|0,v[h+8>>2]=i;gb=d+48|0}function LJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(b<=4?b<=0:1){a=aa(8)|0;v[22640]=0;c=Q(112,c|0,4998)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=xh(65536/b);a=a+32|0;v[v[a>>2]+480244>>2]=d;Eq(v[a>>2]);gb=c+16|0;return}d=P()|0;O()|0;da(a|0)}S(d|0)}L()}function JJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(b<=4?b<=0:1){a=aa(8)|0;v[22640]=0;c=Q(112,c|0,5019)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=xh(b*65536);a=a+32|0;v[v[a>>2]+480240>>2]=d;Eq(v[a>>2]);gb=c+16|0;return}d=P()|0;O()|0;da(a|0)}S(d|0)}L()}function Is(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}e=w[b|0];if(e){while(1){t[a|0]=e;a=a+1|0;e=w[b+1|0];b=b+1|0;if(e){continue}break}}b=c&16384;a:{b:{if((d|0)!=256){if((d|0)!=4){break b}c=b?70:102;break a}c=b?69:101;break a}c=b?65:97;if((d|0)==260){break a}c=b?71:103}t[a|0]=c;return(d|0)!=260}function bla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-608|0;gb=f;c=gb-32|0;gb=c;e=f;tU(c+24|0,f);h=xb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;qd(c+16|0,d,c);g=xb(c+16|0);if((g|0)==(h|0)){cd(d,xb(c+24|0))}gb=c+32|0;d=(g|0)==(h|0);if(!d){sU(e)}e=-1;a:{if(!d){break a}e=0;if(!vU(f)){break a}e=Ne(a,b,uU(f),jb)}gb=f+608|0;return e|0}function Qoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-576|0;gb=f;c=gb-32|0;gb=c;e=f;pX(c+24|0,f);h=xb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;qd(c+16|0,d,c);g=xb(c+16|0);if((g|0)==(h|0)){cd(d,xb(c+24|0))}gb=c+32|0;d=(g|0)==(h|0);if(!d){oX(e)}e=-1;a:{if(!d){break a}e=0;if(!sX(f)){break a}e=Ne(a,b,rX(f),jb)}gb=f+576|0;return e|0}function Joa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-192|0;gb=f;c=gb-32|0;gb=c;e=f;Jr(c+24|0,f);h=xb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;qd(c+16|0,d,c);g=xb(c+16|0);if((g|0)==(h|0)){cd(d,xb(c+24|0))}gb=c+32|0;d=(g|0)==(h|0);if(!d){SW(e)}e=-1;a:{if(!d){break a}e=0;if(!mX(f)){break a}e=Ne(a,b,lX(f),jb)}gb=f+192|0;return e|0}function DZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;v[a>>2]=0;v[a+4>>2]=0;if(!Pb(b,c)){c=xf(b)}v[a>>2]=c;e=v[b>>2];a:{if(kb[v[v[e>>2]+16>>2]](e)|0){c=a;a=v[b>>2];f=c,g=(kb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[f+4>>2]=g;break a}e=a+8|0;Fk(e,v[a>>2]);if($c(e)){break a}a=Wd(d+24|0,kc(e,0),c);c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;fc(d+16|0,b,d+8|0)}gb=d+32|0}function DH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;c=Tb(d,c);v[22640]=0;U(2411,d+16|0,b|0,c|0);e=v[22640];v[22640]=0;a:{b:{if((e|0)!=1){v[22640]=0;Q(2412,a|0,d+16|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}vb(d+16|0);vb(c);v[a>>2]=78956;c=v[b+4>>2];v[a+8>>2]=v[b>>2];v[a+12>>2]=c;gb=d+32|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;vb(d+16|0)}vb(c);S(a|0);L()}function yJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b>>>0>=256){b=aa(8)|0;v[22640]=0;c=Q(112,c|0,8049)|0;a=v[22640];v[22640]=0;if((a|0)==1){break c}qc(b,c);v[22640]=0;U(223,b|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}a=v[a+32>>2]+B(b,872)|0;v[a+1075008>>2]=0;v[a+1075068>>2]=0;gb=c+16|0;return}a=P()|0;O()|0;da(b|0)}S(a|0)}L()}function t8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-48|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d+16>>2]=b;v[d+20>>2]=e;v[d+32>>2]=b;v[d+36>>2]=e;Lh(d+40|0,d+16|0);b=bk(d+24|0,c);v[22640]=0;e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;W(239,a|0,d+8|0,d|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){pe(c);gb=d+48|0;return}a=P()|0;O()|0;pe(c);S(a|0);L()}
function fF(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179340888|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1213419859){break a}b=a+4|0;if(!Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+12|0;if(!Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}c=Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>27}return c}function d0(){var a=0,b=0,c=0,d=0,e=0,f=0;b=gb-48|0;gb=b;a:{a=v[116446];if(a){c=a+48|0;if(yG(c)){d=b;if(v[c>>2]==1126902529&v[c+4>>2]==1129074247){c=v[a+44>>2]}else{c=a+80|0}v[d+44>>2]=c;a=v[a>>2];c=v[a+4>>2];if(uG(88856,a,b+44|0)){break a}v[b+20>>2]=c;v[b+16>>2]=3184;L()}v[b+32>>2]=3184;L()}L()}a=v[b+44>>2];e=b,f=kb[v[v[a>>2]+8>>2]](a)|0,v[e+8>>2]=f;v[b+4>>2]=c;v[b>>2]=3184;L()}function Vaa(a){a=a|0;var b=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Zb(Ct(b))}v[a+24>>2]=0;b=v[a+20>>2];if(b){Zb(b);v[a+20>>2]=0}Zb(a);return}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,2174,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function U6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=gb-16|0;gb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;SJ(a,c);if(!(!v[b+8>>2]|z[a+24>>2]==C(1))){h=a+12|0;while(1){if(v[b+4>>2]){i=e+g|0;d=0;while(1){f=Ug(h,d,i);z[f>>2]=z[f>>2]*z[a+24>>2];d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}gb=c+16|0}function Mna(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;c=a;if(!w[c+8|0]){if(w[c+24|0]){t[c+24|0]=0;e=c+40|0;while(1){f=ln(e,b),g=0,t[f+8|0]=g;b=b+1|0;if((b|0)!=16){continue}break}b=c+28|0;Fk(b,0);nX(b)}b=c+12|0;Fk(b,v[c+4>>2]);be(d+24|0,b);b=v[v[c>>2]+40>>2];e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;kb[b|0](d+16|0,c,0,d+8|0);t[c+8|0]=1}gb=d+32|0;return v[a+12>>2]}function xla(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;a:{if(!YC(a,b+16|0)){break a}c=0;if(!MU(b+16|0)){break a}c=-1;if(!_j(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+8|0;c=(c|0)==((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))&2139062143)}a=c;gb=b+32|0;return a|0}function xJ(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=v[((w[b|0]^a&255)<<2)+59920>>2]^a>>>8;a=a>>>8^v[((w[b+1|0]^a&255)<<2)+59920>>2];a=a>>>8^v[((w[b+2|0]^a&255)<<2)+59920>>2];a=a>>>8^v[((w[b+3|0]^a&255)<<2)+59920>>2];b=b+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=v[((w[b|0]^a&255)<<2)+59920>>2]^a>>>8;b=b+1|0;c=c-1|0;if(c){continue}break}}return a^-1}function sX(a){var b=0,c=0,d=0;a:{if((w[a+60|0]|w[a+61|0]<<8|(w[a+62|0]<<16|w[a+63|0]<<24))!=808537417){break a}b=a+32|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}b=a+576|0;a=a- -64|0;while(1){c=0;b:{switch(w[a+15|0]){case 0:case 1:d=1;break;case 2:break b;default:break a}}c=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}return c&1}function kma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-128|0;gb=f;c=gb-32|0;gb=c;e=f;cV(c+24|0,f);h=xb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;d=a;qd(c+16|0,d,c);g=xb(c+16|0);if((g|0)==(h|0)){cd(d,xb(c+24|0))}gb=c+32|0;d=(g|0)==(h|0);if(!d){bV(e)}e=-1;a:{if(!d){break a}e=0;if(!gV(f)){break a}e=Ne(a,b,256,0)}gb=f+128|0;return e|0}function fqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,10);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0}return a|0}function qN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{if(ye(a)>>>0>=b>>>0){g=d,h=Nb(a),v[g+8>>2]=h;e=v[a>>2];b=c;f=v[Fb(d+12|0,d+8|0)>>2];if(f){while(1){z[e>>2]=z[b>>2];e=e+4|0;f=f-1|0;if(f){continue}break}}b=v[d+12>>2];e=v[d+8>>2];if(b>>>0>e>>>0){Wy(a,b-e|0,c);break a}dj(a,v[a>>2]+(b<<2)|0);break a}JN(a);aw(a,_g(a,b));Wy(a,b,c)}gb=d+16|0}function kpa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){d=gb-16|0;gb=d;c=Ri(d,a,1);wb(a);jp(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+1;$b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=dh(d+8|0,vh(a,pc(a)+1|0),pc(a),c);jp(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+1;v[22640]=0;R(43,a|0,c|0);a=v[22640];v[22640]=0;a:{if((a|0)!=1){ae(c);gb=d+32|0;break a}a=P()|0;O()|0;ae(c);S(a|0);L()}}function fG(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(b>>>0>=d>>>0){if(!e){return d}d=a+d|0;h=a+b|0;b=h;f=gb-16|0;gb=f;e=(c+e|0)-c|0;a:{if(!e){b=d;break a}g=b-d|0;if((g|0)<(e|0)){break a}t[f+15|0]=w[c|0];i=1-e|0;while(1){d=vp(d,g+i|0,f+15|0);if(!d){break a}if(!po(d,c,e)){b=d;break a}d=d+1|0;g=b-d|0;if((g|0)>=(e|0)){continue}break}}gb=f+16|0;a=(b|0)==(h|0)?-1:b-a|0}else{a=-1}return a}function RH(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){c=gb-16|0;gb=c;b=aa(16)|0;a=gb-16|0;gb=a;a:{if(t[460568]&1){break a}if(!Pd(460568)){break a}Od(460568)}pd(a+8|0,1,90236);d=v[a+12>>2];c=c+8|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=d;gb=a+16|0;v[22640]=0;Q(2364,b|0,c|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){ia(b|0,78268,2365);L()}a=P()|0;O()|0;da(b|0);S(a|0);L()}}function Qda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;c=rf(64);v[22640]=0;e=T(1323,c|0)|0;f=v[22640];v[22640]=0;a:{if((f|0)!=1){c=is(d,e);e=v[c>>2];v[22640]=0;a=W(1534,e|0,a|0,b|0)|0;b=v[22640];v[22640]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}Rz(d+8|0);break b}a=P()|0;O()|0;Dg(c);break a}ni(d+8|0,c)}Dg(c);gb=d+16|0;return v[d+8>>2]}a=P()|0;O()|0;Zb(c)}S(a|0);L()}function Oaa(a,b){a=a|0;b=b|0;var c=0;v[22640]=0;_(1934,a|0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}Zb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,2752,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Di(a,b,c,d);v[a+4224>>2]=1049951732;c=a+4216|0;v[c>>2]=1065353216;v[c+4>>2]=1049951732;v[a+4208>>2]=1060320051;v[a+4212>>2]=1041865114;v[a>>2]=51776;v[22640]=0;W(1536,a+44|0,2,2)|0;c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}v[22640]=0;Vh(b);c=v[22640];v[22640]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;hf(b);S(a|0);L()}function _ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;wb(a);v[c+12>>2]=268435455;v[22640]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22640];v[22640]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Rc();L()}wb(a);c=b;if(c>>>0>268435455){nd(8513);L()}c=Mc(c<<4,8);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+(b<<4)|0,v[f>>2]=g;EG(a,0)}function Sja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=gb-80|0;gb=e;c=gb-32|0;gb=c;cW(c+24|0,e);g=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;qd(c+16|0,d,c);f=xb(c+16|0);if((f|0)==(g|0)){cd(d,xb(c+24|0))}d=e;gb=c+32|0;c=(f|0)==(g|0);if(!c){bW(d)}d=-1;a:{if(!c){break a}d=0;if(!iT(e)){break a}d=Ne(a,b,hT(e),jb)}gb=e+80|0;return d|0}function r$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){hG(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=ns(c+8|0,Mw(a,Cc(a)+1|0),Cc(a),d);f=v[a+8>>2];v[22640]=0;Mn(d,f,b);b=v[22640];v[22640]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+12;v[22640]=0;Ln(e,a);b=v[22640];v[22640]=0;if((b|0)==1){break b}ms(a);gb=c+32|0;break a}b=P()|0;O()|0;ms(a);S(b|0);L()}}function $Q(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){hG(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=ns(c+8|0,Mw(a,Cc(a)+1|0),Cc(a),d);f=v[a+8>>2];v[22640]=0;Mn(d,f,b);b=v[22640];v[22640]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+12;v[22640]=0;Ln(e,a);b=v[22640];v[22640]=0;if((b|0)==1){break b}ou(a);gb=c+32|0;break a}b=P()|0;O()|0;ou(a);S(b|0);L()}}function qda(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function Qca(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-16|0;gb=c;v[v[a+20>>2]+148>>2]=-1;v[22640]=0;un(c+8|0,a+4228|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){b=v[a+20>>2];d=v[c+8>>2];e=v[c+12>>2];v[22640]=0;U(1668,b+4|0,d|0,e|0);b=v[22640];v[22640]=0;if((b|0)!=1){break b}}b=V(88880)|0;if((O()|0)!=(ea(88880)|0)){break a}Z(b|0)|0;zr(v[a+20>>2]+4|0);$()}gb=c+16|0;return}S(b|0);L()}function PV(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=gb-32|0;gb=b;if(!w[a+20|0]){if(!(kb[v[v[a>>2]+40>>2]](a)|0)){d=a+4|0;while(1){aW(a,65536);c=Wd(b+16|0,kc(d,v[a+16>>2]),65536);e=v[v[a>>2]+44>>2];f=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=f;kb[e|0](b+24|0,a,b+8|0);g=a,h=xb(b+24|0)+v[a+16>>2]|0,v[g+16>>2]=h;if(!(kb[v[v[a>>2]+40>>2]](a)|0)){continue}break}}t[a+20|0]=1}gb=b+32|0}function Uq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=gb-16|0;gb=b;e=Sb(a);f=Wb(a);c=gb-16|0;gb=c;v[c>>2]=f;v[c+8>>2]=e;if(Gb(c+8|0,c)){while(1){d=A[v[c+8>>2]>>3]+d;uu(c+8|0);if(Gb(c+8|0,c)){continue}break}}gb=c+16|0;g=b,h=Sb(a),v[g+8>>2]=h;g=b,h=Wb(a),v[g>>2]=h;if(Gb(b+8|0,b)){d=-d;while(1){a=v[b+8>>2];d=A[a>>3]+d;A[a>>3]=d;uu(b+8|0);if(Gb(b+8|0,b)){continue}break}}gb=b+16|0}function dB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;v[e+8>>2]=c;f=e,g=xf(b),v[f+28>>2]=g;Pe(e+8|0,b,v[Fb(e+8|0,e+28|0)>>2]);v[22640]=0;b=Rd(e+8|0);c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}c=v[e+8>>2];v[22640]=0;ca(925,a|0,b|0,c|0,d|0)|0;a=v[22640];v[22640]=0;if((a|0)==1){break a}xc(e+8|0);gb=e+32|0;return 1}a=P()|0;O()|0;xc(e+8|0);S(a|0);L()}function N0(){var a=0;a:{if(t[464392]&1){break a}if(!Pd(464392)){break a}a=464224;while(1){a=Kb(a)+12|0;if((a|0)!=464392){continue}break}Od(464392)}Vc(464224,2336);Vc(464236,2343);Vc(464248,2309);Vc(464260,2317);Vc(464272,2300);Vc(464284,2350);Vc(464296,2327);Vc(464308,6918);Vc(464320,7290);Vc(464332,8634);Vc(464344,10221);Vc(464356,2595);Vc(464368,8107);Vc(464380,3650)}function Lna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=f+B(b,6);a:{if(v[d>>2]!=v[d+4>>2]){while(1){f=v[a+16>>2];b=v[d>>2];v[22640]=0;rC(f,b,c);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[d>>2]+6|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}Yc(d);gb=e+16|0;return}a=P()|0;O()|0;Yc(d);S(a|0);L()}function rna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=e+B(b,20);a:{if(v[c>>2]!=v[c+4>>2]){while(1){e=v[a+16>>2];b=v[c>>2];v[22640]=0;R(380,e|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[c>>2]+20|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}Yc(c);gb=d+16|0;return}a=P()|0;O()|0;Yc(c);S(a|0);L()}function qla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;GU(a,c+11|0);if((w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24))!=1414807888){a=c+12|0}else{GU(a,c+11|0);t[b|0]=1;a=c+11|0}b=gb-16|0;gb=b;a:{b:{if(a){a=Tb(b,a);v[22640]=0;d=T(884,a|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break b}vb(a)}gb=b+16|0;break a}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=c+16|0;return d|0}function fA(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,872)+a|0;v[c+1075688>>2]=0;d=c+1075e3|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075080|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,872)+a|0;v[c+1075680>>2]=0;c=v[c+1075080>>2]}d=B(b,872)+a|0;v[d+1075080>>2]=c|2097152;Jm(a,b,255,0);if(!(w[d+1075081|0]&2)){break a}a=a+1298260|0;if(!Bd(a)){break a}Mi(v[a>>2],b,0)}}function Tla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=gb-1120|0;gb=e;c=gb-32|0;gb=c;WU(c+24|0,e+8|0);g=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;qd(c+16|0,d,c);f=xb(c+16|0);if((f|0)==(g|0)){cd(d,xb(c+24|0))}gb=c+32|0;d=-1;a:{if((f|0)!=(g|0)){break a}d=0;if(!ZU(e+8|0)){break a}d=Ne(a,b,YU(e+8|0),jb)}gb=e+1120|0;return d|0}function Mda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=Di(a,b,c,d);v[a>>2]=50024;d=nc(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=0;e=a,f=uf(c),v[e+4232>>2]=f;PY(a+4260|0,80,150,80,255);v[22640]=0;W(1536,a+44|0,2,2)|0;c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}v[22640]=0;Vh(b);c=v[22640];v[22640]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Lc(d);hf(b);S(a|0);L()}function EU(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28486832|w[a+63|0]!=26|(w[a+66|0]|(w[a+65|0]!=1?w[a+65|0]!=16:0))){break a}if(w[a- -64|0]&3){break a}b=a+78|0;if((w[b|0]|w[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((w[a|0]|w[a+1|0]<<8)>>>0>127){break a}c=gb-16|0;gb=c;d=bE(b,a);gb=c+16|0;a=d?a:b;return(w[a|0]|w[a+1|0]<<8)!=0}return 0}function aq(a,b){var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[wb(a)>>2]){iI(a,b);return}c=gb-32|0;gb=c;e=a;d=wb(a);a=dh(c+8|0,vh(a,pc(a)+1|0),pc(a),d);f=v[a+8>>2];v[22640]=0;dl(d,f,b);b=v[22640];v[22640]=0;a:{b:{if((b|0)==1){break b}v[a+8>>2]=v[a+8>>2]+1;v[22640]=0;R(162,e|0,a|0);b=v[22640];v[22640]=0;if((b|0)==1){break b}ae(a);gb=c+32|0;break a}b=P()|0;O()|0;ae(a);S(b|0);L()}}function Nfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;a:{a=v[a+1298424>>2];b:{if(a){kb[v[v[a>>2]+8>>2]](a,b,c);break b}v[d+8>>2]=0;if(!JF(au(d+8|0),b)){break b}v[d+8>>2]=0;au(d+8|0);v[d+24>>2]=0;a=au(d+24|0);gP(d+8|0,6328,8180,132,42);v[22640]=0;ha(33,a|0,d+8|0,b|0,10624,c|0);a=v[22640];v[22640]=0;if((a|0)==1){break a}}gb=d+32|0;return}a=P()|0;O()|0;S(a|0);L()}function Naa(a){a=a|0;var b=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}Zb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,6127,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function vl(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=gb-32|0;gb=c;f=uc(c+24|0,v[a>>2]);d=v[e+8>>2];g=v[d+4>>2];d=v[d>>2];v[c+16>>2]=d;v[c+20>>2]=g;h=v[f+4>>2];v[c+8>>2]=v[f>>2];v[c+12>>2]=h;v[c>>2]=d;v[c+4>>2]=g;f=Fc(c+8|0,c);gb=c+32|0;if(f){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}gb=e+16|0;return a}function pN(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=gb-16|0;gb=c;e=0;a:{if(!Tf(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;Bk(a,c+12|0);d=v[c+12>>2];e=0;if(d>>>0>65535){break a}El(b,d);if(v[c+12>>2]){d=0;while(1){v[c+8>>2]=0;qq(a,c+8|0);f=z[c+8>>2];g=Mb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<y[c+12>>2]){continue}break}}e=Tf(v[v[a>>2]-12>>2]+a|0)}d=e;gb=c+16|0;return d}function oN(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=gb-16|0;gb=c;e=0;a:{if(!Tf(v[v[a>>2]-12>>2]+a|0)){break a}u[c+14>>1]=0;Xf(a,c+14|0);d=x[c+14>>1];e=0;if(d>>>0>65535){break a}El(b,d);if(x[c+14>>1]){d=0;while(1){v[c+8>>2]=0;qq(a,c+8|0);f=z[c+8>>2];g=Mb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}e=Tf(v[v[a>>2]-12>>2]+a|0)}a=e;gb=c+16|0;return a}function nA(a,b,c,d){var e=0,f=0;e=gb-32|0;gb=e;a:{if(v[b+480180>>2]&64671904){b=w[c+4|0];t[e+31|0]=0;u[a>>1]=w[(b&15)+39472|0];t[a+2|0]=w[e+31|0];break a}t[e+30|0]=0;f=w[c+4|0];if(!(w[c+3|0]!=4|v[b+480180>>2]!=4)){t[e+30|0]=1;f=f<<1}Db(e+16|0,b+1074312|0,66);if(!(!Cb(e+16|0)|!d)){u[e+14>>1]=0;hC(a,e+14|0,e+30|0);break a}u[e+12>>1]=f<<4;hC(a,e+12|0,e+30|0)}gb=e+32|0}function Am(a){if((a|0)>=0){if((a|0)<=16383){if((a|0)<=15){return t[a+69472|0]}if((a|0)<=511){return t[(a>>>5|0)+69472|0]+5|0}return t[(a>>>10|0)+69472|0]+10|0}if((a|0)<=16777215){if((a|0)<=524287){return t[(a>>>15|0)+69472|0]+15|0}return t[(a>>>20|0)+69472|0]+20|0}if((a|0)<=536870911){return t[(a>>>25|0)+69472|0]+25|0}a=t[(a>>>30|0)+69472|0]+30|0}else{a=0}return a}function Paa(a){a=a|0;var b=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return ie(a)|0}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,9479,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();return 0}return ie(18693)|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function mea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,52)+f;a:{a=v[d>>2];if((a|0)!=v[d+4>>2]){while(1){v[22640]=0;R(1493,a|0,c|0);a=v[22640];v[22640]=0;if((a|0)==1){break a}a=v[d>>2]+52|0;v[d>>2]=a;if(v[d+4>>2]!=(a|0)){continue}break}}Yc(d);gb=e+16|0;return}a=P()|0;O()|0;Yc(d);S(a|0);L()}function K2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[ec(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=v[b>>2];i=v[a>>2];g=Wp((f|0)==2485?0:v[a>>2],d);if(g){if((f|0)!=2485){$d(a)}v[e+4>>2]=2434;f=ge(e+8|0,g,e+4|0);_G(a,f);Gc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=v[a>>2]+(d&-4);gb=e+16|0;return}Ns();L()}function gW(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;v[f+12>>2]=a;d=B(B(a,d),2500);a:{if(!(!c|b)){break a}if(!(!b|!a)){tc(f+12|0,10);d=B(w[v[f+12>>2]+29392|0],1e4);break a}e=+(a>>>0);b:{if(a-1>>>0<=9){e=7338401.379310345/e;if(!(e<4294967296&e>=0)){break b}d=~~e>>>0;break a}e=e*37878.78787878787;if(!(e<4294967296&e>=0)){break b}d=~~e>>>0;break a}d=0}gb=f+16|0;return d}function HJ(a,b){a=a|0;b=+b;var c=0,d=0;c=gb-16|0;gb=c;a:{b:{c:{if(b<=1?b<0:1){a=aa(8)|0;v[22640]=0;c=Q(112,c|0,9056)|0;d=v[22640];v[22640]=0;if((d|0)==1){break c}qc(a,c);v[22640]=0;U(223,a|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}d=P()|0;O()|0;vb(c);break b}d=xh(b*256);v[v[a+32>>2]+1074456>>2]=d;gb=c+16|0;return}d=P()|0;O()|0;da(a|0)}S(d|0)}L()}function GF(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=119304647;v[22640]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22640];v[22640]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=Yk(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function fY(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=89478485;v[22640]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22640];v[22640]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=on(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function eka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=119304647;v[22640]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22640];v[22640]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Rc();L()}c=b;if(c>>>0>=119304648){nd(8513);L()}c=Mc(B(c,36),4);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,36)|0,v[f>>2]=g}function Lq(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+810|0]=w[b+810|0]&15|c<<4;break a}c=w[b+810|0]>>>4|0;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function lpa(a){a=a|0;var b=0,c=0,d=0,e=0;c=mh(a);v[22640]=0;_(537,a|0);d=v[22640];v[22640]=0;if((d|0)!=1){d=gb-16|0;gb=d;c=d;v[c>>2]=a;b=v[a+4>>2];v[c+4>>2]=b;v[c+8>>2]=b+32768;b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){u[b>>1]=0;u[b+2>>1]=0;b=b+4|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return a|0}a=P()|0;O()|0;WC(c);S(a|0);L()}function L2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[ec(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:1;h=v[b>>2];i=v[a>>2];g=Wp((f|0)==2485?0:v[a>>2],d);if(g){if((f|0)!=2485){$d(a)}v[e+4>>2]=2434;f=ge(e+8|0,g,e+4|0);_G(a,f);Gc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=d+v[a>>2];gb=e+16|0;return}Ns();L()}function nL(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=v[d+8>>2];b:{c:{e=v[a>>2];f=Lf(e);if((f|0)==(Ab(c)|0)){v[22640]=0;c=ga(571,c|0,0,-1,e|0,f|0)|0;e=v[22640];v[22640]=0;if((e|0)==1){break c}c=!c}else{c=0}break b}V(0)|0;O()|0;Bb();L()}if(c){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}gb=d+16|0;return a}function cka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=4925421;v[22640]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22640];v[22640]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Rc();L()}c=b;if(c>>>0>=4925422){nd(8513);L()}c=Mc(B(c,872),8);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,872)|0,v[f>>2]=g}function Dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=477218588;v[22640]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22640];v[22640]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Rc();L()}c=b;if(c>>>0>=477218589){nd(8513);L()}c=Mc(B(c,9),1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,9)|0,v[f>>2]=g}function Apa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=715827882;v[22640]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22640];v[22640]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Rc();L()}c=b;if(c>>>0>=715827883){nd(8513);L()}c=Mc(B(c,6),1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=c+B(b,6)|0,v[f>>2]=g}function VI(a,b){a:{if((b|0)>=128){a=C(a*C(1.7014118346046923e38));if((b|0)<255){b=b-127|0;break a}a=C(a*C(1.7014118346046923e38));b=((b|0)<381?b:381)-254|0;break a}if((b|0)>-127){break a}a=C(a*C(1.1754943508222875e-38));if((b|0)>-253){b=b+126|0;break a}a=C(a*C(1.1754943508222875e-38));b=((b|0)>-378?b:-378)+252|0}return C(a*(l(2,(b<<23)+1065353216|0),q()))}function Nla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;ug(c+24|0,a);XU(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;b=gb-16|0;gb=b;a=1;d=c;e=c+8|0;if(v[e+4>>2]==v[c+4>>2]){f=v[d+4>>2];a=b;d=v[d>>2];v[a>>2]=d;v[a+4>>2]=f;v[a+8>>2]=d;v[a+12>>2]=f;a=(GW(e,a)|0)!=0}gb=b+16|0;gb=c+32|0;return a|0}function MJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b-32>>>0>=481){b=aa(8)|0;v[22640]=0;c=Q(112,c|0,6538)|0;a=v[22640];v[22640]=0;if((a|0)==1){break c}qc(b,c);v[22640]=0;U(223,b|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);gb=c+16|0;return}a=P()|0;O()|0;da(b|0)}S(a|0)}L()}function MY(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=2147483647;v[22640]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22640];v[22640]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=Lg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function hD(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=153391689;v[22640]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22640];v[22640]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=Wi(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function Uoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=gb-224|0;gb=e;c=gb-32|0;gb=c;wX(c+24|0,e);g=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;d=a;qd(c+16|0,d,c);f=xb(c+16|0);if((f|0)==(g|0)){cd(d,xb(c+24|0))}gb=c+32|0;d=-1;a:{if((f|0)!=(g|0)){break a}d=0;if(!AX(e)){break a}d=Ne(a,b,zX(e),jb)}gb=e+224|0;return d|0}function BO(a,b){var c=0,d=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,872)+a|0;d=w[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}c=t[c+1075785|0];if((c|0)>=0){xP(a,b,(d|0)==32,((w[(B(b,872)+a|0)+1075836|0]<<5)+a|0)+901692|0,c&255);return}xP(a,b,(d|0)==32,(((c&127)<<5)+a|0)+902204|0,0)}}function BB(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=gb-16|0;gb=b;v[b+12>>2]=357913941;v[22640]=0;v[b+8>>2]=2147483647;e=Fb(b+12|0,b+8|0);f=v[22640];v[22640]=0;a:{if((f|0)!=1){gb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>=d>>>0){a=qg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function $s(a,b,c,d){var e=0,f=0;e=gb-160|0;gb=e;hc(e+8|0,74072,144);a:{b:{if(b-1>>>0>=2147483647){if(b){break b}b=1;a=e+159|0}v[e+52>>2]=a;v[e+28>>2]=a;f=-2-a|0;b=b>>>0>f>>>0?f:b;v[e+56>>2]=b;a=a+b|0;v[e+36>>2]=a;v[e+24>>2]=a;a=ZI(e+8|0,c,d,2266,2267);if(!b){break a}b=v[e+28>>2];t[b-((b|0)==v[e+24>>2])|0]=0;break a}v[115121]=61;a=-1}gb=e+160|0;return a}function uz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=F(c,.999);c=d*32768;h=d*3.141592653589793;i=vq(b);while(1){j=a;k=c;g=((e<<12^-1)&28672)+(e>>>3|0)|0;if((g|0)!=16384){f=+(g-16384|0);d=f*.000244140625;f=vq(K(f*-152587890625e-16*d+1)*b);d=h*d;d=f*pi(d)/(d*i)}else{d=1}l=j,m=KT(k*d),u[l>>1]=m;a=a+2|0;e=e+1|0;if((e|0)!=32768){continue}break}}function LD(a){var b=0,c=0,d=0,e=0,f=0;b=a+9|0;d=w[b|0]|w[b+1|0]<<8;c=mqa(w[a+3|0],0,18,0);d=d+c|0;b=jb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;b=a+6|0;c=w[b|0]|w[b+1|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=a+4|0;a=w[a|0]|w[a+1|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;if(b>>>0<3){a=a+1|0}jb=a;return b}function vna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c;e=b;if(qW(b,c+24|0)){b=c+26|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)}else{b=0}rd(d,e,b);b=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24;b=w[c+28|0]|w[c+29|0]<<8;t[a+4|0]=b;t[a+5|0]=b>>>8;Wk(a+8|0,c);yb(c);gb=c+32|0}function fV(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=kb[a|0](b)|0;d=jb;f=d;if((d|0)<0){break b}if((kb[c|0](b,0,0,0)|0)<=-1){break a}if((kb[c|0](b,0,0,2)|0)<=-1){break a}d=kb[a|0](b)|0;a=jb;kb[c|0](b,e,f,0)|0;if((a|0)<0){break b}g=jC(d,a)}return g}kb[c|0](b,e,f,0)|0;return 0}function dz(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(w[b|0]|(e-5&255)>>>0>1){break a}t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=42;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=42;t[b|0]=w[d|0]}t[c|0]=0}}function NJ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{b:{c:{if(b-1>>>0>=65535){b=aa(8)|0;v[22640]=0;c=Q(112,c|0,2940)|0;a=v[22640];v[22640]=0;if((a|0)==1){break c}qc(b,c);v[22640]=0;U(223,b|0,55256,1936);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);break b}v[v[a+32>>2]+1074416>>2]=b;gb=c+16|0;return}a=P()|0;O()|0;da(b|0)}S(a|0)}L()}function vda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<11)+e;a:{if(v[c>>2]!=v[c+4>>2]){while(1){a=v[c>>2];v[22640]=0;Sy(a);a=v[22640];v[22640]=0;if((a|0)==1){break a}a=v[c>>2]+2048|0;v[c>>2]=a;if((a|0)!=v[c+4>>2]){continue}break}}Yc(c);gb=d+16|0;return}a=P()|0;O()|0;Yc(c);S(a|0);L()}function Wq(a,b){var c=0,d=0;a:{if(a-1>>>0<=268435455){a=a+208|0;mqa(b,0,a,0);a=jb?0:B(a,b);break a}a=0}b:{if(!a){break b}v[22640]=0;b=T(2410,a|0)|0;c=v[22640];v[22640]=0;c:{d:{if((c|0)==1){b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;X(20);c=v[22640];v[22640]=0;b=0;if((c|0)==1){break d}}break c}V(0)|0;O()|0;Bb();L()}if(!b){break b}d=Qb(b,0,a)- -64|0}return d}function lea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-16|0;gb=b;u[a>>1]=0;c=nc(a+4|0);d=nc(a+16|0);v[a+36>>2]=0;e=Kb(a+40|0);f=Ck(a+52|0);Cg(c);u[a+28>>1]=65472;v[22640]=0;v[b+12>>2]=1065353216;R(1502,c|0,b+12|0);g=v[22640];v[22640]=0;if((g|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;Cg(d);gb=b+16|0;return a|0}a=P()|0;O()|0;WW(f);vb(e);Lc(d);Lc(c);S(a|0);L()}function lU(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if(w[a+30|0]!=2|((b|0)!=2?(b|0)!=26:0)){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if((b|0)!=88?b>>>0>=65:0){break a}b=a+28|0;a=a+20|0;while(1){c=w[a|0]-32|0;if((c&255)>>>0<=94){a=a+1|0;if((b|0)!=(a|0)){continue}}break}c=(c&255)>>>0<95}return c}function h7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Tg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;cK(a,c);gb=c+16|0}function a7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Tg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;ZJ(a,c);gb=c+16|0}function Z6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Tg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;WJ(a,c);gb=c+16|0}function T6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=C(0),g=0,h=0;c=gb-16|0;gb=c;f=z[a+24>>2];if(!(!v[b+8>>2]|f==C(1))){h=+f;while(1){d=0;if(v[b+4>>2]){while(1){g=Tg(b,d,e);A[g>>3]=A[g>>3]*h;d=d+1|0;if(d>>>0<y[b+4>>2]){continue}break}}e=e+1|0;if(e>>>0<y[b+8>>2]){continue}break}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;RJ(a,c);gb=c+16|0}function Saa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22640]=0;_(1934,a|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,10427,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function tQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(zb(w[b|0])+g|0)+(zb(w[b+1|0])<<8)|0;u[a>>1]=g;d=(zb(w[b+2|0])+d|0)+(zb(w[b+3|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<2}function spa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{e=de(a);b:{if(e>>>0>1){break b}c:{if(e){v[22640]=0;U(529,d|0,a|0,c|0);a=v[22640];v[22640]=0;if((a|0)!=1){lp(b,d);gc(d);break c}a=V(27860)|0;if((O()|0)!=(ea(27860)|0)){break a}Z(a|0)|0;$();break b}if(!Pb(a,c)){break b}SX(a,b,c)}f=pc(b)>>>0>=c>>>0}gb=d+16|0;return f|0}S(a|0);L()}function qQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(zb(w[b+1|0])+g|0)+(zb(w[b|0])<<8)|0;u[a>>1]=g;d=(zb(w[b+3|0])+d|0)+(zb(w[b+2|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<2}function Em(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=gb-16|0;gb=h;if(-17-b>>>0>=c>>>0){i=Jb(a);k=a;a:{if(b>>>0<2147483623){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;c=Xk(v[Jc(h+12|0,h+8|0)>>2]);break a}c=-18}j=c+1|0;c=mi(k,j);if(e){Ng(c,i,e)}d=d-(e+f|0)|0;if(d){Ng((c+e|0)+g|0,(e+i|0)+f|0,d)}b=b+1|0;if((b|0)!=11){al(a,i,b)}bf(a,c);ng(a,j);gb=h+16|0;return}_f();L()}function Aba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Di(a,b,c,d);v[a+4272>>2]=1065353216;v[a>>2]=53152;v[a+4216>>2]=1056964608;v[a+4208>>2]=1056880300;v[a+4212>>2]=1050733080;v[22640]=0;W(1536,a+44|0,2,2)|0;c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}v[22640]=0;Vh(b);c=v[22640];v[22640]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;hf(b);S(a|0);L()}function kba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c+1|0]&4)){break a}c=v[c+4>>2];g=d,h=wd(b),v[g+8>>2]=h;b:{if(!Ab(b)){break b}if(w[mc(b,0)|0]!=(ag(43)&255)){if(w[mc(b,0)|0]!=(ag(45)&255)){break b}}c=c+1|0;Me(d+8|0)}if(Ab(b)>>>0>=c>>>0){break a}e=Fd(d,d+8|0);f=Ab(b);uy(b,v[e>>2],c-f|0,ag(48))}Dc(a,b);gb=d+16|0}function _y(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;d=f;v[d>>2]=a;e=v[a+4>>2];v[d+4>>2]=e;v[d+8>>2]=e+B(b,52);a:{b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){wb(a);v[22640]=0;R(1493,b|0,c|0);e=v[22640];v[22640]=0;if((e|0)==1){break a}b=b+52|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=f+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function _na(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[b>>2];e=v[b>>2]+xb(b)|0;f=Gg(a);v[22640]=0;b=fi(d,e);c=v[22640];v[22640]=0;a:{b:{if((c|0)==1){break b}if(!b){break a}v[22640]=0;R(38,a|0,b|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}v[22640]=0;Y(685,a|0,d|0,e|0,b|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;mn(f);S(a|0);L()}}function Un(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;Ec(d+8|0,b);v[22640]=0;b=T(2459,d+8|0)|0;e=v[22640];v[22640]=0;a:{if((e|0)==1){break a}v[22640]=0;e=T(2468,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break a}v[c>>2]=e;v[22640]=0;R(2469,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break a}Vb(d+8|0);gb=d+16|0;return}a=P()|0;O()|0;Vb(d+8|0);S(a|0);L()}function T5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=gb-16|0;gb=f;v[f+8>>2]=e;v[f+12>>2]=c;c=Ab(a);if(!((e|0)==-1|c>>>0<b>>>0)){v[f>>2]=c-b;g=f,h=v[Fb(f+12|0,f)>>2],v[g+4>>2]=h;b=po(Jb(a)+b|0,d,v[Fb(f+4|0,f+8|0)>>2]);a:{if(b){break a}b=-1;a=v[f+4>>2];c=v[f+8>>2];if(a>>>0<c>>>0){break a}b=a>>>0>c>>>0}gb=f+16|0;return b|0}_n();L()}function Gda(a,b){a=a|0;b=b|0;var c=0;a:{b:{if((pc(v[a+20>>2]+4|0)|0)!=8){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=v[v[a+20>>2]+4>>2];c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=c;v[a+4264>>2]=b;break a}Py(a,b)}Qt(a)}function E_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=gb-16|0;gb=g;f=gb-16|0;gb=f;e=gb-16|0;gb=e;v[f+4>>2]=1;i=f,j=Mc(32,4),v[i+8>>2]=j;gb=e+16|0;e=f;h=v[e+8>>2];v[22640]=0;ca(260,h|0,b|0,c|0,d|0)|0;b=v[22640];v[22640]=0;a:{if((b|0)!=1){b=a;a=Kp(e);Bw(b,cc(a),a);pF(e);gb=f+16|0;break a}a=P()|0;O()|0;pF(e);S(a|0);L()}gb=g+16|0}function Bma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,24);b=c;a:{a=v[c+4>>2];c=v[c+8>>2];if((a|0)!=(c|0)){while(1){v[22640]=0;_(795,a|0);e=v[22640];v[22640]=0;if((e|0)==1){break a}a=a+24|0;v[b+4>>2]=a;if((a|0)!=(c|0)){continue}break}}$b(b);gb=d+16|0;return}a=P()|0;O()|0;$b(b);S(a|0);L()}function apa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a=nc(a);e=d,f=Sb(b),v[e+8>>2]=f;e=d,f=Wb(b),v[e>>2]=f;a:{if(Gb(d+8|0,d)){while(1){b=v[d+8>>2];if((FY(b)|0)==(c|0)){v[22640]=0;R(556,a|0,wb(b)|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}}pp(d+8|0);if(Gb(d+8|0,d)){continue}break}}gb=d+16|0;return}b=P()|0;O()|0;fd(a);S(b|0);L()}function Wn(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;Ec(d+8|0,b);v[22640]=0;b=T(2430,d+8|0)|0;e=v[22640];v[22640]=0;a:{if((e|0)==1){break a}v[22640]=0;e=T(2442,b|0)|0;f=v[22640];v[22640]=0;if((f|0)==1){break a}t[c|0]=e;v[22640]=0;R(2443,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break a}Vb(d+8|0);gb=d+16|0;return}a=P()|0;O()|0;Vb(d+8|0);S(a|0);L()}function Kq(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+810|0];if(c){t[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function tI(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=gb-16|0;gb=f;if(1073741807-b>>>0>=c>>>0){g=Jb(a);i=a;a:{if(b>>>0<536870887){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;c=vm(v[Jc(f+12|0,f+8|0)>>2]);break a}c=1073741806}h=c+1|0;c=Li(i,h);if(e){wi(c,g,e)}d=d-e|0;if(d){e=e<<2;wi(e+c|0,e+g|0,d)}b=b+1|0;if((b|0)!=2){Wh(a,g,b)}bf(a,c);ng(a,h);gb=f+16|0;return}_f();L()}function cg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;c=a;a:{if(!De(b)){v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;break a}g=v[b>>2];b:{c:{d=v[b+4>>2];d:{if(d>>>0<=10){b=c;Ve(c,d);break d}if(d>>>0>4294967279){break c}f=Xk(d)+1|0;b=mi(c,f);bf(c,b);ng(c,f);ee(c,d)}Ng(b,g,d+1|0);break b}_f();L()}}gb=e+16|0;return a|0}function uQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b|0])|zb(w[b+1|0])<<8)^32768,u[f>>1]=g;f=a,g=(zb(w[b+2|0])|zb(w[b+3|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function rQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b+1|0])|zb(w[b|0])<<8)^32768,u[f>>1]=g;f=a,g=(zb(w[b+3|0])|zb(w[b+2|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function bka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,872);b=c;a:{a=v[c+4>>2];c=v[c+8>>2];if((a|0)!=(c|0)){while(1){v[22640]=0;GT(a);e=v[22640];v[22640]=0;if((e|0)==1){break a}a=a+872|0;v[b+4>>2]=a;if((a|0)!=(c|0)){continue}break}}$b(b);gb=d+16|0;return}a=P()|0;O()|0;$b(b);S(a|0);L()}function Sw(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];b:{if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if(v[a+48>>2]!=1){break a}if((d|0)==1){break b}break a}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}v[a+36>>2]=v[a+36>>2]+1}t[a+54|0]=1}}function Zaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c+1|0]&4)){break a}c=v[c+4>>2];g=d,h=wd(b),v[g+8>>2]=h;b:{if(!Ab(b)){break b}if(w[Jb(b)|0]!=(ag(43)&255)){if(w[Jb(b)|0]!=(ag(45)&255)){break b}}c=c+1|0;Me(d+8|0)}if(Ab(b)>>>0>=c>>>0){break a}e=Fd(d,d+8|0);f=Ab(b);UJ(b,v[e>>2],c-f|0,ag(48))}Dc(a,b);gb=d+16|0}function E8(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-32|0;gb=b;a=nc(a);v[22640]=0;R(2068,b+16|0,0);c=v[22640];v[22640]=0;a:{b:{if((c|0)!=1){c=Sb(b+16|0);d=Wb(b+16|0);e=v[yc(b+8|0,a)>>2];v[22640]=0;U(2069,c|0,d|0,e|0);c=v[22640];v[22640]=0;if((c|0)==1){break b}Lc(b+16|0);gb=b+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;Lc(b+16|0)}vd(a);S(c|0);L()}function Al(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;a:{if(!(w[c|0]&32)){break a}g=d,h=wd(b),v[g+8>>2]=h;g=d,h=df(b),v[g>>2]=h;if(!Gb(d+8|0,d)){break a}while(1){e=v[d+8>>2];c=t[e|0];f=ag(97);b:{if((c|0)<(f|0)){break b}if((ag(122)|0)<(c|0)){break b}g=e,h=ag(65)+(c-f|0)|0,t[g|0]=h}Me(d+8|0);if(Gb(d+8|0,d)){continue}break}}Dc(a,b);gb=d+16|0}function tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Di(a,b,c,d);c=a+4216|0;v[c>>2]=1051372203;v[c+4>>2]=0;v[a+4208>>2]=1065353216;v[a+4212>>2]=1065353216;v[a>>2]=53384;v[22640]=0;W(1536,a+44|0,2,2)|0;c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}v[22640]=0;Vh(b);c=v[22640];v[22640]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;hf(b);S(a|0);L()}function _U(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;e=w[b|0]|w[b+1|0]<<8;b=mqa(w[a+30|0],0,37,0);c=jb;d=b;b=a+24|0;b=mqa(w[b|0]|w[b+1|0]<<8,0,192,0);d=d+b|0;c=jb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;e=d;a=w[a+26|0];c=a>>>26|0;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;if(b>>>0<192){a=a+1|0}jb=a;return b}function CE(a){var b=0,c=0,d=0,e=0,f=0;a:{if(w[a+110|0]>64|((w[a|0]|w[a+1|0]<<8)!=20042?(w[a|0]|w[a+1|0]<<8)!=26217:0)|(t[a+112|0]<0|w[a+111|0]>128)){break a}while(1){e=0;d=a+c|0;b=t[d+113|0];f=(b|0)>-1;if(!((b&255)>>>0<254?f:1)){break a}b=w[d+241|0];if(!b&f|b>>>0>15|w[d+369|0]>=64){break a}e=1;c=c+1|0;if((c|0)!=128){continue}break}}return e}function uG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb+-64|0;gb=d;e=1;a:{if(Og(a,b,0)){break a}e=0;if(!b){break a}b=Vw(b,89420,89468);e=0;if(!b){break a}Qb(d+8|4,0,52);v[d+56>>2]=1;v[d+20>>2]=-1;v[d+16>>2]=a;v[d+8>>2]=b;kb[v[v[b>>2]+28>>2]](b,d+8|0,v[c>>2],1);a=v[d+32>>2];if((a|0)==1){v[c>>2]=v[d+24>>2]}e=(a|0)==1}a=e;gb=d- -64|0;return a|0}function o7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;a:{b:{if((xy(a)|0)!=1){break b}if((AK(a)|0)!=(b|0)){break b}d=a+120|0;yi(d);b=gb-16|0;gb=b;v[b+8>>2]=c+8;a=gb-16|0;gb=a;e=v[13992];v[a+8>>2]=v[13991];v[a+12>>2]=e;e=v[13990];v[a>>2]=v[13989];v[a+4>>2]=e;kb[v[Th(a,Vg(d))>>2]](b+8|0,d);gb=a+16|0;gb=b+16|0;break a}zK(a,1,b)}gb=c+16|0}function gm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=v[b+4>>2];b=v[b>>2];v[d+8>>2]=b;v[d+12>>2]=e;v[d+16>>2]=b;v[d+20>>2]=e;Lh(d+24|0,d+8|0);v[22640]=0;b=v[d+28>>2];v[d>>2]=v[d+24>>2];v[d+4>>2]=b;R(244,a|0,d|0);b=v[22640];v[22640]=0;if((b|0)!=1){v[a+8>>2]=0;gj(a+12|0,c);pe(c);gb=d+32|0;return a|0}a=P()|0;O()|0;pe(c);S(a|0);L()}function Taa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[22640]=0;_(1934,a|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:1919;return}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,10457,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Q4(a){a=a|0;a:{v[22640]=0;T(2385,462824)|0;a=v[22640];v[22640]=0;b:{if((a|0)==1){break b}v[22640]=0;T(2386,462908)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}v[22640]=0;T(2385,463160)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}v[22640]=0;T(2386,463244)|0;a=v[22640];v[22640]=0;if((a|0)==1){break b}break a}V(0)|0;O()|0;Bb();L()}}function oK(a,b,c){var d=0,e=0,f=0;a:{d=v[c>>2];c=a;e=mh(c);b:{if(!d){break b}v[22640]=0;R(2113,c|0,d|0);f=v[22640];v[22640]=0;if((f|0)!=1){v[22640]=0;nK(c,d);d=v[22640];v[22640]=0;if((d|0)!=1){break b}}a=P()|0;O()|0;Gl(e);S(a|0);L()}v[22640]=0;b=mK(b);d=v[22640];v[22640]=0;if((d|0)!=1){v[a+12>>2]=b;break a}a=P()|0;O()|0;Gl(c);S(a|0);L()}}function ila(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-160|0;gb=b;e=-1;c=gb-32|0;gb=c;f=b+8|0;xU(c+24|0,f);g=xb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(g|0)){cd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(g|0);if(!a){wU(f)}if(a){e=EU(b+8|0)}gb=b+160|0;return e|0}function Spa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-624|0;gb=b;e=-1;c=gb-32|0;gb=c;f=b+8|0;yY(c+24|0,f);g=xb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(g|0)){cd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(g|0);if(!a){xY(f)}if(a){e=zY(b+8|0)}gb=b+624|0;return e|0}function oha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;v[e+24>>2]=d;f=Zf(a,c);se(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!f){if(id(a,5)){break a}}g=v[a+28>>2];d=0;nE(b,v[e+24>>2]);if(v[e+24>>2]){while(1){PA(g,rc(b,d));d=d+1|0;if(d>>>0<y[e+24>>2]){continue}break}}}Sf(a,f,c,e+16|0);gb=e+32|0}function $i(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e307;if((b|0)<2047){b=b-1023|0;break a}a=a*8.98846567431158e307;b=((b|0)<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2.2250738585072014e-308;if((b|0)>-2045){b=b+1022|0;break a}a=a*2.2250738585072014e-308;b=((b|0)>-3066?b:-3066)+2044|0}l(0,0);l(1,b+1023<<20);return a*+n()}function u_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-32|0;gb=e;a:{if(y[b+16>>2]<=c>>>0){Uj(a,d,0);break a}f=v[b+4>>2];g=v[b+12>>2];h=e,i=xb(d),v[h+20>>2]=i;v[e+16>>2]=v[b+16>>2]-c;Uj(e+24|0,d,v[Fb(e+20|0,e+16|0)>>2]);b=v[v[f>>2]+28>>2];d=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=d;kb[b|0](a,f,c+g|0,e+8|0)}gb=e+32|0}function r2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;d=gb-16|0;gb=d;b=a;a:{if(!De(f)){v[b+8>>2]=v[f+8>>2];a=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=a;break a}e=v[f>>2];b:{c:{c=v[f+4>>2];d:{if(c>>>0<=1){Ve(a,c);break d}if(c>>>0>1073741807){break c}f=vm(c)+1|0;b=Li(a,f);bf(a,b);ng(a,f);ee(a,c)}wi(b,e,c+1|0);break b}_f();L()}}gb=d+16|0}function ipa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-32|0;gb=b;e=-1;c=gb-32|0;gb=c;f=b+8|0;uv(c+24|0,f);g=xb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(g|0)){cd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(g|0);if(!a){NX(f)}if(a){e=PX(b+8|0)}gb=b+32|0;return e|0}function i5(a,b){a=a|0;b=b|0;var c=0;c=v[a+24>>2];if(c>>>0>y[a+44>>2]){v[a+44>>2]=c}a:{if(y[a+8>>2]>=y[a+12>>2]){break a}if(He(b,-1)){Zn(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);return Ss(b)|0}if(!(w[a+48|0]&16)){if(!He(oh(b),t[v[a+12>>2]-1|0])){break a}}Zn(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);c=oh(b);t[v[a+12>>2]]=c;return b|0}return-1}function Ina(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-16|0;gb=b;e=-1;c=gb-32|0;gb=c;f=b+8|0;Qv(c+24|0,f);g=xb(c+24|0);d=v[c+28>>2];h=v[c+24>>2];v[c+8>>2]=h;v[c+12>>2]=d;v[c>>2]=h;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(g|0)){cd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(g|0);if(!a){rW(f)}if(a){e=BW(b+8|0)}gb=b+16|0;return e|0}function IA(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function mq(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;t[d+15|0]=b;a:{b:{c:{d:{if(De(a)){c=ck(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=10;b=w[a+11|0];if((b|0)!=10){break c}}Em(a,c,1,c,c,0,0);b=c;if(De(a)){break b}}c=a;Ve(a,b+1|0);break a}c=v[a>>2];ee(a,b+1|0)}a=b+c|0;zd(a,d+15|0);t[d+14|0]=0;zd(a+1|0,d+14|0);gb=d+16|0}function Iha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;tk(a);i=v[b+4>>2];f=b+4|0;xk(wb(a),v[a>>2],c,f);j=wb(a);g=b+8|0;d=g;h=v[a+4>>2];if((h|0)!=(c|0)){e=v[d>>2];while(1){gn(j,e,c);e=v[d>>2]+4|0;v[d>>2]=e;c=c+4|0;if((h|0)!=(c|0)){continue}break}}jc(a,f);jc(a+4|0,g);jc(wb(a),cc(b));v[b>>2]=v[b+4>>2];Lm(a,Nb(a));return i|0}function su(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=d+8|0;b=gb-16|0;gb=b;v[22640]=0;c=a;YQ(c+4|0);f=v[22640];v[22640]=0;a:{b:{c:{if((f|0)!=1){v[22640]=0;v[b+12>>2]=0;cf(c+8|0,b+12|0,e);e=v[22640];v[22640]=0;if((e|0)!=1){break c}break b}break b}g=c,h=ec(c),v[g>>2]=h;gb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}gb=d+16|0;return a}function Xoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;e=v[b>>2];f=v[b+8>>2];b=v[c+4>>2];c=v[c>>2];v[d+16>>2]=c;v[d+20>>2]=b;v[d+24>>2]=c;v[d+28>>2]=b;Lh(d+32|0,d+16|0);b=v[v[e>>2]+28>>2];c=v[d+36>>2];v[d+8>>2]=v[d+32>>2];v[d+12>>2]=c;kb[b|0](d+40|0,e,f,d+8|0);b=v[d+44>>2];v[d>>2]=v[d+40>>2];v[d+4>>2]=b;Lh(a,d);gb=d+48|0}function Q5(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{b:{c:{d:{if(De(a)){c=ck(a);b=v[a+4>>2];c=c-1|0;if((b|0)==(c|0)){break d}break b}c=1;b=w[a+11|0];if((b|0)!=1){break c}}tI(a,c,1,c,c);b=c;if(De(a)){break b}}c=a;Ve(a,b+1|0);break a}c=v[a>>2];ee(a,b+1|0)}a=(b<<2)+c|0;Fe(a,d+12|0);v[d+8>>2]=0;Fe(a+4|0,d+8|0);gb=d+16|0}function GH(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-16|0;gb=b;e=b+16|0;a:{while(1){c=v[a+36>>2];f=kb[v[v[c>>2]+20>>2]](c,v[a+40>>2],b+8|0,e,b+4|0)|0;c=-1;d=v[b+4>>2]-(b+8|0)|0;if((d|0)!=(Ek(b+8|0,1,d,v[a+32>>2])|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}c=ht(v[a+32>>2])?-1:0}gb=b+16|0;return c|0}function hf(a){a=a|0;var b=0,c=0;v[a>>2]=50492;b=v[a+12>>2];if(v[b>>2]==(a|0)){v[b>>2]=v[a+4>>2]}b=v[a+20>>2];if(b){v[b>>2]=0;v[a+20>>2]=0}b=v[a+4>>2];if(b){v[b+8>>2]=v[a+8>>2]}c=v[a+8>>2];if(c){v[c+4>>2]=b}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+16>>2];v[b+946300>>2]=v[b+946300>>2]-1;b=a+44|0;Lc(b+36|0);Lc(b+24|0);Lt(b+12|0);Lt(b);return a|0}function Vr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;d=Jb(b);e=Jb(b);g=c,h=Ab(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;Bg(d,e+v[Fb(c+12|0,c+8|0)>>2]|0,v[a>>2]);d=v[a>>2];g=c,h=Ab(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;b=v[Fb(c+12|0,c+8|0)>>2];e=v[a+4>>2];f=v[a>>2];t[c+7|0]=0;no(b+d|0,e+f|0,c+7|0);gb=c+16|0;return a|0}function soa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-32|0;gb=d;tC(d+16|0,c);v[22640]=0;ij(d+8|0,d+16|0);c=v[22640];v[22640]=0;b:{if((c|0)==1){break b}v[22640]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(183,a|0,b|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function ooa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-32|0;gb=d;Nn(d+16|0,c);v[22640]=0;ij(d+8|0,d+16|0);c=v[22640];v[22640]=0;b:{if((c|0)==1){break b}v[22640]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(183,a|0,b|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function fma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-32|0;gb=d;lq(d+16|0,c);v[22640]=0;ij(d+8|0,d+16|0);c=v[22640];v[22640]=0;b:{if((c|0)==1){break b}v[22640]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(480,a|0,b|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function dK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ul(v[a+8>>2]);yi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14226];v[c+8>>2]=v[14225];v[c+12>>2]=g;g=v[14224];v[c>>2]=v[14223];v[c+4>>2]=g;kb[v[Th(c,Vg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function cK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ul(v[a+8>>2]);yi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14230];v[c+8>>2]=v[14229];v[c+12>>2]=g;g=v[14228];v[c>>2]=v[14227];v[c+4>>2]=g;kb[v[Th(c,Vg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function _J(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ul(v[a+8>>2]);yi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14431];v[c+8>>2]=v[14430];v[c+12>>2]=g;g=v[14429];v[c>>2]=v[14428];v[c+4>>2]=g;kb[v[Th(c,Vg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function ZJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ul(v[a+8>>2]);yi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14435];v[c+8>>2]=v[14434];v[c+12>>2]=g;g=v[14433];v[c>>2]=v[14432];v[c+4>>2]=g;kb[v[Th(c,Vg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function Xpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-32|0;gb=d;Jh(d+16|0,c);v[22640]=0;ij(d+8|0,d+16|0);c=v[22640];v[22640]=0;b:{if((c|0)==1){break b}v[22640]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(480,a|0,b|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function XJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ul(v[a+8>>2]);yi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14638];v[c+8>>2]=v[14637];v[c+12>>2]=g;g=v[14636];v[c>>2]=v[14635];v[c+4>>2]=g;kb[v[Th(c,Vg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function WJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ul(v[a+8>>2]);yi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14642];v[c+8>>2]=v[14641];v[c+12>>2]=g;g=v[14640];v[c>>2]=v[14639];v[c+4>>2]=g;kb[v[Th(c,Vg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function Soa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-160|0;gb=b;e=-1;c=gb-32|0;gb=c;h=b;uX(c+24|0,b);f=xb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(f|0)){cd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(f|0);if(!a){tX(h)}if(a){e=vX(b)}gb=b+160|0;return e|0}function SJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ul(v[a+8>>2]);yi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14845];v[c+8>>2]=v[14844];v[c+12>>2]=g;g=v[14843];v[c>>2]=v[14842];v[c+4>>2]=g;kb[v[Th(c,Vg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function RJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;v[d+8>>2]=a;f=ul(v[a+8>>2]);yi(f);e=gb-16|0;gb=e;v[e+8>>2]=d+8;c=gb-16|0;gb=c;g=v[14849];v[c+8>>2]=v[14848];v[c+12>>2]=g;g=v[14847];v[c>>2]=v[14846];v[c+4>>2]=g;kb[v[Th(c,Vg(f))>>2]](e+8|0,f);gb=c+16|0;gb=e+16|0;v[a+4>>2]=v[b+8>>2]+v[a+4>>2];gb=d+16|0}function Pka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-208|0;gb=b;e=-1;c=gb-32|0;gb=c;h=b;aU(c+24|0,b);f=xb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(f|0)){cd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(f|0);if(!a){$T(h)}if(a){e=iU(b)}gb=b+208|0;return e|0}function PN(a,b,c,d){var e=0,f=0,g=0;e=gb-32|0;gb=e;g=v[a+20>>2];f=x[a+34>>1];v[22640]=0;f=f&65;v[e+16>>2]=f;v[e+8>>2]=f^65;ka(1477,d|0,a|0,b|0,c|0,e+16|0,e+8|0);d=v[22640];v[22640]=0;a:{if((d|0)==1){break a}v[a>>2]=c;v[a+20>>2]=b;v[22640]=0;Xq(g);a=v[22640];v[22640]=0;if((a|0)==1){break a}gb=e+32|0;return}a=P()|0;O()|0;S(a|0);L()}function Mja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;bc(c+24|0,b,40);gb=d+16|0;d=xb(c+24|0);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;fc(c+16|0,a,c);e=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Qb(b,0,40);gb=c+16|0}return a|0}function Dla(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-48|0;gb=c;a:{if(Uu(a)>>>0<b>>>0){wb(a);d=Vu(c+32|0);v[22640]=0;R(851,d|0,b|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}yk(c+16|0,a);Rl(c+8|0,a);v[22640]=0;U(852,d|0,c+16|0,c+8|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}GB(a,d);Ce(d)}gb=c+48|0;return}a=P()|0;O()|0;Ce(d);S(a|0);L()}function tY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-32|0;gb=d;sD(d+16|0,c);v[22640]=0;ij(d+8|0,d+16|0);c=v[22640];v[22640]=0;b:{if((c|0)==1){break b}v[22640]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(183,a|0,b|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function kX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;bc(c+24|0,b,80);gb=d+16|0;d=xb(c+24|0);e=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=e;v[c>>2]=f;v[c+4>>2]=e;fc(c+16|0,a,c);e=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Qb(b,0,80);gb=c+16|0}return a|0}function iG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-32|0;gb=d;Jh(d+16|0,c);v[22640]=0;ij(d+8|0,d+16|0);c=v[22640];v[22640]=0;b:{if((c|0)==1){break b}v[22640]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(183,a|0,b|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function Xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;e=Pb(a,6);a:{if(e){d=gb-16|0;gb=d;bc(c+24|0,b,6);gb=d+16|0;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;d=gb-16|0;gb=d;f=b+6|0;while(1){Kf(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}gb=d+16|0;gb=a+16|0}gb=c+32|0;return e|0}function NZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-32|0;gb=d;_v(d+16|0,c);v[22640]=0;ij(d+8|0,d+16|0);c=v[22640];v[22640]=0;b:{if((c|0)==1){break b}v[22640]=0;c=v[d+12>>2];v[d>>2]=v[d+8>>2];v[d+4>>2]=c;U(183,a|0,b|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Hb(d+16|0);gb=d+32|0;break a}a=P()|0;O()|0;Hb(d+16|0);S(a|0);L()}}function vQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])|zb(w[b+1|0])<<8,u[f>>1]=g;f=a,g=zb(w[b+2|0])|zb(w[b+3|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function sQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b+1|0])|zb(w[b|0])<<8,u[f>>1]=g;f=a,g=zb(w[b+3|0])|zb(w[b+2|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function PZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=gb-48|0;gb=b;e=-1;c=gb-32|0;gb=c;h=b;_D(c+24|0,b);f=xb(c+24|0);d=v[c+28>>2];g=v[c+24>>2];v[c+8>>2]=g;v[c+12>>2]=d;v[c>>2]=g;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(f|0)){cd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(f|0);if(!a){ZD(h)}if(a){e=pE(b)}gb=b+48|0;return e|0}function LE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b+18|0;b=b+46|0;a=Pc(a,w[d|0]&2?16:8,1,0,(w[b|0]^-1)&1);if(!(!(w[d|0]&4)|c>>>0<532)){Bp(a,3)}a:{b:{if(w[d|0]&8){b=w[b|0]&4?5:4;break b}if(!(w[d|0]&2|w[b|0]!=255)){b=11;break b}if(w[b|0]&2){t[a+2|0]=1}if(w[b|0]&4){zf(a,2)}if(!(w[b|0]&8)){break a}b=9;if(!(w[d|0]&2)){break a}}zf(a,b)}}function zc(a,b){var c=0;c=gb-32|0;gb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=-2147483648;v[c+20>>2]=-1;v[22640]=0;v[c+8>>2]=2147483647;v[c+12>>2]=0;a=iv(c+24|0,c+8|0);b=v[22640];v[22640]=0;a:{if((b|0)==1){break a}v[22640]=0;a=fC(c+16|0,a);b=v[22640];v[22640]=0;if((b|0)==1){break a}gb=c+32|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function jM(a){var b=C(0),c=0,d=C(0),e=0;b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);c=a;d=C(v[a+4256>>2]<<1>>>0);b=C(z[a+4228>>2]*d);a:{if(b<C(4294967296)&b>=C(0)){e=~~b>>>0;break a}e=0}v[c+4248>>2]=e;c=a+4252|0;b=C(z[a+4232>>2]*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function Una(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;Ye(b);v[d+12>>2]=0;a:{if(!Bk(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+11|0]=0;if(!Qh(a,d+11|0)){break b}mq(b,t[d+11|0]);e=1;c=c+1|0;if((c|0)!=v[d+12>>2]){continue}break a}break}e=0}gb=d+16|0;return e|0}function Sna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;Ye(b);t[d+15|0]=0;a:{if(!Qh(a,d+15|0)){break a}f=c;c=w[d+15|0];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+14|0]=0;if(!Qh(a,d+14|0)){break b}mq(b,t[d+14|0]);e=1;c=c+1|0;if(w[d+15|0]!=(c&255)){continue}break a}break}e=0}gb=d+16|0;return e|0}function rM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=(uf(v[a+16>>2])|0)/5|0;b=zc(b,b>>31);v[a+4272>>2]=b;v[22640]=0;v[c+12>>2]=0;U(1544,a+4256|0,b<<1,c+12|0);b=v[22640];v[22640]=0;a:{if((b|0)==1){b=V(88880)|0;if((O()|0)!=(ea(88880)|0)){break a}Z(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;gb=c+16|0;return}S(b|0);L()}function pQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b|0]);g=a,h=ed(zb(w[b+1|0])<<16|f<<8|zb(w[b+2|0])<<24,16),u[g>>1]=h;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,3)|0}function oQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=(c>>>0)/3;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=zb(w[b+2|0]);g=a,h=ed(zb(w[b+1|0])<<16|f<<8|zb(w[b|0])<<24,16),u[g>>1]=h;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return B(e,3)|0}function Ux(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=gb-240|0;gb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((kb[b|0](a,f)|0)>=0){if((kb[b|0](a,e)|0)>-1){break a}}j=f;f=(kb[b|0](f,e)|0)>-1;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}NI(g,h);gb=g+240|0}function Hf(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;a:{if(y[b+8>>2]<c>>>0){v[22640]=0;Y(2120,14461,6285,394,3444);a=v[22640];v[22640]=0;if((a|0)==1){break a}L()}v[d+8>>2]=v[b+8>>2];e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=v[d+4>>2];v[a>>2]=v[d>>2];v[a+4>>2]=b;v[a+8>>2]=v[d+8>>2];v[a+12>>2]=c;gb=d+16|0;return}V(0)|0;O()|0;Bb();L()}function vX(a){a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28490681|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(w[a+76|0]|((w[a+71|0]|w[a+72|0]<<8|(w[a+73|0]<<16|w[a+74|0]<<24))!=1397116231|w[a+75|0]!=1)){break a}a=a+116|0;if((w[a|0]|w[a+1|0]<<8)>>>0>9){break a}return(w[a|0]|w[a+1|0]<<8)!=0}return 0}function Wla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;a:{if(!v[b+300>>2]){break a}if((kb[v[b+304>>2]](v[b+296>>2],c,0,0)|0)<0){break a}c=v[d>>2];f=xb(d);if(!f){break a}while(1){b:{e=kb[v[b+300>>2]](v[b+296>>2],c,f)|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;if(!e){break b}c=c+e|0;f=f-e|0;if(f){continue}}break}e=g}Uj(a,d,e)}function NI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=4;e=gb-256|0;gb=e;a:{if((b|0)<2){break a}h=(b<<2)+a|0;v[h>>2]=e;c=e;while(1){f=d>>>0<256?d:256;hc(c,v[a>>2],f);c=0;while(1){g=(c<<2)+a|0;c=c+1|0;hc(v[g>>2],v[(c<<2)+a>>2],f);v[g>>2]=v[g>>2]+f;if((b|0)!=(c|0)){continue}break}d=d-f|0;if(!d){break a}c=v[h>>2];continue}}gb=e+256|0}function sga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;b=cg(d,b);v[22640]=0;U(1180,d+16|0,b|0,c|0);e=v[22640];v[22640]=0;a:{b:{if((e|0)!=1){v[22640]=0;U(113,a|0,d+16|0,c|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}vb(d+16|0);vb(b);gb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+16|0)}vb(b);S(c|0);L()}function lQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=ed(zb(w[b|0])|zb(w[b+1|0])<<8|zb(w[b+2|0])<<16|zb(w[b+3|0])<<24,16),u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function kQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=ed(zb(w[b+3|0])|zb(w[b+2|0])<<8|zb(w[b+1|0])<<16|zb(w[b|0])<<24,16),u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<2}function Eka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!Ld(a)){break a}f=v[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break a}Ol(b);Zo(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!_m(b)){break a}if(v[a>>2]!=(d|0)){tw(b+68|0)}hc(zb(v[b+20>>2]),zb(v[a+20>>2])+c|0,d);v[b+8>>2]=e?d:0;v[b+4>>2]=0;u[b+34>>1]=x[b+34>>1]&65533|(e?2:0)}}function kE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;wb(b);f=dE(a,c+8|0);a:{d=Nb(b);if(!d){break a}v[22640]=0;R(367,a|0,d|0);e=v[22640];v[22640]=0;if((e|0)!=1){e=v[b+4>>2];b=v[b>>2];v[22640]=0;Y(371,a|0,b|0,e|0,d|0);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;pu(f);S(a|0);L()}gb=c+16|0;return a|0}function eda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=33;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=xf(a)}oC(d+24|0,b);e=Wd(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;fc(d+16|0,a,d+8|0);oC(d+24|0,b);Qb(v[d+24>>2]+c|0,0,33-c|0);Yb(a,v[d+44>>2]);gb=d+48|0;return c|0}function AS(){var a=0,b=0;a=gb-240|0;gb=a;a:{b:{if(t[90720]&1){break b}if(!Pd(90720)){break b}v[22640]=0;X(86);b=v[22640];v[22640]=0;if((b|0)==1){break a}v[22640]=0;_(87,a+120|0);b=v[22640];v[22640]=0;if((b|0)==1){break a}hc(90600,hc(a,a+120|0,120),116);Od(90720)}gb=a+240|0;return 90600}a=P()|0;O()|0;We(90720);S(a|0);L()}function Zda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Pk(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22640]=0;pq(d,f,c);d=v[22640];v[22640]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}Yc(b);gb=e+16|0;return}a=P()|0;O()|0;Yc(b);S(a|0);L()}function Rna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Pk(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22640]=0;Go(d,f,c);d=v[22640];v[22640]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}Yc(b);gb=e+16|0;return}a=P()|0;O()|0;Yc(b);S(a|0);L()}function Nna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=aB(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22640]=0;dl(d,f,c);d=v[22640];v[22640]=0;if((d|0)==1){break a}d=v[b>>2]+1|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}Yc(b);gb=e+16|0;return}a=P()|0;O()|0;Yc(b);S(a|0);L()}function $7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Gg(a);a:{c=v[b+4>>2];if(!c){break a}v[22640]=0;R(2087,a|0,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){c=v[b>>2];e=v[b>>2];f=B(v[b+4>>2],12);b=v[b+4>>2];v[22640]=0;Y(2088,a|0,c|0,e+f|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;iF(d);S(a|0);L()}return a|0}function gf(a,b,c,d){var e=0,f=0;a:{if(!Ab(a)|(c-b|0)<5){break a}Hs(b,c);e=Jb(a);f=Ab(a);a=c-4|0;b:{if(a>>>0>b>>>0){c=e+f|0;while(1){f=w[e|0];if((f|0)!=v[b>>2]?(f-1&255)>>>0<=125:0){break b}e=(c-e|0)>1?e+1|0:e;b=b+4|0;if(a>>>0>b>>>0){continue}break}}b=w[e|0];if((b-1&255)>>>0>125|b>>>0>v[a>>2]-1>>>0){break a}}v[d>>2]=4}}function fu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gb-16|0;gb=e;if(b){Db(e+8|0,a+1074312|0,73);k=Cb(e+8|0)?c- -64|0:c;i=qk(a);l=i^1;c=120;f=1;while(1){g=c>>>1|0;j=g+f|0;h=Yg(a,j,k,d);a:{if(!((h|0)!=0&l|b>>>0<=h>>>0?(h>>>0<=b>>>0|i)==1:0)){f=j+1|0;c=(g^-1)+c|0;break a}c=g}if(c){continue}break}}gb=e+16|0;return f}function T$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Og(a,v[b+8>>2],e)){Rw(b,c,d);return}a:{if(!Og(a,v[b>>2],e)){break a}if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function SZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=gb-16|0;gb=e;a:{b=Dn(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[22640]=0;yn(d,f,c);d=v[22640];v[22640]=0;if((d|0)==1){break a}d=v[b>>2]+2|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}Yc(b);gb=e+16|0;return}a=P()|0;O()|0;Yc(b);S(a|0);L()}function Jfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=gb-16|0;gb=b;d=a+1298260|0;if(!Bd(d)){f=b;c=gb-16|0;gb=c;e=rf(532);a=v[a+24620>>2];v[22640]=0;g=Q(1320,e|0,a|0)|0;a=v[22640];v[22640]=0;a:{if((a|0)!=1){a=v[Ni(c+8|0,g)>>2];gb=c+16|0;break a}a=P()|0;O()|0;Zb(e);S(a|0);L()}v[f+8>>2]=a;hP(d,$d(b+8|0));bu(b+8|0)}gb=b+16|0}function c$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;b=cg(d,b);v[22640]=0;U(213,d+16|0,b|0,c|0);e=v[22640];v[22640]=0;a:{b:{if((e|0)!=1){v[22640]=0;U(5,a|0,d+16|0,c|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}vb(d+16|0);vb(b);gb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vb(d+16|0)}vb(b);S(c|0);L()}function S6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Bt(a+60|0);v[a>>2]=77972;v[d>>2]=77992;v[22640]=0;e=a+8|0;W(148,a|0,78004,e|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){a:{v[a>>2]=77972;v[d>>2]=77992;v[22640]=0;W(149,e|0,b|0,c|8)|0;b=v[22640];v[22640]=0;if((b|0)==1){break a}return a|0}}a=P()|0;O()|0;lh(d);S(a|0);L()}function Pz(a,b){var c=0,d=0,e=0;XV(a);ip(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0;t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function eK(a,b,c,d,e){var f=0,g=0,h=0;if((e|0)!=10){f=c;while(1){a:{if((b|0)==(f|0)){f=b;g=d;break a}f=f-1|0;g=(d>>>0)/(e>>>0)|0;t[f|0]=w[(d-B(g,e)|0)+1991|0];h=d>>>0>=e>>>0;d=g;if(h){continue}}break}b:{if(!g){d=c-f|0;if(d){break b}}v[a+4>>2]=61;v[a>>2]=c;return}b=sh(b,f,d);v[a+4>>2]=0;v[a>>2]=b+d;return}Jy(a,b,c,d)}function FE(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;a:{if(!b){break a}if(!Pb(a,b)){break a}while(1){t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){Jg(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=c+16|0;return d}function SL(a){var b=0;v[a+4116>>2]=0;v[a+4132>>2]=0;v[a+4136>>2]=0;u[a+4128>>1]=0;v[a+4104>>2]=0;v[a+4108>>2]=0;b=a+4140|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4148|0;v[b>>2]=0;v[b+4>>2]=0;RL(a+4164|0);RL(a+4156|0);Gq(a+54060|0);Gq(a+62252|0);Gq(a+70444|0);Gq(a+78636|0);Qb(a+4332|0,0,32768);eB(a+37100|0);Qb(a+37612|0,0,16384)}function Eca(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=uf(v[a+16>>2]);b=zc(nqa(mqa(b,b>>31,3840,0),jb,1e3,0),jb);v[a+4276>>2]=b;v[22640]=0;v[c+12>>2]=0;U(1544,a+4260|0,b|0,c+12|0);b=v[22640];v[22640]=0;a:{if((b|0)==1){b=V(88880)|0;if((O()|0)!=(ea(88880)|0)){break a}Z(b|0)|0;v[a+4276>>2]=0;$()}gb=c+16|0;return}S(b|0);L()}function Ika(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){c=gb-16|0;gb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+12;UT(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+12;$b(c);gb=c+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=Nu(d+8|0,BB(a,Cc(a)+1|0),Cc(a),c);UT(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;dU(a,c);cU(c);gb=d+32|0}function up(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=ji(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22640]=0;yn(f,b,c);f=v[22640];v[22640]=0;if((f|0)==1){break a}b=b+2|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function iU(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=860902483){break a}b=a+4|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>2|w[a+6|0]>128){break a}b=a+200|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>3999){break a}b=a+140|0;if(!Ib(w[b|0]|w[b+1|0]<<8)){break a}a=a+148|0;return(Ib(w[a|0]|w[a+1|0]<<8)|0)==50}return 0}function hd(a,b){var c=0,d=0,e=0,f=0,g=0;d=b;b=uI(b);e=gb-16|0;gb=e;c=cq(a);a:{if(c>>>0>=b>>>0){f=Jb(a);g=f;c=b;b:{c:{if(b){v[22640]=0;JI(g,d,c);d=v[22640];v[22640]=0;if((d|0)==1){break c}}break b}V(0)|0;O()|0;Bb();L()}v[e+12>>2]=0;Fe((b<<2)+f|0,e+12|0);gh(a,b);break a}f=a;a=Ab(a);vI(f,c,b-c|0,a,0,a,b,d)}gb=e+16|0}function gE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=yg(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22640]=0;Go(f,b,c);f=v[22640];v[22640]=0;if((f|0)==1){break a}b=b+4|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function aK(a,b,c,d,e){var f=0,g=0;a:{f=a;if((e|0)!=10){a=c;while(1){b:{if((a|0)==(b|0)){a=b;break b}g=d&255;d=(g|0)/(e|0)|0;a=a-1|0;t[a|0]=w[(g-B(d,e)|0)+1991|0];if(d&255){continue}}break}c:{if(!(d&255)){d=c-a|0;if(d){break c}}v[f+4>>2]=61;v[f>>2]=c;break a}a=sh(b,a,d);v[f+4>>2]=0;v[f>>2]=a+d;break a}CL(f,b,c,d)}}function Lla(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;a:{if(!Rf(a,8)){break a}c=0;if(!Pv(a,11463,8)){break a}c=-1;if(!_j(a,b+8|0)){break a}a=b+8|4;c=0;if(!Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}c=!(Xb(w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))&-2139062144)}a=c;gb=b+16|0;return a|0}function Jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=4896;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=xf(a)}uC(d+24|0,b);e=Wd(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;fc(d+16|0,a,d+8|0);uC(d+24|0,b);Qb(v[d+24>>2]+c|0,0,4896-c|0);Yb(a,v[d+44>>2]);gb=d+48|0}function GC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Cr(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22640]=0;rC(f,b,c);f=v[22640];v[22640]=0;if((f|0)==1){break a}b=b+6|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function Cn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=Ri(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22640]=0;dl(f,b,c);f=v[22640];v[22640]=0;if((f|0)==1){break a}b=b+1|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function jY(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=Cr(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+4|0]=6;t[a+5|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=8;t[a+3|0]=4;a=a+6|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function Eea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{b:{c:{d:{e:{f:{if((b|0)<=28590){if((b|0)==437){break c}if((b|0)==1252){break b}if((b|0)!=20127){break f}e=1;break a}if((b|0)==28591){break e}if((b|0)==28605){break d}e=0;if((b|0)==65001){break a}}e=c;break a}e=2;break a}e=3;break a}e=5;break a}e=8}YN(a,e,d)}function D8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{a=Wl(a);d=Wl(b);b=gb-32|0;gb=b;v[b+24>>2]=c;b:{if((a|0)!=(d|0)){while(1){c=Tb(b+8|0,v[a>>2]);v[22640]=0;R(2121,b+24|0,c|0);e=v[22640];v[22640]=0;if((e|0)==1){break b}vb(c);a=a+4|0;if((d|0)!=(a|0)){continue}break}}gb=b+32|0;break a}a=P()|0;O()|0;vb(c);S(a|0);L()}}function fE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=RD(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=wb(a);v[22640]=0;R(380,e|0,b|0);e=v[22640];v[22640]=0;if((e|0)==1){break a}b=b+20|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function Pja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=263;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=xf(a)}cT(d+24|0,b);e=Wd(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;fc(d+16|0,a,d+8|0);cT(d+24|0,b);Qb(v[d+24>>2]+c|0,0,263-c|0);Yb(a,v[d+44>>2]);gb=d+48|0}function Nt(a){var b=0,c=0,d=0,e=0;b=Ag(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){e=a;if(b<=45e-5){b=0}else{b=Up(b)*1.4426950408889634;d=H(b);b=b-d;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Ag(c+d)*.5}A[e+4248>>3]=b}Mt(a)}function TX(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=320012546|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=184619540|w[a+8|0]>1){break a}b=a+9|0;if(!w[b|0]|w[b|0]>8){break a}b=a+10|0;if((w[b|0]|w[b+1|0]<<8)>>>0>4096){break a}a=a+12|0;c=(w[a|0]|w[a+1|0]<<8)>>>0<4097}return c}function lna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=22;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=xf(a)}uv(d+24|0,b);e=Wd(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;fc(d+16|0,a,d+8|0);uv(d+24|0,b);Qb(v[d+24>>2]+c|0,0,22-c|0);Yb(a,v[d+44>>2]);gb=d+48|0}function kC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;lW(a,b);e=b+8|0;Xc(a,Xb(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+504|0);kW(a,d);a:{b=b+32|0;if(!Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}if(!Xc(a,Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)))){break a}mC(a,c);return}Qb(c,0,80)}function ina(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=40;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=xf(a)}bC(d+24|0,b);e=Wd(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;fc(d+16|0,a,d+8|0);bC(d+24|0,b);Qb(v[d+24>>2]+c|0,0,40-c|0);Yb(a,v[d+44>>2]);gb=d+48|0}function Ppa(a,b){a=a|0;b=b|0;var c=0;_u(a,b);Mf(b);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}t[b+5|0]=159;t[b+3|0]=20;return}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;return}t[b+3|0]=20;t[b+5|0]=a&15|160;return}t[b+3|0]=0}}function Fla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(w[b+40|0]){break a}if(!v[b+28>>2]){t[b+40|0]=1;break a}f=v[c>>2];e=xb(c);if(!e){break a}while(1){b:{d=kb[v[b+28>>2]](v[b+24>>2],f,e)|0;if(!d){t[b+40|0]=1;break b}f=d+f|0;g=d+g|0;h=g>>>0<d>>>0?h+1|0:h;e=e-d|0;if(e){continue}}break}d=g}Uj(a,c,d)}function z7(a,b){a=a|0;b=b|0;var c=0,d=0;a=Kb(a);c=Ab(b);v[22640]=0;R(107,a|0,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){a:{if(Ab(b)){while(1){c=t[mc(b,d)|0];v[22640]=0;R(108,a|0,ag(c)|0);c=v[22640];v[22640]=0;if((c|0)==1){break a}d=d+1|0;if(Ab(b)>>>0>d>>>0){continue}break}}return}}b=P()|0;O()|0;vb(a);S(b|0);L()}function sS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 3:PA(a,b);return;default:break a}}d=gb-32|0;gb=d;v[d+28>>2]=c;u[d+26>>1]=0;v[d+12>>2]=2;kj(d+16|0,a,d+26|0,v[Fb(d+28|0,d+12|0)>>2]);xb(d+16|0);v[d+16>>2]=2;Fb(d+28|0,d+16|0);u[d+16>>1]=x[d+26>>1];u[b>>1]=w[d+16|0]|w[d+17|0]<<8;gb=d+32|0}function LS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=Ck(a);a=b+236|0;b=Cu(a);a:{if((a|0)!=(b|0)){while(1){d=x[a>>1];u[c+14>>1]=d;if(d){v[22640]=0;U(1093,c|0,e|0,c+14|0);d=v[22640];v[22640]=0;if((d|0)==1){break a}}a=a+2|0;if((b|0)!=(a|0)){continue}break}}gb=c+16|0;return}a=P()|0;O()|0;nr(e);S(a|0);L()}function Iz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;c=a;d=gb-96|0;gb=d;lP(b,d,d+96|0);b=0;while(1){e=b<<3;f=e+c|0;g=v[d+e>>2];e=v[(e|4)+d>>2];v[f>>2]=g;v[f+4>>2]=e&65535;b=b+1|0;if((b|0)!=12){continue}break}v[c+104>>2]=0;v[c+96>>2]=!(v[c+88>>2]|v[c+92>>2]);v[c+100>>2]=0;gb=d+96|0;v[a+112>>2]=0;return a|0}function Afa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=gb-16|0;gb=e;d=gb-16|0;gb=d;Ve(c,1);Ir(c,1,b<<24>>24);t[d+15|0]=0;zd(c+1|0,d+15|0);gb=d+16|0;gb=e+16|0;b=c;d=Jb(c);e=Ab(c);v[22640]=0;W(159,a|0,d|0,e|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){vb(b);gb=c+16|0;return a|0}a=P()|0;O()|0;vb(b);S(a|0);L()}function jC(a,b){var c=0;c=gb-32|0;gb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=0;v[c+20>>2]=0;v[22640]=0;v[c+8>>2]=-1;v[c+12>>2]=0;a=iv(c+24|0,c+8|0);b=v[22640];v[22640]=0;a:{if((b|0)==1){break a}v[22640]=0;a=fC(c+16|0,a);b=v[22640];v[22640]=0;if((b|0)==1){break a}gb=c+32|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function GW(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;v[d+12>>2]=v[a+4>>2];c=v[b+4>>2];v[22640]=0;v[d+8>>2]=c;c=Fb(d+12|0,d+8|0);e=v[22640];v[22640]=0;if((e|0)!=1){c=po(v[a>>2],v[b>>2],v[c>>2]);a:{if(c){break a}c=0;if(v[a+4>>2]==v[b+4>>2]){break a}c=y[a+4>>2]<y[b+4>>2]?-1:1}gb=d+16|0;return c}V(0)|0;O()|0;Bb();L()}function SS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=v[a+92>>2];e=v[a+96>>2];if(d|e){if(c){while(1){f=ed((ed(0-d|0,31)&255)+d|0,8);j=ed((ed(0-e|0,31)&255)+e|0,8);h=g<<3;i=h+b|0;d=d-f|0;v[i>>2]=d+v[i>>2];f=(h|4)+b|0;e=e-j|0;v[f>>2]=e+v[f>>2];g=g+1|0;if((g|0)!=(c|0)){continue}break}}v[a+96>>2]=e;v[a+92>>2]=d}}function RB(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=gb-1024|0;gb=f;d=gb-32|0;gb=d;MB(d+24|0,f);g=xb(d+24|0);e=v[d+28>>2];h=v[d+24>>2];v[d+8>>2]=h;v[d+12>>2]=e;v[d>>2]=h;v[d+4>>2]=e;fc(d+16|0,a,d);e=xb(d+16|0);if((e|0)==(g|0)){Yb(a,xb(d+24|0))}gb=d+32|0;if((e|0)==(g|0)){i=OB(f,c)>>>0<=b>>>0}gb=f+1024|0;return i}function Qaa(a){a=a|0;var b=0;v[22640]=0;_(1934,a|0);b=v[22640];v[22640]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,2782,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function LN(a,b){var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){d=gb-16|0;gb=d;c=v[b>>2];e=v[b+4>>2];b=jr(c,e);a:{if(b>>>0<=ye(a)>>>0){if(Nb(a)>>>0<b>>>0){v[d+12>>2]=c;ZV(d+12|0,Nb(a));f=c;c=v[d+12>>2];Bg(f,c,v[a>>2]);$v(a,c,e,b-Nb(a)|0);break a}dj(a,Bg(c,e,v[a>>2]));break a}JN(a);aw(a,_g(a,b));$v(a,c,e,b)}gb=d+16|0}}function aN(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[22640]=0;v[c+12>>2]=0;U(1544,a+4208|0,b<<1,c+12|0);b=v[22640];v[22640]=0;a:{if((b|0)==1){b=V(88880)|0;if((O()|0)!=(ea(88880)|0)){break a}Z(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;gb=c+16|0;return}S(b|0);L()}function So(a,b,c,d){var e=0,f=0,g=0;a:{e=v[c>>2];if(e|v[d>>2]){if(!b){break a}while(1){e=ed((ed(0-e|0,31)&255)+e|0,8);f=v[d>>2];f=ed((ed(0-f|0,31)&255)+f|0,8);v[c>>2]=v[c>>2]-e;v[d>>2]=v[d>>2]-f;e=g<<3;v[e+a>>2]=v[c>>2];v[(e|4)+a>>2]=v[d>>2];g=g+1|0;if((g|0)==(b|0)){break a}e=v[c>>2];continue}}TS(a,b<<1)}}function S2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=gb-128|0;gb=c;v[c+12>>2]=c+116;dH(a+8|0,c+16|0,c+12|0,e,f,g);e=v[c+12>>2];a=gb-16|0;gb=a;v[a+8>>2]=b;d=c+16|0;if((e|0)!=(d|0)){while(1){_H(a+8|0,t[d|0]);d=d+1|0;if((e|0)!=(d|0)){continue}break}b=v[a+8>>2]}gb=a+16|0;gb=c+128|0;return b|0}function lba(){var a=0,b=0;v[22640]=0;a=v[22640];v[22640]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22640]=0;Y(1911,7223,0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();a=0}else{a=19923012}return a|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function Y2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=gb-32|0;gb=g;h=v[20855];v[g+24>>2]=v[20854];v[g+28>>2]=h;h=v[20853];v[g+16>>2]=v[20852];v[g+20>>2]=h;h=v[20851];v[g+8>>2]=v[20850];v[g+12>>2]=h;h=v[20849];v[g>>2]=v[20848];v[g+4>>2]=h;a=ek(a,b,c,d,e,f,g,g+32|0);gb=g+32|0;return a|0}function Doa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;uC(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){c=gb-16|0;gb=c;Qb(b,0,4896);gb=c+16|0}return a|0}function A9(a){a=a|0;var b=0;v[22640]=0;_(2007,a|0);b=v[22640];v[22640]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;Z(b|0)|0;v[22640]=0;Y(1911,9278,a|0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a:{b=AT(d,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){v[22640]=0;R(1099,a|0,c|0);a=v[22640];v[22640]=0;if((a|0)==1){break a}a=v[b>>2]+32|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Yc(b);gb=d+16|0;return}a=P()|0;O()|0;Yc(b);S(a|0);L()}function cw(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;a:{if(Pb(a,256)){d=gb-16|0;gb=d;bc(c+24|0,b,256);gb=d+16|0;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;d=gb-16|0;gb=d;e=b+256|0;while(1){Kf(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}gb=d+16|0;gb=a+16|0}gb=c+32|0}function T7(a){a=a|0;var b=0,c=0,d=0;b=gb-32|0;gb=b;a:{b:{if(yj(a)){th(b+24|0);break b}mo(b+8|0,a);v[22640]=0;c=T(2084,b+8|0)|0;d=v[22640];v[22640]=0;if((d|0)==1){break a}v[b+24>>2]=c;Uf(b+8|0)}if(yj(a)){a=a+36|0}else{a=v[b+24>>2]}a=jo(a);yl(b+24|0);gb=b+32|0;return a|0}a=P()|0;O()|0;Uf(b+8|0);S(a|0);L()}function Sg(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;g=a;h=a;a:{if(!b){b=0;break a}c=b>>31;e=c+b^c;c=E(e);If(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[h>>2]=b;v[g+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;gb=d+16|0}function Pca(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;a:{b:{if((pc(v[a+20>>2]+4|0)|0)!=7){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=Sb(v[a+20>>2]+4|0);c=Wb(v[a+20>>2]+4|0);un(d+8|0,a+4228|0);Ti(b,c,v[d+8>>2]);break a}Py(a,b)}Jt(a);gb=d+16|0}function nba(){var a=0,b=0;v[22640]=0;a=v[22640];v[22640]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22640]=0;Y(1911,7195,0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();a=0}else{a=393216}return a|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function zl(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;Vf(c,b);v[22640]=0;R(2041,c+16|0,c|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){v[22640]=0;U(2042,a|0,0,c+16|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Hc(c+16|0);vb(c);gb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hc(c+16|0)}vb(c);S(a|0);L()}function jV(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=v[a>>2];a:{if(!b){break a}d=v[a+8>>2];if(!d){break a}e=v[a+12>>2];if(!e){break a}f=kb[e|0](b)|0;a=jb;if((a|0)<0){break a}c=0;b:{if((kb[d|0](b,0,0,0)|0)<0){break b}c=0;if((kb[d|0](b,0,0,2)|0)<0){break b}kb[e|0](b)|0;c=(jb|0)>-1}kb[d|0](b,f,a,0)|0}return c|0}function gK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=gb-16|0;gb=c;v[c+12>>2]=-1;v[22640]=0;v[c+8>>2]=2147483647;d=Fb(c+12|0,c+8|0);e=v[22640];v[22640]=0;a:{if((e|0)!=1){gb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Bb();L()}if(b>>>0>c>>>0){Rc();L()}c=Mc(b,1);v[a>>2]=c;v[a+4>>2]=c;f=wb(a),g=b+c|0,v[f>>2]=g}function aW(a,b){var c=0,d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;c=a+4|0;a:{if(pc(c)>>>0>=v[a+16>>2]+b>>>0){break a}if(!pc(c)){Fk(c,cC(v[a+16>>2]+b|0,65536));break a}f=d,g=pc(c),v[f+12>>2]=g;e=wf(d+12|0);a=v[a+16>>2]+b|0;if(e>>>0<a>>>0){Fk(c,cC(a,65536));break a}f=d,g=pc(c),v[f+8>>2]=g;Fk(c,wf(d+8|0))}gb=d+16|0}function Zga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=Zp(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22640]=0;IR(b);f=v[22640];v[22640]=0;if((f|0)==1){break a}b=b+16|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function QY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=Pb(a,8);a:{if(d){BY(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;e=gb-16|0;gb=e;f=b+8|0;while(1){Kf(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}gb=e+16|0;gb=a+16|0}gb=c+32|0;return d|0}function JQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])^128,t[f|0]=g;f=a,g=zb(w[b+1|0])^128,t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function IQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=zb(w[b|0])+g|0;t[a|0]=g;d=zb(w[b+1|0])+d|0;t[a+1|0]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function DP(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=v[a+1074416>>2];a=v[a+1074392>>2];t[b+851|0]=w[b+851|0]|32;g=b;d=a?w[b+813|0]:0;h=v[b+852>>2]+((c|0)>-1?0-d|0:d)|0;f=(+(a>>>0)+1)*+(c|0)/+(e>>>0);a:{if(D(f)<2147483648){d=~~f;break a}d=-2147483648}v[g+852>>2]=h+d;c=(a+1|0)==(e|0)?c:d;a=c>>31;t[b+813|0]=a^a+c}function xma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb+-64|0;gb=c;b=-1;a:{if(!Rf(a,1084)){break a}Tl(a,1080);EV(a,c+60|0);d=DV(c+40|0);b=0;if(!CV(c+60|0,d)){break a}Tl(a,20);b=1;while(1){BV(a,c+8|0);e=TB(c+8|0)+e|0;f=b&65535;b=b+1|0;if(f>>>0<31){continue}break}b=y[d+4>>2]>=e>>>0}gb=c- -64|0;return b|0}function qH(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;e=jr(b,c);if(e>>>0<=1073741807){a:{if(e>>>0<=1){Ve(a,e);d=a;break a}g=vm(e)+1|0;d=Li(a,g);bf(a,d);ng(a,g);ee(a,e)}if((b|0)!=(c|0)){while(1){Fe(d,b);d=d+4|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}v[f+12>>2]=0;Fe(d,f+12|0);gb=f+16|0;return}_f();L()}function pea(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-48|0;gb=c;d=c+40|0;b=x[b>>1];t[d|0]=b;t[d+1|0]=b>>>8;Bn(c+16|0,c+40|0);b=zb(v[c+16>>2]);Bn(c+8|0,c+40|0);b=Bj(c+24|0,b,zb(v[c+8>>2]+2|0));v[22640]=0;Q(1110,a|0,b|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){vb(b);gb=c+48|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function TA(a,b,c){var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=pB(e,a,b);b=v[d+4>>2];f=v[d+8>>2];if((b|0)!=(f|0)){while(1){wb(a);v[22640]=0;R(1099,b|0,c|0);g=v[22640];v[22640]=0;if((g|0)==1){break a}b=b+32|0;v[d+4>>2]=b;if((b|0)!=(f|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function RM(a,b,c){var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;e=fi(b,c);if(e>>>0<=4294967279){a:{if(e>>>0<=10){Ve(a,e);d=a;break a}g=Xk(e)+1|0;d=mi(a,g);bf(a,d);ng(a,g);ee(a,e)}if((b|0)!=(c|0)){while(1){zd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;zd(d,f+15|0);gb=f+16|0;return}_f();L()}function $w(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=gb-16|0;gb=f;h=b;c=uI(b);d=gb-16|0;gb=d;b=a;a:{if(c>>>0<=1073741807){b:{if(c>>>0<=1){Ve(b,c);e=b;break b}g=vm(c)+1|0;e=Li(b,g);bf(b,e);ng(b,g);ee(b,c)}wi(e,h,c);v[d+12>>2]=0;Fe((c<<2)+e|0,d+12|0);gb=d+16|0;break a}_f();L()}gb=f+16|0;return a|0}function $aa(){var a=0,b=0;v[22640]=0;a=v[22640];v[22640]=0;a:{if((a|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22640]=0;Y(1911,8466,0,0,0);a=v[22640];v[22640]=0;if((a|0)==1){break a}$();a=0}else{a=2048}return a|0}a=P()|0;O()|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Bb();L()}function yr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=Ri(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22640]=0;Kf(b);f=v[22640];v[22640]=0;if((f|0)==1){break a}b=b+1|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function Zu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;u[d+14>>1]=b;u[d+12>>1]=c;if((b|0)!=(c|0)){b=Sb(a);c=Wb(a);a=gb-16|0;gb=a;v[a>>2]=c;v[a+8>>2]=b;if(Gb(a+8|0,a)){while(1){if(x[v[a+8>>2]>>1]==x[d+14>>1]){u[v[a+8>>2]>>1]=x[d+12>>1]}mf(a+8|0);if(Gb(a+8|0,a)){continue}break}}gb=a+16|0}gb=d+16|0}function XD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=ji(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22640]=0;Yv(b);f=v[22640];v[22640]=0;if((f|0)==1){break a}b=b+2|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function Or(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=gb-16|0;gb=f;v[f+12>>2]=c;tc(f+12|0,256);tc(f+12|0,65535);h=x[f+12>>1];yf(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=bj(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}gb=f+16|0}function efa(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:Dl(a,0,c);return;case 1:Dl(a,1,c);return;case 2:Dl(a,2,c);return;case 3:Dl(a,3,c);return;case 4:Dl(a,4,c);return;case 5:Dl(a,5,c);return;case 6:OM(a,25488,c);return;case 7:OM(a,26512,c);return;case 8:Dl(a,6,c);return;default:break a}}Kb(a)}function Uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=b;a:{if(hg(a)>>>0>=b>>>0){f=d,g=pc(a),v[f+8>>2]=g;li(v[a>>2],v[Fb(d+12|0,d+8|0)>>2],c);e=v[d+8>>2];b=v[d+12>>2];if(e>>>0<b>>>0){Cn(a,b-e|0,c);break a}jn(a,b+v[a>>2]|0);break a}vv(a);gp(a,vh(a,b));Cn(a,b,c)}gb=d+16|0}function N6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;v[f+8>>2]=d;d=v[ni(f,f+8|0)>>2];v[22640]=0;ga(1933,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){QJ(a);b=PJ(a+88|0);v[a>>2]=59472;v[b>>2]=59560;bg(f+8|0);gb=f+16|0;return a|0}a=P()|0;O()|0;bg(f+8|0);S(a|0);L()}function d6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a=Kb(a);e=Ab(b);f=Ab(c);b=Jb(b);v[22640]=0;Y(158,a|0,b|0,e|0,e+f|0);b=v[22640];v[22640]=0;a:{if((b|0)!=1){b=Jb(c);v[22640]=0;W(159,a|0,b|0,f|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=d+16|0}function _Q(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;lT(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-28|0;qu(h,e-28|0,c);e=v[d>>2]-28|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}jc(a,f);jc(a+4|0,b+8|0);jc(wb(a),cc(b));v[b>>2]=v[b+4>>2];Ch(a);Wi(a);Wi(a)}function Sf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=gb-48|0;gb=c;a:{if(!b){b=1;if(id(a,5)){break a}b=JH(c+32|0);e=v[a+8>>2];f=v[d>>2];v[b+4>>2]=f-e;se(c,v[a+28>>2]);XH(c+16|0,c,v[d>>2],v[d+4>>2]);v[b+8>>2]=v[c+24>>2]}v[a>>2]=v[a>>2]|134217728;v[a+20>>2]=v[a+20>>2]+1;b=0}gb=c+48|0;return b|0}function SQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){g=zb(w[b|0])+d|0;d=g+zb(w[b+1|0])|0;u[a>>1]=d<<8|g&255;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function J_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;AF(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-36|0;zF(h,e-36|0,c);e=v[d>>2]-36|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}jc(a,f);jc(a+4|0,b+8|0);jc(wb(a),cc(b));v[b>>2]=v[b+4>>2];Zk(a);Yk(a);Yk(a)}function yI(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;d=Ab(a);f=Kc(a);a:{if(f-d>>>0>=c>>>0){if(!c){break a}e=Jb(a);h=e;f=d;if(d){bm(c+e|0,e,f);b=b>>>0>=e>>>0?d+e>>>0>b>>>0?b+c|0:b:b}bm(h,b,c);b=c+d|0;gh(a,b);t[g+15|0]=0;zd(b+e|0,g+15|0);break a}Ap(a,f,(c+d|0)-f|0,d,0,0,c,b)}gb=g+16|0;return a}function nR(a,b,c){var d=0,e=0,f=0;d=Vd(a);e=ec(a);a:{if(d){f=wb(a);b:{while(1){c:{a=d+16|0;d:{if(Ml(f,c,a)){if(!v[d>>2]){break a}a=d;break d}if(!Ml(f,a,c)){break b}a=d+4|0;if(!v[d+4>>2]){break c}d=a;a=d}e=a;d=v[d>>2];continue}break}v[b>>2]=d;return a}v[b>>2]=d;return e}d=ec(a)}v[b>>2]=d;return d}function Wy(a,b,c){var d=0,e=0,f=0,g=0;e=gb-16|0;gb=e;a:{d=yg(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=wb(a);v[22640]=0;pq(f,b,c);f=v[22640];v[22640]=0;if((f|0)==1){break a}b=b+4|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function Fr(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;tc(d+12|0,128);tc(d+12|0,65535);f=x[d+12>>1];yf(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==65535){e=65535;break a}if((e|0)!=65535){break a}e=65534}g=bj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function tv(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-20|0;v[b+8>>2]=d;v[22640]=0;R(388,c|0,d|0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){QD(v[a+16>>2],v[a>>2],(v[cc(a)>>2]-v[a>>2]|0)/20|0)}}function fs(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-36|0;v[b+8>>2]=d;v[22640]=0;R(250,c|0,d|0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){es(v[a+16>>2],v[a>>2],(v[cc(a)>>2]-v[a>>2]|0)/36|0)}}function wm(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;v[a+20>>2]=0;u[a+16>>1]=65535;v[a+8>>2]=0;v[a+12>>2]=0;v[a+24>>2]=11;v[a+28>>2]=b;nc(a+32|0);ad(a+44|0);v[a+72>>2]=0;v[a+76>>2]=0;v[a+64>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;v[a+80>>2]=0;v[a+84>>2]=0;v[a+88>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;return a|0}function wN(a){var b=0,c=0,d=0,e=0;c=a;d=v[a+4>>2];a:{while(1){b=v[c+8>>2];if((b|0)==(d|0)){break a}e=v[c+16>>2];b=b-52|0;v[c+8>>2]=b;v[22640]=0;R(1332,e|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}c=v[a>>2];if(c){Nz(v[a+16>>2],c,(v[cc(a)>>2]-v[a>>2]|0)/52|0)}}function oM(a,b,c){var d=0,e=0,f=0,g=0;g=(b|0)<1;if(C(D(a))<C(2147483648)){d=~~a}else{d=-2147483648}f=d&-2147483648;e=f?0-d|0:d;a:{if(!(g|(e|0)<0)){while(1){d=b-1|0;e=e<<1;if((b|0)<2){break a}b=d;if((e|0)>-1){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return C((f?b^-1|f:b)|0)}function Kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-32|0;gb=d;g=d;e=b;if(qp(b,d+24|0)){f=dn(d+24|0)}rd(g,e,f);e=Zl(a,d+24|0,d);yb(d);a:{a=(f>>>0)%(c>>>0)|0;if(!a){break a}v[22640]=0;Q(350,b|0,c-a|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Xd(e);S(a|0);L()}gb=d+32|0}function KQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=oh(w[b|0]),t[f|0]=g;f=a,g=oh(w[b+1|0]),t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function re(a){var b=C(0),c=C(0),d=0,e=0;d=(p(a),j(2));e=d>>>23&255;if(e>>>0<=149){if(e>>>0<=125){return C(a*C(0))}a=(d|0)>-1?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){c=C(C(a+b)+C(-1));break a}a=C(a+b);c=a;if(!(b<=C(-.5))){break a}c=C(a+C(1))}a=c;a=(d|0)>-1?a:C(-a)}return a}function Zna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 2:Rh(a,b);return;default:break a}}d=gb-32|0;gb=d;v[d+28>>2]=c;t[d+27|0]=0;v[d+12>>2]=1;kj(d+16|0,a,d+27|0,v[Fb(d+28|0,d+12|0)>>2]);xb(d+16|0);v[d+16>>2]=1;Fb(d+28|0,d+16|0);t[d+16|0]=w[d+27|0];t[b|0]=w[d+16|0];gb=d+32|0}function QP(a,b,c,d){var e=0,f=0;f=gb-16|0;gb=f;e=-2147483648;e=!c|!(t[c+15|0]&1)?e:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){e=x[d+28>>1];break b}if((e|0)==-2147483648){break a}}Ro(b,e,a);Db(f+8|0,a+1074312|0,10);if(!Cb(f+8|0)|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}gb=f+16|0}function Im(a,b,c,d){var e=0;a:{if(b>>>0>255){break a}b:{c:{d:{e:{switch(c|0){case 1:break b;case 3:break c;case 0:break d;case 2:break e;default:break a}}e=NP(a,b,d);if(e-251>>>0<5){break d}if(e){break a}}return MP(a,b,d)}e=MP(a,b,d);if(e-251>>>0<5){break b}if(e){break a}}e=NP(a,b,d)}return e}function ED(a,b,c){var d=0,e=0,f=0;d=gb-48|0;gb=d;v[d+44>>2]=c;v[d+24>>2]=192;c=v[Fb(d+44|0,d+24|0)>>2];if(!Pb(a,c)){c=xf(a)}Jr(d+24|0,b);e=Wd(d+32|0,v[d+24>>2],c);f=v[e+4>>2];v[d+8>>2]=v[e>>2];v[d+12>>2]=f;fc(d+16|0,a,d+8|0);Jr(d+24|0,b);Qb(v[d+24>>2]+c|0,0,192-c|0);Yb(a,v[d+44>>2]);gb=d+48|0}function Yd(a,b){var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;Kn(a);a=Ni(d+8|0,a);a:{if(Nb(465584)>>>0<=b>>>0){v[22640]=0;_(2538,b+1|0);c=v[22640];v[22640]=0;if((c|0)==1){break a}}c=v[Mb(465584,b)>>2];if(c){Jn(c)}c=$d(a);e=Mb(465584,b),f=c,v[e>>2]=f;PG(a);gb=d+16|0;return}b=P()|0;O()|0;PG(a);S(b|0);L()}function PX(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=777268804){break a}b=a+4|0;if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<14){break a}if(Xb(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>256){break a}a=a+8|0;return!Ib(w[a|0]|w[a+1|0]<<8)}return 0}function FX(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;tc(d+12|0,256);tc(d+12|0,65535);f=x[d+12>>1];yf(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=bj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function EE(a,b){var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;a:{if(!b){break a}if(!Pb(a,b)){break a}f=1;while(1){t[c+13|0]=0;e=(c+14|0)+d|0;if(b>>>0>d>>>0){Jg(a,c+13|0);d=w[c+13|0]}else{d=0}t[e|0]=d;d=1;e=f;f=0;if(e){continue}break}u[c+10>>1]=x[c+14>>1];a=c+10|0;d=w[a|0]|w[a+1|0]<<8}gb=c+16|0;return d}function AE(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;tc(d+12|0,128);tc(d+12|0,65535);f=x[d+12>>1];yf(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=bj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}gb=d+16|0}function sI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a=Kb(a);e=Lf(b);f=Ab(c);v[22640]=0;Y(2276,a|0,b|0,e|0,e+f|0);b=v[22640];v[22640]=0;a:{if((b|0)!=1){b=Jb(c);v[22640]=0;W(2277,a|0,b|0,f|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;vb(a);S(b|0);L()}gb=d+16|0}function fB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-16|0;gb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;e=c,f=Ab(a),v[e+4>>2]=f;v[c>>2]=v[c+12>>2];a=po(Jb(a),v[c+8>>2],v[Fb(c+4|0,c)>>2]);a:{if(a){break a}a=-1;b=v[c>>2];d=v[c+4>>2];if(b>>>0>d>>>0){break a}a=b>>>0<d>>>0}gb=c+16|0;return a|0}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=Di(a,b,c,d);v[a+4208>>2]=1017370378;v[a+4212>>2]=0;v[a>>2]=52632;v[22640]=0;W(1536,a+44|0,2,2)|0;c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}v[22640]=0;Vh(b);c=v[22640];v[22640]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;hf(b);S(a|0);L()}function Ln(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;Qp(a);h=wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-12|0;Mn(h,e-12|0,c);e=v[d>>2]-12|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}jc(a,f);jc(a+4|0,b+8|0);jc(wb(a),cc(b));v[b>>2]=v[b+4>>2];Lw(a,Cc(a))}function xL(a,b){var c=0;c=gb-32|0;gb=c;Vf(c,b);v[22640]=0;U(2047,c+16|0,0,c|0);b=v[22640];v[22640]=0;a:{b:{if((b|0)!=1){v[22640]=0;R(2048,a|0,c+16|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Hc(c+16|0);vb(c);gb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;Hc(c+16|0)}vb(c);S(a|0);L()}function Kr(a){var b=0,c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;b=gb-32|0;gb=b;Qr(b+24|0,d+15|0);e=xb(b+24|0);c=v[b+28>>2];f=v[b+24>>2];v[b+8>>2]=f;v[b+12>>2]=c;v[b>>2]=f;v[b+4>>2]=c;qd(b+16|0,a,b);c=xb(b+16|0);if((c|0)==(e|0)){cd(a,xb(b+24|0))}gb=b+32|0;gb=d+16|0;return((c|0)==(e|0)?w[d+15|0]:0)&255}function iM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[22640]=0;v[c+12>>2]=0;U(1544,a+4208|0,b<<2,c+12|0);b=v[22640];v[22640]=0;a:{if((b|0)==1){b=V(88880)|0;if((O()|0)!=(ea(88880)|0)){break a}Z(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;gb=c+16|0;return}S(b|0);L()}function fz(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{c=a-12|0;d:{if(c>>>0>31){break d}a=1;d=1<<c;if(d&-2145904587){break b}if(d&65792){break c}if((c|0)!=7){break d}b=b&240;if(!b|(b|0)==96|(b|0)==224){break b}}return 0}a=0;b=(b&240)-96|0;if(b>>>0<144){break a}}return a|0}return 297>>>(b>>>4)&1}function NX(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function GQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b|0])|zb(w[b+1|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function Dz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=v[b+48>>2]+1|0;v[b+52>>2]=e;a:{if(y[_b(a+484344|0,x[b+70>>1])+12>>2]>e>>>0){break a}if(!c){u[b+74>>1]=x[b+72>>1]+1}v[b+52>>2]=0;Db(d+8|0,a+1074312|0,63);if(!Cb(d+8|0)){break a}a=v[b+56>>2];v[b+56>>2]=0;v[b+52>>2]=a}gb=d+16|0}function DQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(zb(w[b+1|0])|zb(w[b|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function Aw(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function AP(a,b,c){var d=0;a:{if(v[a+480180>>2]==4){d=w[b+813|0];if(c){t[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}ok(a,b,b+700|0,c<<2,0)}}function mN(a,b){var c=0,d=0,e=0,f=0;d=gb-16|0;gb=d;a:{c=yg(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);v[22640]=0;Vo(b);f=v[22640];v[22640]=0;if((f|0)==1){break a}b=b+4|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function Ge(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=gb-16|0;gb=g;e=gb-16|0;gb=e;d=a;a:{if(b>>>0<=4294967279){b:{if(b>>>0<=10){Ve(d,b);f=d;break b}h=Xk(b)+1|0;f=mi(d,h);bf(d,f);ng(d,h);ee(d,b)}Ir(f,b,c);t[e+15|0]=0;zd(b+f|0,e+15|0);gb=e+16|0;break a}_f();L()}gb=g+16|0;return a|0}function Qna(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Pk(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22640]=0;Ik(b);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}Yc(a);gb=c+16|0;return}b=P()|0;O()|0;Yc(a);S(b|0);L()}function Kpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(y[a+4>>2]<y[wb(a)>>2]){d=gb-16|0;gb=d;a=jD(d,a);bY(v[a+4>>2],b,c);v[a+4>>2]=v[a+4>>2]+28;$b(a);gb=d+16|0;return}e=gb-32|0;gb=e;d=wb(a);d=gD(e+8|0,hD(a,Ch(a)+1|0),Ch(a),d);bY(v[d+8>>2],b,c);v[d+8>>2]=v[d+8>>2]+28;IY(a,d);fD(d);gb=e+32|0}function FQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(zb(w[b|0])+d|0)+(zb(w[b+1|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function CQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(zb(w[b+1|0])+d|0)+(zb(w[b|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f<<1}function lN(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Pk(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22640]=0;Vo(b);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}Yc(a);gb=c+16|0;return}b=P()|0;O()|0;Yc(a);S(b|0);L()}function gB(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=aB(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22640]=0;Kf(b);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a>>2]+1|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}Yc(a);gb=c+16|0;return}b=P()|0;O()|0;Yc(a);S(b|0);L()}function _Z(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Pk(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22640]=0;Sr(b);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a>>2]+4|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}Yc(a);gb=c+16|0;return}b=P()|0;O()|0;Yc(a);S(b|0);L()}function Vn(a,b){var c=0,d=0;c=gb-16|0;gb=c;Ec(c+8|0,a);v[22640]=0;a=T(2458,c+8|0)|0;d=v[22640];v[22640]=0;a:{b:{if((d|0)==1){break b}v[22640]=0;Y(2470,a|0,83184,83210,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Vb(c+8|0);gb=c+16|0;break a}a=P()|0;O()|0;Vb(c+8|0);S(a|0);L()}return b}function FZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Dn(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22640]=0;Yv(b);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a>>2]+2|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}Yc(a);gb=c+16|0;return}b=P()|0;O()|0;Yc(a);S(b|0);L()}function FP(a,b,c){var d=0;a:{if(v[a+480180>>2]==4){d=w[b+814|0];if(c){t[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}ok(a,b,b+700|0,c,0)}}function BZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{a=Dn(c,a+8|0,b);if(v[a>>2]!=v[a+4>>2]){while(1){b=v[a>>2];v[22640]=0;Kk(b);b=v[22640];v[22640]=0;if((b|0)==1){break a}b=v[a>>2]+2|0;v[a>>2]=b;if((b|0)!=v[a+4>>2]){continue}break}}Yc(a);gb=c+16|0;return}b=P()|0;O()|0;Yc(a);S(b|0);L()}function $n(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=gb-16|0;gb=c;g=a;h=a;a:{if(!b){b=0;e=0;break a}d=b;b=E(b);If(c,d,0,0,0,b+81|0);d=0+v[c+8>>2]|0;b=(v[c+12>>2]^65536)+(16414-b<<16)|0;b=d>>>0<f>>>0?b+1|0:b;f=d;d=b;b=v[c+4>>2];e=v[c>>2]}v[h>>2]=e;v[g+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=d;gb=c+16|0}function $j(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;if(b){g=v[a+8>>2];c=v[a>>2];while(1){h=a;a:{if(c){d=v[a+4>>2];c=c-1|0;break a}v[a>>2]=8;c=g;d=v[a+12>>2];if((c|0)!=(d|0)){c=d-1|0;v[a+12>>2]=c}d=w[c|0];c=7}v[h>>2]=c;v[a+4>>2]=d>>>1;e=d&1|e<<1;f=f+1|0;if((f|0)!=(b|0)){continue}break}}return e}function g1(a){a=a|0;var b=0,c=0;b=v[a+8>>2];v[22640]=0;b=T(2552,b|0)|0;c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}b:{if(b){a=-1}else{a=v[a+8>>2];if(a){break b}a=1}return a|0}v[22640]=0;a=T(2553,a|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break a}return(a|0)==1|0}V(0)|0;O()|0;Bb();L()}function Yla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,1030);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,1030)}return a|0}function QH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=_s(a);v[a+32>>2]=b;v[a>>2]=78532;Ts(d+8|0,e);v[22640]=0;b=T(2383,d+8|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){Vb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Yn(b),t[g+44|0]=h;gb=d+16|0;return}a=P()|0;O()|0;Vb(d+8|0);um(e);S(a|0);L()}function PH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=mI(a);v[a+32>>2]=b;v[a>>2]=78636;Ts(d+8|0,e);v[22640]=0;b=T(2384,d+8|0)|0;f=v[22640];v[22640]=0;if((f|0)!=1){Vb(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Yn(b),t[g+44|0]=h;gb=d+16|0;return}a=P()|0;O()|0;Vb(d+8|0);bq(e);S(a|0);L()}function Ic(a,b,c){var d=0,e=0;d=b^-2147483648;e=a;b=c&31;if((c&63)>>>0>=32){a=0;b=d>>>b|0}else{a=d>>>b|0;b=((1<<b)-1&d)<<32-b|e>>>b}e=b;d=c&31;if((c&63)>>>0>=32){c=0;d=-2147483648>>>d|0}else{c=-2147483648>>>d|0;d=((1<<d)-1&-2147483648)<<32-d}e=e-d|0;jb=a-(c+(b>>>0<d>>>0)|0)|0;return e}function EF(a){a=a|0;var b=0,c=0;b=Kb(a);v[22640]=0;T(251,a+12|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){b=gb-16|0;gb=b;v[b+12>>2]=0;v[22640]=0;cf(a+32|0,b+12|0,b+8|0);c=v[22640];v[22640]=0;a:{if((c|0)!=1){gb=b+16|0;break a}V(0)|0;O()|0;Bb();L()}return a|0}a=P()|0;O()|0;vb(b);S(a|0);L()}function sha(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[wb(a)>>2]){d=gb-16|0;gb=d;c=pB(d,a,1);wb(a);RA(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;$b(c);gb=d+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=jS(d+8|0,$q(a,Ae(a)+1|0),Ae(a),c);RA(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;iS(a,c);QA(c);gb=d+32|0}function Xma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,422);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,422)}return a|0}function SC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;cE(a);wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-20|0;Wk(e-20|0,c);e=v[d>>2]-20|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}jc(a,f);jc(a+4|0,b+8|0);jc(wb(a),cc(b));v[b>>2]=v[b+4>>2];SD(a,Ze(a))}function Rma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,826);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,826)}return a|0}function Rea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,225);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,225)}return a|0}function Oea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,326);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,326)}return a|0}function Ipa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;$X(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){t[b+2|0]=0;t[b|0]=0;t[b+1|0]=0}}function $C(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[Bf(d+15|0,d+14|0)|0];e=a>>>0<15|b>>>0<2;if(!e){t[d+13|0]=1;t[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=w[Bf(d+13|0,d+12|0)|0]}gb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function zla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,71);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,71)}return a|0}function gZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=Pb(a,120);a:{if(d){bc(c+24|0,b,120);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;e=b+120|0;while(1){Kf(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}gb=a+16|0}gb=c+32|0;return d|0}function Tea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,73);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,73)}return a|0}function Se(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;yE(b+9|0);v[a>>2]=v[b>>2];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;c=v[b+24>>2];v[a+20>>2]=v[b+20>>2];v[a+24>>2]=c;t[a+28|0]=w[b+28|0];gb=b+32|0}function Mea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,60);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,60)}return a|0}function Lf(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=w[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function HQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])|zb(w[b+1|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function Ena(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,91);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Qb(b,0,91)}return a|0}function EQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b+1|0])|zb(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e<<1}function Cca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;f=fi(b,c);d=Kc(a);if(f>>>0>d>>>0){g=d;h=f-d|0;d=Ab(a);Em(a,g,h,d,0,d,0)}d=Jb(a);if((b|0)!=(c|0)){while(1){zd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[e+15|0]=0;zd(d,e+15|0);gh(a,f);gb=e+16|0}function s4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;a:{if(v[b>>2]){if(!dd(c)){Nw(c,14831)}e=v[b+4>>2];kb[v[v[e>>2]+24>>2]](d,e,v[b>>2]);v[22640]=0;Q(1183,c|0,d|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break a}vb(d)}Dc(a,c);gb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function lX(a){var b=0,c=0,d=0,e=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+38|0;e=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;b=(w[b|0]|w[b+1|0]<<8)+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function Y8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=mh(a);a:{b=b+4|0;c=qf(b);if(!c){break a}v[22640]=0;R(2043,a|0,c|0);d=v[22640];v[22640]=0;if((d|0)!=1){d=v[b+4>>2];b=v[b>>2];v[22640]=0;Y(2044,a|0,b|0,d|0,c|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Gt(e);S(a|0);L()}}function JO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=fi(b,c);a:{if(e>>>0<=hg(a)>>>0){if(pc(a)>>>0<e>>>0){v[d+12>>2]=b;HO(d+12|0,pc(a));Bg(b,v[d+12>>2],v[a>>2]);rr(a,v[d+12>>2],c,e-pc(a)|0);break a}jn(a,Bg(b,c,v[a>>2]));break a}vv(a);gp(a,vh(a,e));rr(a,b,c,e)}gb=d+16|0}function Bga(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Pb(b,8)){Hp(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;gd(c+16|0,b,c+8|0);break a}u[c+16>>1]=0;b=4;while(1){d=w[c+16|0]|w[c+17|0]<<8;t[a|0]=d;t[a+1|0]=d>>>8;a=a+2|0;b=b-1|0;if(b){continue}break}}gb=c+32|0}function bO(a,b,c){a:{switch(b|0){case 0:lk(a,0,c);return;case 1:lk(a,1,c);return;case 2:lk(a,2,c);return;case 3:lk(a,3,c);return;case 4:lk(a,4,c);return;case 5:lk(a,5,c);return;case 6:JM(a,25488,c);return;case 7:JM(a,26512,c);return;case 8:lk(a,6,c);return;default:break a}}Kb(a)}function Lh(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;v[c+16>>2]=b;v[c+20>>2]=d;d=gb-16|0;gb=d;b=c+8|0;e=v[b>>2];b=v[b>>2]+xb(b)|0;v[22640]=0;Sn(a,e,b);a=v[22640];v[22640]=0;a:{if((a|0)!=1){gb=d+16|0;break a}V(0)|0;O()|0;Bb();L()}gb=c+32|0}function st(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;v[b+12>>2]=12;v[b+8>>2]=32;a:{if(!v[Fb(b+12|0,b+8|0)>>2]){break a}d=15;while(1){e=yo(a);v[b+8>>2]=32;c=c^e;if(y[Fb(b+12|0,b+8|0)>>2]<=d>>>0){break a}c=c<<15;d=d+15|0;continue}}gb=b+16|0;a=v[b+12>>2];return(a>>>0>31?-1:-1<<a^-1)&c}function fpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=Pb(a,64);a:{if(d){dD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;e=b- -64|0;while(1){Kk(b);b=b+2|0;if((e|0)!=(b|0)){continue}break}gb=a+16|0}gb=c+32|0;return d|0}function V8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-48|0;gb=d;v[d+44>>2]=b;zl(d+8|0,c);b=d+24|0;v[b>>2]=v[d+44>>2];Dc(b+4|0,d+8|0);v[22640]=0;R(2046,a+4|0,d+24|0);a=v[22640];v[22640]=0;if((a|0)!=1){zk(d+24|0);vb(d+8|0);gb=d+48|0;return}a=P()|0;O()|0;zk(d+24|0);vb(d+8|0);S(a|0);L()}function G4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;if(!w[a+44|0]){e=(c|0)>0?c:0;if((c|0)>=1){while(1){if(((g=a,h=Ig(t[b|0]),f=v[v[a>>2]+52>>2],kb[f](g|0,h|0)|0)|0)==-1){return d|0}b=b+1|0;d=d+1|0;if((d|0)!=(e|0)){continue}break}}return e|0}return Ek(b,1,c,v[a+32>>2])|0}function _d(a,b){var c=0,d=0,e=0,f=0;c=v[a+4>>2];d=c+b|0;v[a+4>>2]=d;if((d|0)<=v[a+8>>2]){d=v[a>>2]+(c>>3)|0;a=c&7;c=w[d|0]&255>>>a;a=a+b|0;a:{if((a|0)<9){b=a;break a}while(1){b=a-8|0;e=c<<b|e;f=(a|0)>16;c=w[d+1|0];a=b;d=d+1|0;if(f){continue}break}}a=c>>>8-b|e}else{a=0}return a}function Sc(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[22640]=0;v[b+4>>2]=32767;a=ld(b+12|0,b+4|0);c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}v[22640]=0;a=Nf(b+8|0,a);c=v[22640];v[22640]=0;if((c|0)==1){break a}gb=b+16|0;return u[a>>1]}V(0)|0;O()|0;Bb();L()}function Os(a,b){var c=0,d=0;c=-1;a:{if((a|0)==-1){break a}d=v[b+76>>2]>=0;b:{c:{c=v[b+4>>2];d:{if(!c){FI(b);c=v[b+4>>2];if(!c){break d}}if(v[b+44>>2]-8>>>0<c>>>0){break c}}c=-1;if(d){break b}break a}c=c-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;c=a;if(!d){break a}}}return c}function mv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;g=Zf(a,c);se(e+8|0,v[a+28>>2]);f=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=f;a:{b:{if(!g){f=-1;if(!id(a,5)){break b}break a}f=v[g+8>>2]}kb[d|0](v[a+28>>2],b,f)}a=Sf(a,g,c,e+24|0);gb=e+32|0;return a|0}function co(a,b,c){var d=0,e=0,f=0;a:{if(b>>>0<1){d=a;break a}while(1){d=pqa(a,b,10,0);e=jb;f=e;e=mqa(d,e,10,0);c=c-1|0;t[c|0]=a-e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=d-B(a,10)|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function Aka(a,b){a=a|0;b=b|0;var c=0,d=0;b=gb-16|0;gb=b;c=-1;a:{if(!_j(a,b+8|0)){break a}c=0;if(!TT(b+8|0)){break a}c=-1;if(!Rf(a,4)){break a}c=gb-16|0;gb=c;if(FT(a,c+8|0)){a=c+8|0;d=Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}gb=c+16|0;c=d>>>31|0}gb=b+16|0;return c|0}function v7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;Jp(a);v[a>>2]=55668;v[22640]=0;d=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;Q(2109,cc(a)|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){gb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function s7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;Jp(a);v[a>>2]=55812;v[22640]=0;d=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;Q(2110,cc(a)|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){gb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function qn(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[wb(a)>>2]){c=gb-16|0;gb=c;a=jD(c,a);iD(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;$b(a);gb=c+16|0;return}d=gb-32|0;gb=d;c=wb(a);c=gD(d+8|0,hD(a,Ch(a)+1|0),Ch(a),c);iD(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;IY(a,c);fD(c);gb=d+32|0}function Hpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a;d=mh(a);a:{if(!b){break a}v[22640]=0;R(511,c|0,b|0);e=v[22640];v[22640]=0;if((e|0)!=1){v[22640]=0;jY(c,b);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;_C(d);S(a|0);L()}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function F_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-32|0;gb=e;v[e+24>>2]=d;v[e+28>>2]=c;v[22640]=0;Y(259,e+8|0,b|0,e+28|0,e+24|0);c=v[22640];v[22640]=0;if((c|0)!=1){qF(e+16|0,e+8|0);bk(a,e+16|0);pe(e+16|0);pe(e+8|0);pe(b);gb=e+32|0;return}a=P()|0;O()|0;pe(b);S(a|0);L()}function CM(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=v[v[a+16>>2]+1074404>>2];v[22640]=0;v[c+12>>2]=0;U(1544,a+4208|0,B(b,254)|0,c+12|0);b=v[22640];v[22640]=0;a:{if((b|0)==1){b=V(88880)|0;if((O()|0)!=(ea(88880)|0)){break a}Z(b|0)|0;$()}v[a+4220>>2]=0;gb=c+16|0;return}S(b|0);L()}function sna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;oC(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){pC(b)}return a|0}function fha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;UR(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){IA(b)}return a|0}function YE(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;u[(v[a+1068>>2]<<1)+d>>1]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=bd(v[a+1060>>2])+v[a+1068>>2]|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function Jm(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,872)+a|0)+1075648>>2];if(!f){break a}if(!Fj(f)){break a}e=w[f+34|0];if(e-251>>>0<5|!e){break a}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break a}kb[v[v[e>>2]+92>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,872)+a|0)+1075834>>1]=65535}}function D_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-32|0;gb=e;Jp(a);v[a>>2]=28424;f=cc(a);b=gj(e+16|0,b);c=v[c>>2];d=v[d>>2];g=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=g;Br(f);v[f>>2]=28552;b=e+8|0;gj(f+4|0,b);v[f+16>>2]=d;v[f+12>>2]=c;pe(b);gb=e+32|0;return a|0}function ou(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[22640]=0;R(311,c|0,d|0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){im(v[a+16>>2],v[a>>2],Lp(a))}}function oE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;_D(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){ZD(b)}return a|0}function ms(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[22640]=0;R(218,c|0,d|0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){im(v[a+16>>2],v[a>>2],Lp(a))}}function ZQ(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-28|0;v[b+8>>2]=d;v[22640]=0;R(966,c|0,d|0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){iB(v[a+16>>2],v[a>>2],GY(a))}}function Vv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;CD(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){BD(b)}return a|0}function Tu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;OU(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){NU(b)}return a|0}function GV(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=-128;v[22640]=0;v[b+4>>2]=127;a=ld(b+12|0,b+4|0);c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}v[22640]=0;a=Nf(b+8|0,a);c=v[22640];v[22640]=0;if((c|0)==1){break a}gb=b+16|0;return t[a|0]}V(0)|0;O()|0;Bb();L()}function y8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=gb-16|0;gb=c;v[c+4>>2]=1;f=c,g=Mc(324,4),v[f+8>>2]=g;d=c;e=v[c+8>>2];v[22640]=0;Q(2107,e|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){b=a;a=Kp(d);yK(b,cc(a),a);xK(d);gb=c+16|0;break a}a=P()|0;O()|0;xK(d);S(a|0);L()}}function wf(a){a=a|0;var b=0,c=0,d=0,e=0;c=gb-16|0;gb=c;v[c+12>>2]=-1;b=gb-16|0;gb=b;d=2;e=v[a>>2];if(e>>>0>=2){v[b+12>>2]=e>>>1;v[b+8>>2]=-1-v[a>>2];d=Fb(b+12|0,b+8|0);v[b+12>>2]=v[a>>2]+v[d>>2];v[b+8>>2]=v[c+12>>2];d=v[Fb(b+12|0,b+8|0)>>2]}gb=b+16|0;gb=c+16|0;return d|0}function rR(a){var b=0,c=0,d=0,e=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-12|0;v[b+8>>2]=c;v[22640]=0;R(1142,e|0,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){im(v[a+16>>2],b,Lp(a))}}function lha(a,b){a=a|0;b=b|0;var c=0;c=gb-48|0;gb=c;t[c+40|0]=w[b|0];Qr(c+16|0,c+40|0);b=zb(v[c+16>>2]);Qr(c+8|0,c+40|0);b=Bj(c+24|0,b,zb(v[c+8>>2]+1|0));v[22640]=0;Q(1110,a|0,b|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){vb(b);gb=c+48|0;return}a=P()|0;O()|0;vb(b);S(a|0);L()}function iS(a,b){var c=0,d=0,e=0,f=0,g=0;Yu(a);wb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-32|0;RA(e-32|0,c);e=v[d>>2]-32|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}wc(a,f);wc(a+4|0,b+8|0);wc(wb(a),cc(b));v[b>>2]=v[b+4>>2];SA(a,Ae(a))}function QA(a){var b=0,c=0,d=0,e=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}e=v[b+16>>2];c=c-32|0;v[b+8>>2]=c;v[22640]=0;R(1112,e|0,c|0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){Tk(v[a+16>>2],b,oB(a))}}function x8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=gb-16|0;gb=c;v[c+4>>2]=1;f=c,g=Mc(56,4),v[f+8>>2]=g;d=c;e=v[c+8>>2];v[22640]=0;Q(2108,e|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){b=a;a=Kp(d);yK(b,cc(a),a);uK(d);gb=c+16|0;break a}a=P()|0;O()|0;uK(d);S(a|0);L()}}function O8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;mo(c,a);a=b;if(v[a>>2]){Nd(a);vy(v[a>>2],av(a));d=wb(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=wb(c);d=wb(b),e=v[a>>2],v[d>>2]=e;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Uf(c);gb=c+16|0}function AU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;wb(b);d=mh(a);a:{c=pc(b);if(c){v[22640]=0;R(513,a|0,c|0);e=v[22640];v[22640]=0;if((e|0)==1){break a}d=v[b>>2];e=v[b+4>>2];b=gb-16|0;gb=b;c=Ri(b,a,c);wb(a);dv(d,e,c+4|0);$b(c);gb=b+16|0}return a|0}a=P()|0;O()|0;mn(d);S(a|0);L()}function fe(a){var b=0,c=0,d=0,e=0;o(+a);b=j(1)|0;j(0)|0;e=b;b=b>>>20&2047;if(b>>>0<=1074){if(b>>>0<=1021){return a*0}a=(e|0)>-1?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){d=a+c+-1;break a}a=a+c;d=a;if(!(c<=-.5)){break a}d=a+1}a=d;a=(e|0)>-1?a:-a}return a}function di(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[22640]=0;v[b+4>>2]=255;a=ld(b+12|0,b+4|0);c=v[22640];v[22640]=0;a:{if((c|0)==1){break a}v[22640]=0;a=Nf(b+8|0,a);c=v[22640];v[22640]=0;if((c|0)==1){break a}gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Bb();L()}function Wx(a){var b=0,c=0;a:{if(y[a+20>>2]<=y[a+28>>2]){break a}kb[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break a}return-1}b=v[a+4>>2];c=v[a+8>>2];if(b>>>0<c>>>0){b=b-c|0;kb[v[a+40>>2]](a,b,b>>31,1)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;return 0}function Oda(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[c+8>>2]=b;b=0;a:{if(Nb(a)>>>0>511){break a}if(!Bd(c+8|0)){break a}b=v[c+8>>2];v[22640]=0;R(1532,a|0,c+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Dg(c+8|0);S(a|0);L()}Dg(c+8|0);gb=c+16|0;return b|0}function Cha(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(!Ld(b)){break a}if(v[b+20>>2]==(zb(v[a+20>>2])|0)){v[a+20>>2]=0}tc(a,v[b>>2]);c=x[a+34>>1]&-2|u[b+34>>1]&1;u[a+34>>1]=c;u[a+34>>1]=c&65471|x[b+34>>1]&64;if(!_m(a)){break a}hc(zb(v[a+20>>2]),v[b+20>>2],Yi(a));d=1}return d|0}function gma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,274);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,274)}}function fO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=gb-16|0;gb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Jb(d);Bj(b,a,Ab(d)+a|0);break c}bO(e,c,d);v[22640]=0;U(99,a|0,b|0,e|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Hc(e)}gb=e+16|0;break a}a=P()|0;O()|0;Hc(e);S(a|0);L()}}function cma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,106);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,106)}}function Zy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(!Of(a)){break a}while(1){if(!hi($e(a,e))){break a}d=d+1|0;e=d&65535;if(Of(a)>>>0>e>>>0){continue}break}}b:{if(c){c=65535;if(x[v[v[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0){break b}}c=qh(a,d&65535,b)?d:-1}return c&65535}function Wpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,136);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,136)}}function Mla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c;e=b;if(qp(b,c+24|0)){b=c+28|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>=9){b=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-8|0}else{b=0}}else{b=0}rd(d,e,b);Zl(a,c+24|0,c);yb(c);gb=c+32|0}function kW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,284);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,284)}}function bz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=wd(b);e=df(b);f=wd(b);c=gb-32|0;gb=c;v[c+16>>2]=e;v[c+24>>2]=d;v[c+8>>2]=f;if(Gb(c+24|0,c+16|0)){while(1){d=tq(t[v[c+24>>2]]);t[v[c+8>>2]]=d;Me(c+24|0);Me(c+8|0);if(Gb(c+24|0,c+16|0)){continue}break}}gb=c+32|0;Dc(a,b)}function _ba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=6){Fi(d+12|0);c=z[d+12>>2];a:{if(!((b|0)!=1|c>=C(1))){v[d+12>>2]=0;c=C(0);break a}if((b|0)!=4){break a}c=C(re(C(c*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;Oy(a)}gb=d+16|0}function XE(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;t[v[a+1068>>2]+d|0]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=bd(v[a+1060>>2])+v[a+1068>>2]|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function Wg(a,b){var c=0,d=0,e=0,f=0;c=Ab(a);a:{if((c|0)!=(Ab(b)|0)){break a}d=Jb(a);b=Jb(b);b:{if(!De(a)){if(c){break b}return 1}return!po(d,b,c)}while(1){a=w[b|0];e=w[d|0];f=(a|0)==(e|0);if((a|0)!=(e|0)){break a}b=b+1|0;d=d+1|0;c=c-1|0;if(c){continue}break}}return f}function Tp(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(e*.16666666666666632+(d*(b*.5-e*f)-b))}function Gca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=6){Fi(d+12|0);c=z[d+12>>2];a:{if(!((b|0)!=3|c>=C(1))){v[d+12>>2]=0;c=C(0);break a}if((b|0)!=4){break a}c=C(re(C(c*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;Oy(a)}gb=d+16|0}function tga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;f=c;d=b;if(qp(b,c+24|0)){e=JY(c+24|0)}rd(f,d,e);d=Zl(a,c+24|0,c);yb(c);a:{if(!(e&1)){break a}v[22640]=0;Q(350,b|0,1)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Xd(d);S(a|0);L()}gb=c+32|0}function jm(a){var b=0,c=0,d=0,e=0;Qp(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=wb(d);v[22640]=0;b=b-12|0;R(218,c|0,b|0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[d+4>>2]=e;im(wb(a),v[a>>2],qg(a))}}function fna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,42);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,42)}}function e4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{if((d|0)!=(e|0)){while(1){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}b=b+4|0;d=d+4|0;if((e|0)!=(d|0)){continue}break}}a=(b|0)!=(c|0)}return a|0}function bpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,34);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,34)}}function bma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,72);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,72)}}function Vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;v[a+4>>2]=b;v[a>>2]=0;b=yu(a+8|0,d);v[22640]=0;Q(1653,a+20|0,c|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&224|25;return a|0}a=P()|0;O()|0;Hb(b);S(a|0);L()}function Jt(a){var b=0,c=C(0),d=0;if(w[a+4232|0]>=5){t[a+4232|0]=0}if(t[a+4233|0]<=-1){t[a+4233|0]=127}b=t[a+4234|0];if((b|0)<=-1){t[a+4234|0]=127;b=127}d=a;a:{if((EM(a)|0)==3){c=C(C(1)-me(C(2),C(-C((b&255)+1|0))));break a}c=me(C(2),C(-C((b&255)>>>0)))}z[d+4224>>2]=c}function SY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,50);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,50)}}function AK(a){var b=0,c=0,d=0,e=0;d=gb-16|0;gb=d;b=a+120|0;yi(b);c=gb-16|0;gb=c;v[c+8>>2]=d+8;a=gb-16|0;gb=a;e=v[13988];v[a+8>>2]=v[13987];v[a+12>>2]=e;e=v[13986];v[a>>2]=v[13985];v[a+4>>2]=e;b=kb[v[Th(a,Vg(b))>>2]](c+8|0,b)|0;gb=a+16|0;gb=c+16|0;gb=d+16|0;return b}function h4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{if((d|0)!=(e|0)){while(1){a=-1;if((b|0)==(c|0)){break a}f=t[b|0];g=t[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}b=b+1|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}a=(b|0)!=(c|0)}return a|0}function bha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=mh(a);a:{d=of(b);if(d){v[22640]=0;R(1126,a|0,d|0);e=v[22640];v[22640]=0;if((e|0)==1){break a}c=gb-16|0;gb=c;e=v[b>>2];f=v[b+4>>2];b=bs(c,a,d);dv(e,f,b+4|0);$b(b);gb=c+16|0}return a|0}a=P()|0;O()|0;Jf(c);S(a|0);L()}function il(a,b,c,d){var e=0;if(d&2048){t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}e=w[b|0];if(e){while(1){t[a|0]=e;a=a+1|0;e=w[b+1|0];b=b+1|0;if(e){continue}break}}e=d&74;b=111;a:{if((e|0)==64){break a}b=d&16384?88:120;if((e|0)==8){break a}b=c?100:117}t[a|0]=b}function RF(a,b){var c=0,d=0;c=gb-16|0;gb=c;Ec(c+8|0,a);v[22640]=0;a=T(21,c+8|0)|0;d=v[22640];v[22640]=0;a:{if((d|0)==1){break a}v[22640]=0;a=Q(22,a|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break a}Vb(c+8|0);gb=c+16|0;return a}a=P()|0;O()|0;Vb(c+8|0);S(a|0);L()}function QQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=zb(w[b|0])^128,t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function PK(a,b){a=a|0;b=b|0;var c=C(0),d=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125));d=C(c*c);c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125));c=C(K(C(d+C(c*c))))}return C(c)}function MR(a,b){var c=0,d=0,e=0;u[a+24>>1]=0;v[a+20>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;e=a;c=3546895/+(b>>>0);d=c*.25;a:{if(D(d)<2147483648){b=~~d;break a}b=-2147483648}v[e+16>>2]=b;b=MT(c-+(b<<2));v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=b;v[a+12>>2]=jb}function $N(a,b){var c=0,d=0,e=0;c=a;if(v[c>>2]){Ch(c);kT(c);Wi(c);Ch(c);iB(wb(c),v[c>>2],Wi(c));d=wb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0}ip(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function rh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(b?1:v[a+480180>>2]&1){e=v[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function mX(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=778924148?(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1297108297:0){break a}b=a+34|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+36|0;return(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return 0}function fka(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,4);a:{if(d){_B(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}t[c+16|0]=0;a=4;while(1){t[b|0]=w[c+16|0];b=b+1|0;a=a-1|0;if(a){continue}break}}gb=c+32|0;return d|0}function PI(a,b,c){var d=0;d=gb-32|0;gb=d;v[d+28>>2]=c;v[d+24>>2]=0;v[d+12>>2]=4;kj(d+16|0,a,d+24|0,v[Fb(d+28|0,d+12|0)>>2]);xb(d+16|0);v[d+16>>2]=4;Fb(d+28|0,d+16|0);v[d+16>>2]=v[d+24>>2];a=d+16|0;v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);gb=d+32|0}function iF(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(e);v[22640]=0;b=b-12|0;R(311,c|0,b|0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[e+4>>2]=d;im(wb(a),v[a>>2],qg(a))}}function VM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;uh(a+12|0,d);if(b){d=b;if(b>>>0>2097151){nd(8513);L()}f=Mc(d<<11,4)}v[a>>2]=f;c=(c<<11)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=(b<<11)+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function tl(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=mt(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function RQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Fb(d+12|0,d+8|0)>>2];b=zb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=oh(w[b|0]),t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=d+16|0;return e|0}function PQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];f=v[Fb(e+12|0,e+8|0)>>2];b=zb(b);if(f){a=v[a+20>>2];c=f;while(1){d=zb(w[b|0])+d|0;t[a|0]=d;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}gb=e+16|0;return f|0}function Opa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Pb(a,64)){dD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;d=b- -64|0;while(1){Kf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0}gb=c+32|0}function wY(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;zv(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){cd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){ZC(b)}return a}function wH(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;v[b>>2]=0;t[c+15|0]=0;Qh(a,c+15|0);d=w[c+15|0];v[b>>2]=d>>>2;a:{e=d&3;if(!e){break a}d=1;while(1){t[c+15|0]=0;Qh(a,c+15|0);v[b>>2]=v[b>>2]|w[c+15|0]<<(d<<3)-2;if((d|0)==(e|0)){break a}d=d+1|0;continue}}gb=c+16|0}function mU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;CX(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){cd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){BX(b)}return a}function lW(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;fW(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){eW(b)}return a}function cna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;RV(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Kk(b)}}function _j(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;Hp(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){cd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){ak(b)}return a}function YF(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;IF(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){cd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){Aw(b)}return a}function YC(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;XX(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){cd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){WX(b)}return a}function RU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;OU(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){cd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){NU(b)}return a}function OC(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;CX(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){BX(b)}return a}function Ms(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;d=aa(16)|0;EH();a=pd(c+8|0,a,90536);v[22640]=0;e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;W(2413,d|0,c|0,b|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){ia(d|0,78992,2414);L()}a=P()|0;O()|0;da(d|0);S(a|0);L()}function BV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;qV(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){cd(a,xb(c+24|0))}gb=c+32|0;a=(d|0)==(e|0);if(!a){pV(b)}return a}function yv(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-48;v[22640]=0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){cY(v[a+16>>2],v[a>>2],(v[cc(a)>>2]-v[a>>2]|0)/48|0)}}function tha(a){a=a|0;var b=0,c=0,d=0;c=gb-32|0;gb=c;b=255;a:{if(Oi(a)>>>0<=49){b=UA(c,v[a+12>>2]);v[22640]=0;R(1100,a|0,b|0);d=v[22640];v[22640]=0;if((d|0)==1){break a}Xm(b);Pi(a,Oi(a)-1&255);b=Oi(a)-1|0}gb=c+32|0;return b&255}a=P()|0;O()|0;Xm(b);S(a|0);L()}function sO(a,b){var c=0,d=0;v[a+4>>2]=b;v[a>>2]=90568;v[a+20>>2]=0;v[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;v[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;v[a+8>>2]=d;v[a+32>>2]=d>>>0<31?-1>>>31-d|0:-1;v[a+28>>2]=b>>>0<c>>>0?0:-1>>>32-d|0;v[a+16>>2]=(B(c,d)-b|0)+c;return a}function eha(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Pb(a,27)){UR(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;d=b+27|0;while(1){Kf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0}gb=c+32|0}function Xu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;aV(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){IB(b)}}function W$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Og(a,v[b+8>>2],0)){Uw(b,c,d);return}e=v[a+12>>2];f=a+16|0;tG(f,b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){tG(a,b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function UB(a){var b=0,c=0,d=0;if(v[a>>2]){c=a;b=v[a+4>>2];d=v[a>>2];if((b|0)!=(d|0)){while(1){b=b-24|0;yb(b);if((b|0)!=(d|0)){continue}break}}v[c+4>>2]=d;c=v[a>>2];a=av(a);v[22640]=0;Nc(c,B(a,24),4);a=v[22640];v[22640]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function mO(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;if(v[a+4>>2]==v[b+4>>2]){d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=c;b=v[b>>2];v[a+16>>2]=b;v[a+20>>2]=f;v[a+8>>2]=e;v[a+12>>2]=d;v[a>>2]=b;v[a+4>>2]=f;d=!BN(a+8|0,a)}gb=c+32|0;return d}function eV(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Pb(a,32)){aV(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;d=b+32|0;while(1){Kf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0}gb=c+32|0}function R5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;d=cq(a);e=Ab(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);wi(d+(e<<2)|0,b,c);b=c+e|0;gh(a,b);v[f+12>>2]=0;Fe(d+(b<<2)|0,f+12|0);break a}vI(a,d,(c+e|0)-d|0,e,e,0,c,b)}gb=f+16|0;return a|0}function Ola(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;bc(c+24|0,b,1100);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function kv(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-6;v[22640]=0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){wC(v[a+16>>2],v[a>>2],(v[cc(a)>>2]-v[a>>2]|0)/6|0)}}function gd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=gb-16|0;gb=d;e=v[b>>2];g=v[b+8>>2];f=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=f;h=v[v[e>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=f;kb[h|0](a,e,g,d);i=b,j=xb(a)+v[b+8>>2]|0,v[i+8>>2]=j;gb=d+16|0}function Tma(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Pb(a,2)){RV(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;d=b+2|0;while(1){Kf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0}gb=c+32|0}function $ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;zM(a,b,c,d);v[a+4232>>2]=1056964608;b=a+4224|0;v[b>>2]=1056964608;v[b+4>>2]=1048406533;b=a+4216|0;v[b>>2]=1020054733;v[b+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1065353216;v[a>>2]=52372;return a|0}function Vq(a,b,c,d){var e=0,f=0,g=0,h=0;a:{e=Nl(a,b);if((e|0)==255){break a}if(vk(a)){break a}b=ln(a+314|0,e);e=ZR(e);if(f=1,g=t[lc(b,10)|0]&1,h=d,h?f:g){Yh(v[a>>2],e- -64&65535,YR(c,w[lc(b,2)|0]))}if(d){break a}Yh(v[a>>2],e+67&65535,YR(c,w[lc(b,3)|0]))}}function Pt(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-2048;v[22640]=0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){SM(v[a+16>>2],v[a>>2],v[cc(a)>>2]-v[a>>2]>>11)}}function JG(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=83504;b=v[a+8>>2];v[22640]=0;c=fa(2454)|0;d=v[22640];v[22640]=0;a:{if((d|0)!=1){if((b|0)==(c|0)){break a}b=v[a+8>>2];v[22640]=0;ux(b);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}V(0)|0;O()|0;Bb();L()}return a|0}function Gu(a){var b=0,c=0;a:{if(w[a+4|0]|(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1414687062){break a}b=a+6|0;if(Ib(w[b|0]|w[b+1|0]<<8)>>>0>1){break a}b=a+12|0;if(Ib(w[b|0]|w[b+1|0]<<8)){break a}a=a+16|0;c=(Ib(w[a|0]|w[a+1|0]<<8)|0)==20}return c}function qE(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;bc(c+24|0,b,37);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){Qb(b,0,37)}}function W2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Ec(g,d);v[22640]=0;b=T(2458,g|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){Vb(g);gH(a,f+24|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Vb(g);S(a|0);L()}function V2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Ec(g,d);v[22640]=0;b=T(2458,g|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){Vb(g);fH(a,f+16|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Vb(g);S(a|0);L()}function UI(a,b){var c=0,d=0,e=0;o(+a);c=j(1)|0;d=j(0)|0;e=c;c=c>>>20&2047;if((c|0)!=2047){if(!c){c=b;if(a==0){b=0}else{a=UI(a*0x10000000000000000,b);b=v[b>>2]+-64|0}v[c>>2]=b;return a}v[b>>2]=c-1022;l(0,d|0);l(1,e&-2146435073|1071644672);a=+n()}return a}function ID(a){var b=0,c=0,d=0,e=0;b=a+5|0;b=w[b|0]|w[b+1|0]<<8;c=b+w[a+2|0]|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;e=c;a=a+3|0;a=w[a|0]|w[a+1|0]<<8;d=a>>>30|0;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;if(b>>>0<47){a=a+1|0}jb=a;return b}function EK(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;u[c+10>>1]=0;u[c+8>>1]=65535;a:{if(At(c+12|0,c+10|0,c+8|0)){a=a+24|0;d=0;if(!ke(v[a>>2]+484344|0,b&65535)){break a}d=v[_b(v[a>>2]+484344|0,b)+12>>2];break a}d=0}a=d;gb=c+16|0;return a|0}function vga(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-2496|0;gb=c;lP(b,c,c+2496|0);b=hc(a,c,2496);v[b+2496>>2]=0;a:{if(v[b>>2]<=-1){break a}d=1;while(1){if(v[b+(d<<2)>>2]){break a}d=d+1|0;if((d|0)!=624){continue}break}v[b>>2]=-2147483648}gb=c+2496|0;return a|0}function nz(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=gb-16|0;gb=b;d=qf(a);e=b,f=Sb(a),v[e+8>>2]=f;e=b,f=Wb(a),v[e>>2]=f;if(Gb(b+8|0,b)){c=+(d>>>0);while(1){a=v[b+8>>2];A[a>>3]=A[a>>3]/c;A[a+8>>3]=A[a+8>>3]/c;Wo(b+8|0);if(Gb(b+8|0,b)){continue}break}}gb=b+16|0}function wea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-32|0;gb=d;f=Zf(a,c);se(d+8|0,v[a+28>>2]);e=v[d+20>>2];v[d+24>>2]=v[d+16>>2];v[d+28>>2]=e;a:{b:{if(!f){e=-1;if(!id(a,5)){break b}break a}e=v[f+8>>2]}QO(v[a+28>>2],b,e)}Sf(a,f,c,d+24|0);gb=d+32|0}function oga(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,16);a:{if(d){Zv(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=b+16|0;while(1){t[b|0]=0;b=b+1|0;if((a|0)!=(b|0)){continue}break}}gb=c+32|0;return d|0}function ema(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Gg(a);a:{if(!b){break a}v[22640]=0;R(830,a|0,b|0);e=v[22640];v[22640]=0;if((e|0)!=1){v[22640]=0;U(831,a|0,b|0,c|0);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Zr(d);S(a|0);L()}return a|0}function b3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Ec(g,d);v[22640]=0;b=T(21,g|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){Vb(g);jH(a,f+24|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Vb(g);S(a|0);L()}function a3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=b;Ec(g,d);v[22640]=0;b=T(21,g|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){Vb(g);iH(a,f+16|0,g+8|0,c,e,b);gb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Vb(g);S(a|0);L()}function Zw(a){a=a|0;var b=0,c=0,d=0;b=v[a+8>>2];v[22640]=0;c=fa(2454)|0;d=v[22640];v[22640]=0;a:{b:{if((d|0)==1){break b}if((b|0)!=(c|0)){b=v[a+8>>2];v[22640]=0;ux(b);b=v[22640];v[22640]=0;if((b|0)==1){break b}}break a}V(0)|0;O()|0;Bb();L()}return a|0}function Pla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;bC(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)|0}function xT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<8)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){nB(a);a=v[c>>2]+256|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}Yc(c);gb=d+16|0}function wW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,33)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){pC(a);a=v[c>>2]+33|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}Yc(c);gb=d+16|0}function j5(a){a=a|0;var b=0,c=0;c=v[a+44>>2];b=v[a+24>>2];if(c>>>0<b>>>0){v[a+44>>2]=b;c=b}a:{if(!(w[a+48|0]&8)){break a}if(y[a+16>>2]<c>>>0){Zn(a,v[a+8>>2],v[a+12>>2],c)}b=v[a+16>>2];a=v[a+12>>2];if(b>>>0<=a>>>0){break a}return Ig(t[a|0])|0}return-1}function iX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Gg(a);a:{if(!b){break a}v[22640]=0;R(637,a|0,b|0);e=v[22640];v[22640]=0;if((e|0)!=1){v[22640]=0;U(638,a|0,b|0,c|0);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;nv(d);S(a|0);L()}return a|0}function MP(a,b,c){var d=0,e=0;d=v[(B(b,872)+a|0)+1075080>>2];a:{if(!(!(d&134218752)|(c|0)!=1)|d&67108864){break a}if(x[a+480188>>1]<=b>>>0){c=x[(B(b,872)+a|0)+1075778>>1];b=c?c-1|0:b}b=b&65535;if(b>>>0>126){break a}e=w[((b<<5)+a|0)+480288|0]}return e}function LZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Gg(a);a:{if(!b){break a}v[22640]=0;R(367,a|0,b|0);e=v[22640];v[22640]=0;if((e|0)!=1){v[22640]=0;U(368,a|0,b|0,c|0);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;pu(d);S(a|0);L()}return a|0}function Dv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Gg(a);a:{if(!b){break a}v[22640]=0;R(513,a|0,b|0);e=v[22640];v[22640]=0;if((e|0)!=1){v[22640]=0;U(514,a|0,b|0,c|0);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;mn(d);S(a|0);L()}return a|0}function DD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Gg(a);a:{if(!b){break a}v[22640]=0;R(425,a|0,b|0);e=v[22640];v[22640]=0;if((e|0)!=1){v[22640]=0;U(426,a|0,b|0,c|0);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;mn(d);S(a|0);L()}return a|0}function Bz(a,b,c){var d=0,e=0,f=0;e=gb-16|0;gb=e;f=v[b+656>>2];d=0;a:{if(!f){break a}f=ew(f,c);d=a+1074312|0;Db(e+8|0,d,31);a=0;if(!Cb(e+8|0)){Db(e,d,93);a=Cb(e)^1}if(!(t[uO(b,c)+6|0]&1)){d=0;if(!(t[f+12|0]&1)|a){break a}}d=$c(f)^1}gb=e+16|0;return d}function en(a){var b=0,c=0,d=0,e=0;Yu(a);if(v[a>>2]){c=a;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}wb(c);v[22640]=0;b=b-32|0;e=v[22640];v[22640]=0;if((e|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[c+4>>2]=d;lV(wb(a),v[a>>2],$h(a))}}function ae(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-1;v[22640]=0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}if(v[a>>2]){al(v[a+16>>2],v[a>>2],v[cc(a)>>2]-v[a>>2]|0)}}function FI(a){var b=0,c=0;b=w[a+74|0];t[a+74|0]=b-1|b;if(y[a+20>>2]>y[a+28>>2]){kb[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function xw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=(b<<3)+e;a=v[c>>2];if((a|0)!=v[c+4>>2]){while(1){ak(a);a=v[c>>2]+8|0;v[c>>2]=a;if(v[c+4>>2]!=(a|0)){continue}break}}Yc(c);gb=d+16|0}function poa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=gb-16|0;gb=d;ME(d+8|0,a);FW(c+24|0,d+8|0);gb=d+16|0;ug(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=Fc(c+8|0,c);gb=c+32|0;return a|0}function nqa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=b^d;h=e>>31;f=b>>31;a=a^f;i=a-f|0;g=b;b=b>>31;g=(g^b)-((a>>>0<f>>>0)+b|0)|0;a=d>>31;b=c^a;c=d>>31;e=e>>31;a=pqa(i,g,b-a|0,(c^d)-((a>>>0>b>>>0)+c|0)|0)^e;b=a-e|0;jb=(h^jb)-((a>>>0<e>>>0)+h|0)|0;return b}function TN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-16|0;gb=d;b:{c:{if(!b){b=a;a=Jb(c);Bj(b,a,Ab(c)+a|0);break c}QN(d,c);v[22640]=0;U(99,a|0,b|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Hc(d)}gb=d+16|0;break a}a=P()|0;O()|0;Hc(d);S(a|0);L()}}function PW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,48)+e;if(v[c>>2]!=v[c+4>>2]){while(1){OW(v[c>>2]);a=v[c>>2]+48|0;v[c>>2]=a;if((a|0)!=v[c+4>>2]){continue}break}}Yc(c);gb=d+16|0}function YN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=gb-16|0;gb=d;b:{c:{if(!b){b=a;a=Jb(c);Bj(b,a,Ab(c)+a|0);break c}bO(d,b,c);v[22640]=0;R(100,a|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}Hc(d)}gb=d+16|0;break a}a=P()|0;O()|0;Hc(d);S(a|0);L()}}function OB(a,b){var c=0,d=0,e=0,f=0;c=a;d=a+1024|0;if((d|0)!=(a|0)){f=b?224:240;while(1){a=c;b=a+16|0;if((a|0)!=(b|0)){while(1){e=((f&w[lc(a,0)|0])!=0)+e|0;a=a+4|0;if((b|0)!=(a|0)){continue}break}}c=c+16|0;if((d|0)!=(c|0)){continue}break}}return e}function IY(a,b){var c=0,d=0,e=0,f=0,g=0;f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-28|0;iD(e-28|0,c);e=v[d>>2]-28|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}wc(a,f);wc(a+4|0,b+8|0);wc(wb(a),cc(b));v[b>>2]=v[b+4>>2]}function wka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;bn(a,b);d=c,e=Sb(a),v[d+8>>2]=e;d=c,e=Wb(a),v[d>>2]=e;if(Gb(c+8|0,c)){b=0;while(1){a=v[c+8>>2];b=zb(w[a|0])+b&255;d=a,e=zb(b),t[d|0]=e;Me(c+8|0);if(Gb(c+8|0,c)){continue}break}}gb=c+16|0}function v6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;e=_s(a);v[a>>2]=77092;f=Kb(a+32|0);v[a+48>>2]=c;v[a+44>>2]=0;v[22640]=0;R(150,a|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){gb=d+16|0;return a|0}a=P()|0;O()|0;vb(f);um(e);S(a|0);L()}function rO(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(!b){break a}g=c;h=c>>31;c=1;while(1){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=zc(nqa(mqa(d,d>>31,g,h),jb,256,0),jb);v[a+4>>2]=f-d;v[a>>2]=d+f;if((b|0)==(c|0)){break a}a=a+8|0;c=c+1|0;continue}}}function hna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;v[d+12>>2]=c;tc(d+12|0,256);tc(d+12|0,65535);e=x[d+12>>1];yf(a,e);if(e){c=0;while(1){f=w[b+c|0];g=bj(a,c),h=f,u[g>>1]=h;c=c+1|0;if((e|0)!=(c|0)){continue}break}}gb=d+16|0}function coa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=d;d=Zf(a,c);se(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(id(a,5)){break a}}eX(v[a+28>>2],b,v[e+24>>2],0)}Sf(a,d,c,e+16|0);gb=e+32|0}function XY(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(Pb(a,512)){qD(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}a=gb-16|0;gb=a;d=b+512|0;while(1){Ik(b);b=b+4|0;if((d|0)!=(b|0)){continue}break}gb=a+16|0}gb=c+32|0}function DY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=b;a=Dn(d+8|0,a+8|0,eD(b,c));c=v[a>>2];if((c|0)!=v[a+4>>2]){while(1){Gr(c,v[d+24>>2]);v[a>>2]=v[a>>2]+2;nD(d+24|0);c=v[a>>2];if((c|0)!=v[a+4>>2]){continue}break}}Yc(a);gb=d+32|0}function vV(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;qV(c+24|0,b);e=xb(c+24|0);d=v[c+28>>2];f=v[c+24>>2];v[c+8>>2]=f;v[c+12>>2]=d;v[c>>2]=f;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((d|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0;if((d|0)!=(e|0)){pV(b)}}function fR(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)!=(c|0)){while(1){d=zb(w[b|0]);e=v[a+4>>2];g=e>>>8|0;f=v[a>>2];e=(e&255)<<24|f>>>8;d=(((d^f)&255)<<3)+19344|0;f=v[d>>2];d=v[d+4>>2]^g;v[a>>2]=e^f;v[a+4>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function Dp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=gb-16|0;gb=f;d=Kc(a);e=Ab(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);Ng(d+e|0,b,c);b=c+e|0;gh(a,b);t[f+15|0]=0;zd(b+d|0,f+15|0);break a}Ap(a,d,(c+e|0)-d|0,e,e,0,c,b)}gb=f+16|0;return a|0}function Ct(a){var b=0,c=0;b=a+24|0;c=v[b>>2];v[22640]=0;T(1299,c|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){vd(a+68|0);Uf(a+36|0);iq(a+32|0);Bi(b);Ai(a+4|0);bg(a);return a}V(0)|0;O()|0;vd(a+68|0);Uf(a+36|0);iq(a+32|0);Bi(b);Ai(a+4|0);bg(a);Bb();L()}function eea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-32|0;gb=e;v[e+24>>2]=d;d=Zf(a,c);se(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(id(a,5)){break a}}nN(v[a+28>>2],b,v[e+24>>2])}Sf(a,d,c,e+16|0);gb=e+32|0}function VP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a=Sc(Om(a,x[c+70>>1],v[c+48>>2],b,0)-32768|0);a:{if(!d){break a}d=sk(c)-v[c+16>>2]|0;if((d|0)<2){break a}e=a;a=u[(B(b,872)+c|0)+1390>>1];a=Sc(((e-a|0)/(d|0)|0)+a|0)}u[(B(b,872)+c|0)+1390>>1]=a}function NE(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=gb-16|0;gb=d;e=v[a+4>>2];f=e+b|0;v[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0<32){break a}}h=v[a>>2];v[(f>>>0<33?h:(g>>>3&536870908)+h|0)>>2]=0}yp(d+8|0,a,e);xp(d+8|0,b,c);gb=d+16|0}function U2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=gb-16|0;gb=a;v[a+8>>2]=b;Ec(a,d);v[22640]=0;b=T(2458,a|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){Vb(a);eH(f+20|0,a+8|0,c,e,b);gb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Vb(a);S(b|0);L()}function CC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=nc(a+8|0);v[22640]=0;d=T(492,b|0)|0;e=v[22640];v[22640]=0;b:{if((e|0)==1){break b}v[22640]=0;U(383,a|0,b|0,d|0);a=v[22640];v[22640]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;gc(c);S(a|0);L()}}function C4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(!w[a+44|0]){e=(c|0)>0?c:0;if((c|0)>=1){while(1){if((kb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}b=b+4|0;d=d+1|0;if((d|0)!=(e|0)){continue}break}}return e|0}return Ek(b,4,c,v[a+32>>2])|0}function AO(a,b){var c=0,d=0,e=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}d=b;c=v[c>>2];b:{if(c){e=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[e+696>>2]=a;a=(B(a,v[b>>2])|0)/65536|0;break b}if(v[a+696>>2]){break a}a=0}v[d>>2]=a}}function xpa(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;a:{if(!YC(a,b+16|0)){break a}c=0;if(!ZX(b+16|0)){break a}if(v[b+16>>2]==1179472708){c=-1;if(!cd(a,4)){break a}}c=-1;if(!_j(a,b+8|0)){break a}c=v[b+8>>2]==1196314451}gb=b+32|0;return c|0}function MA(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(w[a+530|0]){while(1){d=c&65535;Mi(a,d,1);c=c+1|0;if(d>>>0<255){continue}break}t[a+530|0]=0}t[b+15|0]=0;li(a+4|0,18,b+15|0);fv(a+22|0,18,35866);t[b+14|0]=255;li(a+58|0,256,b+14|0);gb=b+16|0}function Bu(a){a=a|0;var b=0,c=0,d=0,e=0;c=XS(a);if((c|0)!=(a|0)){while(1){b=0;e=a;dX(a);a:{while(1){d=b+e|0;if(w[d|0]){b=b+1|0;if((b|0)!=32){continue}break a}break}if(b>>>0>31){break a}Qb(d,0,32-b|0)}a=a+32|0;if((c|0)!=(a|0)){continue}break}}}function wF(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function _2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=gb-16|0;gb=a;v[a+8>>2]=b;Ec(a,d);v[22640]=0;b=T(21,a|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){Vb(a);hH(f+20|0,a+8|0,c,e,b);gb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Vb(a);S(b|0);L()}function Sp(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function r3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e+12>>2]=b;v[e+8>>2]=d;b=vi(e,e+12|0);v[22640]=0;a=W(2475,a|0,c|0,v[e+8>>2])|0;c=v[22640];v[22640]=0;if((c|0)!=1){ff(b);gb=e+16|0;return a|0}a=P()|0;O()|0;ff(b);S(a|0);L()}function TI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=gb-16|0;gb=e;if(d>>>0<=4294967279){a:{if(d>>>0<=10){Ve(a,c);d=a;break a}f=Xk(d)+1|0;d=mi(a,f);bf(a,d);ng(a,f);ee(a,c)}Ng(d,b,c);t[e+15|0]=0;zd(c+d|0,e+15|0);gb=e+16|0;return}_f();L()}function Kfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;b=(b-a|0)/160|0;if((b|0)>=1){while(1){f=a;d=c;v[a>>2]=v[d>>2];e=a+4|0;if((e|0)!=(d+4|0)){JO(e,v[d+4>>2],v[d+8>>2])}hc(f+16|0,d+16|0,144);a=a+160|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function xe(){var a=0,b=0;a:{b:{if(t[463956]&1){break b}if(!Pd(463956)){break b}v[22640]=0;a=W(2456,2147483647,11550,0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break a}v[115988]=a;Od(463956)}return v[115988]}a=P()|0;O()|0;We(463956);S(a|0);L()}function xF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;bc(c+24|0,b,20);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function pW(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;bc(c+24|0,b,18);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function gD(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;ef(a+12|0,d);if(b){d=b;if(b>>>0>=153391690){nd(8513);L()}f=Mc(B(d,28),4)}v[a>>2]=f;c=B(c,28)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=B(b,28)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Pma(a,b){a=a|0;b=b|0;var c=0,d=0;c=mh(a);a:{if(!b){break a}v[22640]=0;R(791,a|0,b|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;R(792,a|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;UB(c);S(a|0);L()}return a|0}function Nu(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;ef(a+12|0,d);if(b){d=b;if(b>>>0>=357913942){nd(8513);L()}f=Mc(B(d,12),4)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=B(b,12)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Hd(a,b){var c=0,d=0,e=0,f=0,g=0;a:{c=x[a+20>>1];if(c){d=x[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0>=2048){break a}c=c+1|0;if((g|0)!=(c|0)){continue}break}}return}u[a+20>>1]=c-d}function $P(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;a:{if(!c){break a}v[b+40>>2]=c;if(v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[Jc(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=RP(c&255),v[e+44>>2]=f}gb=d+16|0}function vO(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=7;v[b+8>>2]=32;if(v[Fb(b+12|0,b+8|0)>>2]){c=15;while(1){d=yo(a);v[b+12>>2]=7;v[b+8>>2]=32;if(c>>>0<y[Fb(b+12|0,b+8|0)>>2]){c=c+15|0;continue}break}a=d&127}else{a=0}gb=b+16|0;return a}function jX(a,b){a=a|0;b=b|0;var c=0,d=0;c=Gg(a);a:{if(!b){break a}v[22640]=0;R(513,a|0,b|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;R(626,a|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;mn(c);S(a|0);L()}return a|0}function IZ(a,b){a=a|0;b=b|0;var c=0,d=0;c=Gg(a);a:{if(!b){break a}v[22640]=0;R(369,a|0,b|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;R(370,a|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;eE(c);S(a|0);L()}return a|0}function FF(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;uh(a+12|0,d);if(b){d=b;if(b>>>0>119304647){nd(8513);L()}f=Mc(B(d,36),4)}v[a>>2]=f;c=B(c,36)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=B(b,36)+f|0,v[g>>2]=h;gb=e+16|0;return a}function DE(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;bc(c+24|0,b,1);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function rpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Gg(a);a:{if(!b){break a}v[22640]=0;R(38,a|0,b|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;R(39,a|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;mn(c);S(a|0);L()}return a|0}function eY(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;uh(a+12|0,d);if(b){d=b;if(b>>>0>89478485){nd(8513);L()}f=Mc(B(d,48),4)}v[a>>2]=f;c=B(c,48)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=B(b,48)+f|0,v[g>>2]=h;gb=e+16|0;return a}function TQ(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+3|0]|w[b+4|0]<<8|(w[b+5|0]<<16|w[b+6|0]<<24);t[a+3|0]=b;t[a+4|0]=b>>>8;t[a+5|0]=b>>>16;t[a+6|0]=b>>>24}function Pe(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=nc(a+8|0);v[22640]=0;U(383,a|0,b|0,c|0);c=v[22640];v[22640]=0;a:{if((c|0)!=1){a=v[a>>2];v[22640]=0;Q(350,b|0,a|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;gc(d);S(a|0);L()}}function w7(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[b+4>>2]){a=0;while(1){c=0;if(v[b+8>>2]){while(1){d=v[v[b>>2]+(a<<2)>>2]+(c<<3)|0;v[d>>2]=0;v[d+4>>2]=0;c=c+1|0;if(c>>>0<y[b+8>>2]){continue}break}}a=a+1|0;if(a>>>0<y[b+4>>2]){continue}break}}}function qW(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;KX(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function oV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;nV(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function o8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=gb-32|0;gb=e;c=b+4|0;b=v[c+48>>2];a:{if(b&16){b=v[c+44>>2];d=v[c+24>>2];if(b>>>0<d>>>0){v[c+44>>2]=d;b=d}Bj(a,v[c+20>>2],b);break a}if(b&8){Bj(a,v[c+8>>2],v[c+16>>2]);break a}Kb(a)}gb=e+32|0}function iY(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;zv(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function ds(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;ti(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function dW(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;cW(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function dR(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;ef(a+12|0,d);if(b){d=b;if(b>>>0>=613566757){nd(8513);L()}f=Mc(B(d,7),1)}v[a>>2]=f;c=B(c,7)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=B(b,7)+f|0,v[g>>2]=h;gb=e+16|0;return a}function dF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;_r(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function as(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;Hp(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function _X(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;Zv(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function VX(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;XX(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function UX(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;dD(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function SV(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;_B(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Rv(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;Qv(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function QX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=b;a=aB(d+8|0,a+8|0,RX(b,c));if(v[a>>2]!=v[a+4>>2]){while(1){jp(v[a>>2],v[d+24>>2]);v[a>>2]=v[a>>2]+1;Me(d+24|0);if(v[a>>2]!=v[a+4>>2]){continue}break}}Yc(a);gb=d+32|0}function Nv(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;un(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Jg(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;Qr(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Jea(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=-1;a:{if(!YF(a,c+8|0)){break a}d=0;if(!SN(c+8|0)){break a}if(b){a=c+16|0;if(v[b>>2]!=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|v[b+4>>2]){break a}}d=1}gb=c+32|0;return d|0}function JI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(a-b>>2>>>0<c>>>0){while(1){c=c-1|0;d=c<<2;v[d+a>>2]=v[b+d>>2];if(c){continue}break a}}if(!c){break a}d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function HF(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;IF(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function FT(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;_B(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;qd(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){cd(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Ep(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;Bn(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function AD(a,b){var c=0,d=0,e=0;c=gb-32|0;gb=c;zD(c+24|0,b);b=xb(c+24|0);d=v[c+28>>2];e=v[c+24>>2];v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=e;v[c+4>>2]=d;fc(c+16|0,a,c);d=xb(c+16|0);if((b|0)==(d|0)){Yb(a,xb(c+24|0))}gb=c+32|0;return(b|0)==(d|0)}function Tq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=1/(A[v[a+4>>2]-8>>3]-A[v[a>>2]>>3]);while(1){d=-fe(A[ze(a,c)>>3]*131072*f);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=ci(b,c),h=e,v[g>>2]=h;c=c+1|0;if((c|0)!=2048){continue}break}}function TG(a){var b=0,c=0,d=0;d=gb-16|0;gb=d;b=d;v[b>>2]=465584;c=v[116397];v[b+4>>2]=c;v[b+8>>2]=c+(a<<2);c=b;a=v[b+4>>2];b=v[b+8>>2];if((a|0)!=(b|0)){while(1){Vo(a);a=a+4|0;v[c+4>>2]=a;if((a|0)!=(b|0)){continue}break}}$b(c);gb=d+16|0}function Rt(a,b,c){var d=0,e=0;d=gb-32|0;gb=d;a:{e=!b|!c;if(!e){b=Tb(d,b);v[22640]=0;U(1480,d+16|0,b|0,c|0);c=v[22640];v[22640]=0;if((c|0)==1){break a}Eb(a+36|0,d+16|0);vb(d+16|0);vb(b)}gb=d+32|0;return!e}a=P()|0;O()|0;vb(b);S(a|0);L()}function O_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=gb-16|0;gb=e;f=v[b+8>>2];if(f>>>0>c>>>0){v[e+12>>2]=f-c;h=e,i=xb(d),v[h+8>>2]=i;f=Fb(e+12|0,e+8|0);b=v[b+4>>2]+c|0;g=v[f>>2];Bg(b,b+g|0,v[d>>2])}Uj(a,d,g);gb=e+16|0}function ypa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;dY(a);wb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-48|0,48)|0;v[c>>2]=f;if((d|0)>=1){hc(f,e,d)}jc(a,c);jc(a+4|0,b+8|0);jc(wb(a),cc(b));v[b>>2]=v[b+4>>2];Tj(a);on(a);on(a)}function Yda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=0;a:{if(!Nb(a)){break a}while(1){cg(d,v[Mb(a,e)>>2]+40|0);c=vr(d,b);vb(d);if(c){c=v[Mb(a,e)>>2];break a}e=e+1|0;if(Nb(a)>>>0>e>>>0){continue}break}c=0}gb=d+16|0;return c|0}function Fca(a){a=a|0;var b=0;kb[v[v[a>>2]+128>>2]](a);Oy(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=kb[v[v[a>>2]+192>>2]](a)|0;v[a+4272>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4292>>2]=b;v[a+4288>>2]=b;v[a+4284>>2]=b;v[a+4280>>2]=b}function UG(a){var b=0,c=0,d=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}v[b+8>>2]=c-16;v[22640]=0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){On(v[a+16>>2],b,_w(a))}}function Sma(a,b){a=a|0;b=b|0;var c=0,d=0;c=mh(a);a:{if(!b){break a}v[22640]=0;R(789,a|0,b|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;lr(a,b);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;ai(c);S(a|0);L()}return a|0}function Nja(a,b){a=a|0;b=b|0;var c=0,d=0;c=Gg(a);a:{if(!b){break a}v[22640]=0;R(367,a|0,b|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;eT(a,b);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;pu(c);S(a|0);L()}return a|0}function Zma(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(hg(a)>>>0<b>>>0){d=wb(a);b=dh(c+8|0,b,pc(a),d);v[22640]=0;R(328,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break a}ae(b)}gb=c+32|0;return}a=P()|0;O()|0;ae(b);S(a|0);L()}function Pg(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function BA(a){var b=0,c=0,d=0;b=a;d=v[b+4>>2];a:{while(1){c=v[b+8>>2];if((c|0)==(d|0)){break a}v[b+8>>2]=c-8;v[22640]=0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}b=v[a>>2];if(b){AA(v[a+16>>2],b,sF(a))}}function qpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(hg(a)>>>0<b>>>0){d=wb(a);b=dh(c+8|0,b,pc(a),d);v[22640]=0;R(43,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break a}ae(b)}gb=c+32|0;return}a=P()|0;O()|0;ae(b);S(a|0);L()}function hW(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(Lg(a)>>>0<b>>>0){d=wb(a);b=En(c+8|0,b,sc(a),d);v[22640]=0;R(345,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break a}Gh(b)}gb=c+32|0;return}a=P()|0;O()|0;Gh(b);S(a|0);L()}function AY(a,b,c){var d=0,e=0;ol(b,zb(v[c>>2]),xb(c));d=gb-16|0;gb=d;v[d+12>>2]=v[b+4>>2];v[22640]=0;v[d+8>>2]=0;b=Nf(d+8|0,d+12|0);e=v[22640];v[22640]=0;a:{if((e|0)!=1){gb=d+16|0;b=v[b>>2];break a}V(0)|0;O()|0;Bb();L()}Uj(a,c,b)}function pP(a,b){a=a|0;b=b|0;kP(a);kP(a+368680|0);if(b){kO(a,1);return a|0}iO();Xt(221840,287376,a+131112|0);Xt(287376,352912,a+196648|0);Xt(352912,418448,a+262184|0);Xt(90752,221840,a+24|0);hc(a+327720|0,418448,40960);return a|0}function kG(){var a=0,b=0,c=0;b=gb-16|0;gb=b;a=Tb(b,12228);a:{if(!Ab(a)){break a}c=1;if((rg(a,11887)|0)!=-1){break a}if((rg(a,13908)|0)!=-1){break a}if((rg(a,11098)|0)!=-1){break a}c=(rg(a,11141)|0)!=-1}vb(a);gb=b+16|0;return c|0}function dg(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>1]<<17;e=x[a+20>>1];if(e){d=x[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-B(v[ci(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function Pm(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;uh(a+12|0,d);if(b){f=Li(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function Gba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=12){Fi(d+12|0);c=z[d+12>>2];if((b|0)==12){c=C(re(C(c*C(3)))*C(.3333333432674408));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;t[a+5046|0]=1}gb=d+16|0}function lD(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;ef(a+12|0,d);if(b){d=b;if((b|0)<=-1){nd(8513);L()}f=Mc(d<<1,1)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=(b<<1)+f|0,v[g>>2]=h;gb=e+16|0;return a}function yU(a,b){var c=0,d=0,e=0,f=0;c=gb-32|0;gb=c;d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=v[b>>2];v[c+16>>2]=a;v[c+20>>2]=f;v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=a;v[c+4>>2]=f;a=SU(c+8|0,c);gb=c+32|0;return a}function Vc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=Lf(b);e=gb-16|0;gb=e;c=Kc(a);a:{if(c>>>0>=d>>>0){c=Jb(a);bm(c,b,d);t[e+15|0]=0;zd(d+c|0,e+15|0);gh(a,d);break a}f=c;g=d-c|0;c=Ab(a);Ap(a,f,g,c,0,c,d,b)}gb=e+16|0;return a|0}function QR(a,b){var c=0,d=0;c=Gg(a);a:{if(!b){break a}v[22640]=0;R(1128,a|0,b|0);d=v[22640];v[22640]=0;if((d|0)!=1){v[22640]=0;R(1129,a|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;JR(c);S(a|0);L()}return a}function Pd(a){var b=0,c=0,d=0;c=gb-16|0;gb=c;a=Xw(c,a);d=gb-16|0;gb=d;if(!w[v[yc(d+8|0,v[a+4>>2])>>2]]){a:{b:{a=v[a+8>>2];b=w[a|0];if((b|0)!=1){if(b&2){break b}t[a|0]=2;a=1}else{a=0}break a}L()}b=a}gb=d+16|0;gb=c+16|0;return b}function Lpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;Hp(c+24|0,b);e=xb(c+24|0);b=v[c+28>>2];d=v[c+24>>2];v[c+8>>2]=d;v[c+12>>2]=b;v[c>>2]=d;v[c+4>>2]=b;fc(c+16|0,a,c);if((xb(c+16|0)|0)==(e|0)){Yb(a,xb(c+24|0))}gb=c+32|0}function LB(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=gb-16|0;gb=d;f=v[b+12>>2];e=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=e;g=v[v[b>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=e;kb[g|0](a,b,f,d);h=b,i=xb(a)+v[b+12>>2]|0,v[h+12>>2]=i;gb=d+16|0}function qs(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=gb-16|0;gb=f;if(b){e=Kc(a);d=Ab(a);g=d+b|0;if(e-d>>>0<b>>>0){Em(a,e,g-e|0,d,d,0,0)}e=d;d=Jb(a);Ir(e+d|0,b,c);gh(a,g);t[f+15|0]=0;zd(d+g|0,f+15|0)}gb=f+16|0;return a|0}function nfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;a:{if(qg(a)>>>0<b>>>0){d=wb(a);b=ns(c+8|0,b,Cc(a),d);v[22640]=0;Ln(a,b);a=v[22640];v[22640]=0;if((a|0)==1){break a}ou(b)}gb=c+32|0;return}a=P()|0;O()|0;ou(b);S(a|0);L()}function jA(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[a+104>>2];if(d){v[a+88>>2]=v[a+88>>2]&-131|128;d=v[d>>2];v[a+76>>2]=d;v[c+12>>2]=b<<8;v[c+8>>2]=d-1;b=d+(v[Fb(c+12|0,c+8|0)>>2]^-1)|0;v[a>>2]=0;v[a+4>>2]=b}gb=c+16|0}function MK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(!(t[(b+v[a>>2]|0)+1075081|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125))}return C(c)}function LK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(!(t[(b+v[a>>2]|0)+1075081|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125))}return C(c)}function aD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=0;a:{if(!a){break a}e=a|-16;if(b>>>0>1?a>>>0<16&c:1){break a}t[d+15|0]=1;t[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=w[Bf(d+15|0,d+14|0)|0]}a=e;gb=d+16|0;return a&255}function ON(a,b,c){var d=0,e=0,f=0;d=gb-32|0;gb=d;v[d+16>>2]=c;v[d+24>>2]=b;b=v[a>>2];e=d,f=Sb(a),v[e+8>>2]=f;b=b+B(St(d+24|0,d+8|0),6)|0;if(Gb(d+24|0,d+16|0)){FC(a,cz(b+B(St(d+16|0,d+24|0),6)|0,v[a+4>>2],b))}bh(b);gb=d+32|0}function i4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=c;v[d+8>>2]=c;e=-1;c=$s(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=Ad(c);v[f>>2]=a;if(!a){break a}e=$s(a,c,b,v[d+12>>2])}gb=d+16|0;return e|0}function ZX(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179011410|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1179472708)){return 1}return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179472708}function $t(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=49868;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=49884;break a;case 2:c=49880;break a;case 1:break b;case 0:break c}}c=49876;break a}c=49872}v[a>>2]=v[c>>2]}function zfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;v[a+480180>>2]=b;Yz(c,Fq(a));d=v[c+12>>2];b=a+1074320|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074312>>2]=v[c>>2];v[a+1074316>>2]=b;$t(a+8|0,Fq(a));gb=c+16|0}function OK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(t[(b+v[a>>2]|0)+1075081|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075834|0])*C(.0078125))}return C(c)}function NK(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,872);if(t[(b+v[a>>2]|0)+1075081|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075835|0])*C(.0078125))}return C(c)}function SO(a,b){a=a|0;b=b|0;var c=0;c=65535;a:{if(x[v[a+8>>2]+58>>1]<b>>>0){break a}while(1){if(!v[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if(x[v[a+8>>2]+58>>1]>=(b&65535)>>>0){continue}break}}return c&65535}function sP(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;b=bs(d,a,b);a=v[b+4>>2];e=v[b+8>>2];if((a|0)!=(e|0)){while(1){f=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=f;a=a+8|0;v[b+4>>2]=a;if((a|0)!=(e|0)){continue}break}}$b(b);gb=d+16|0}function Qla(a,b){a=a|0;b=b|0;var c=0;Br(a);v[a>>2]=18876;nc(a+4|0);t[a+20|0]=0;v[a+16>>2]=0;v[a>>2]=18984;c=v[b+4>>2];v[a+24>>2]=v[b>>2];v[a+28>>2]=c;c=v[b+12>>2];v[a+32>>2]=v[b+8>>2];v[a+36>>2]=c;t[a+40|0]=0;return a|0}function LU(a,b){var c=0,d=0,e=0;c=a;if(v[c>>2]){LY(c);kD(v[c>>2],Wi(c));d=wb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0}v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=wb(b);d=wb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0}function xs(a,b,c){var d=0,e=0,f=0;d=gb-16|0;gb=d;if(c>>>0<=4294967279){a:{if(c>>>0<=10){Ve(a,c);e=a;break a}f=Xk(c)+1|0;e=mi(a,f);bf(a,e);ng(a,f);ee(a,c)}Ng(e,b,c);t[d+15|0]=0;zd(c+e|0,d+15|0);gb=d+16|0;return}_f();L()}function nU(a,b,c){var d=0;d=gb-16|0;gb=d;t[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|b>>>0>=c>>>0|b>>>0>=109|c>>>0>=109)){t[d+14|0]=(x[(b<<1)+39438>>1]-x[(c<<1)+39438>>1]|0)/5;a=w[ac(d+15|0,d+14|0)|0]}gb=d+16|0;return a&255}function mt(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!_x(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=Le(a)}return b}ba(12841,10568,1563,2521);L()}function hT(a){var b=0,c=0,d=0;b=a- -64|0;d=w[b|0]|w[b+1|0]<<8;b=a+70|0;a=a+72|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<2|a>>>30;c=c<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function gu(a,b){var c=0,d=0;c=B(b,872)+a|0;a:{if(v[c+1075080>>2]&134218752){break a}if(!rk(c+1074992|0)){break a}b=w[v[(B(b,872)+a|0)+1075648>>2]+34|0];if((b+5&255)>>>0<6){break a}d=v[(B(b,160)+a|0)+906140>>2]}return d}function dh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;uh(a+12|0,d);if(b){f=mi(v[a+16>>2],b)}v[a>>2]=f;c=c+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=b+f|0,v[g>>2]=h;gb=e+16|0;return a|0}function Ys(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(hg(a)>>>0<b>>>0){d=wb(a);b=dh(c+8|0,b,pc(a),d);v[22640]=0;R(162,a|0,b|0);a=v[22640];v[22640]=0;if((a|0)==1){break a}ae(b)}gb=c+32|0;return}a=P()|0;O()|0;ae(b);S(a|0);L()}function oW(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function SG(){var a=0;a:{b:{if(t[463968]&1){break b}if(!Pd(463968)){break b}v[22640]=0;X(2540);a=v[22640];v[22640]=0;if((a|0)==1){break a}v[115991]=463960;Od(463968)}return v[115991]}a=P()|0;O()|0;We(463968);S(a|0);L()}function QV(a){var b=0,c=0;a:{if(yd(a,12215,3)){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<423|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>2147483646){break a}c=w[a+3|0]<6}return c}function H1(){var a=0;a:{b:{if(t[463980]&1){break b}if(!Pd(463980)){break b}v[22640]=0;X(2541);a=v[22640];v[22640]=0;if((a|0)==1){break a}v[115994]=463972;Od(463980)}return v[115994]}a=P()|0;O()|0;We(463980);S(a|0);L()}function z0(a){a=a|0;a:{b:{if(t[464088]&1){break b}if(!Pd(464088)){break b}v[22640]=0;X(2567);a=v[22640];v[22640]=0;if((a|0)==1){break a}v[116021]=465216;Od(464088)}return v[116021]}a=P()|0;O()|0;We(464088);S(a|0);L()}function qU(a){var b=0,c=0,d=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<1|a>>>31;c=c<<1;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;jb=a;return b}function pY(a,b,c){var d=0;d=gb-32|0;gb=d;v[d+16>>2]=b;v[d+24>>2]=a;v[d+8>>2]=c;if(Gb(d+24|0,d+16|0)){while(1){if(!aY(d+8|0,v[d+24>>2])){pp(d+24|0);if(Gb(d+24|0,d+16|0)){continue}}break}a=v[d+24>>2]}gb=d+32|0;return a}function O0(a){a=a|0;a:{b:{if(t[464048]&1){break b}if(!Pd(464048)){break b}v[22640]=0;X(2557);a=v[22640];v[22640]=0;if((a|0)==1){break a}v[116011]=464224;Od(464048)}return v[116011]}a=P()|0;O()|0;We(464048);S(a|0);L()}function L0(a){a=a|0;a:{b:{if(t[464056]&1){break b}if(!Pd(464056)){break b}v[22640]=0;X(2559);a=v[22640];v[22640]=0;if((a|0)==1){break a}v[116013]=464400;Od(464056)}return v[116013]}a=P()|0;O()|0;We(464056);S(a|0);L()}function I0(a){a=a|0;a:{b:{if(t[464064]&1){break b}if(!Pd(464064)){break b}v[22640]=0;X(2561);a=v[22640];v[22640]=0;if((a|0)==1){break a}v[116015]=464576;Od(464064)}return v[116015]}a=P()|0;O()|0;We(464064);S(a|0);L()}function Fga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;v[d+24>>2]=c;v[d+16>>2]=b;if(Gb(d+16|0,d+24|0)){while(1){v[d+12>>2]=v[v[d+16>>2]>>2];LA(a,d+12|0);Xg(d+16|0);if(Gb(d+16|0,d+24|0)){continue}break}}gb=d+32|0}function F0(a){a=a|0;a:{b:{if(t[464072]&1){break b}if(!Pd(464072)){break b}v[22640]=0;X(2563);a=v[22640];v[22640]=0;if((a|0)==1){break a}v[116017]=464880;Od(464072)}return v[116017]}a=P()|0;O()|0;We(464072);S(a|0);L()}function C0(a){a=a|0;a:{b:{if(t[464080]&1){break b}if(!Pd(464080)){break b}v[22640]=0;X(2565);a=v[22640];v[22640]=0;if((a|0)==1){break a}v[116019]=465184;Od(464080)}return v[116019]}a=P()|0;O()|0;We(464080);S(a|0);L()}function $R(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function wk(a){a=a|0;tc(a+16|0,v[a>>2]);tc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function mqa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;jb=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function kT(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(a);v[22640]=0;b=b-28|0;R(966,c|0,b|0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function Xga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ad(a);e=Ck(a+12|0);t[a+32|0]=c;v[a+28>>2]=0;v[a+24>>2]=b;v[22640]=0;R(1133,a|0,1);b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;AR(e);GR(d);S(a|0);L()}function W5(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a:{if(xr(b,7591)){sI(c,14645,b);a=Jb(c);v[22640]=0;R(2270,44,a|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(c);S(a|0);L()}gb=c+16|0;return a|0}L()}function UF(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=wb(a);v[22640]=0;b=b-36|0;R(250,c|0,b|0);c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=d}function Qz(a,b,c){var d=0;a:{if(x[a+480192>>1]){if(!ve(b)|x[a+480192>>1]<c>>>0){break a}c=v[((c<<2)+a|0)+900380>>2];if(!c){break a}d=x[sd(c+236|0,b-1|0)>>1];break a}d=c}return(x[a+480190>>1]<(d&65535)>>>0?0:d)&65535}function pA(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=(v[a+480208>>2]&32768?28.85390081777927:34.624680981335125)*(Up(b)+-4.8737671609324025),A[d+8>>3]=e;dQ(c+8|0,127);a=fn(A[c+8>>3]);gb=c+16|0;return a|0}function Xja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-32|0;gb=d;e=Oe(b);c=oT(d+8|0,c);v[22640]=0;Y(965,a|0,b|0,e-1&65535,c|0);a=v[22640];v[22640]=0;if((a|0)!=1){Ce(c);gb=d+32|0;return}a=P()|0;O()|0;Ce(c);S(a|0);L()}function Nca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=2){v[d+8>>2]=0;v[d+4>>2]=1065353216;e=(a+b|0)+4232|0,f=cA(C(z[Wf(d+12|0,d+8|0,d+4|0)>>2]*C(127))),t[e|0]=f;Jt(a)}gb=d+16|0}function $x(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!lt(a)){break a}if(!(t[a+1375|0]&1)){continue}break}dc(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function Ro(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;Db(d+8|0,c+1074312|0,102);a:{if(!Cb(d+8|0)){break a}c=x[a+692>>1]+1|0;u[a+784>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+784>>1]=c|32768}v[a+692>>2]=b;gb=d+16|0}function NR(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=c*A[a+8>>3]+A[a>>3]*b+e*A[a+16>>3]-(f*A[a+32>>3]+d*A[a+24>>3]);A[a+56>>3]=b;return b}function MT(a){a=+a;a=a*4294967296;if(D(a)<0x8000000000000000){jb=D(a)>=1?~~(a>0?F(H(a*2.3283064365386963e-10),4294967295):I((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0|0}jb=-2147483648;return 0}function IL(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=rf(12);b=v[b>>2];a=v[a>>2];v[22640]=0;a=HL(d,a,b);b=v[22640];v[22640]=0;if((b|0)!=1){a=v[Ni(c+8|0,a)>>2];gb=c+16|0;return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function x7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[b+4>>2]){a=0;while(1){c=0;if(v[b+8>>2]){while(1){d=ir(b,a,c),e=0,v[d>>2]=e;c=c+1|0;if(c>>>0<y[b+8>>2]){continue}break}}a=a+1|0;if(a>>>0<y[b+4>>2]){continue}break}}}function bo(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=d*(c*.13339200271297674+.3333313950307914)+a;a=c*c;a=e+d*a*(c*.024528318116654728+.05338123784456704+a*(c*.009465647849436732+.002974357433599673));return C(b?-1/a:a)}function OX(a){var b=0,c=0,d=0;b=v[a>>2];c=UC(a);d=gb-16|0;gb=d;a:{if((b|0)==(c|0)){break a}a=b+4|0;if((c|0)==(a|0)){break a}while(1){b=Ed(a,b)?a:b;a=a+4|0;if((c|0)!=(a|0)){continue}break}}gb=d+16|0;return v[b>>2]}function u0(a){a=a|0;a:{b:{if(t[464120]&1){break b}if(!Pd(464120)){break b}v[22640]=0;Q(2570,464108,83668)|0;a=v[22640];v[22640]=0;if((a|0)==1){break a}Od(464120)}return 464108}a=P()|0;O()|0;We(464120);S(a|0);L()}function q0(a){a=a|0;a:{b:{if(t[464152]&1){break b}if(!Pd(464152)){break b}v[22640]=0;Q(2570,464140,83704)|0;a=v[22640];v[22640]=0;if((a|0)==1){break a}Od(464152)}return 464140}a=P()|0;O()|0;We(464152);S(a|0);L()}function m0(a){a=a|0;a:{b:{if(t[464184]&1){break b}if(!Pd(464184)){break b}v[22640]=0;Q(2570,464172,83740)|0;a=v[22640];v[22640]=0;if((a|0)==1){break a}Od(464184)}return 464172}a=P()|0;O()|0;We(464184);S(a|0);L()}function i0(a){a=a|0;a:{b:{if(t[464216]&1){break b}if(!Pd(464216)){break b}v[22640]=0;Q(2570,464204,83824)|0;a=v[22640];v[22640]=0;if((a|0)==1){break a}Od(464216)}return 464204}a=P()|0;O()|0;We(464216);S(a|0);L()}function hG(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Mp(d,a,1);a=wb(a);e=v[c+4>>2];v[22640]=0;Mn(a,e,b);a=v[22640];v[22640]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+12;$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function gR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a=Dn(d,a+8|0,ar(b,c));if(v[a>>2]!=v[a+4>>2]){while(1){Qo(v[a>>2],b);c=v[a>>2]+2|0;v[a>>2]=c;b=b+2|0;if(v[a+4>>2]!=(c|0)){continue}break}}Yc(a);gb=d+16|0}function _P(a,b,c){var d=0,e=0;d=gb-16|0;gb=d;e=c&15;if(e){t[b+824|0]=e}c=c&240;if(c){t[b+823|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;Db(d+8|0,a+1074312|0,80);if(!(!Cb(d+8|0)|!e)){t[b+824|0]=w[b+824|0]<<2}gb=d+16|0}function ZH(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=kb[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!He(b,-1)){break a}v[a>>2]=0}return a|0}function Tv(a,b,c){var d=0;a=a+3|0;a=(w[a|0]|w[a+1|0]<<8)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-8;t[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function Aoa(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,12);a:{if(d){NW(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}t[c+16|0]=0;li(b,12,c+16|0)}gb=c+32|0;return d|0}function xA(a,b){var c=0,d=0,e=0,f=0;c=a<<8&16711680|a<<24;d=b<<24|a>>>8;e=d&65280;d=b<<8|a>>>24;c=d&255|e|c;a=((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24)|f;jb=c;return a}function sW(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=yg(d,a,1);a=wb(a);e=v[c+4>>2];v[22640]=0;gn(a,e,b);a=v[22640];v[22640]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function s0(a){a=a|0;a:{b:{if(t[464136]&1){break b}if(!Pd(464136)){break b}v[22640]=0;Q(112,464124,11091)|0;a=v[22640];v[22640]=0;if((a|0)==1){break a}Od(464136)}return 464124}a=P()|0;O()|0;We(464136);S(a|0);L()}function o0(a){a=a|0;a:{b:{if(t[464168]&1){break b}if(!Pd(464168)){break b}v[22640]=0;Q(112,464156,10859)|0;a=v[22640];v[22640]=0;if((a|0)==1){break a}Od(464168)}return 464156}a=P()|0;O()|0;We(464168);S(a|0);L()}function iI(a,b){var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Ri(d,a,1);a=wb(a);e=v[c+4>>2];v[22640]=0;dl(a,e,b);a=v[22640];v[22640]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+1;$b(c);gb=d+16|0;return}a=P()|0;O()|0;$b(c);S(a|0);L()}function Jz(a,b){var c=0;c=v[b+24>>2];c=c?c:1;v[a+24628>>2]=c>>>0<512?c:512;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}hc(a+24604|0,b,40);DO(a,c)}function w0(a){a=a|0;a:{b:{if(t[464104]&1){break b}if(!Pd(464104)){break b}v[22640]=0;Q(112,464092,2361)|0;a=v[22640];v[22640]=0;if((a|0)==1){break a}Od(464104)}return 464092}a=P()|0;O()|0;We(464104);S(a|0);L()}function sk(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=v[a+24>>2];d=v[a+40>>2];v[22640]=0;v[b+12>>2]=1;a=Jc(a+20|0,b+12|0);e=v[22640];v[22640]=0;if((e|0)!=1){gb=b+16|0;return B(v[a>>2],c+d|0)}V(0)|0;O()|0;Bb();L()}function q2(){var a=0;a=gb-16|0;gb=a;v[116396]=0;v[116397]=0;v[a+12>>2]=0;Vo(465600);t[465744]=0;gb=a+16|0;v[22640]=0;X(2536);a=v[22640];v[22640]=0;if((a|0)!=1){TG(30);return}a=P()|0;O()|0;ex(465584);S(a|0);L()}function k0(a){a=a|0;a:{b:{if(t[464200]&1){break b}if(!Pd(464200)){break b}v[22640]=0;Q(112,464188,6428)|0;a=v[22640];v[22640]=0;if((a|0)==1){break a}Od(464200)}return 464188}a=P()|0;O()|0;We(464200);S(a|0);L()}function vw(a,b){var c=0,d=0;c=gb-32|0;gb=c;a:{if(Pb(b,3)){d=gb-16|0;gb=d;bc(c+24|0,a,3);gb=d+16|0;a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;gd(c+16|0,b,c+8|0);break a}t[c+16|0]=0;li(a,3,c+16|0)}gb=c+32|0}function nda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;a=jk(a);if(a){d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;e=v[v[a>>2]+72>>2];v[c>>2]=b;v[c+4>>2]=d;a=kb[e|0](a,c)|0}else{a=1}gb=c+16|0;return a|0}function Hz(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;CO(a+24648|0);YO(a)}function qS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e>>2]=c;v[e+8>>2]=b;if(Gb(e+8|0,e)){while(1){yn(a,v[d>>2],v[e+8>>2]);mf(e+8|0);v[d>>2]=v[d>>2]+2;if(Gb(e+8|0,e)){continue}break}}gb=e+16|0}function ko(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a:{if(c){Tb(d,c);break a}Kb(d)}v[22640]=0;U(13,a|0,b|0,d|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(d);gb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function ht(a){var b=0;if(a){if(v[a+76>>2]<=-1){return Wx(a)}return Wx(a)}if(v[22632]){b=ht(v[22632])}a=v[115120];if(a){while(1){if(y[a+20>>2]>y[a+28>>2]){b=Wx(a)|b}a=v[a+56>>2];if(a){continue}break}}return b}function ao(a,b,c){var d=0,e=0;d=Ed(b,a);e=Ed(c,b);a:{b:{if(!d){d=0;if(!e){break a}jc(b,c);d=1;if(!Ed(b,a)){break a}jc(a,b);break b}if(e){jc(a,c);return 1}jc(a,b);d=1;if(!Ed(c,b)){break a}jc(b,c)}d=2}return d}function Uw(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function LO(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=a;b=v[a+112>>2];a:{if((b|0)<=10){c=b+1|0;break a}e=a;b=378;while(1){KO(e);c=f-(b>>>0<1)|0;b=b-1|0;f=c;if(b|c){continue}break}c=1}v[d+112>>2]=c;a=KO(a);return a|0}function Bka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=gb-16|0;gb=e;g=v[v[b>>2]+20>>2];f=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=f;f=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=f;kb[g|0](a,b,e,d);gb=e+16|0}function BU(a){var b=0,c=0,d=0;c=a;b=v[a+8>>2];d=v[a+4>>2];if((b|0)!=(d|0)){while(1){b=b-56|0;v[c+8>>2]=b;Su(b);b=v[c+8>>2];if((d|0)!=(b|0)){continue}break}}c=v[a>>2];if(c){Qu(c,(v[cc(a)>>2]-v[a>>2]|0)/56|0)}}function Z7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Mp(e,a,d);wb(a);v[22640]=0;U(2089,b|0,c|0,d+4|0);a=v[22640];v[22640]=0;if((a|0)!=1){$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function Rg(a){var b=0;v[22640]=0;a=T(1298,a|0)|0;b=v[22640];v[22640]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;Z(a|0)|0;v[22640]=0;X(20);b=v[22640];v[22640]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Bb();L()}function LR(a){a=a|0;var b=0,c=0,d=0;c=gb-16|0;gb=c;b=bs(c,a,2048);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){v[a>>2]=0;v[a+4>>2]=0;a=a+8|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function yD(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function rP(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+28>>2];v[a+24>>2]=v[b+24>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function bD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;v[d+12>>2]=c;e=d,f=pY(Sb(b),Wb(b),d+12|0),v[e+8>>2]=f;e=d,f=Wb(b),v[e>>2]=f;a:{if(Gb(d+8|0,d)){Je(a,wb(v[d+8>>2]));break a}Ih(a)}gb=d+16|0}function YO(a){var b=0,c=0;b=gb-544|0;gb=b;if(!(!(w[a+480210|0]&128)|!v[a+24668>>2])){MR(b,uf(a));c=a+1298224|0;a=a+1074992|0;while(1){hc(a+112|0,b,538);a=a+872|0;if((c|0)!=(a|0)){continue}break}}gb=b+544|0}function PB(a,b,c){var d=0;d=gb-16|0;gb=d;v[d>>2]=b;v[d+8>>2]=a;a:{if(!Gb(d+8|0,d)){break a}while(1){if(x[v[d+8>>2]>>1]==x[c>>1]){break a}mf(d+8|0);if(Gb(d+8|0,d)){continue}break}}gb=d+16|0;return v[d+8>>2]}function Dx(a){a=a|0;var b=0;v[a>>2]=78204;v[22640]=0;R(2363,a|0,0);b=v[22640];v[22640]=0;if((b|0)!=1){Vb(a+28|0);Zb(v[a+32>>2]);Zb(v[a+36>>2]);Zb(v[a+48>>2]);Zb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Bb();L()}function uR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22640]=0;c=c-12|0;R(1142,d|0,c|0);d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function ns(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;uh(a+12|0,d);if(b){f=ZF(v[a+16>>2],b)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=B(b,12)+f|0,v[g>>2]=h;gb=e+16|0;return a}function nS(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22640]=0;c=c-32|0;R(1112,d|0,c|0);d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function dH(a,b,c,d,e,f){var g=0,h=0,i=0;g=gb-16|0;gb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){Dh(g+13|0,g+14|0)}h=c,i=($a(b|0,fU(b,v[c>>2])|0,g+12|0,d|0,v[a>>2])|0)+b|0,v[h>>2]=i;gb=g+16|0}function MO(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22640]=0;c=c-52|0;R(1332,d|0,c|0);d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function LX(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;uh(a+12|0,d);if(b){f=TD(v[a+16>>2],b)}v[a>>2]=f;c=B(c,20)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=B(b,20)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Bv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Lb(128/(B(v[Nf(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[Bf(c+7|0,c+6|0)|0];gb=c+16|0;return a|b<<4&240}function tfa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){nO(a,b);return}d=gb-32|0;gb=d;c=wb(a);c=vo(d+8|0,kr(a,Nb(a)+1|0),Nb(a),c);Cq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;aT(a,c);tz(c);gb=d+32|0}function jfa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[wb(a)>>2]){nO(a,b);return}d=gb-32|0;gb=d;c=wb(a);c=vo(d+8|0,kr(a,Nb(a)+1|0),Nb(a),c);Cq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;aO(a,c);tz(c);gb=d+32|0}function hu(a,b){a=hc(a,b,88);v[a+88>>2]=v[b+88>>2];hc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];hc(a+672|0,b+672|0,52);xo(a+724|0,b+724|0);xo(a+732|0,b+732|0);xo(a+740|0,b+740|0);hc(a+748|0,b+748|0,123)}function Ska(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;XU(c+24|0,a);ug(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=Fc(c+8|0,c);gb=c+32|0;return a|0}function PD(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=wb(a);v[22640]=0;c=c-20|0;R(388,d|0,c|0);d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function OA(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=v[c>>2];if(d){Lo(d);aS(v[c>>2])}b=b+1|0;if((b|0)!=4){continue}break}}function D1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((b|0)!=(c|0)){while(1){a=d;if(y[b>>2]<=127){e=x[Yp()+(v[b>>2]<<1)>>1]}else{e=0}u[a>>1]=e;d=d+2|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function zp(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;uh(a+12|0,d);if(b){f=JE(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a}function xi(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;d=v[a+8>>2];g=v[a+4>>2];e=d-g|0;f=e>>31;v[a+120>>2]=e;v[a+124>>2]=f;v[a+104>>2]=b|c?((c|0)<(f|0)?1:(c|0)<=(f|0)?b>>>0<e>>>0:0)?b+g|0:d:d}function uN(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;ug(c+24|0,a);ug(c+16|0,b);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;a=v[c+20>>2];v[c>>2]=v[c+16>>2];v[c+4>>2]=a;a=BN(c+8|0,c);gb=c+32|0;return a|0}function Mba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=gb-16|0;gb=f;b=zc(nqa(mqa(d,d>>31,b,0),jb,1e3,0),jb);v[a+16>>2]=0;v[a+12>>2]=b+c;dM(a,e);b=v[a+12>>2];v[f+12>>2]=0;qN(a,b,f+12|0);gb=f+16|0}function JW(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;uh(a+12|0,d);if(b){f=KW(v[a+16>>2],b)}v[a>>2]=f;c=B(c,6)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=B(b,6)+f|0,v[g>>2]=h;gb=e+16|0;return a}function En(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;uh(a+12|0,d);if(b){f=UE(v[a+16>>2],b)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=(b<<1)+f|0,v[g>>2]=h;gb=e+16|0;return a}function $f(a,b,c,d,e){var f=0;f=gb-256|0;gb=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Qb(f,b&255,d?c:256);if(!d){while(1){sf(a,f,256);c=c-256|0;if(c>>>0>255){continue}break}}sf(a,f,c)}gb=f+256|0}function yP(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[22640]=0;v[c>>2]=2147483647;v[c+4>>2]=0;a=Qk(c+8|0,c);b=v[22640];v[22640]=0;if((b|0)!=1){gb=c+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function rX(a){var b=0,c=0;b=a+36|0;c=mqa(w[b|0]|w[b+1|0]<<8,0,384,0);a=a+34|0;b=w[a|0]|w[a+1|0]<<8;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+jb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;if(b>>>0<256){a=a+1|0}jb=a;return b}function rU(a){var b=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1297236819|w[a+29|0]!=16){break a}a=a+42|0;if((w[a|0]|w[a+1|0]<<8)!=2?(w[a|0]|w[a+1|0]<<8)!=1:0){break a}b=1}return b}function nK(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=yg(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){v[a>>2]=0;Ui(a);a=a+4|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function lA(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=1073741823;v[22640]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function eT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=yg(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);Vo(b);b=b+4|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0}function Zd(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Ad(b)}return c}function VE(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=2147483647;v[22640]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function KN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=gb-16|0;gb=d;c=Cr(d,a,b);b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){wb(a);gi(b);b=b+6|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}$b(c);gb=d+16|0}function GN(a){var b=0,c=0,d=0;if(Of(a)){while(1){b=a;d=c&65535;if(Of(b)>>>0>d>>>0){b=$e(b,d);v[b+20>>2]=0;v[b+12>>2]=0;v[b+16>>2]=0;NN(b);Ye(b+36|0)}c=c+1|0;if(Of(a)>>>0>(c&65535)>>>0){continue}break}}}function iO(){var a=0;a:{b:{if(t[459432]&1){break b}if(!Pd(459432)){break b}v[22640]=0;Q(1421,90728,1)|0;a=v[22640];v[22640]=0;if((a|0)==1){break a}Od(459432)}return}a=P()|0;O()|0;We(459432);S(a|0);L()}function _F(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=357913941;v[22640]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function W8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a=Zp(e,a,d);v[22640]=0;U(2045,b|0,c|0,a+4|0);b=v[22640];v[22640]=0;if((b|0)!=1){$b(a);gb=e+16|0;return}b=P()|0;O()|0;$b(a);S(b|0);L()}function UD(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=214748364;v[22640]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function LW(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=715827882;v[22640]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function B1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if((c|0)==(d|0)){break a}while(1){if(y[c>>2]>127){break a}if(!(x[Yp()+(v[c>>2]<<1)>>1]&b)){break a}c=c+4|0;if((d|0)!=(c|0)){continue}break}c=d}return c|0}function kp(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=1073741823;v[22640]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function f1(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=a;a=vi(b+8|0,b+12|0);v[22640]=0;c=zI(0,0,4);d=v[22640];v[22640]=0;if((d|0)!=1){ff(a);gb=b+16|0;return c|0}b=P()|0;O()|0;ff(a);S(b|0);L()}function aha(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;c=rf(2500);v[22640]=0;a=Q(91,c|0,a|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){a=v[Ni(b+8|0,a)>>2];gb=b+16|0;return a|0}a=P()|0;O()|0;Zb(c);S(a|0);L()}function S8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;a=v[a+24>>2];xL(d,c);v[22640]=0;U(580,a|0,b|0,d|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(d);gb=d+16|0;return}a=P()|0;O()|0;vb(d);S(a|0);L()}function PU(a){var b=0,c=0,d=0,e=0;jb=0;d=w[a+4|0];e=w[a+92|0];c=w[a+93|0];b=a+94|0;b=c+(w[b|0]|w[b+1|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function Ela(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=IE(a);if(d>>>0>=b>>>0){a=Uu(a);if(a>>>0<d>>>1>>>0){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[Jc(c+12|0,c+8|0)>>2]}gb=c+16|0;return d|0}Rc();L()}function zA(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=ec(a);if(w[a+4|0]){v[22640]=0;c=v[22640];v[22640]=0;if((c|0)==1){break b}tR(b+16|0)}if(b){es(v[a>>2],b,1)}break a}V(0)|0;O()|0;Bb();L()}}}function ww(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=536870911;v[22640]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function oR(a){var b=0,c=0,d=0;c=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22640]=0;b=b-8|0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=c}function hN(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=ec(a);if(w[a+4|0]){v[22640]=0;c=v[22640];v[22640]=0;if((c|0)==1){break b}zk(b+16|0)}if(b){Tk(v[a>>2],b,1)}break a}V(0)|0;O()|0;Bb();L()}}}function ZO(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];a:{if(!b){break a}if(!(kb[v[v[b>>2]+116>>2]](b)|0)){break a}kb[v[v[b>>2]+96>>2]](b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function MG(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=268435455;v[22640]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function FV(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=178956970;v[22640]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function BT(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=134217727;v[22640]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function QO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=gb-16|0;gb=c;Xf(a,c+14|0);HC(b,x[c+14>>1],16777216);if(x[c+14>>1]){while(1){Bk(a,Mb(b,d));d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}Oz(b);gb=c+16|0}function AN(){var a=0,b=0,c=0;a=gb-16|0;gb=a;v[a+12>>2]=82595524;v[22640]=0;v[a+8>>2]=2147483647;b=Fb(a+12|0,a+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=a+16|0;return v[b>>2]}V(0)|0;O()|0;Bb();L()}function tL(){var a=0,b=0,c=0,d=0;a=gb-16|0;gb=a;b=rf(1298432);v[22640]=0;c=T(2051,b|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){b=v[Ni(a+8|0,c)>>2];gb=a+16|0;return b|0}a=P()|0;O()|0;Zb(b);S(a|0);L()}function OR(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function Id(a,b){var c=0,d=0,e=0;d=x[a+24>>1];if((d|0)!=(b&65535)){c=x[a+22>>1]-1&127;u[a+22>>1]=c;e=x[a+20>>1];if(e>>>0<=127){u[a+20>>1]=e+1}c=(c<<2)+a|0;u[c+26>>1]=b-d;u[c+28>>1]=0;u[a+24>>1]=b}}function xj(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Ps(a){var b=0;if(v[a+76>>2]<0){b=v[a+4>>2];if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;return w[b|0]}return Mx(a)}b=v[a+4>>2];a:{if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;a=w[b|0];break a}a=Mx(a)}return a}function NP(a,b,c){var d=0,e=0;d=v[(B(b,872)+a|0)+1075648>>2];a:{if(!d){break a}b:{if((c|0)!=1){break b}a=v[(B(b,872)+a|0)+1075096>>2];if(!a){break b}if(w[a+35|0]&4){break a}}e=w[d+34|0]}return e}function xv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function uS(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;t[a+16|0]=0;c=UA(b,v[a+12>>2]);v[22640]=0;R(1098,a|0,c|0);a=v[22640];v[22640]=0;if((a|0)!=1){Xm(c);gb=b+32|0;return}a=P()|0;O()|0;Xm(c);S(a|0);L()}function ih(a,b){a:{if(y[a+4>>2]<=b>>>0){a=aa(8)|0;v[22640]=0;T(315,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break a}b=P()|0;O()|0;da(a|0);S(b|0);L()}return w[v[a>>2]+b|0]}ia(a|0,28664,242);L()}function e1(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;v[b+12>>2]=a;a=vi(b+8|0,b+12|0);v[22640]=0;c=tH();d=v[22640];v[22640]=0;if((d|0)!=1){ff(a);gb=b+16|0;return c|0}b=P()|0;O()|0;ff(a);S(b|0);L()}function c4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if((b|0)==(c|0)){a=0;break a}a=0;while(1){a=v[b>>2]+a|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;if((c|0)==(b|0)){break a}a=a<<4;continue}}return a|0}function Uc(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[22640]=0;v[c>>2]=-1;v[c+4>>2]=0;a=Qk(c+8|0,c);b=v[22640];v[22640]=0;if((b|0)!=1){gb=c+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function RT(a){var b=0,c=0;b=gb-16|0;gb=b;wb(a);v[b+12>>2]=-1;v[22640]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function f4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if((b|0)==(c|0)){a=0;break a}a=0;while(1){a=t[b|0]+a|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;if((c|0)==(b|0)){break a}a=a<<4;continue}}return a|0}function Uda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gb-16|0;gb=d;e=1;a=a+32|0;if(y[v[b>>2]>>2]<pc(a)>>>0){a=Xn(d,kc(a,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);b=xx(c,a);Hb(a);e=b^1}gb=d+16|0;return e|0}function S_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;Jp(a);v[a>>2]=27976;e=cc(a);d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;v[c+16>>2]=b;v[c+20>>2]=d;NF(e,c+8|0);gb=c+32|0;return a|0}function SK(a){a=a|0;var b=0;a=a+24|0;b=TK(v[a>>2]);if(Qi(Rb(v[a>>2]+484360|0))>>>0<=b>>>0){return x[v[a>>2]+1074446>>1]}b=x[rc(Rb(v[a>>2]+484360|0),b)>>1];return($l(v[a>>2]+484344|0,b)?b:-1)|0}function Nh(a,b){var c=0,d=0;a=v[a>>2];b=Td(b);c=b;d=a+16|0;if(Nb(d)>>>0>b>>>0){c=v[Mb(d,c)>>2]!=0}else{c=0}if(!c){a=aa(4)|0;Bm(a);v[a>>2]=89324;ia(a|0,89372,2298);L()}return v[Mb(a+16|0,b)>>2]}function HG(a,b,c,d,e){var f=0;f=gb-16|0;gb=f;v[f+12>>2]=e;e=vi(f+8|0,f+12|0);v[22640]=0;a=$p(a,b,c,d);b=v[22640];v[22640]=0;if((b|0)!=1){ff(e);gb=f+16|0;return a}a=P()|0;O()|0;ff(e);S(a|0);L()}function vo(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;ef(a+12|0,d);if(b){f=Kz(b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=(b<<2)+f|0,v[g>>2]=h;gb=e+16|0;return a}function vg(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb+-64|0;gb=c;d=$y(c+8|0,a);v[22640]=0;U(1494,a|0,b|0,d|0);a=v[22640];v[22640]=0;if((a|0)!=1){Hm(d);gb=c- -64|0;return}a=P()|0;O()|0;Hm(d);S(a|0);L()}function lr(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=yg(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){Ik(a);a=a+4|0;v[b+4>>2]=a;if((a|0)!=(d|0)){continue}break}}$b(b);gb=c+16|0}function jS(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;ef(a+12|0,d);if(b){f=lS(b)}v[a>>2]=f;c=(c<<5)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=(b<<5)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Xf(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;u[c+30>>1]=0;kj(c+16|0,a,c+30|0,2);a=xb(c+16|0);u[c+14>>1]=x[c+30>>1];d=b;b=c+14|0;u[d>>1]=w[b|0]|w[b+1|0]<<8;gb=c+32|0;return(a|0)==2|0}function WG(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;ef(a+12|0,d);if(b){f=vG(b)}v[a>>2]=f;c=(c<<4)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=(b<<4)+f|0,v[g>>2]=h;gb=e+16|0;return a}function Sga(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=WT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){qR(a);a=v[b>>2]+12|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Yc(b);gb=c+16|0}function DA(a,b,c,d){var e=0,f=0,g=0,h=0;e=gb-16|0;gb=e;v[e+12>>2]=0;ef(a+12|0,d);if(b){f=KR(b)}v[a>>2]=f;c=(c<<3)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=cc(a),h=(b<<3)+f|0,v[g>>2]=h;gb=e+16|0;return a}function C1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if((c|0)==(d|0)){break a}while(1){if(y[c>>2]<=127){if(x[Yp()+(v[c>>2]<<1)>>1]&b){break a}}c=c+4|0;if((d|0)!=(c|0)){continue}break}c=d}return c|0}function zT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=IG(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){xv(a);a=v[b>>2]+16|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Yc(b);gb=c+16|0}function yla(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(Pb(b,5)){Qv(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;gd(c+16|0,b,c+8|0);break a}t[c+16|0]=0;li(a,5,c+16|0)}gb=c+32|0}function dU(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-12|0,12)|0;v[c>>2]=f;if((d|0)>=1){hc(f,e,d)}wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),cc(b));v[b>>2]=v[b+4>>2]}function YT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=WT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){VT(a);a=v[b>>2]+12|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Yc(b);gb=c+16|0}function VG(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=IG(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){zG(a);a=v[b>>2]+16|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Yc(b);gb=c+16|0}function Ii(a){var b=0,c=0,d=0,e=0;e=de(a);b=e&63;a:{if(!(e&64)){break a}c=6;while(1){d=de(a);b=(d&127)<<c|b;if(!(d&128)){break a}d=c>>>0<25;c=c+7|0;if(d){continue}break}}return e&128?0-b|0:b}function DT(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=AT(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){IB(a);a=v[b>>2]+32|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Yc(b);gb=c+16|0}function $oa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(Pb(b,6)){KX(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;gd(c+16|0,b,c+8|0);break a}t[c+16|0]=0;li(a,6,c+16|0)}gb=c+32|0}function xn(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(Pb(b,4)){ti(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;gd(c+16|0,b,c+8|0);break a}t[c+16|0]=0;li(a,4,c+16|0)}gb=c+32|0}function uba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Rg(86224);if(!d){return 0}v[22640]=0;a=ca(1887,d|0,a|0,b|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function rC(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8;t[b+4|0]=a;t[b+5|0]=a>>>8}function mF(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808603728|(w[a+4|0]-9&255)>>>0>6|((w[a+5|0]-9&255)>>>0>6|(w[a+6|0]-9&255)>>>0>6))){return(w[a+7|0]-9&255)>>>0<7}return 0}function mD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>=1){while(1){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function fc(a,b,c){var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=v[b>>2];f=v[b+8>>2];b=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=b;g=v[v[e>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=b;kb[g|0](a,e,f,d);gb=d+16|0}function ev(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=Pk(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){Ik(a);a=v[b>>2]+4|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Yc(b);gb=c+16|0}function TV(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;b=Dn(c,a+8|0,b);a=v[b>>2];if((a|0)!=v[b+4>>2]){while(1){Kk(a);a=v[b>>2]+2|0;v[b>>2]=a;if(v[b+4>>2]!=(a|0)){continue}break}}Yc(b);gb=c+16|0}function xca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Rg(4280);if(!d){return 0}v[22640]=0;a=ca(1730,d|0,a|0,b|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function tda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Rg(4304);if(!d){return 0}v[22640]=0;a=ca(1598,d|0,a|0,b|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function pca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Rg(4276);if(!d){return 0}v[22640]=0;a=ca(1754,d|0,a|0,b|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function hca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Rg(4268);if(!d){return 0}v[22640]=0;a=ca(1777,d|0,a|0,b|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function cR(a,b){var c=0,d=0,e=0,f=0;c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-7|0,7)|0;v[c>>2]=f;if((d|0)>=1){hc(f,e,d)}wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),cc(b));v[b>>2]=v[b+4>>2]}function bx(a,b,c,d){var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;d=vi(e+8|0,e+12|0);v[22640]=0;a=sl(a,b,c);b=v[22640];v[22640]=0;if((b|0)!=1){ff(d);gb=e+16|0;return a}a=P()|0;O()|0;ff(d);S(a|0);L()}function aca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Rg(4296);if(!d){return 0}v[22640]=0;a=ca(1801,d|0,a|0,b|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function _S(a){var b=0,c=0;a:{b:{b=a&240;if((b|0)!=192){if((b|0)==240){break b}c=3;if((b|0)!=208){break a}}c=2;break a}c=1;a=a+15&255;if(a>>>0>2){break a}return 131842>>>(a<<3)&255}return c}function Vba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Rg(4228);if(!d){return 0}v[22640]=0;a=ca(1814,d|0,a|0,b|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function UM(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22640]=0;c=c-2048|0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function Tca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Rg(4236);if(!d){return 0}v[22640]=0;a=ca(1666,d|0,a|0,b|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function T8(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;a=v[a+24>>2];xL(c,b);v[22640]=0;U(580,a|0,1,c|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(c);gb=c+16|0;return}a=P()|0;O()|0;vb(c);S(a|0);L()}function Ry(a){var b=0,c=0,d=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){b=yo(d)^b;if(a>>>0<=16){a=a+15|0;b=b<<15;continue}break}A[c+4280>>3]=C(C(b|0)*C(-4.656612873077393e-10))}function Nda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Rg(4268);if(!d){return 0}v[22640]=0;a=ca(1535,d|0,a|0,b|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function Mz(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;yc(b+8|0,a+116|0);v[22640]=0;c=Ma(1334,a|0)|0;a=O()|0;c=c|0;d=v[22640];v[22640]=0;if((d|0)!=1){gb=b+16|0;jb=a;return c}a=P()|0;O()|0;S(a|0);L()}function Lba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Rg(5048);if(!d){return 0}v[22640]=0;a=ca(1837,d|0,a|0,b|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function Kha(){var a=0,b=0,c=0,d=0;a=gb-16|0;gb=a;b=rf(1);v[22640]=0;c=T(82,b|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){b=v[Ni(a+8|0,c)>>2];gb=a+16|0;return b|0}a=P()|0;O()|0;Zb(b);S(a|0);L()}function Jca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Rg(4296);if(!d){return 0}v[22640]=0;a=ca(1697,d|0,a|0,b|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function FR(a,b){var c=0,d=0;c=v[a+24>>2];v[22640]=0;c=ke(c+484344|0,b);d=v[22640];v[22640]=0;if((d|0)!=1){if(c){a=v[_b(v[a+24>>2]+484344|0,b)+12>>2]}else{a=1}return a}V(0)|0;O()|0;Bb();L()}function Bba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Rg(4276);if(!d){return 0}v[22640]=0;a=ca(1864,d|0,a|0,b|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zb(d);S(a|0);L()}function ep(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=Pb(a,4);a:{if(d){ti(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;gd(c+16|0,a,c+8|0);break a}EW(b)}gb=c+32|0;return d|0}function bw(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a:{if(Pb(b,2)){Bn(c+24|0,a);a=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=a;gd(c+16|0,b,c+8|0);break a}t[c+16|0]=0;YD(a,c+16|0)}gb=c+32|0}function Xea(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;a:{if(!_j(a,b+8|0)){break a}c=0;if(!WN(b+8|0)){break a}c=b;a=FT(a,b);if(!a){Ik(c)}c=-1;if(!a){break a}c=VN(b)}gb=b+16|0;return c|0}function XH(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;b=v[a+8>>2];d=v[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;v[a+8>>2]=b-c;v[a+12>>2]=d}function Kca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=v[b>>2];a:{if((xb(b)|0)!=8){break a}d=c;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=1869112133){break a}hc(a+4228|0,c,xb(b));Jt(a)}}function Bda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=v[b>>2];a:{if((xb(b)|0)!=8){break a}d=c;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=1869112133){break a}hc(a+4260|0,c,xb(b));Qt(a)}}function BH(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function AX(a){var b=0,c=0;a:{if(yd(a,18682,11)){break a}b=a+215|0;a=a+63|0;while(1){if(w[a+16|0]>3|w[a+17|0]>3|w[a+18|0]>=16){break a}a=a+19|0;if((b|0)!=(a|0)){continue}break}c=1}return c}function z1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=v[b>>2];if(a>>>0<=127){a=v[Ds()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function x1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=v[b>>2];if(a>>>0<=127){a=v[Cs()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function uha(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;c=Tb(b,7591);v[22640]=0;a=Q(89,a|0,c|0)|0;d=v[22640];v[22640]=0;if((d|0)!=1){vb(c);gb=b+16|0;return a|0}a=P()|0;O()|0;vb(c);S(a|0);L()}function ika(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;ST(b,c);if(Pb(a,c<<8)){bc(d+24|0,v[b>>2],ah(b)<<8);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;gd(d+16|0,a,d+8|0)}gb=d+32|0}function hY(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22640]=0;c=c-48|0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function dy(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function dca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=4){Fi(d+12|0);c=z[d+12>>2];if((b|0)==4){c=re(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4220>>2]=c;jM(a)}gb=d+16|0}function Si(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22640]=0;v[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Bb();L()}function Rba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=1){Fi(d+12|0);c=z[d+12>>2];if((b|0)==1){c=re(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;eM(a)}gb=d+16|0}function QG(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22640]=0;c=c-16|0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function vt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=gb-16|0;gb=a;if(Nb(b)){while(1){v[a+8>>2]=0;Ui(a+8|0);d=Mb(b,c),e=v[a+8>>2],v[d>>2]=e;c=c+1|0;if(Nb(b)>>>0>c>>>0){continue}break}}gb=a+16|0}function mG(a){var b=0;a:{b:{a=v[a>>2];if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a|0)!=(a&-256)}return b}function jia(){var a=0;a:{b:{if(t[90596]&1){break b}if(!Pd(90596)){break b}v[22640]=0;X(77);a=v[22640];v[22640]=0;if((a|0)==1){break a}Od(90596)}return}a=P()|0;O()|0;We(90596);S(a|0);L()}function gT(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22640]=0;c=c-1|0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function Y_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;vF(b,c);c=Pb(a,c<<3);if(c){uF(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;gd(d+16|0,a,d+8|0)}gb=d+32|0;return c|0}function Xh(a){var b=0;a=re(a);b=2147483647;a:{if(!(a<C(2147483648))){break a}b=-2147483648;if(!(a>C(-2147483648))){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function WE(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22640]=0;c=c-2|0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function Vu(a){var b=0,c=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[22640]=0;cf(a+8|0,b+12|0,b+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function UW(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22640]=0;c=c-6|0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function TO(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}wb(a);v[22640]=0;c=c-4|0;d=v[22640];v[22640]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}v[a+4>>2]=b}function Gg(a){var b=0,c=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[22640]=0;jf(a+8|0,b+12|0,b+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function ut(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;b=Ri(c,a,b);a=v[b+4>>2];d=v[b+8>>2];if((a|0)!=(d|0)){while(1){a=a+1|0;if((d|0)!=(a|0)){continue}break}v[b+4>>2]=d}$b(b);gb=c+16|0}function uj(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function n4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=jt(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;hc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function hA(a){var b=0,c=0;b=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(b|0)){break a}v[a+8>>2]=v[a+8>>2]-4;v[22640]=0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}}function fD(a){var b=0,c=0,d=0;b=a;c=v[b+8>>2];d=v[b+4>>2];if((c|0)!=(d|0)){while(1){c=c-28|0;v[b+8>>2]=c;Xd(c);c=v[b+8>>2];if((d|0)!=(c|0)){continue}break}}b=v[a>>2];if(b){kD(b,GY(a))}}function _aa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=GL(f,b,c,d,0,0,0,0,e);gb=f+16|0;return a|0}function XT(a){var b=0,c=0,d=0;b=a;c=v[b+8>>2];d=v[b+4>>2];if((c|0)!=(d|0)){while(1){c=c-12|0;v[b+8>>2]=c;ZT(c);c=v[b+8>>2];if((d|0)!=(c|0)){continue}break}}b=v[a>>2];if(b){Mu(b,Lp(a))}}function TE(a){var b=0,c=0;b=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(b|0)){break a}v[a+8>>2]=v[a+8>>2]-2;v[22640]=0;c=v[22640];v[22640]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}}function Fm(a,b){var c=0,d=C(0),e=0;e=u[a+28>>1];c=a+4|0;Nb(c);d=C(1);a:{if((b|0)<(e|0)){break a}if((x[a+28>>1]+Nb(c)<<16)-65536>>16<(b|0)){break a}d=z[Mb(c,b-u[a+28>>1]|0)>>2]}return d}function $S(a){var b=0,c=0;c=v[a+4>>2];a:{while(1){b=v[a+8>>2];if((b|0)==(c|0)){break a}v[a+8>>2]=b-4;v[22640]=0;b=v[22640];v[22640]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Bb();L()}}function ne(a,b){var c=0;a:{c=Lf(b);if((c|0)==(Ab(a)|0)){v[22640]=0;a=ga(571,a|0,0,-1,b|0,c|0)|0;b=v[22640];v[22640]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Bb();L()}function PL(a,b){var c=0,d=0,e=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);e=+a;c=Ke(31415.926535897932/+b);d=Oo((32768-(K((1-c)*+C(a+a)+(c*c-1)*+C(a*a))+c*e)*32768)/(1-e))}return d}function hR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(w[b+30|0]!=4){break a}d=b+31|0;if(w[d|0]&4|w[d|0]&2){break a}Pc(a,8,1,0,11);return}d=a;a=b+31|0;Pc(d,w[a|0]&4?16:8,w[a|0]&2|1,0,c^1)}function SX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;Fk(b,c);c=Pb(a,c);if(c){uD(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;gd(d+16|0,a,d+8|0)}gb=d+32|0;return c|0}function Rx(a,b,c,d,e){var f=0;f=Sx(a,b,c,d);if(Ed(e,d)){jc(d,e);if(!Ed(d,c)){return f+1|0}jc(c,d);if(!Ed(c,b)){return f+2|0}jc(b,c);if(!Ed(b,a)){return f+3|0}jc(a,b);f=f+4|0}return f}function Lx(a,b,c,d,e,f,g,h,i){var j=0;j=gb-16|0;gb=j;tg(j,b,c,d,e,f,g,h,i^-2147483648);b=v[j+4>>2];v[a>>2]=v[j>>2];v[a+4>>2]=b;b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;gb=j+16|0}function Ada(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);d=gb-16|0;gb=d;e=d,f=C(C(kb[v[v[a>>2]+48>>2]](a,b))+c),z[e+12>>2]=f;Fi(d+12|0);kb[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);gb=d+16|0}function tN(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22640]=0;v[b+8>>2]=32767;a=Fb(b+12|0,b+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=b+16|0;return u[a>>1]}V(0)|0;O()|0;Bb();L()}function r1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=t[b|0];if((a|0)>=0){a=v[Ds()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function p_(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;a=In(c+8|0,a);v[22640]=0;a=W(304,a|0,b|0,10485)|0;b=v[22640];v[22640]=0;if((b|0)!=1){gb=c+32|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function p1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((b|0)!=(c|0)){while(1){d=b;a=t[b|0];if((a|0)>=0){a=v[Cs()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function Ev(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22640]=0;v[b+8>>2]=65535;a=Fb(b+12|0,b+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=b+16|0;return x[a>>1]}V(0)|0;O()|0;Bb();L()}function y0(){var a=0;a:{if(t[465240]&1){break a}if(!Pd(465240)){break a}a=465216;while(1){a=Kb(a)+12|0;if((a|0)!=465240){continue}break}Od(465240)}hd(465216,88704);hd(465228,88716)}function wv(a){var b=0,c=0;b=gb-16|0;gb=b;u[b+14>>1]=a;v[22640]=0;u[b+12>>1]=255;a=Oc(b+14|0,b+12|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Bb();L()}function vh(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=RT(a);if(d>>>0<=b>>>0){a=hg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function qd(a,b,c){var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;f=v[b+12>>2];e=v[c+4>>2];c=v[c>>2];v[d+8>>2]=c;v[d+12>>2]=e;g=v[v[b>>2]+28>>2];v[d>>2]=c;v[d+4>>2]=e;kb[g|0](a,b,f,d);gb=d+16|0}function qC(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=LW(a);if(d>>>0<=b>>>0){a=Sj(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function ola(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=kb[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function _g(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=lA(a);if(d>>>0<=b>>>0){a=ye(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function Rk(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=VE(a);if(d>>>0<=b>>>0){a=Lg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function Mw(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=_F(a);if(d>>>0<=b>>>0){a=qg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function MX(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=UD(a);if(d>>>0<=b>>>0){a=am(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function KL(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=gb-16|0;gb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=JL(f,b,c,d,e,0,0,0,0);gb=f+16|0;return+c}function Cma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(FV()>>>0<b>>>0){Rc();L()}c=b;if(c>>>0>=178956971){nd(8513);L()}c=Mc(B(c,24),4);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=c+B(b,24)|0,v[d>>2]=e}function B0(){var a=0;a:{if(t[465208]&1){break a}if(!Pd(465208)){break a}a=465184;while(1){a=Kb(a)+12|0;if((a|0)!=465208){continue}break}Od(465208)}Vc(465184,11222);Vc(465196,11201)}function vs(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;d=Ab(b);if(d>>>0<c>>>0){_n();L()}b=Jb(b);v[e+4>>2]=d-c;xs(a,b+c|0,v[Fb(e+12|0,e+4|0)>>2]);gb=e+16|0}function roa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;hX(b,c,32);gX(a,c);gb=c+32|0}function p7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)!=(b|0)){d=v[c>>2];while(1){v[d>>2]=v[a>>2];cg(d+4|0,a+4|0);d=v[c>>2]+16|0;v[c>>2]=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}}function kr(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=kp();if(d>>>0<=b>>>0){a=ye(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function ho(a){var b=0,c=0;b=gb-16|0;gb=b;a:{if(lK(a)){break a}v[22640]=0;R(2115,b+8|0,a|0);c=v[22640];v[22640]=0;if((c|0)!=1){break a}V(0)|0;O()|0;Bb();L()}t[a+20|0]=255;gb=b+16|0}function fx(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=MG();if(d>>>0<=b>>>0){a=si(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function eP(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;bP(c,b+80|0);v[22640]=0;U(13,a|0,0,c|0);a=v[22640];v[22640]=0;if((a|0)!=1){vb(c);gb=c+16|0;return}a=P()|0;O()|0;vb(c);S(a|0);L()}function dE(a,b){var c=0;c=gb-16|0;gb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[22640]=0;jf(a+8|0,c+12|0,b);b=v[22640];v[22640]=0;if((b|0)!=1){gb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function cs(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=ww();if(d>>>0<=b>>>0){a=pg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function XQ(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{if(w[ec(a)+4|0]){v[22640]=0;a=v[22640];v[22640]=0;if((a|0)==1){break b}Rm(b+16|0)}if(b){tA(b)}break a}V(0)|0;O()|0;Bb();L()}}}function WO(a){a=a|0;var b=0;b=1;a=v[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function VN(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179012417){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=538987841){break a}}b=1}return b}function EN(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=AN();if(d>>>0<=b>>>0){a=mk(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function $q(a,b){var c=0,d=0;c=gb-16|0;gb=c;v[c+12>>2]=b;d=b;b=BT();if(d>>>0<=b>>>0){a=$h(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Jc(c+8|0,c+12|0)>>2]}gb=c+16|0;return b}Rc();L()}function zS(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=ji(e,a,d);a=wb(a);v[22640]=0;qS(a,b,c,d+4|0);a=v[22640];v[22640]=0;if((a|0)!=1){$b(d);gb=e+16|0;return}a=P()|0;O()|0;$b(d);S(a|0);L()}function dm(a){var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=a;v[22640]=0;v[b+8>>2]=255;a=Fb(b+12|0,b+8|0);c=v[22640];v[22640]=0;if((c|0)!=1){gb=b+16|0;return w[a|0]}V(0)|0;O()|0;Bb();L()}function OG(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=83432;b=a+16|0;if(Nb(b)){while(1){d=v[Mb(b,c)>>2];if(d){Jn(d)}c=c+1|0;if(Nb(b)>>>0>c>>>0){continue}break}}vb(a+192|0);ex(b);return a|0}function Ky(a){a=a|0;var b=0;a:{if(!a){a=aa(8)|0;v[22640]=0;T(1947,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break a}b=P()|0;O()|0;da(a|0);S(b|0);L()}return}ia(a|0,55096,1936);L()}function EL(a){a=a|0;var b=0;a:{if(!a){a=aa(8)|0;v[22640]=0;T(1935,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){break a}b=P()|0;O()|0;da(a|0);S(b|0);L()}return}ia(a|0,55040,1936);L()}function Bb(){var a=0;v[22640]=0;a=v[22640];v[22640]=0;a:{if((a|0)!=1){a=v[116446];if(!a){break a}if(!yG(a+48|0)){break a}xG(v[a+12>>2]);L()}V(0)|0;O()|0;Bb();L()}xG(v[22635]);L()}function qJ(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;h=a+2304|0;while(1){c=d<<2;e=c+a|0;c=c+h|0;f=z[c>>2];g=z[e>>2];z[e>>2]=f+g;z[c>>2]=g-f;d=d+1|0;if((d|0)!=(b|0)){continue}break}}function HN(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+4|0]|w[b+5|0]<<8;t[a+4|0]=b;t[a+5|0]=b>>>8}function ym(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=(a&-252645136)>>>4|(a&252645135)<<4;a=(a&-858993460)>>>2|(a&858993459)<<2;return(a&-1431655766)>>>1|(a&1431655765)<<1}function jj(a,b){var c=0,d=0;c=gb-16|0;gb=c;if(De(a)){Wh(a,v[a>>2],ck(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;Ve(b,0);v[c+12>>2]=0;Fe(b,c+12|0);gb=c+16|0}function d3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-16|0;gb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;a=fk(a,b,c,d,e,f,g+8|0,g+16|0);gb=g+16|0;return a|0}function az(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Cr(e,a,d);wb(a);a=c-b|0;if((a|0)>=1){hc(v[d+4>>2],b,a);v[d+4>>2]=v[d+4>>2]+B((a>>>0)/6|0,6)}$b(d);gb=e+16|0}function QU(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=441273424|w[a+5|0]!=16){break a}b=a+54|0;if(!w[b|0]|w[b|0]>32){break a}return w[a+4|0]>95}return 0}function PS(a,b){var c=0;c=w[a+800|0];a:{if(c){break a}c=di(w[a+797|0]-u[a+770>>1]|0);if(!b|(!v[a+656>>2]|!c|c>>>0>=129)){break a}c=w[lc(v[a+656>>2]+108|0,c-1|0)|0]}return c&255}function z4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;kb[v[v[a>>2]+12>>2]](d+8|0,a,b);a=d+8|0;if(He(v[a+4>>2],v[c+4>>2])){a=v[a>>2]==v[c>>2]}else{a=0}gb=d+16|0;return a|0}function s$(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;TN(b,0,a);v[22640]=0;a=T(180,b|0)|0;c=v[22640];v[22640]=0;if((c|0)!=1){vb(b);gb=b+16|0;return a|0}a=P()|0;O()|0;vb(b);S(a|0);L()}function qx(a,b){var c=0,d=0;c=gb-16|0;gb=c;u[b>>1]=0;t[c+15|0]=0;Qh(a,c+15|0);d=w[c+15|0];u[b>>1]=d>>>1;if(d&1){t[c+15|0]=0;Qh(a,c+15|0);u[b>>1]=x[b>>1]|w[c+15|0]<<7}gb=c+16|0}function lma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;WB(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+8|0,d+12|0)>>2]}gb=d+16|0;return c|0}function HX(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28163770){break a}if(yd(a+44|0,14888,3)){break a}a=a+47|0;b=(w[a|0]|w[a+1|0]<<8)>>>0>97}return b}function Eb(a,b){var c=0,d=0;c=gb-16|0;gb=c;if(De(a)){al(a,v[a>>2],ck(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;Ve(b,0);t[c+15|0]=0;zd(b,c+15|0);gb=c+16|0}function Bk(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=0;kj(c,a,c+12|0,4);a=xb(c);v[c>>2]=v[c+12>>2];v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);gb=c+16|0;return(a|0)==4}function yC(a,b){var c=0;a:{if(b){yC(a,v[b>>2]);yC(a,v[b+4>>2]);a=ec(a);v[22640]=0;c=v[22640];v[22640]=0;if((c|0)==1){break a}zk(b+16|0);Tk(a,b,1)}return}V(0)|0;O()|0;Bb();L()}function k7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[13996];v[c+8>>2]=v[13995];v[c+12>>2]=d;d=v[13994];v[c>>2]=v[13993];v[c+4>>2]=d;kb[v[Th(c,Vg(b))>>2]](a,b);gb=c+16|0}function jea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=gb-16|0;gb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(Nb(a+4|0)+e|0)-1|0,u[f+10>>1]=g;a=sN(a,b,c,d+8|0);gb=d+16|0;return a|0}function epa(a,b){a=a|0;b=b|0;if(!VX(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0}}function Qq(a,b){var c=0;a:{if(b){Qq(a,v[b>>2]);Qq(a,v[b+4>>2]);a=ec(a);v[22640]=0;c=v[22640];v[22640]=0;if((c|0)==1){break a}tR(b+16|0);es(a,b,1)}return}V(0)|0;O()|0;Bb();L()}function DN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!ke(a,b)){break a}c=Zy(a,v[$e(a,b)+12>>2],c);d=65535;if((c|0)==65535){break a}b=$e(a,b);MN($e(a,c),b);d=c}return d|0}function wba(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=Fo(C(C(C(uf(v[a+16>>2])>>>0)*C(20938023226335645e-21))+C(-.005025125574320555)),C(0),C(1)),z[b+4272>>2]=c;YL(a);XL(a)}function pR(a,b,c,d){var e=0,f=0;e=gb-16|0;gb=e;if(c){a=wb(a);while(1){f=Ml(a,c+16|0,b);d=f?d:c;c=v[(f?4:0)+c>>2];if(c){continue}break}}a=v[yc(e+8|0,d)>>2];gb=e+16|0;return a}function ni(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=$d(b),v[d+12>>2]=e;v[22640]=0;cf(a,c+12|0,b);b=v[22640];v[22640]=0;if((b|0)!=1){gb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function Vp(a){var b=0,c=0;b=v[22636];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(Pw()>>>0<a>>>0){if(!(va(a|0)|0)){break a}}v[22636]=a;return b}v[115121]=48;return-1}function Gt(a){var b=0,c=0,d=0;if(v[a>>2]){d=a;b=v[a+4>>2];c=v[a>>2];if((b|0)!=(c|0)){while(1){b=b-16|0;zk(b);if((b|0)!=(c|0)){continue}break}}v[d+4>>2]=c;sK(v[a>>2],si(a))}}function FU(a){var b=0,c=0,d=0;if(v[a>>2]){d=a;b=v[a+4>>2];c=v[a>>2];if((b|0)!=(c|0)){while(1){b=b-56|0;Su(b);if((b|0)!=(c|0)){continue}break}}v[d+4>>2]=c;Qu(v[a>>2],DU(a))}}function $A(a,b,c,d,e){var f=0;a:{if(!d){break a}f=1;while(1){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;if((d|0)==(f|0)){break a}c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;continue}}}function _la(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-32|0;gb=d;vF(b,c);if(Pb(a,c<<3)){uF(d+24|0,b);b=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=b;gd(d+16|0,a,d+8|0)}gb=d+32|0}function Y4(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=v[b+4>>2];b=v[b>>2];v[c>>2]=b;v[c+4>>2]=d;v[c+8>>2]=b;v[c+12>>2]=d;DH(a,c,6154);v[a>>2]=78184;gb=c+16|0;return a|0}function ur(a){var b=0,c=0;c=v[a+4>>2];b=v[c>>2];v[a+4>>2]=b;if(b){cp(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(jg(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c>>2]=a;cp(a,c)}function tr(a){var b=0,c=0;c=v[a>>2];b=v[c+4>>2];v[a>>2]=b;if(b){cp(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(jg(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c+4>>2]=a;cp(a,c)}function jna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;v[c+8>>2]=b;d=c,e=Sb(a),v[d>>2]=e;b=gv(c+8|0,c);b=v[a>>2]+(b<<2)|0;dj(a,Bg(b+4|0,v[a+4>>2],b));bh(b);gb=c+16|0}function XI(a){var b=0,c=0,d=0;a:{if(!Sh(t[v[a>>2]])){break a}while(1){c=v[a>>2];d=t[c|0];v[a>>2]=c+1;b=(b+d|0)-48|0;if(!Sh(t[c+1|0])){break a}b=B(b,10);continue}}return b}function wla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=kb[v[v[a>>2]+24>>2]](a)|0;a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function wha(a,b){a=a|0;b=b|0;var c=0;c=ad(a);t[a+16|0]=0;v[a+12>>2]=b;v[22640]=0;_(1097,a|0);b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;zu(c);S(a|0);L()}function vA(a,b){var c=0;c=gb-16|0;gb=c;ug(c+8|0,b);v[22640]=0;a=fB(a,c+8|0);b=v[22640];v[22640]=0;a:{if((b|0)!=1){gb=c+16|0;break a}V(0)|0;O()|0;Bb();L()}return a>>>31|0}function Xp(a,b){var c=0,d=0,e=0;c=0;a:{if(!a){break a}d=mqa(a,0,b,0);e=jb;c=d;if((a|b)>>>0<65536){break a}c=e?-1:d}b=c;a=Ad(b);if(!(!a|!(w[a-4|0]&3))){Qb(a,0,b)}return a}function u1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if((b|0)!=(c|0)){while(1){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;if((c|0)!=(b|0)){continue}break}}return c|0}function Zl(a,b,c){var d=0;d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a>>2]=d;v[a+4>>2]=b;Wk(a+8|0,c);return a}function HT(a){var b=0;if(v[a>>2]){Nd(a);b=v[a>>2];a=(v[wb(a)>>2]-v[a>>2]|0)/872|0;v[22640]=0;Nc(b,B(a,872),8);a=v[22640];v[22640]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function vW(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-33>>>0)/33^-1,33)+c}b=v[a>>2];if(b){uW(b,(v[cc(a)>>2]-v[a>>2]|0)/33|0)}}function mA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[b+56>>2]=0;d=b,e=Om(a,x[b+70>>1],v[b+48>>2],c,0),u[d+68>>1]=e;if(!(!(v[a+480180>>2]&5)|v[b+60>>2]==-1)){v[b+60>>2]=0}}function Wu(a){var b=0,c=0,d=0;d=a+32|0;a:{while(1){c=w[a|0];if(!((c-1&255)>>>0<31|((b^1)&1?0:c))){b=!c|b;a=a+1|0;if((d|0)!=(a|0)){continue}break a}break}b=0}return b&1}function UQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if((b|0)!=(c|0)){while(1){v[d+12>>2]=v[b>>2];LA(a,d+12|0);b=b+4|0;if((c|0)!=(b|0)){continue}break}}gb=d+16|0}function rJ(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function m1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if((b|0)!=(c|0)){while(1){a=t[b|0];t[e|0]=(a|0)>-1?a:d;e=e+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function lt(a){var b=0,c=0;b=a;a:{if((Le(b)|0)!=79){break a}if((Le(b)|0)!=103){break a}if((Le(b)|0)!=103){break a}c=(Le(b)|0)==83}if(!c){dc(a,30);return 0}return fJ(a)}function gea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=Si(v[b>>2]),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[Tm(c+12|0,c+8|0,50008)>>2],v[d+36>>2]=e;rq(a);gb=c+16|0}function dma(a,b){a=a|0;b=b|0;var c=0;a:{if(a>>>0>=515){a=og(b);og(b);break a}a=Kg(b);Kg(b)}if(a){while(1){if(a&1){Yb(b,260)}c=a>>>0>1;a=a>>>1|0;if(c){continue}break}}}function b_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[a>>2]=0;v[a+4>>2]=0;v[d+12>>2]=0;cf(a+8|0,d+12|0,d+8|0);if(b){Tr(a,b);NE(a,b,w[c|0])}gb=d+16|0;return a|0}function V4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=_p(d,a);NG(a,c);v[22640]=0;R(2363,b|0,1);a=v[22640];v[22640]=0;if((a|0)==1){a=P()|0;O()|0;Vb(d);S(a|0);L()}}function Fc(a,b){var c=0,d=0;c=gb-16|0;gb=c;if(v[a+4>>2]==v[b+4>>2]){d=v[b+4>>2];b=v[b>>2];v[c>>2]=b;v[c+4>>2]=d;v[c+8>>2]=b;v[c+12>>2]=d;d=!GW(a,c)}gb=c+16|0;return d}function FK(a,b){a=a|0;b=b|0;var c=0;c=-1;a:{if((b|0)<0){break a}a=a+24|0;if((Qi(Rb(v[a>>2]+484360|0))|0)<=(b|0)){break a}c=x[rc(Rb(v[a>>2]+484360|0),b)>>1]}return c|0}function yd(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=w[a|0];e=w[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function tG(a,b,c,d){var e=0,f=0,g=0;f=v[a+4>>2];e=0;a:{if(!c){break a}g=f>>8;e=g;if(!(f&1)){break a}e=Tw(v[c>>2],g)}a=v[a>>2];kb[v[v[a>>2]+28>>2]](a,b,c+e|0,f&2?d:2)}function mba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b){f=v[b+24>>2];g=v[b+8>>2];h=v[b+4>>2];i=v[b>>2];e=v[b+12>>2]}else{e=0}NL(a,i,h,g,e,f,b,c,d)}function Cj(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;A[a>>3]=A[a>>3]-A[c>>3];A[a+8>>3]=A[a+8>>3]-A[c+8>>3]}function s_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function sZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;if(Jg(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=wD(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0;return c|0}function rf(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Ad(a);if(!b){b=v[116448];if(!b){break a}kb[b|0]();continue}break}return b|0}a=aa(4)|0;km(a);ia(a|0,88880,1928);L()}function qma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;WB(a,b,c);a=v[a+16>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function kl(a,b,c){var d=0;d=gb-16|0;gb=d;nl(d+8|0,a+24|0,b);a=v[d+12>>2];a:{if(c){b=v[d+8>>2];v[b>>2]=a|v[b>>2];break a}b=v[d+8>>2];v[b>>2]=v[b>>2]&(a^-1)}gb=d+16|0}function TT(a){if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1299020115){a=a+4|0;a=(Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|0)==1}else{a=0}return a}function KD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;if(Jg(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=xD(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0;return c|0}function Ima(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=nc(a+8|0);v[22640]=0;U(383,a|0,b|0,c|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;gc(d);S(a|0);L()}}function CB(a){var b=0;if(v[a>>2]){Nd(a);b=v[a>>2];a=(v[wb(a)>>2]-v[a>>2]|0)/9|0;v[22640]=0;Nc(b,B(a,9),1);a=v[22640];v[22640]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function zX(a){var b=0,c=0;c=mqa(w[a+217|0],0,9,0);b=w[a+216|0];a=b>>>31|0;b=b<<1;c=c+b|0;a=a+jb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;if(b>>>0<11){a=a+1|0}jb=a;return b}function c6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;a=ct(Pa(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);gb=e+16|0;jb=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function bR(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-7>>>0)/7^-1,7)+c}b=v[a>>2];if(b){VQ(b,(v[cc(a)>>2]-v[a>>2]|0)/7|0)}}function WS(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=w[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function M_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Fb(d+12|0,d+8|0)>>2]}gb=d+16|0;return c|0}function MU(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=541938512|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1162627398)){return 1}return 0}function Ee(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(!c){break a}a=v[ec(a)>>2];v[22640]=0;_(a|0,c|0);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Dfa(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[22640]=0;a=Q(1321,a|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){gb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function Cx(a,b){var c=0;c=Bt(a+4|0);v[a>>2]=77008;v[c>>2]=77028;v[22640]=0;R(2381,c|0,b|0);a=v[22640];v[22640]=0;if((a|0)!=1){return}a=P()|0;O()|0;lh(c);S(a|0);L()}function Bx(a,b){var c=0;c=MH(a+4|0);v[a>>2]=77056;v[c>>2]=77076;v[22640]=0;R(2382,c|0,b|0);a=v[22640];v[22640]=0;if((a|0)!=1){return}a=P()|0;O()|0;lh(c);S(a|0);L()}function gI(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=Ig(b),d=v[v[a>>2]+52>>2],kb[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return Ig(b)}function Jy(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=9){if((Iy(d)|0)>(e|0)){break b}}g=a,h=Hy(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function Ey(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=4){if((Iy(d)|0)>(e|0)){break b}}g=a,h=Hy(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function CL(a,b,c,d){var e=0,f=0,g=0,h=0;f=a;a:{b:{e=c-b|0;if((e|0)<=2){if((Iy(d)|0)>(e|0)){break b}}g=a,h=Hy(d,b),v[g>>2]=h;a=0;break a}v[a>>2]=c;a=61}v[f+4>>2]=a}function yt(a,b){a=a|0;b=b|0;v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Qb(a+32|0,0,40);dx(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function vB(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;MR(a+112|0,48e3);v[a+668>>2]=0;uB(a+724|0);uB(a+732|0);uB(a+740|0);Zi(a+788|0);return a}function lp(a,b){var c=0,d=0,e=0;vv(a);ip(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[wb(b)>>2];d=wb(a),e=c,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function gha(a,b){a=a|0;b=b|0;var c=0;c=th(a);t[a+530|0]=0;v[22640]=0;R(1113,a|0,b|0);b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Zm(c);S(a|0);L()}function Yb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Pb(a,b);if(c){v[a+8>>2]=v[a+8>>2]+b;return c|0}b=a;a=v[a>>2];d=b,e=kb[v[v[a>>2]+24>>2]](a)|0,v[d+8>>2]=e;return c|0}function IS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=a+108|0;c=a+128|0;if((a|0)!=(c|0)){while(1){d=a,e=pn(w[a|0]+b|0),t[d|0]=e;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function FB(a,b){var c=0,d=0,e=0;wb(b);c=mh(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];a=v[wb(b)>>2];d=wb(c),e=a,v[d>>2]=e;d=wb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function uA(a,b){a:{if(b){uA(a,v[b>>2]);uA(a,v[b+4>>2]);ec(a);v[22640]=0;a=v[22640];v[22640]=0;if((a|0)==1){break a}Rm(b+16|0);tA(b)}return}V(0)|0;O()|0;Bb();L()}function pE(a){var b=0,c=0;a:{if(yd(a,11486,3)){break a}b=a+3|0;if(w[b|0]<8|w[b|0]>14){break a}a=a+40|0;if(!(w[b|0]>9?w[a|0]<33?w[a|0]:0:1)){break a}c=1}return c}function _q(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function P$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=v[c>>2];a=kb[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}gb=d+16|0;return a|0}function k2(){var a=0,b=0;a:{Ud(465296);v[116324]=83504;v[22640]=0;a=fa(2454)|0;b=v[22640];v[22640]=0;if((b|0)!=1){v[116326]=a;break a}a=P()|0;O()|0;S(a|0);L()}}function Vla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-80|0;gb=d;c=-1;a:{if(!wY(a,d+8|0)){break a}c=0;if(!$U(d+8|0)){break a}c=Ne(a,b,_U(d+8|0),jb)}gb=d+80|0;return c|0}function Qh(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+31|0]=0;kj(c+16|0,a,c+31|0,1);a=xb(c+16|0);t[c+8|0]=w[c+31|0];t[b|0]=w[c+8|0];gb=c+32|0;return(a|0)==1|0}function wT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-256>>>8^-1)<<8)+c}b=v[a>>2];if(b){qB(b,v[cc(a)>>2]-v[a>>2]>>8)}}function t4(a,b,c){a=a|0;b=b|0;c=c|0;b=c;a:{if((c|0)>=257){EH();c=90536;break a}b:{if(t[463684]&1){break b}if(!Pd(463684)){break b}Od(463684)}c=90532}pd(a,b,c)}function cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=nc(a);v[22640]=0;U(90,a|0,b|0,c|0);b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Lc(d);S(a|0);L()}function Oj(a){var b=0,c=0;c=a;a=v[a>>2];b=v[a+4>>2];a:{if(!b){if(!jg(a)){while(1){a=v[a+8>>2];if(!jg(a)){continue}break}}a=v[a+8>>2];break a}a=UV(b)}v[c>>2]=a}function IM(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[c+8>>2]=127;b=Fb(c+12|0,c+8|0);z[v[a+20>>2]+144>>2]=C(C(y[b>>2])*C(-.007874015718698502))+C(1);gb=c+16|0}function Be(a,b,c){a=a|0;b=b|0;c=c|0;t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a|0}function rK(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function rE(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(De(a)){d=v[a>>2];t[c+15|0]=0;zd(b+d|0,c+15|0);ee(a,b);break a}t[c+14|0]=0;zd(a+b|0,c+14|0);Ve(a,b)}gb=c+16|0}function oqa(a,b,c){var d=0,e=0;d=b>>31;e=a^d;a=b>>31;kqa(e-d|0,(b^a)-((d>>>0>e>>>0)+a|0)|0,c,0);jb=ib;b=d^hb;c=b-d|0;jb=(a^jb)-((b>>>0<d>>>0)+a|0)|0;return c}function o4(a,b){a=a|0;b=b|0;Bm(a);v[a>>2]=88920;b=Jb(b);v[22640]=0;Q(2425,a+4|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function lF(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=v[b>>2];d=zb((kb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0);a=v[b>>2];Wd(c,d,(kb[v[v[a>>2]+24>>2]](a)|0)-v[b+8>>2]|0)}function is(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[22640]=0;cf(a,c+12|0,c+8|0);b=v[22640];v[22640]=0;if((b|0)!=1){gb=c+16|0;return a}V(0)|0;O()|0;Bb();L()}function Hy(a,b){var c=0,d=0;a:{if(a>>>0<=99999999){a=Px(b,a);break a}c=(a>>>0)/1e8|0;d=a-B(c,1e8)|0;a=(d>>>0)/1e4|0;a=tj(tj(LI(b,c),a),d-B(a,1e4)|0)}return a}function wda(a,b){a=a|0;b=b|0;var c=0;TM(a);c=b+4|0;xk(wb(a),v[a>>2],v[a+4>>2],c);jc(a,c);jc(a+4|0,b+8|0);jc(wb(a),cc(b));v[b>>2]=v[b+4>>2];Qf(a);Cl(a);Cl(a)}function XL(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function Gs(a){a=a|0;var b=0;b=aa(8)|0;v[22640]=0;Q(1981,b|0,a|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){ia(b|0,89228,242);L()}a=P()|0;O()|0;da(b|0);S(a|0);L()}function EV(a,b){var c=0;c=gb-32|0;gb=c;a:{if(Rf(a,4)){ti(c+24|0,b);b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;LB(c+16|0,a,c+8|0);break a}EW(b)}gb=c+32|0}function AB(a,b){var c=0,d=0,e=0,f=0;d=mh(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=wb(b);e=wb(d),f=v[c>>2],v[e>>2]=f;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function ud(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(!b){break a}if(!Pb(a,b)){break a}t[c+15|0]=0;Jg(a,c+15|0);t[c+8|0]=w[c+15|0];d=w[c+8|0]}gb=c+16|0;return d}function X2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=kb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return ek(g,b,c,d,e,f,Jb(a),Jb(a)+(Ab(a)<<2)|0)|0}function P6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)!=(b|0)){d=v[c>>2];while(1){Vf(d,a);d=v[c>>2]+12|0;v[c>>2]=d;a=a+12|0;if((b|0)!=(a|0)){continue}break}}}function HE(a,b){var c=0,d=0;c=gb-16|0;gb=c;a:{if(!b){break a}if(!Pb(a,b)){break a}t[c+15|0]=0;Jg(a,c+15|0);t[c+8|0]=w[c+15|0];d=t[c+8|0]}gb=c+16|0;return d}function fm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[ac(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;gb=d+16|0}function em(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=gb-16|0;gb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[ac(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;gb=d+16|0}function J7(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=cg(a,b);v[22640]=0;Q(111,a+12|0,c|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){break a}a=P()|0;O()|0;vb(b);S(a|0);L()}}function t_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function ri(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function kA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(v[a+480180>>2]&2){break a}}v[b+56>>2]=0;d=Om(a,x[b+70>>1],v[b+48>>2],c,0)}return d|0}function Rz(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=0;v[22640]=0;cf(a,b+12|0,b+8|0);a=v[22640];v[22640]=0;if((a|0)!=1){gb=b+16|0;return}V(0)|0;O()|0;Bb();L()}function KT(a){var b=0;a=fe(a);b=32767;a:{if(!(a<32767)){break a}b=-32768;if(!(a>-32768)){break a}b=~~a;if(D(a)<2147483648){break a}b=-2147483648}return b}function HS(a,b,c,d){v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;if(v[v[a>>2]>>2]){v[a>>2]=v[v[a>>2]>>2]}_W(v[ec(a)>>2],v[c>>2]);a=wb(a);v[a>>2]=v[a>>2]+1}function Gj(a){var b=0;a=re(a);b=-1;a:{if(!(a<C(4294967296))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function rt(a){var b=0,c=0,d=0;c=v[a+4>>2];b=((c<<2)+(jw(v[a>>2],1)^270549120)|0)+2019860093|0;d=jw(b,16);v[a>>2]=b;b=a;a=B(d,5)+c|0;v[b+4>>2]=a;return a}function koa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=c;c=0;a:{if(!b){break a}if(!Pb(a,b)){break a}if(b>>>0<=3){c=FE(a,b);break a}c=og(a);Yb(a,b-4|0)}v[d>>2]=c}function iy(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(C(z[((c&3)<<2)+62592>>2]*a)*C(1073741824>>>(c>>2)|0));b=b-c|0;if((b|0)>0){continue}break}return a}function hoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=c;c=0;a:{if(!b){break a}if(!Pb(a,b)){break a}if(b>>>0<=1){c=EE(a,1);break a}c=Kg(a);Yb(a,b-2|0)}u[d>>1]=c}function eg(a,b,c){a:{switch(b-1|0){case 0:if(c){return Ej(a,1)}return Ej(a,0);case 1:if(c){return Ej(a,3)}return Ej(a,2);default:break a}}return Ej(a,4)}function W4(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];if(c){while(1){c=c-1|0;d=c<<2;kb[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);if(c){continue}break}}}function N_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Ek(a,b,c,d){var e=0,f=0;e=B(b,c);f=e;a:{if(v[d+76>>2]<=-1){a=VC(a,e,d);break a}a=VC(a,e,d)}if((f|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function ov(a){var b=0;b=gb-16|0;gb=b;pd(b+8|0,a,0);v[22640]=0;xp(b+8|0,113,0);a=v[22640];v[22640]=0;if((a|0)!=1){gb=b+16|0;return}V(0)|0;O()|0;Bb();L()}function eo(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=Ad(b)}return c}function eU(a,b){a=a|0;b=b|0;var c=0,d=0;u[a+34>>1]=0;c=gb-16|0;gb=c;t[c+15|0]=0;d=a+43|0;no(d,d+22|0,c+15|0);gb=c+16|0;v[a+20>>2]=0;td(a,b);return a|0}function c3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=kb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return fk(g,b,c,d,e,f,Jb(a),Jb(a)+Ab(a)|0)|0}function c1(a){a=a|0;var b=0;a=v[a+8>>2];if(!a){return 1}v[22640]=0;a=T(2553,a|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}V(0)|0;O()|0;Bb();L()}function Xc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(kb[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function XR(a){var b=0,c=0,d=0;b=a+26|0;c=w[b|0]+27|0;if(w[b|0]){while(1){c=w[(a+d|0)+27|0]+c|0;d=d+1|0;if(d>>>0<w[b|0]){continue}break}}return c&65535}function P4(a,b){a=a|0;b=b|0;var c=0,d=0;b=Ex(b);v[a+36>>2]=b;c=a,d=wo(b),v[c+44>>2]=d;c=a,d=Yn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Gs(2655);L()}}function L4(a,b){a=a|0;b=b|0;var c=0,d=0;b=Ax(b);v[a+36>>2]=b;c=a,d=wo(b),v[c+44>>2]=d;c=a,d=Yn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Gs(2655);L()}}function vE(a,b){a=a|0;b=b|0;var c=0;Fp(a);c=b+4|0;xk(wb(a),v[a>>2],v[a+4>>2],c);jc(a,c);jc(a+4|0,b+8|0);jc(wb(a),cc(b));v[b>>2]=v[b+4>>2];Wr(a,sc(a))}function lE(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;vw(b+8|0,a);a=w[lc(b+8|0,0)|0];c=w[lc(b+8|0,1)|0];d=lc(b+8|0,2);gb=b+16|0;return a|c<<8|w[d|0]<<16}function Pq(a,b){a=a|0;b=b|0;var c=0;tk(a);c=b+4|0;xk(wb(a),v[a>>2],v[a+4>>2],c);jc(a,c);jc(a+4|0,b+8|0);jc(wb(a),cc(b));v[b>>2]=v[b+4>>2];Lm(a,Nb(a))}function Od(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;a=Xw(b,a);c=gb-16|0;gb=c;d=v[yc(c+8|0,v[a+4>>2])>>2],e=1,t[d|0]=e;t[v[a+8>>2]]=1;gb=c+16|0;gb=b+16|0}function DC(a,b){a=a|0;b=b|0;var c=0;sv(a);c=b+4|0;xk(wb(a),v[a>>2],v[a+4>>2],c);jc(a,c);jc(a+4|0,b+8|0);jc(wb(a),cc(b));v[b>>2]=v[b+4>>2];Lu(a,pc(a))}function CH(a,b){a=a|0;b=b|0;Bm(a);v[a>>2]=88920;v[22640]=0;Q(2425,a+4|0,b|0)|0;b=v[22640];v[22640]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function Ak(a,b,c,d){v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;b=a;d=v[v[a>>2]>>2];if(d){v[b>>2]=d}_W(v[ec(a)>>2],v[c>>2]);a=wb(a);v[a>>2]=v[a>>2]+1}function xba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=2){Fi(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];YL(a)}gb=d+16|0}function tca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=5){Fi(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];sM(a)}gb=d+16|0}function qba(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=3){Fi(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];VL(a)}gb=d+16|0}function p4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Lf(b);d=rf(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=hc(d+12|0,b,c+1|0),v[e>>2]=f;return a|0}function lca(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=gb-16|0;gb=d;z[d+12>>2]=c;if((b|0)<=4){Fi(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];nM(a)}gb=d+16|0}function cP(a,b){var c=0,d=0;d=gb-32|0;gb=d;c=wb(a);c=vo(d+8|0,kr(a,Nb(a)+1|0),Nb(a),c);Cq(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;Uk(a,c);EO(c);gb=d+32|0}function _pa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(DE(a,d+8|0)){v[d+4>>2]=w[d+8|0];NY(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0}function _i(a,b){var c=0;c=v[v[b>>2]-12>>2];v[22640]=0;b=v[(b+c|0)+24>>2];c=v[22640];v[22640]=0;if((c|0)!=1){v[a>>2]=b;return a}V(0)|0;O()|0;Bb();L()}function _7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(_F(a)>>>0<b>>>0){Rc();L()}c=ZF(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,12)+c|0,v[d>>2]=e;Lw(a,0)}function Tr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(IE(a)>>>0<b>>>0){Rc();L()}b=(b-1>>>5|0)+1|0;c=Li(wb(a),b);v[a+4>>2]=0;v[a>>2]=c;d=wb(a),e=b,v[d>>2]=e}function Pn(a){var b=0;b=aa(8)|0;v[22640]=0;Q(167,b|0,a|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){ia(b|0,89160,24);L()}a=P()|0;O()|0;da(b|0);S(a|0);L()}function K3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;c=gb-16|0;gb=c;v[c+12>>2]=b;v[c+8>>2]=d;b=vi(c,c+12|0);a=AH(a,6437,v[c+8>>2]);ff(b);gb=c+16|0;return a|0}function GZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(UD(a)>>>0<b>>>0){Rc();L()}c=TD(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,20)+c|0,v[d>>2]=e;SD(a,0)}function rZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;if(Jg(a,d+8|0)){v[d+4>>2]=w[d+8|0];vD(a,b,v[Fb(d+4|0,d+12|0)>>2])}gb=d+16|0}function rV(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1297239878?(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))==1279545165:0}function nd(a){var b=0;b=aa(8)|0;v[22640]=0;Q(23,b|0,a|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){ia(b|0,89108,24);L()}a=P()|0;O()|0;da(b|0);S(a|0);L()}function jla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c;e=b;if(qp(b,c+24|0)){b=dn(c+24|0)}else{b=0}rd(d,e,b);Zl(a,c+24|0,c);yb(c);gb=c+32|0}function fX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(LW(a)>>>0<b>>>0){Rc();L()}c=KW(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=B(b,6)+c|0,v[d>>2]=e;sC(a,0)}function cA(a){var b=0;a=re(a);b=255;a:{if(!(a<C(255))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function aw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(lA(a)>>>0<b>>>0){Rc();L()}c=Li(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e;Lm(a,0)}function aP(a){if(w[a+480224|0]==2){return+y[a+1074420>>2]*1e-4}return+y[a+24620>>2]*60/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))}function _ja(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-48|0;gb=d;c=-1;a:{if(!mU(a,d)){break a}c=0;if(!rT(d)){break a}c=Ne(a,b,qT(d),jb)}gb=d+48|0;return c|0}function Yka(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-96|0;gb=d;c=-1;a:{if(!RU(a,d)){break a}c=0;if(!rU(d)){break a}c=Ne(a,b,qU(d),jb)}gb=d+96|0;return c|0}function Ye(a){var b=0,c=0;b=gb-16|0;gb=b;a:{if(De(a)){c=v[a>>2];t[b+15|0]=0;zd(c,b+15|0);ee(a,0);break a}t[b+14|0]=0;zd(a,b+14|0);Ve(a,0)}gb=b+16|0}function TB(a){var b=0,c=0;c=(w[a+24|0]>15)+(w[a+25|0]>64)|0;b=a+26|0;a=a+22|0;return c+(Ib(w[b|0]|w[b+1|0]<<8)>>>0>Ib(w[a|0]|w[a+1|0]<<8)<<1>>>0)|0}function S1(){var a=0;a:{Ud(465520);v[22640]=0;T(2539,465528)|0;a=v[22640];v[22640]=0;if((a|0)!=1){v[116380]=86208;break a}a=P()|0;O()|0;S(a|0);L()}}function Rka(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-48|0;gb=d;c=-1;a:{if(!mU(a,d)){break a}c=0;if(!lU(d)){break a}c=Ne(a,b,kU(d),jb)}gb=d+48|0;return c|0}function Q1(){var a=0;a:{Ud(465536);v[22640]=0;T(2539,465544)|0;a=v[22640];v[22640]=0;if((a|0)!=1){v[116384]=86364;break a}a=P()|0;O()|0;S(a|0);L()}}function JB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(VE(a)>>>0<b>>>0){Rc();L()}c=UE(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<1)+c|0,v[d>>2]=e;Wr(a,0)}function Bla(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-96|0;gb=d;c=-1;a:{if(!RU(a,d)){break a}c=0;if(!QU(d)){break a}c=Ne(a,b,PU(d),jb)}gb=d+96|0;return c|0}function R$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Og(a,v[b+8>>2],f)){Sw(b,c,d,e);return}a=v[a+8>>2];kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function OY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;d=c;e=b;if(qp(b,c+24|0)){b=JY(c+24|0)}else{b=0}rd(d,e,b);Zl(a,c+24|0,c);yb(c);gb=c+32|0}function JR(a){var b=0;if(v[a>>2]){cX(a);wb(a);b=v[a>>2];a=si(a);v[22640]=0;Nc(b,a<<4,8);a=v[22640];v[22640]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function In(a,b){var c=0;v[a>>2]=19304;v[a>>2]=28104;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function gy(a,b){var c=0,d=0;c=b&1?a:1;if(b+1>>>0>=3){d=b;while(1){a=a*a;d=(d|0)/2|0;c=d&1?a*c:c;if(d+1>>>0>2){continue}break}}return(b|0)<0?1/c:c}function WX(a){t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function KA(a,b,c){var d=0,e=0,f=0;d=Nl(a,b);if((d|0)!=255){e=sd(a+22|0,d),f=c,u[e>>1]=f;a=a+58|0;e=lc(a,b),f=255,t[e|0]=f;e=lc(a,c),f=d,t[e|0]=f}}function H7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-32|0;gb=h;CK(h+8|0,b,c,d,e,f,g);Dc(a,h+20|0);Rm(h+8|0);gb=h+32|0}function A7(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-32|0;gb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;xs(a,v[c+8>>2],v[c+12>>2]);gb=c+32|0;return a|0}function w1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){while(1){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function gx(a,b,c){a:{if((a|0)==(b|0)){break a}c=v[c>>2];while(1){if((c|0)==v[a>>2]){break a}a=a+4|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function eM(a){var b=0;b=(uf(v[a+16>>2])>>>0)/(Gj(C(z[a+4208>>2]*C(999)))+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;tc(a+4224|0,b)}function cU(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=B(((c-d|0)-12>>>0)/12^-1,12)+c}b=v[a>>2];if(b){Mu(b,Lp(a))}}function XN(a,b){a=a|0;b=b|0;var c=0;if(!(w[b+14|0]&48|w[b+17|0]!=173)){Pc(a,8,1,0,11);return}c=a;a=b+14|0;Pc(c,w[a|0]&16?16:8,w[a|0]&32?3:1,0,2)}function Sx(a,b,c,d){var e=0;e=ao(a,b,c);if(Ed(d,c)){jc(c,d);if(!Ed(c,b)){return e+1|0}jc(b,c);if(!Ed(b,a)){return e+2|0}jc(a,b);e=e+3|0}return e}function I7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=gb-32|0;gb=h;CK(h+8|0,b,c,d,e,f,g);Dc(a,h+8|0);Rm(h+8|0);gb=h+32|0}function BD(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0}function xB(a){var b=0;if(v[a>>2]){Nd(a);b=v[a>>2];a=Yk(a);v[22640]=0;Nc(b,B(a,36),4);a=v[22640];v[22640]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function q5(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(Tf(v[v[b>>2]-12>>2]+b|0)){b=v[(v[v[b>>2]-12>>2]+b|0)+72>>2];if(b){fI(b)}t[a|0]=1}return a|0}function o1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}return c|0}function fq(a,b){var c=0;a:{if(!rJ(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function dx(a){var b=0,c=0;v[22640]=0;c=fa(2542)|0;b=v[22640];v[22640]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;Kn(a);return}V(0)|0;O()|0;Bb();L()}function Mx(a){var b=0,c=0;b=gb-16|0;gb=b;c=-1;a:{if(FI(a)){break a}if((kb[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}gb=b+16|0;return c}function F5(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(Tf(v[v[b>>2]-12>>2]+b|0)){b=v[(v[v[b>>2]-12>>2]+b|0)+72>>2];if(b){Ws(b)}t[a|0]=1}return a|0}function CA(a,b){var c=0;zR(a);wb(a);c=b+4|0;cl(v[a>>2],v[a+4>>2],c);wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),cc(b));v[b>>2]=v[b+4>>2];of(a);pg(a);pg(a)}function uk(a,b){var c=0,d=0;a:{b=Nl(a,b);if((b|0)==255){break a}if(vk(a)){break a}c=lc(a+4|0,b);d=w[c|0]&223;t[c|0]=d;Yh(v[a>>2],xu(b)|176,d)}}function mm(a,b){a:{if((a|0)==(b|0)){break a}b=b-1|0;if(b>>>0<=a>>>0){break a}while(1){Dh(a,b);a=a+1|0;b=b-1|0;if(a>>>0<b>>>0){continue}break}}}function gp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(RT(a)>>>0<b>>>0){Rc();L()}c=mi(wb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=b+c|0,v[d>>2]=e;Lu(a,0)}function fn(a){a=+a;var b=0;a=fe(a);b=255;a:{if(!(a<255)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function _C(a){var b=0;if(v[a>>2]){Nd(a);b=v[a>>2];a=Sj(a);v[22640]=0;Nc(b,B(a,6),1);a=v[22640];v[22640]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function Jpa(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;u[b+14>>1]=1;c=b,d=Yl(a),u[c+12>>1]=d;a=x[Ie(b+14|0,b+12|0)>>1];gb=b+16|0;return a-1&65535}function Hs(a,b){a:{if((a|0)==(b|0)){break a}b=b-4|0;if(b>>>0<=a>>>0){break a}while(1){jc(a,b);a=a+4|0;b=b-4|0;if(a>>>0<b>>>0){continue}break}}}function EW(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=gb-16|0;gb=c;d=a+4|0;while(1){Kf(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}gb=c+16|0;gb=b+16|0}function EA(a){var b=0,c=0,d=0;c=w[a+32|0];d=Oi(v[a+24>>2]+484360|0);b=v[a+24>>2]+484360|0;if(c>>>0>=d>>>0){return Rb(b)}return Nj(b,w[a+32|0])}function Dm(a,b,c){a:{if((a|0)==(b|0)){break a}c=w[c|0];while(1){if((c|0)==w[a|0]){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function B6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];v[a+4>>2]=0;yt(v[v[a>>2]-12>>2]+a|0,c);return a|0}function aJ(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];if(!w[a+23|0]){v[(c<<2)+g>>2]=b;return}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;v[f+g>>2]=c}function yT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-16>>>4^-1)<<4)+c}b=v[a>>2];if(b){sB(b,_w(a))}}function WC(a){var b=0;if(v[a>>2]){Nd(a);b=v[a>>2];a=ye(a);v[22640]=0;Nc(b,a<<2,2);a=v[22640];v[22640]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function U5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=v[a+20>>2];d=v[a+16>>2]-e|0;d=c>>>0<d>>>0?c:d;hc(e,b,d);v[a+20>>2]=d+v[a+20>>2];return c|0}function Jv(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(ds(a,b+8|0)){c=Xb(w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))}gb=b+16|0;return c|0}function Jf(a){var b=0;if(v[a>>2]){Nd(a);b=v[a>>2];a=pg(a);v[22640]=0;Nc(b,a<<3,8);a=v[22640];v[22640]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function CT(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-32>>>5^-1)<<5)+c}b=v[a>>2];if(b){tB(b,oB(a))}}function $L(a){a=a|0;var b=0,c=0;v[a>>2]=52864;b=a+4960|0;c=a+4504|0;while(1){b=b-24|0;Lc(b);if((b|0)!=(c|0)){continue}break}hf(a);return a|0}function tF(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-8>>>3^-1)<<3)+c}b=v[a>>2];if(b){yF(b,sF(a))}}function rp(a){var b=0,c=0,d=0;b=a;c=v[a+8>>2];d=v[a+4>>2];if((c|0)!=(d|0)){v[b+8>>2]=(((c-d|0)-2>>>1^-1)<<1)+c}b=v[a>>2];if(b){EY(b,ow(a))}}function qP(a,b){var c=0,d=0,e=0;d=w[a|0];e=w[b|0];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(d>>>0>e>>>0){break a}c=x[a+2>>1]<x[b+2>>1]}return c}function Zz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>=1){while(1){v[a>>2]=v[c>>2];a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function Ur(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-16|0;gb=c;e=v[b+4>>2];d=v[b>>2];t[c+15|0]=0;d=Dm(d,d+e|0,c+15|0);Bj(a,v[b>>2],d);gb=c+16|0}function Ml(a,b,c){var d=0,e=0;a=x[b>>1];e=x[c>>1];d=1;a:{if(a>>>0<e>>>0){break a}d=0;if(a>>>0>e>>>0){break a}d=y[b+4>>2]<y[c+4>>2]}return d}function FW(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;e=v[b+4>>2];d=v[b>>2];t[c+15|0]=0;d=Dm(d,d+e|0,c+15|0);e=a;a=v[b>>2];pd(e,a,d-a|0);gb=c+16|0}function BE(a){var b=0,c=0;c=mqa(w[a+111|0],0,1536,0);b=jb;a=mqa(w[a+110|0],0,25,0);c=c+a|0;b=jb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;jb=b;return a}function Ym(a){if(!(a<2147483647)){return 2147483647}if(!(a>-2147483648)){return-2147483648}if(D(a)<2147483648){return~~a}return-2147483648}function Wda(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(!id(a,4)){nx(a)}c=b,d=Sb(a+44|0),v[c>>2]=d;a=v[Fd(b+8|0,b)>>2];gb=b+16|0;return a|0}function Vda(a){a=a|0;var b=0,c=0,d=0;b=gb-16|0;gb=b;if(!id(a,4)){nx(a)}c=b,d=Wb(a+44|0),v[c>>2]=d;a=v[Fd(b+8|0,b)>>2];gb=b+16|0;return a|0}function Mt(a){var b=0;b=A[a+4248>>3]/+(uf(v[a+16>>2])>>>0);A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*.016666666666666666*A[a+4288>>3]}}function $U(a){a:{if(yd(a,11190,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64)){break a}a=a+33|0;if(w[a|0]>32){break a}return w[a|0]!=0}return 0}function ty(a){var b=0;if(v[a>>2]){Nd(a);b=v[a>>2];a=hg(a);v[22640]=0;Nc(b,a,1);a=v[22640];v[22640]=0;if((a|0)==1){V(0)|0;O()|0;Bb();L()}}}function l1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=gb-16|0;gb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Fb(a+12|0,a+8|0);gb=a+16|0;return v[b>>2]}function kfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(ye(a)>>>0<b>>>0){d=wb(a);e=a;a=vo(c+8|0,b,Nb(a),d);aO(e,a);tz(a)}gb=c+32|0}function aT(a,b){var c=0;tk(a);wb(a);c=b+4|0;cl(v[a>>2],v[a+4>>2],c);wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),cc(b));v[b>>2]=v[b+4>>2];Lm(a,Nb(a))}function aO(a,b){var c=0;tk(a);wb(a);c=b+4|0;cl(v[a>>2],v[a+4>>2],c);jc(a,c);jc(a+4|0,b+8|0);jc(wb(a),cc(b));v[b>>2]=v[b+4>>2];Lm(a,Nb(a))}function Wga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(pg(a)>>>0<b>>>0){d=wb(a);e=a;a=DA(c+8|0,b,of(a),d);CA(e,a);BA(a)}gb=c+32|0}function LY(a){var b=0,c=0;c=a;b=v[a+4>>2];a=v[a>>2];if((b|0)!=(a|0)){while(1){b=b-28|0;Xd(b);if((a|0)!=(b|0)){continue}break}}v[c+4>>2]=a}function Jka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(qg(a)>>>0<b>>>0){d=wb(a);e=a;a=Nu(c+8|0,b,Cc(a),d);dU(e,a);cU(a)}gb=c+32|0}function Iga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=gb-32|0;gb=c;if(sA(a)>>>0<b>>>0){d=wb(a);e=a;a=dR(c+8|0,b,wA(a),d);cR(e,a);bR(a)}gb=c+32|0}function IO(a,b,c){var d=0;d=nc(a);v[22640]=0;U(97,a|0,b|0,c|0);b=v[22640];v[22640]=0;if((b|0)!=1){return a}a=P()|0;O()|0;Lc(d);S(a|0);L()}function qi(a){var b=0;a=a*a;b=a*a;return C(a*-.499999997251031+1+b*.04166662332373906+a*b*(a*2439044879627741e-20+-.001388676377460993))}function a6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+15&-16;v[c>>2]=b+16;d=a,e=Yx(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function Zt(a,b){a=a|0;b=b|0;var c=0;c=b>>>0>126;if(!c){Se(((b<<5)+a|0)+480280|0);$m((B(b,872)+a|0)+1074992|0,7,a,b,134217728)}return c|0}function RP(a){a=50-(B(w[(a>>>4|0)+38160|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return zc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function PT(a){var b=0,c=0;b=gb-16|0;gb=b;if(SV(a,b+8|0)){a=b+8|0;c=Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}gb=b+16|0;return c}function Mi(a,b,c){a=a|0;b=b|0;c=c|0;a:{if((Nl(a,b)|0)==255){break a}uk(a,b);Vq(a,b,0,0);if(!c){break a}a=lc(a+58|0,b);t[a|0]=w[a|0]|128}}function K6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=zt(a+8|0,b,c,d,2);if(a>>>0<=15){a=w[a+49936|0]}else{a=0}if(a>>>0<=4){return a+1|0}return 0}function J6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=zt(a+8|0,b,c,d,3);if(a>>>0<=44){a=w[a+49888|0]}else{a=0}if(a>>>0<=4){return a+1|0}return 0}function Cga(a){a=a|0;var b=0;b=v[a>>2];if(kb[v[v[b>>2]+32>>2]](b,0,32)|0){a=v[a>>2];a=kb[v[v[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function noa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;it(a,b,c);gb=c+32|0}function jE(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;v[c>>2]=b;v[c+8>>2]=a;a=gb-16|0;gb=a;Tx(v[c+8>>2],v[c>>2],a+8|0);gb=a+16|0;gb=c+16|0}function iea(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=1;it(a,b,c);gb=c+32|0}function QL(a){var b=0,c=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*.0016609640474436812;c=C(Ag(b-J(b+.5)))}else{c=C(0)}return c}function K7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;DK(g+8|0,b,c,d,e,f);Dc(a,g+20|0);Rm(g+8|0);gb=g+32|0}function II(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function Hja(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=3;LV(a,b,c);gb=c+32|0}function F1(a){a=a|0;var b=0,c=0,d=0;b=v[v[a>>2]>>2];c=v[b+8>>2];a=v[b+4>>2];b=v[b>>2]+(c>>1)|0;d=b;if(c&1){a=v[a+v[b>>2]>>2]}kb[a|0](d)}function $ka(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;Sv(a,b,c);gb=c+32|0}function j6(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=4;it(a,b,c);gb=c+32|0}function hZ(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;Sv(a,b,c);gb=c+32|0}function h6(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;it(a,b,c);gb=c+32|0}function eqa(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=274;v[c+4>>2]=0;Sv(a,b,c);gb=c+32|0}function cd(a,b){var c=0,d=0,e=0;c=Rf(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=kb[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function XB(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;LV(a,b,c);gb=c+32|0}function Sk(a){var b=0;b=a+28|0;a=b;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>=128){a=w[b|0]^-128}else{a=255}return a&255}function Ox(a,b){var c=0;if(b>>>0<=99){return LI(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return at(KI(c,a),b-B(a,100)|0)}return tj(a,b)}function M$(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;Gw(a,b,c);gb=c+32|0}function L7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=gb-32|0;gb=g;DK(g+8|0,b,c,d,e,f);Dc(a,g+8|0);Rm(g+8|0);gb=g+32|0}function $ca(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;v[b+12>>2]=0;c=b+12|0;t[c|0]=0;t[c+1|0]=0;t[c+2|0]=0;t[c+3|0]=0;GM(a,b+12|0);gb=b+16|0}function jw(a,b){var c=0,d=0;if((b|0)<=-1){b=0-b|0;c=0-b&31;d=(a&-1>>>c)<<c;c=a;a=b&31;return d|(c&-1<<a)>>>a}return qqa(a,(b|0)%32|0)}function jda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!ve(c&255)|!d)){QM(a,8,C(0))}a=jk(a);if(a){kb[v[v[a>>2]+92>>2]](a,b,c,d,e)}}function ft(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function e6(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=257;v[c+4>>2]=0;Gw(a,b,c);gb=c+32|0}function Ob(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if(b>>>0>=113){Pn(9446);L()}Db(d+8|0,a,b);Af(d+8|0,c);gb=d+16|0;return a|0}function O$(a,b){a=a|0;b=b|0;var c=0;c=gb-32|0;gb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=290;v[c+4>>2]=0;Gw(a,b,c);gb=c+32|0}function Ls(a,b){Bm(a);v[a>>2]=88900;v[22640]=0;Q(2425,a+4|0,b|0)|0;a=v[22640];v[22640]=0;if((a|0)!=1){return}a=P()|0;O()|0;S(a|0);L()}function Kb(a){var b=0,c=0;b=gb-16|0;gb=b;v[22640]=0;c=v[22640];v[22640]=0;if((c|0)!=1){yA(a);gb=b+16|0;return a}V(0)|0;O()|0;Bb();L()}function $ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(ww()>>>0<b>>>0){Rc();L()}c=KR(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<3)+c|0,v[d>>2]=e}function $I(a,b){a:{if(w[a+23|0]){a=1;if((b|0)!=255){break a}ba(11497,10568,1165,2826);L()}if((b|0)==255){return 0}a=b>>>0>10}return a}function xI(a){var b=0,c=0,d=0;c=Jb(a);b=Ab(a);a=gb-16|0;gb=a;t[a+15|0]=0;d=-1;if(b){b=vp(c,b,a+15|0);d=b?b-c|0:-1}gb=a+16|0;return d}function og(a){var b=0,c=0;b=gb-16|0;gb=b;if(ds(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}gb=b+16|0;return c}function m7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(kp()>>>0<b>>>0){Rc();L()}c=Kz(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e}function jG(a){a=a|0;var b=0;a=Kb(a);v[22640]=0;Q(194,a|0,11049)|0;b=v[22640];v[22640]=0;if((b|0)==1){b=P()|0;O()|0;vb(a);S(b|0);L()}}function X8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(MG()>>>0<b>>>0){Rc();L()}c=vG(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<4)+c|0,v[d>>2]=e}function Sz(a,b){a=a|0;b=b|0;var c=0;c=18693;a:{if(b>>>0>255){break a}a=v[((b<<2)+a|0)+900380>>2];if(!a){break a}c=a+492|0}return c|0}function Qw(a,b,c,d,e,f){var g=0,h=0;g=v[a+4>>2];h=g>>8;if(g&1){h=Tw(v[d>>2],h)}a=v[a>>2];kb[v[v[a>>2]+20>>2]](a,b,c,d+h|0,g&2?e:2,f)}function KV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(kp()>>>0<b>>>0){Rc();L()}c=_V(b);v[a>>2]=c;v[a+4>>2]=c;d=wb(a),e=(b<<2)+c|0,v[d>>2]=e}function Lr(a,b){return(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0?b:a}function Hga(a,b){a=a|0;b=b|0;a=Nv(a,b);if(!a){t[b+6|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0}return a|0}function Ff(a,b,c,d,e){var f=0;f=gb-16|0;gb=f;v[f+12>>2]=c;v[f+8>>2]=e;c=vi(f,f+12|0);a=$s(a,b,d,v[f+8>>2]);ff(c);gb=f+16|0;return a}function yB(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[22640]=0;a=ar(a,b);b=v[22640];v[22640]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function xb(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[22640]=0;a=fi(a,b);b=v[22640];v[22640]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function ps(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[22640]=0;a=Op(a,b);b=v[22640];v[22640]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Bb();L()}function jpa(a){a=a|0;var b=0,c=0,d=0;if(kp()>>>0<=8191){Rc();L()}b=Mc(32768,2);v[a>>2]=b;v[a+4>>2]=b;c=wb(a),d=b+32768|0,v[c>>2]=d}function j$(){var a=0,b=0;a=gb-16|0;gb=a;v[a+8>>2]=19923012;a:{if(mG(a+8|0)){break a}if(lG()){break a}b=kG()^1}gb=a+16|0;return b|0}function dt(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function V7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];yt(v[v[a>>2]-12>>2]+a|0,c);return a|0}function Ix(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return Ig(t[b|0])|0}function vY(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1179468868){return(w[a+4|0]-1&255)>>>0<10}return 0}function ZM(a){a=a|0;a=gb-16|0;gb=a;v[a+12>>2]=1869112133;gb=a+16|0;a=a+12|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function Xca(a){a=a|0;var b=0,c=0,d=0;b=gb-32|0;gb=b;if(ye(a)>>>0<=11){c=wb(a);d=a;a=vo(b+8|0,12,Nb(a),c);Uk(d,a);EO(a)}gb=b+32|0}function As(a,b,c,d,e){var f=0,g=0;f=v[a+4>>2];g=f>>8;if(f&1){g=Tw(v[c>>2],g)}a=v[a>>2];kb[v[v[a>>2]+24>>2]](a,b,c+g|0,f&2?d:2,e)}function sL(a){a=a|0;var b=0,c=0;c=gb-16|0;gb=c;b=rf(8);iL(b);v[b+4>>2]=a;v[b>>2]=55996;a=v[Ni(c+8|0,b)>>2];gb=c+16|0;return a|0}function Pj(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;Fe(a,d+12|0);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;gb=d+16|0;return a}function EB(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=wb(b),d=0,v[c>>2]=d}function pe(a){var b=0;a=v[a+4>>2];if(a){if(Jn(a)){a:{b=a+8|0;if(v[b>>2]){if((Dw(b)|0)!=-1){break a}}kb[v[v[a>>2]+16>>2]](a)}}}}function jk(a){var b=0,c=0;b=Sk(v[a+20>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[(v[a+16>>2]+B(b,160)|0)+906300>>2]}return c}function iH(a,b,c,d,e,f){a=kb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Ks(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function fH(a,b,c,d,e,f){a=kb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Js(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function by(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}hc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function RS(a){var b=0;b=v[a+16>>2];a=v[a+32>>2];b=mqa(b,b>>31,a,a>>31)+5e5|0;a=jb;return zc(nqa(b,b>>>0<5e5?a+1|0:a,1e6,0),jb)}function QS(a){var b=0;b=v[a+16>>2];a=v[a+36>>2];b=mqa(b,b>>31,a,a>>31)+5e5|0;a=jb;return zc(nqa(b,b>>>0<5e5?a+1|0:a,1e6,0),jb)}function lG(){var a=0,b=0,c=0;a=gb-16|0;gb=a;b=Tb(a,12228);if(Ab(b)){c=(rg(b,11223)|0)!=-1}else{c=0}vb(b);gb=a+16|0;return c|0}function gS(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){ee(b,a)}if(c){ee(c,a)}if(d){ee(d,a)}if(e){ee(e,a)}}function Yf(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;if(b>>>0>=113){Pn(9411);L()}Db(c+8|0,a,b);Af(c+8|0,0);gb=c+16|0;return a|0}function Ck(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;wr(a+4|0);v[b+12>>2]=0;Fe(a+8|0,b+12|0);c=a,d=ec(a),v[c>>2]=d;gb=b+16|0;return a}function X$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Og(a,v[b+8>>2],0)){Uw(b,c,d);return}a=v[a+8>>2];kb[v[v[a>>2]+28>>2]](a,b,c,d)}function Tl(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(kb[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function L5(a){a=a|0;var b=0;if((kb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+1;return Ig(t[a|0])|0}function Kl(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=c;c=v[b>>2];v[d+8>>2]=v[b+4>>2];pd(a,c,v[Fb(d+12|0,d+8|0)>>2]);gb=d+16|0}function n6(a){a=a|0;var b=0;if(!a){return-2}b=v[a+28>>2];if(!b){return 0}kb[v[a+36>>2]](v[a+40>>2],b);v[a+28>>2]=0;return 0}function mg(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=ih(d,a);return((ih(d,a+1|0)<<8|e<<16|ih(d,a+2|0))<<(b&7)&16777215)>>>24-c|0}function mI(a){v[a>>2]=76852;dx(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function kj(a,b,c,d){var e=0;e=gb-16|0;gb=e;bc(e+8|0,zb(c),d);c=v[e+12>>2];v[e>>2]=v[e+8>>2];v[e+4>>2]=c;AY(a,b,e);gb=e+16|0}function kU(a){var b=0,c=0;b=w[a+33|0];c=b>>>24|0;a=w[a+31|0]?1120:1056;b=a+(b<<8)|0;c=a>>>0>b>>>0?c+1|0:c;a=b;jb=c;return a}function jH(a,b,c,d,e,f){a=kb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Ks(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function gH(a,b,c,d,e,f){a=kb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Js(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function _s(a){v[a>>2]=76788;dx(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function WN(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1179011410){a=dn(a)>>>0>80}else{a=0}return a}function Ub(a,b){var c=0,d=0,e=0;c=a;d=v[b>>2];e=d+v[a>>2]|0;a=v[a+4>>2]+v[b+4>>2]|0;v[c>>2]=e;v[c+4>>2]=e>>>0<d>>>0?a+1|0:a}function vq(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=c+b;if(b*1e-7<c){continue}break}return+b}function sq(a){a=a|0;var b=0,c=0;b=Oe(a);while(1){c=b;if(c&65535){b=c-1|0;if(!ke(a,b&65535)){continue}}break}return c&65535}function ff(a){a:{a=v[a>>2];if(a){v[22640]=0;tx(a);a=v[22640];v[22640]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function jO(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function _T(a,b){var c=0;c=v[a+4>>2];if((c|0)!=(b|0)){while(1){c=c-12|0;ZT(c);if((b|0)!=(c|0)){continue}break}}v[a+4>>2]=b}function _A(a){a=a|0;v[a+700>>2]=0;u[a+842>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function KB(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function HI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=b;d=d+4|0;c=c-1|0;if(c){continue}break}}return a|0}function xG(a){v[22640]=0;X(a|0);a=v[22640];v[22640]=0;if((a|0)!=1){v[22640]=0;L()}a=V(0)|0;O()|0;Z(a|0)|0;v[22640]=0;L()}function wi(a,b,c){a:{if(c){v[22640]=0;II(a,b,c);a=v[22640];v[22640]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Bb();L()}function ve(a){var b=0;b=gb-16|0;gb=b;t[b+15|0]=a;t[b+14|0]=1;t[b+13|0]=120;a=Av(b+15|0,b+14|0,b+13|0);gb=b+16|0;return a}function l7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!((b|0)==(c|0)|(d|0)>-1)){t[b|0]=45;d=DL(d);b=b+1|0}eK(a,b,c,d,e)}function je(a,b){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))}function bT(a,b){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24}function Qd(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}v[a>>2]=b}}function Gp(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}v[a>>2]=b}}function iT(a){var b=0;b=a+68|0;if(!(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>127)){return!yd(a,14745,17)}return 0}function bI(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function _v(a,b){a=a|0;b=b|0;var c=0,d=0;d=gb-16|0;gb=d;c=gb-16|0;gb=c;t[c+15|0]=w[b|0];ZL(a,c+15|0);gb=c+16|0;gb=d+16|0}function H5(a){a=a|0;var b=0;if((kb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+4;return v[a>>2]}function Fl(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;pz(a,c)}function FS(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){DS(a,1);DS(a,0)}}function ES(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){CS(a,1);CS(a,0)}}function CZ(a){a=a|0;var b=0;a:{if(!He(-1,v[a+76>>2])){a=v[a+76>>2];break a}b=a;a=RF(a,32);v[b+76>>2]=a}return a<<24>>24}function zY(a){var b=0;a:{if(yd(a,28932,20)){break a}b=a+25|0;if(!w[b|0]|w[b|0]>8){break a}return t[a+47|0]>-1}return 0}function no(a,b,c){var d=0;b=b-a|0;if((b|0)>=1){while(1){t[a|0]=w[c|0];a=a+1|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function eR(a){var b=0;a:{if(w[a|0]<24){break a}b:{if(!w[a+3|0]){b=16;break b}b=15;if(w[a+3|0]!=3){break a}}t[a+3|0]=b}}function BW(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1279544644){return w[a+4|0]<32}return 0}function qk(a){var b=0,c=0;b=gb-16|0;gb=b;Db(b+8|0,a+1074312|0,7);if(Cb(b+8|0)){c=v[a+480180>>2]!=4}gb=b+16|0;return c}function Nma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Ep(a,b+8|0)){c=(w[b+8|0]|w[b+9|0]<<8)<<16>>16}gb=b+16|0;return c|0}function Le(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function qc(a,b){var c=0;Bm(a);v[a+4>>2]=0;v[a>>2]=55220;c=a;a=Ad(Ab(b)+1|0);v[c+4>>2]=a;if(a){hc(a,Jb(b),Ab(b)+1|0)}}function Xv(a,b){a=a|0;b=b|0;var c=0;c=v[b+4>>2];if(c){bc(a,c,v[b>>2]);return}b=b+8|0;if(!$c(b)){be(a,b);return}Sd(a)}function TY(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==810369604){return w[a+4|0]<4}return 0}function Rfa(a){a=a|0;var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=b+8|0;d=c,e=Mz(a),v[d>>2]=e;yo(c);gb=b+16|0;return v[c>>2]}function to(a){var b=0;a:{while(1){if(w[b+49952|0]==(a|0)){break a}b=b+1|0;if((b|0)!=45){continue}break}b=0}return b}function hV(a){var b=0,c=0;b=gb-16|0;gb=b;c=a+512|0;while(1){Kf(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}gb=b+16|0}function YU(a){var b=0;a=a+1104|0;a=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))+8|0;b=a>>>0<8?1:b;jb=b;return a}function DF(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;Jp(a);v[a>>2]=28200;c=cc(a);Br(c);v[c>>2]=28328;gb=b+16|0;return a|0}function rr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=Ri(e,a,d);OD(wb(a),b,c,d+4|0);$b(d);gb=e+16|0}function EI(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function $v(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gb-16|0;gb=e;d=yg(e,a,d);OD(wb(a),b,c,d+4|0);$b(d);gb=e+16|0}function im(a,b,c){a:{v[22640]=0;Nc(b,B(c,12),4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function iB(a,b,c){a:{v[22640]=0;Nc(b,B(c,28),4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function fr(a,b,c){if(v[b>>2]<=(Ib(w[a|0]|w[a+1|0]<<8)|0)){a=(Ib(w[a|0]|w[a+1|0]<<8)|0)<=v[c>>2]}else{a=0}return a}function es(a,b,c){a:{v[22640]=0;Nc(b,B(c,36),4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function cY(a,b,c){a:{v[22640]=0;Nc(b,B(c,48),4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Vh(a){a=a|0;var b=0,c=0;v[v[a+20>>2]>>2]=a;c=v[a+12>>2];b=v[c>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[c>>2]=a}function Uk(a,b){var c=0;c=b+4|0;cl(v[a>>2],v[a+4>>2],c);wc(a,c);wc(a+4|0,b+8|0);wc(wb(a),cc(b));v[b>>2]=v[b+4>>2]}function Tfa(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;if(b>>>0>=250){Pn(9446);L()}Db(c+8|0,a,b);er(c+8|0);gb=c+16|0}function QD(a,b,c){a:{v[22640]=0;Nc(b,B(c,20),4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function PY(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function Nz(a,b,c){a:{v[22640]=0;Nc(b,B(c,52),4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Eda(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=cA(C(c*C(255))),t[d|0]=e;Qt(a)}}function yS(a){var b=0,c=0;if(v[a>>2]){sn(a);pw(wb(a),v[a>>2],Lg(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function wK(a,b){a:{v[22640]=0;Nc(a,B(b,324),4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function wC(a,b,c){a:{v[22640]=0;Nc(b,B(c,6),1);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function vv(a){var b=0,c=0;if(v[a>>2]){zr(a);al(wb(a),v[a>>2],hg(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function nO(a,b){var c=0,d=0;d=gb-16|0;gb=d;c=Lz(d,a);wb(a);Cq(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+4;$b(c);gb=d+16|0}function mM(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function _H(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!He(gI(c,b),-1)){break a}v[a>>2]=0}return a|0}function ZP(a,b){var c=0;c=b&15;if(c){t[a+827|0]=c<<2}b=b&240;if(b){t[a+826|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function XV(a){var b=0,c=0;if(v[a>>2]){Cg(a);fw(wb(a),v[a>>2],ye(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function JN(a){var b=0,c=0;if(v[a>>2]){Cg(a);Wh(wb(a),v[a>>2],ye(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function IN(a){var b=0,c=0;if(v[a>>2]){NN(a);wC(wb(a),v[a>>2],Sj(a));b=wb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function Hl(a,b){var c=0;c=b&15;if(c){t[a+824|0]=c<<2}b=b&240;if(b){t[a+823|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function vy(a,b){a:{v[22640]=0;Nc(a,B(b,24),8);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function uW(a,b){a:{v[22640]=0;Nc(a,B(b,33),1);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function kD(a,b){a:{v[22640]=0;Nc(a,B(b,28),4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function ce(a){a=a|0;var b=0;b=gb-16|0;gb=b;t[b+15|0]=1;t[b+14|0]=120;a=Av(a,b+15|0,b+14|0);gb=b+16|0;return a|0}function ZN(a,b){a=a|0;b=b|0;t[b+38|0]=w[a+202|0];t[b+39|0]=w[a+203|0];t[b+40|0]=w[a+204|0];t[b+41|0]=w[a+205|0]}function WI(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+(c*c-e+(c+c)*d)}function SM(a,b,c){a:{v[22640]=0;Nc(b,c<<11,4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Qu(a,b){a:{v[22640]=0;Nc(a,B(b,56),4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Mu(a,b){a:{v[22640]=0;Nc(a,B(b,12),4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function MF(a,b){a:{v[22640]=0;Nc(a,B(b,24),4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function vC(a,b,c){a:{v[22640]=0;Nc(b,c<<2,1);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function pw(a,b,c){a:{v[22640]=0;Nc(b,c<<1,2);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function nu(a){var b=0;b=1;a:{switch(w[a+3|0]-4|0){default:b=w[a+2|0]==11;break;case 0:case 2:break a}}return b}function lV(a,b,c){a:{v[22640]=0;Nc(b,c<<5,8);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function fw(a,b,c){a:{v[22640]=0;Nc(b,c<<2,2);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Wh(a,b,c){a:{v[22640]=0;Nc(b,c<<2,4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function WD(a,b,c){a:{v[22640]=0;Nc(b,c<<1,1);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function VQ(a,b){a:{v[22640]=0;Nc(a,B(b,7),1);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Tk(a,b,c){a:{v[22640]=0;Nc(b,c<<5,4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function On(a,b,c){a:{v[22640]=0;Nc(b,c<<4,4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function Mh(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function Lv(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Ep(a,b+8|0)){c=Ib(w[b+8|0]|w[b+9|0]<<8)}gb=b+16|0;return c|0}function Ht(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!((b|0)==(c|0)|(d|0)>-1)){t[b|0]=45;d=DL(d);b=b+1|0}Jy(a,b,c,d)}function H4(a,b){a=a|0;b=b|0;var c=0,d=0;kb[v[v[a>>2]+24>>2]](a)|0;b=Ex(b);v[a+36>>2]=b;c=a,d=Yn(b),t[c+44|0]=d}function D4(a,b){a=a|0;b=b|0;var c=0,d=0;kb[v[v[a>>2]+24>>2]](a)|0;b=Ax(b);v[a+36>>2]=b;c=a,d=Yn(b),t[c+44|0]=d}function An(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function AA(a,b,c){a:{v[22640]=0;Nc(b,c<<3,8);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function xS(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a+4>>2];v[c>>2]=v[b+4>>2];a=Gb(c+8|0,c);gb=c+16|0;return a}function mK(a){var b=0,c=0,d=0,e=0;b=gb-16|0;gb=b;c=b+8|0;d=c,e=LO(a),v[d>>2]=e;yo(c);gb=b+16|0;return v[c>>2]}function Uaa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=Tb(b,9809);qc(a,c);vb(c);v[a>>2]=55180;gb=b+16|0;return a|0}function Og(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!uj(v[a+4>>2],v[b+4>>2])}function Daa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=Tb(b,5404);qc(a,c);vb(c);v[a>>2]=55200;gb=b+16|0;return a|0}function Cv(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=(B(a,b)>>>0)/255;Qd(c+12|0,0,15);gb=c+16|0;return w[c+12|0]}function Af(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function yF(a,b){a:{v[22640]=0;Nc(a,b<<3,1);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function wV(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(!(b<0)){A[a+8>>3]=b;v[a+16>>2]=3}return a}function uO(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function tf(a){a=a|0;var b=0;b=v[19500];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[19503];xt(a+8|0);lh(a+60|0);return a|0}function tP(a,b){a:{v[22640]=0;Nc(a,b<<3,4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function tB(a,b){a:{v[22640]=0;Nc(a,b<<5,1);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function sK(a,b){a:{v[22640]=0;Nc(a,b<<4,4);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function sB(a,b){a:{v[22640]=0;Nc(a,b<<4,1);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function qB(a,b){a:{v[22640]=0;Nc(a,b<<8,1);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function hq(a){a=a|0;var b=0;b=v[19455];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[19458];xt(a+4|0);lh(a+56|0);return a|0}function f9(a,b){a=a|0;b=b|0;if(a){b=kb[v[v[b>>2]+8>>2]](b)|0;a:{if(b){b=ie(b);break a}b=ie(18693)}v[a>>2]=b}}function eC(a,b){a:{v[22640]=0;Nc(a,b<<2,1);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function dT(a,b){var c=0;c=v[a+4>>2]+b|0;v[a+4>>2]=c&31;v[a>>2]=v[a>>2]+(((b|0)>=0?c>>>5|0:(c-31|0)/32|0)<<2)}function EY(a,b){a:{v[22640]=0;Nc(a,b<<1,1);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function uJ(a){a=a|0;var b=0;b=v[v[a>>2]-12>>2]+a|0;v[b+4>>2]=v[b+4>>2]&-75;v[b+4>>2]=v[b+4>>2]|8;return a|0}function mna(a,b){a=a|0;b=b|0;if(!qW(a,b)){t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0}}
function iW(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;u[c+14>>1]=b;if((Yl(a)|0)!=65535){FD(a,c+14|0)}gb=c+16|0}function hr(a){if(!(a<4294967295)){return-1}if(!(a>0)){return 0}if(a<4294967296&a>=0){return~~a>>>0}return 0}function hI(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+36>>2]](a)|0}return Ig(t[b|0])}function hH(a,b,c,d,e){b=mj(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function eH(a,b,c,d,e){b=lj(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function dC(a){var b=0,c=0;c=a;b=v[a+8>>2];a=v[a+4>>2];if((b|0)!=(a|0)){v[c+8>>2]=(((b-a|0)-4>>>2^-1)<<2)+b}}function al(a,b,c){a:{v[22640]=0;Nc(b,c,1);a=v[22640];v[22640]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Bb();L()}}function aS(a){var b=0;b=v[a+4>>2];u[a+70>>1]=w[((x[b+22>>1]<<4|x[b+20>>1]>>>6)&65535)+35728|0]>>>x[a+68>>1]}function Mo(a,b){a=a|0;b=b|0;if(sc(a)>>>0>b>>>0){a=ke(v[a+24>>2]+484344|0,x[bj(a,b)>>1])}else{a=0}return a|0}function mJ(a,b,c,d){z[d+4>>2]=c+a;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=a+b}function bX(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){WW(c+52|0);vb(c+40|0);Lc(c+16|0);Lc(c+4|0);Zb(c)}}}function Uh(a,b){var c=0;c=a;b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Ac(c,(b>>31&a)+b|0)>>2]}function Tm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;if(!Ou(a,b)){b=Ou(c,a)?c:a}gb=d+16|0;return b|0}function Px(a,b){var c=0;if(b>>>0<=9999){return Ox(a,b)}c=a;a=(b>>>0)/1e4|0;return tj(Ox(c,a),b-B(a,1e4)|0)}function M1(){var a=0;if(kp()>>>0<=29){Rc();L()}a=CG(Yw(465584),30);v[116396]=a;v[116397]=a;v[116400]=a+120}function yo(a){var b=0,c=0,d=0;b=a;a=v[a>>2];c=b,d=zb(B(a,214013)+2531011|0),v[c>>2]=d;return a>>>16&32767}function vJ(a){var b=0;b=v[(w[a+2|0]&12)+61488>>2];a=w[a+1|0];return b>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function ly(a,b){var c=0;c=(B(B(jy(a),ky(a)),125)>>>0)/(vJ(a)>>>0)|0;a=(w[a+1|0]&6)==6?c&-4:c;return a?a:b}function iqa(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(_j(a,b+8|0)){c=TY(b+8|0)}gb=b+16|0;return c|0}function ew(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function V5(a){a=a|0;a=gb-16|0;gb=a;if(fb(a+12|0,4)|0){Ms(v[115121],10001);L()}gb=a+16|0;return v[a+12>>2]}function Tt(a){var b=0;b=gb-16|0;gb=b;t[b+15|0]=251;t[b+14|0]=255;a=Av(a,b+15|0,b+14|0);gb=b+16|0;return a}function Npa(a,b){a=a|0;b=b|0;var c=0;b=gb-80|0;gb=b;c=-1;if(wY(a,b+8|0)){c=vY(b+8|0)}gb=b+80|0;return c|0}function $ma(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(_j(a,b+8|0)){c=QV(b+8|0)}gb=b+16|0;return c|0}function yL(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>-1)){t[b|0]=45;d=0-(d&65535)&65535;b=b+1|0}Ey(a,b,c,d&65535)}function r_(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(_j(a,b+8|0)){c=mF(b+8|0)}gb=b+16|0;return c|0}function kw(a,b){a=a|0;b=b|0;if((a&4088)>>>0>=520){b=jw(0-qqa(b^1230262859,25)|0,4)^1247037516}return b|0}function hL(a){var b=0;while(1){if(!v[(b<<2)+a>>2]){return b}b=b+1|0;if((b|0)!=4){continue}break}return 4}function cI(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return kb[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function _u(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;xn(c+8|0,a);v[c+4>>2]=v[c+8>>2];gr(c+4|0,b);gb=c+16|0}function Yp(){var a=0;v[22640]=0;a=v[22640];v[22640]=0;if((a|0)!=1){return v[19826]}V(0)|0;O()|0;Bb();L()}function Kg(a){var b=0,c=0;b=gb-16|0;gb=b;if(Ep(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8}gb=b+16|0;return c}function KG(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function Ds(){var a=0;v[22640]=0;a=v[22640];v[22640]=0;if((a|0)!=1){return v[20408]}V(0)|0;O()|0;Bb();L()}function Cs(){var a=0;v[22640]=0;a=v[22640];v[22640]=0;if((a|0)!=1){return v[20020]}V(0)|0;O()|0;Bb();L()}function $y(a,b){nc(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;Ho(a+24|0);Kb(a+36|0);v[a+48>>2]=b;return a}function $_(a,b){a=a|0;b=b|0;var c=0;b=gb-32|0;gb=b;c=-1;if(YF(a,b+8|0)){c=XF(b+8|0)}gb=b+32|0;return c|0}function kq(a,b){var c=0,d=0,e=0;c=gb-16|0;gb=c;d=c,e=$d(b),v[d+12>>2]=e;Fe(a,c+12|0);gb=c+16|0;return a}function Mg(a,b){var c=0,d=0;c=v[a>>2];d=v[b>>2];jb=v[a+4>>2]-(v[b+4>>2]+(c>>>0<d>>>0)|0)|0;return c-d|0}function Ji(a,b,c){var d=0,e=0,f=0,g=0;d=A[c>>3];e=A[b>>3];f=A[c+8>>3];g=A[b+8>>3];Vm(a,d*e-f*g,e*f+d*g)}function FO(a,b){v[22640]=0;Nc(a,b<<2,4);a=v[22640];v[22640]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function zz(a,b){var c=0;c=gb-16|0;gb=c;u[c+14>>1]=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=x[c+14>>1];gb=c+16|0}function jc(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=v[c+12>>2];gb=c+16|0}function jU(a,b){var c=0;c=y[b>>2]>y[a>>2];a=v[a+4>>2];b=v[b+4>>2];return(a|0)<(b|0)?1:(a|0)<=(b|0)?c:0}function dP(a,b){var c=0;c=gb-16|0;gb=c;a=Lz(c,a);Cq(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;$b(a);gb=c+16|0}function Bw(a,b,c){var d=0;d=gb-16|0;gb=d;a=Sd(a);v[a+4>>2]=c;v[a>>2]=b;v[d+4>>2]=b;v[d>>2]=b;gb=d+16|0}function tx(a){a=a|0;var b=0;b=v[22545];if(a){v[22545]=(a|0)==-1?460544:a}return((b|0)==460544?-1:b)|0}function QB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=v[b>>2]+c|0;if((d|0)==-1){d=xb(b)-c|0}Wd(a,e,d)}function Iq(a,b,c){a=sk(a+1074376|0)-v[a+1074392>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function GS(a){var b=0,c=0;while(1){c=(b<<2)+a|0;b=b+1|0;v[c+68>>2]=b<<11;if((b|0)!=9){continue}break}}function mh(a){var b=0;b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;Vo(a+8|0);gb=b+16|0;return a}function ky(a){var b=0;b=w[a+1|0];return w[(B(b>>>3&1,45)+B(b>>>1&3,15)+(w[a+2|0]>>>4)|0)+61489|0]<<1}function dQ(a,b){var c=0,d=0;a:{if(b<0){break a}c=A[a>>3];if(!(c<0)){d=b;if(b>=c){break a}}A[a>>3]=d}}function vT(a){v[22640]=0;Nc(a,48,4);a=v[22640];v[22640]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function tA(a){v[22640]=0;Nc(a,40,4);a=v[22640];v[22640]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function mT(a){an(a+140|0);yb(a+120|0);yb(a+100|0);yb(a+80|0);yb(a+60|0);yb(a+40|0);yb(a+20|0);yb(a)}function hO(a){v[22640]=0;Nc(a,28,4);a=v[22640];v[22640]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function cv(a){v[22640]=0;Nc(a,20,4);a=v[22640];v[22640]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function ak(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function YW(a){v[22640]=0;Nc(a,32,4);a=v[22640];v[22640]=0;if((a|0)!=1){return}V(0)|0;O()|0;Bb();L()}function Ov(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0}function Oca(a,b){a=a|0;b=b|0;return C((b|0)<=2?C(C(w[(a+b|0)+4232|0])*C(.007874015718698502)):C(0))}function Fda(a,b){a=a|0;b=b|0;return C((b|0)<=3?C(C(w[(a+b|0)+4264|0])*C(.003921568859368563)):C(0))}function sE(a){var b=0;b=w[a+35|0];a=b>>>21|0;b=(b<<11)+2624|0;if(b>>>0<2624){a=a+1|0}jb=a;return b}function iw(a,b){var c=0,d=0;c=v[a+4>>2];d=v[b+4>>2];return(c|0)==(d|0)&y[b>>2]>y[a>>2]|c>>>0<d>>>0}function hda(a,b,c){a=a|0;b=b|0;c=c|0;a=jk(a);if(!a){return 0}return kb[v[v[a>>2]+100>>2]](a,b,c)|0}function bZ(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Ok(c+8|0,a,20);Vr(c+8|0,b);gb=c+16|0;return a|0}function VR(a,b,c){if((b|0)!=(c|0)){while(1){TR(a,w[b|0]);b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function Kd(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=55296;v[b+8>>2]=55400;Fu(a,b+12|0,b+8|0);gb=b+16|0}function $Z(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Ok(c+8|0,a,22);Vr(c+8|0,b);gb=c+16|0;return a|0}function pma(a,b){a=a|0;b=b|0;var c=0;b=gb-16|0;gb=b;c=-1;if(YC(a,b)){c=rV(b)}gb=b+16|0;return c|0}function d9(a,b){a=a|0;b=b|0;var c=0;c=v[a+4>>2];b=Jb(b);if(c){kb[c|0](b,v[a+8>>2]);return}It(b,a)}function _m(a){a=a|0;var b=0;Ol(a);b=Wq(v[a>>2],fj(a));v[a+20>>2]=b;if(!b){return 0}return Yi(a)|0}function XZ(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=DE(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function Fi(a){var b=C(0),c=C(0);a:{b=z[a>>2];if(!(b<C(0))){c=C(1);if(b<=C(1)){break a}}z[a>>2]=c}}function E1(a,b,c){a=a|0;b=b|0;c=c|0;if(c>>>0<=127){a=(x[Yp()+(c<<1)>>1]&b)!=0}else{a=0}return a|0}function D$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return kb[a|0](b,c,d,e,f,g)|0}function wg(a){a=a|0;var b=0,c=0;while(1){c=b&65535;Zt(a,c);b=b+1|0;if(c>>>0<126){continue}break}}function wI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ab(a);if(d>>>0<b>>>0){qs(a,b-d|0,c);return}rE(a,b)}function pr(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;u[c+14>>1]=b;fv(a+236|0,128,c+14|0);gb=c+16|0}function WQ(a,b,c){a=a|0;b=b|0;c=c|0;Fe(a,b);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;return a|0}function FM(a){a=a|0;var b=0;b=v[a>>2];if(b){kb[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;zr(a);nX(a)}function F8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;kb[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;_p(d,a);NG(a,c)}function Dh(a,b){var c=0;c=gb-16|0;gb=c;t[c+15|0]=w[a|0];t[a|0]=w[b|0];t[b|0]=w[c+15|0];gb=c+16|0}function yX(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];xX(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function y5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function we(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];dw(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function w5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function u5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function s5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function qT(a){var b=0;b=w[a+47|0];a=b>>>27|0;b=(b<<5)+259|0;if(b>>>0<259){a=a+1|0}jb=a;return b}function d_(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;SE(c+8|0,a);Vr(c+8|0,b);gb=c+16|0;return a|0}function dV(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>=1){b=120;if((c|0)<121){break a}}v[a>>2]=b}}function Yq(a){a=a|0;var b=0;b=gb-16|0;gb=b;t[b+15|0]=0;no(a,a+32|0,b+15|0);gb=b+16|0;return a|0}function Xo(a,b){var c=0;c=gb-16|0;gb=c;v[c+8>>2]=v[a>>2];VV(c+8|0,b);gb=c+16|0;return v[c+8>>2]}function U7(a,b){a=a|0;b=b|0;_s(a);v[a>>2]=77092;Kb(a+32|0);v[a+48>>2]=b;v[a+44>>2]=0;return a|0}function GA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=A[b+8>>3];d=Ow(A[b>>3]);e=pi(c);Vm(a,d*Ke(c),d*e)}function DR(a,b){var c=0;c=gb-16|0;gb=c;a=v[yc(c+8|0,pR(a,b,Vd(a),ec(a)))>>2];gb=c+16|0;return a}function C5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+12>>2]](a,b,c,d,e,f)|0}function A5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function xN(a,b){b=gb-16|0;gb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;Vo(a+8|0);gb=b+16|0;return a}function mfa(a,b){a=a|0;b=b|0;Ii(a);Ii(a);a:{if(b>>>0>=60){Yb(a,4);break a}Ii(a)}return Ii(a)|0}function iJ(a){var b=0;b=+((a&2097151)>>>0);return C($i(+C((a|0)>-1?b:-b),(a>>>21&1023)-788|0))}function fda(a,b){a=a|0;b=b|0;b=gb-16|0;gb=b;be(b,v[a+20>>2]+4|0);MM(a,le(b+8|0,b),0);gb=b+16|0}function eZ(a,b){a=a|0;b=b|0;if(!Rv(a,b)){t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b|0]=0}}function e8(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=v[Ni(b+8|0,AB(rf(12),a))>>2];gb=b+16|0;return a|0}function e5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function cca(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=uf(v[a+16>>2]),v[b+4256>>2]=c;jM(a);iM(a)}function YZ(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;if(Jg(a,b+8|0)){c=w[b+8|0]}gb=b+16|0;return c|0}function Vna(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=ds(a,b+8|0);gb=b+16|0;return C(a?z[b+8>>2]:C(0))}function Q$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Og(a,v[b+8>>2],f)){Sw(b,c,d,e)}}function Dda(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=uf(v[a+16>>2]),v[b+4232>>2]=c;Qt(a);aN(a)}function Cka(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[v[v[b>>2]+16>>2]](a,b,c,d,e,f)}function Aq(a,b,c){a=v[a>>2]+1074992|0;return v[(a+B(b,872)|0)+680>>2]>v[(a+B(c,872)|0)+680>>2]}function nY(a,b){return(Lb((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Lb((B(a&15,b)>>>0)/15|0,1,15))&255}function eD(a,b){var c=0;c=gb-16|0;gb=c;v[c>>2]=b;v[c+8>>2]=a;a=tp(c,c+8|0);gb=c+16|0;return a}function de(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=Jg(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)&255}function RX(a,b){var c=0;c=gb-16|0;gb=c;v[c>>2]=b;v[c+8>>2]=a;a=Xj(c,c+8|0);gb=c+16|0;return a}function No(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=xh(Ag(b)*+(c>>>0)),v[d+24>>2]=e}function Iy(a){var b=0;b=B(32-E(a|1)|0,1233)>>>12|0;return(b-(y[(b<<2)+27536>>2]>a>>>0)|0)+1|0}function y4(a,b,c){a=a|0;b=b|0;c=c|0;if(He(a,v[b+4>>2])){a=v[b>>2]==(c|0)}else{a=0}return a|0}function v$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=kb[a|0](b,c,d,e)|0;ma(jb|0);return a|0}function ui(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Jb(a)+(Ab(a)<<2)|0)>>2];gb=b+16|0;return a}function WT(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function Df(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=a;a=Tb(c,b);Dc(d,a);vb(a);gb=c+16|0}function zma(a){a=a|0;var b=0,c=0;b=gb-32|0;gb=b;c=a;a=Ih(b+8|0);OV(c,a,0,0);yb(a);gb=b+32|0}function uI(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function m5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return kb[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function hE(a){var b=0;b=gb-16|0;gb=b;a=Jg(a,b+15|0);gb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function Pk(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<2)+d;return a}function OI(a){var b=0;b=lqa(v[a>>2]-1|0);if(!b){a=lqa(v[a+4>>2]);return a?a+32|0:0}return b}function LG(a){a=a|0;var b=0;v[a>>2]=83452;b=v[a+8>>2];if(!(!b|!w[a+12|0])){Zb(b)}return a|0}function IG(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<4)+d;return a}function Dn(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<1)+d;return a}function AT(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<5)+d;return a}function vr(a,b){var c=0;c=Ab(a);if((c|0)==(Ab(b)|0)){a=po(Jb(a),Jb(b),c)}else{a=1}return!a}function ld(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Ou(b,a);gb=c+16|0;return(d?b:a)|0}function kS(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=ji(e,a,d);wb(a);dv(b,c,d+4|0);$b(d);gb=e+16|0}function kP(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3}function iv(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=jU(b,a);gb=c+16|0;return(d?b:a)|0}function iA(a){var b=0;v[a+84>>2]=0;v[a+88>>2]=0;b=v[a+80>>2];v[a+92>>2]=b;v[a+96>>2]=b<<12}function fC(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=jU(a,b);gb=c+16|0;return(d?b:a)|0}function dM(a,b){var c=0;c=v[a+12>>2];if((c|0)>=1){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function ac(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=lH(b,a);gb=c+16|0;return(d?b:a)|0}function aba(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;NL(a,b,c,d,e,0,0,f,g)}function Zla(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=as(a,b+8|0);gb=b+16|0;return+(a?A[b+8>>3]:0)}function YV(a,b,c,d){var e=0;e=gb-16|0;gb=e;d=yg(e,a,d);wb(a);dv(b,c,d+4|0);$b(d);gb=e+16|0}function Qk(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=iw(b,a);gb=c+16|0;return(d?b:a)|0}function Pb(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];return kb[v[v[c>>2]+32>>2]](c,v[a+8>>2],b)|0}function Oc(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Fn(b,a);gb=c+16|0;return(d?b:a)|0}function Nf(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Ou(a,b);gb=c+16|0;return(d?b:a)|0}function Jc(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Ed(a,b);gb=c+16|0;return(d?b:a)|0}function Ie(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Fn(a,b);gb=c+16|0;return(d?b:a)|0}function HL(a,b,c){a=a|0;b=b|0;c=c|0;Fy(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=55116;return a|0}function Fb(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=Ed(b,a);gb=c+16|0;return(d?b:a)|0}function Bf(a,b){a=a|0;b=b|0;var c=0,d=0;c=gb-16|0;gb=c;d=lH(a,b);gb=c+16|0;return(d?b:a)|0}function xoa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,13325);Dc(c,a);vb(a);gb=b+16|0}function uea(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=-1?(c|0)!=4:0)){Bk(a,b);return}PI(a,b,c)}function mz(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=v[(b<<2)+18796>>2]}else{b=6902}Tb(a,b)}function mda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=jk(a);if(a){kb[v[v[a>>2]+76>>2]](a,b,c,d)}}function lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=jk(a);if(a){kb[v[v[a>>2]+84>>2]](a,b,c,d)}}function kda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=jk(a);if(a){kb[v[v[a>>2]+88>>2]](a,b,c,d)}}function gO(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[ec(a)+4|0]){Hb(b+16|0)}if(b){hO(b)}}}function ch(a){var b=0;b=a+44|0;ax(b);if(v[b>>2]){cX(b);On(wb(b),v[b>>2],si(b))}gc(a+32|0)}function Xk(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function UH(a){var b=0;b=v[a>>2];if(b){if(!He(hI(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function TH(a){var b=0;b=v[a>>2];if(b){if(!He(cI(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function NF(a,b){var c=0,d=0;Br(a);v[a>>2]=28104;v[a+4>>2]=v[b>>2];c=a,d=xb(b),v[c+8>>2]=d}function Hv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;_e(c,1,a);RE(c,b);gb=c+16|0;return a|0}function HW(a,b,c,d){a=c-b|0;c=v[d>>2]+B((a|0)/-6|0,6)|0;v[d>>2]=c;if((a|0)>=1){hc(c,b,a)}}function Gv(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Hr(c,1,a);RE(c,b);gb=c+16|0;return a|0}function Dma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,13928);Dc(c,a);vb(a);gb=b+16|0}function Dc(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];yA(b)}function Bj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gb-16|0;gb=d;RM(a,b,c);gb=d+16|0;return a|0}function w$(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;kb[a|0](b,c,d,e,f,g)}function toa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1580);Dc(c,a);vb(a);gb=b+16|0}function qqa(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function mpa(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1040);Dc(c,a);vb(a);gb=b+16|0}function id(a,b){var c=0;c=gb-16|0;gb=c;nl(c+8|0,a+24|0,b);a=Cb(c+8|0);gb=c+16|0;return a}function gt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function f$(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,13955);Dc(c,a);vb(a);gb=b+16|0}function Wma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1983);Dc(c,a);vb(a);gb=b+16|0}function Wka(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1274);Dc(c,a);vb(a);gb=b+16|0}function Vma(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1031);Dc(c,a);vb(a);gb=b+16|0}function PM(a){a=a|0;var b=0;b=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];A[a+4256>>3]=b-J(b)}function Nx(a,b,c,d){var e=0;e=gb-16|0;gb=e;v[e+12>>2]=d;a=$s(a,b,c,d);gb=e+16|0;return a}function Gy(a){a=a|0;var b=0;v[a>>2]=55220;b=v[a+4>>2];if(b){Zb(b);v[a+4>>2]=0}return a|0}function Ema(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1116);Dc(c,a);vb(a);gb=b+16|0}function yi(a){if(lK(a)){a=aa(4)|0;v[a>>2]=0;Bm(a);v[a>>2]=79180;ia(a|0,79216,1928);L()}}function oda(a,b){a=a|0;b=b|0;a=jk(a);if(!a){return 1}return kb[v[v[a>>2]+68>>2]](a,b)|0}function iZ(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1467);Dc(c,a);vb(a);gb=b+16|0}function ge(a,b,c){var d=0;d=gb-16|0;gb=d;v[d+12>>2]=b;kH(a,d+12|0,c);gb=d+16|0;return a}function g$(a){a=a|0;var b=0,c=0;b=gb-16|0;gb=b;c=a;a=Tb(b,1628);Dc(c,a);vb(a);gb=b+16|0}function fv(a,b,c){if(b){while(1){u[a>>1]=x[c>>1];a=a+2|0;b=b-1|0;if(b){continue}break}}}function df(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Jb(a)+Ab(a)|0)>>2];gb=b+16|0;return a}function Z4(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){zx(a,c);return}Tb(a,5098)}function Q7(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;hw(c+8|0,b,20);Ur(a,c+8|0);gb=c+16|0}function Iw(){var a=0,b=0;a=gb-16|0;gb=a;b=is(a+8|0,nc(rf(12)));gb=a+16|0;return v[b>>2]}function CP(a,b){var c=0;c=w[a+851|0];if(c&1){t[a+851|0]=c|32;v[a+852>>2]=v[a+852>>2]+b}}function w_(a){a=a|0;var b=0;b=v[a+4>>2];return(kb[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function gn(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c>>1]|x[c+2>>1]<<16;u[b>>1]=a;u[b+2>>1]=a>>>16}function aY(a,b){return v[v[a>>2]>>2]==(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))}function aB(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function Zi(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function Yt(a,b){if(!(v[a+480180>>2]==8?t[b+851|0]&1:0)){Az(a,b,0);Az(a,b,1);Az(a,b,2)}}function Wf(a,b,c){var d=0;d=gb-16|0;gb=d;if(!$u(a,b)){b=$u(c,a)?c:a}gb=d+16|0;return b}function OT(a,b,c){var d=0;d=v[b>>2];if((c|0)==-1){c=cr(b)}v[a>>2]=d;v[a+4>>2]=(c<<2)+d}function Jn(a){var b=0;b=Dw(a+4|0);if((b|0)==-1){kb[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function $g(a,b,c){var d=0;d=gb-16|0;gb=d;if(!jT(a,b)){b=jT(c,a)?c:a}gb=d+16|0;return b}function zH(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;a=AH(a,8419,b);gb=c+16|0;return a}function yE(a){var b=0,c=0;b=gb-16|0;gb=b;c=Pp(a);t[b+15|0]=0;no(a,c,b+15|0);gb=b+16|0}function pH(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=0;kH(a,c+12|0,b);gb=c+16|0;return a}function mP(a){Kb(a);Kb(a+12|0);Kb(a+24|0);Kb(a+36|0);Kb(a+48|0);v[a+60>>2]=0;return a}function li(a,b,c){if(b){while(1){t[a|0]=w[c|0];a=a+1|0;b=b-1|0;if(b){continue}break}}}function hU(a){var b=0;b=44325e5/+(a>>>0);if(b<4294967296&b>=0){return~~b>>>0}return 0}function cl(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]-b|0;v[d>>2]=c;if((b|0)>=1){hc(c,a,b)}}function bl(a){var b=0;b=a+36|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function aG(a){var b=0;b=a+48|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function YR(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function We(a){var b=0,c=0,d=0;b=gb-16|0;gb=b;c=v[Xw(b,a)+8>>2],d=0,t[c|0]=d;gb=b+16|0}function WY(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+28880|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function Tb(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;xs(a,b,Lf(b));gb=c+16|0;return a|0}function RA(a,b){FB(a,b);Dc(a+12|0,b+12|0);u[a+28>>1]=x[b+28>>1];v[a+24>>2]=v[b+24>>2]}function Cf(a){var b=0;b=a+24|0;while(1){b=vb(b-12|0);if((b|0)!=(a|0)){continue}break}}function x0(a){a=a|0;a=465240;while(1){a=Hc(a-12|0);if((a|0)!=465216){continue}break}}function vm(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function i6(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function g6(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function c_(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;mw(c+8|0,b);Ur(a,c+8|0);gb=c+16|0}function Ru(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function M2(a,b){a=a|0;b=b|0;var c=0;c=Ix(v[b>>2])<<24;v[a+4>>2]=v[b>>2];t[a|0]=c>>24}function M0(a){a=a|0;a=464392;while(1){a=vb(a-12|0);if((a|0)!=464224){continue}break}}function J0(a){a=a|0;a=464568;while(1){a=Hc(a-12|0);if((a|0)!=464400){continue}break}}function It(a,b){a=a|0;b=b|0;b=gb-16|0;gb=b;v[b>>2]=a;_I(14896,b);ht(89864);gb=b+16|0}function G0(a){a=a|0;a=464864;while(1){a=vb(a-12|0);if((a|0)!=464576){continue}break}}function D0(a){a=a|0;a=465168;while(1){a=Hc(a-12|0);if((a|0)!=464880){continue}break}}function A0(a){a=a|0;a=465208;while(1){a=vb(a-12|0);if((a|0)!=465184){continue}break}}function xf(a){a=a|0;var b=0;b=v[a>>2];return(kb[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function s1(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Ds()+((b&255)<<2)>>2]}return b<<24>>24}function q1(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Cs()+((b&255)<<2)>>2]}return b<<24>>24}function gi(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;Zi(a)}function bh(a){a=a|0;var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,a)>>2];gb=b+16|0;return a|0}function Waa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return FL(a,b,c,d,0,0,0,0,e)|0}function UT(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function Ni(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;Cq(a,c+12|0);gb=c+16|0;return a}function Ija(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;xs(a,b,12);gb=c+16|0;return a|0}function CG(a,b){a:{if(!(w[a+128|0]|b>>>0>30)){t[a+128|0]=1;break a}a=Kz(b)}return a}function z$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=kb[a|0](b,c,d)|0;ma(jb|0);return a|0}function bk(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function uT(a,b,c,d,e,f){yc(a,b);yc(a+4|0,c);yc(a+8|0,d);yc(a+12|0,e);yc(a+16|0,f)}function th(a){var b=0;b=gb-16|0;gb=b;v[b+12>>2]=0;Cq(a,b+12|0);gb=b+16|0;return a}function jJ(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function gC(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,v[a>>2])>>2];gb=b+16|0;return a}function bj(a,b){a=a|0;b=b|0;if(sc(a)>>>0<=b>>>0){Qx();L()}return v[a>>2]+(b<<1)|0}function YP(a,b){var c=0;c=b&15;if(c){t[a+830|0]=c}b=b&240;if(b){t[a+829|0]=b>>>4}}function Rd(a){a=a|0;var b=0;b=gb-16|0;gb=b;Nr(b+8|0,a);gb=b+16|0;return v[b+8>>2]}function Li(a,b){a=a|0;b=b|0;if(b>>>0>1073741823){nd(8513);L()}return Mc(b<<2,4)|0}function $W(a){var b=0,c=0;b=gb-16|0;gb=b;c=b+8|0;XW(c,a);gb=b+16|0;return v[c>>2]}function yw(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,36);return a}function qF(a,b){var c=0;v[a>>2]=v[b>>2];c=a;a=v[b+4>>2];v[c+4>>2]=a;if(a){Kn(a)}}function gY(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,48);return a}function Zo(a,b){a=hc(a,b,34);u[a+34>>1]=x[b+34>>1];hc(a+36|0,b+36|0,68);return a}function RD(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,20);return a}function Mp(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,12);return a}function zh(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,yh(a))>>2];gb=b+16|0;return a}function zF(a,b,c){a=a|0;b=b|0;c=c|0;Dc(b,c);Wk(b+12|0,c+12|0);ni(b+32|0,c+32|0)}function yh(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,ec(a))>>2];gb=b+16|0;return a}function yg(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<2);return a}function wd(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,Jb(a))>>2];gb=b+16|0;return a}function pB(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<5);return a}function or(a){var b=0;b=gb-16|0;gb=b;a=v[yc(b+8|0,gC(a))>>2];gb=b+16|0;return a}function oP(a){a=a|0;t[a+8|0]=0;v[a>>2]=0;v[a+4>>2]=4194432;yE(a+9|0);return a|0}function ji(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<1);return a}function bs(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<3);return a}function _I(a,b){var c=0;c=gb-16|0;gb=c;v[c+12>>2]=b;ZI(89864,a,b,0,0);gb=c+16|0}function Zp(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<4);return a}function JY(a){a=a+4|0;return Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function HY(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;Wk(a+8|0,b+8|0)}function Cr(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,6);return a}function y$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;kb[a|0](b,c,d,e,f)}function d4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=gb-16|0;gb=b;qH(a,c,d);gb=b+16|0}function bg(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(b){kb[v[v[b>>2]+4>>2]](b)}}}function Uca(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[wb(a)>>2]){dP(a,b);return}cP(a,b)}function TR(a,b){var c=0;c=a;a=v[a>>2];v[c>>2]=a<<8^v[((a>>>24^b)<<2)+35868>>2]}function KY(a,b){a=a|0;b=b|0;return v[b+8>>2]==v[a+8>>2]&v[a+12>>2]==v[b+12>>2]}function s6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return zJ(a-88|0,b,c,d,e)|0}function bL(a,b){a=a|0;b=b|0;v[(v[v[a>>2]-12>>2]+a|0)+8>>2]=v[b>>2];return a|0}function Yo(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function Hfa(a,b){a=a|0;b=b|0;if(y[a+4>>2]<y[wb(a)>>2]){dP(a,b);return}cP(a,b)}function Hba(a,b){a=a|0;b=b|0;return C((b|0)<=12?z[((b<<2)+a|0)+4208>>2]:C(0))}function B$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return kb[a|0](b,c,d,e)|0}function Au(a,b){return xh(Ag((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function zB(a){return(+y[a>>2]+ +v[a+4>>2]*4294967296)*2.3283064365386963e-10}function yba(a,b){a=a|0;b=b|0;return C((b|0)<=2?z[((b<<2)+a|0)+4208>>2]:C(0))}function w4(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Tb(a,5134);return}zx(a,c)}function vj(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}Zb(b)}function uca(a,b){a=a|0;b=b|0;return C((b|0)<=5?z[((b<<2)+a|0)+4208>>2]:C(0))}function u4(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Tb(a,5064);return}zx(a,c)}function rba(a,b){a=a|0;b=b|0;return C((b|0)<=3?z[((b<<2)+a|0)+4208>>2]:C(0))}function qo(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function oA(a){var b=0;if(!(w[a+2|0]|(w[a|0]|w[a+1|0]))){b=!w[a+3|0]}return b}function mca(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4208>>2]:C(0))}function kR(a){v[a>>2]=0;v[a+4>>2]=0;v[a>>2]=-2078137563;v[a+4>>2]=-873292572}function jF(a,b){var c=0;c=gb-16|0;gb=c;b=gj(c+8|0,b);PF(b,a);pe(b);gb=c+16|0}function gj(a,b){v[a>>2]=v[b>>2];b=v[b+4>>2];v[a+4>>2]=b;if(b){Kn(b)}return a}function eca(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function Y$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Og(a,v[b+8>>2],0)){Uw(b,c,d)}}function Xy(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function Sba(a,b){a=a|0;b=b|0;return C((b|0)<=1?z[((b<<2)+a|0)+4208>>2]:C(0))}function SF(a,b){var c=0;c=gb-16|0;gb=c;b=bk(c+8|0,b);PF(b,a);pe(b);gb=c+16|0}function Hca(a,b){a=a|0;b=b|0;return C((b|0)<=6?z[((b<<2)+a|0)+4208>>2]:C(0))}function xk(a,b,c,d){a=c-b|0;c=v[d>>2]-a|0;v[d>>2]=c;if((a|0)>=1){hc(c,b,a)}}function tj(a,b){var c=0;c=a;a=(b>>>0)/100|0;return at(at(c,a),b-B(a,100)|0)}function rd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];Yb(b,c);Ew(a,b,d,c)}function qL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){ho(c+120|0);Zb(c)}}}function nH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[a>>2]+32>>2]](a,b,c,d)|0}function mH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;kb[v[v[a>>2]+48>>2]](a,b,c,d)|0}function dn(a){a=a+4|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function br(a){var b=0;b=gb-16|0;gb=b;a=v[tT(b+8|0,a)>>2];gb=b+16|0;return a}function _G(a,b){var c=0,d=0;Ee(a,$d(b));b=v[ec(b)>>2];c=ec(a),d=b,v[c>>2]=d}function Wl(a){var b=0;b=gb-16|0;gb=b;v[b+8>>2]=a;gb=b+16|0;return v[b+8>>2]}function Tz(a,b){a=a|0;b=b|0;return(b>>>0<4e3?((b<<5)+a|0)+946304|0:18693)|0}function Qy(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=$u(a,b);gb=c+16|0;return d?b:a}function OD(a,b,c,d){a=c-b|0;if((a|0)>=1){hc(v[d>>2],b,a);v[d>>2]=v[d>>2]+a}}function EH(){a:{if(t[463688]&1){break a}if(!Pd(463688)){break a}Od(463688)}}function Cm(a,b){var c=0,d=0;c=gb-16|0;gb=c;d=$u(b,a);gb=c+16|0;return d?b:a}function rT(a){if((w[a+14|0]-49&255)>>>0<=3){return!yd(a,12702,14)}return 0}function oT(a,b){zU(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function ks(a,b){a=a|0;b=b|0;a=v[a>>2];return kb[v[v[a>>2]+32>>2]](a,0,b)|0}function hz(a,b){a=a|0;b=b|0;return(b>>>0<=15?t[v[a+88>>2]+b|0]:63)<<24>>24}function hw(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(!c){ba(12861,6259,85,7862);L()}}function gz(a,b){a=a|0;b=b|0;return(b>>>0<=44?t[v[a+84>>2]+b|0]:63)<<24>>24}function YH(a,b,c,d,e,f,g,h){return kb[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function UV(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function Rs(a,b,c,d,e,f,g,h){return kb[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function Ri(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function Ok(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(!c){ba(12861,6259,48,7862);L()}}function Ju(a,b,c){var d=0;d=gb-16|0;gb=d;yc(d+8|0,ap(a,b,Wl(c)));gb=d+16|0}function y1(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Cs()+(b<<2)>>2]}return b|0}function oo(a,b){a=v[a+4276>>2];return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function lg(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function ke(a,b){a=a|0;b=b|0;if($l(a,b)){a=hi($e(a,b))}else{a=0}return a|0}function jD(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+28;return a}function iR(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;dT(a,c)}function dv(a,b,c){b=b-a|0;if((b|0)>=1){hc(v[c>>2],a,b);v[c>>2]=b+v[c>>2]}}function at(a,b){b=x[(b<<1)+73872>>1];t[a|0]=b;t[a+1|0]=b>>>8;return a+2|0}function Xw(a,b){v[a+12>>2]=0;v[a+4>>2]=b;v[a>>2]=b;v[a+8>>2]=b+1;return a}function Bh(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function A1(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Ds()+(b<<2)>>2]}return b|0}function xV(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function vn(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+48>>2]](a,b,c)|0}function r5(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+32>>2]](a,b,c)|0}function ml(a,b,c){a=a|0;b=b|0;c=c|0;return kb[v[v[a>>2]+12>>2]](a,b,c)|0}function lR(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+8;return a}function cda(a,b){a=a|0;b=b|0;a=v[a+20>>2]+24|0;t[a|0]=w[a|0]&253|(b?2:0)}function bQ(a,b){var c=0;c=gb-16|0;gb=c;nl(c+8|0,a,b);er(c+8|0);gb=c+16|0}function bF(a){return(v[a+88>>2]&2050)==2?(w[v[a+104>>2]+34|0]&8)>>>3|0:0}function XU(a,b){var c=0;c=gb-16|0;gb=c;mw(c+8|0,b);FW(a,c+8|0);gb=c+16|0}function Pc(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function Lz(a,b){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+4;return a}function Jl(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function Il(a,b){var c=0;c=gb-16|0;gb=c;Db(c+8|0,a,b);er(c+8|0);gb=c+16|0}function H_(a){a=a|0;var b=0;b=gb-16|0;gb=b;cc(a);On(b+8|0,a,1);gb=b+16|0}function B_(a){a=a|0;var b=0;b=gb-16|0;gb=b;cc(a);Tk(b+8|0,a,1);gb=b+16|0}function Aea(a,b,c){a=a|0;b=b|0;c=c|0;if(Ab(b)>>>0>c>>>0){jq(b,c)}Dc(a,b)}function uq(a,b){a=a|0;b=b|0;return(b>>>0<=44?w[v[a+84>>2]+b|0]!=63:0)|0}function pI(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Bh(a,-1,-1)}function iz(a,b){a=a|0;b=b|0;return(b>>>0<=15?w[v[a+88>>2]+b|0]!=63:0)|0}function bE(a,b){return(w[a|0]|w[a+1|0]<<8)>>>0<(w[b|0]|w[b+1|0]<<8)>>>0}function FY(a){return Xb(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}function uc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=Lf(b),v[c+4>>2]=d;return a}function od(a,b){SF(a,b);v[a+8>>2]=v[b+8>>2];SF(a+12|0,b+12|0);return a}function jh(a,b,c){return(c|0)>=0?(x[v[a+8>>2]+((c&255)<<1)>>1]&b)!=0:0}function fS(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function cx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function Zx(a){return((nh(a)+(nh(a)<<8)|0)+(nh(a)<<16)|0)+(nh(a)<<24)|0}function ZR(a){if(a>>>0<=8){return w[a+35856|0]}return w[a+35847|0]|256}function Uf(a){var b=0;b=a;if(v[b>>2]){Nd(b);vy(v[b>>2],av(b))}return a}function Je(a,b){gj(a,b);v[a+8>>2]=v[b+8>>2];gj(a+12|0,b+12|0);return a}function JH(a){u[a+12>>1]=0;v[a+8>>2]=-1;v[a>>2]=0;v[a+4>>2]=0;return a}function IJ(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function DV(a){v[a+8>>2]=0;v[a>>2]=0;v[a+4>>2]=40;u[a+12>>1]=0;return a}function xo(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];t[a+6|0]=w[b+6|0]}function xC(a,b){if(b){xC(a,v[b>>2]);xC(a,v[b+4>>2]);zk(b+16|0);YW(b)}}function sz(a,b){if(b){sz(a,v[b>>2]);sz(a,v[b+4>>2]);Hb(b+16|0);hO(b)}}function pz(a,b){A[a>>3]=A[b>>3]+A[a>>3];A[a+8>>3]=A[b+8>>3]+A[a+8>>3]}function kF(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function hl(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function hP(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){Zm(c);Zb(c)}}}function _h(a){a=a|0;a=jB(a)?a+172|0:a+156|0;return w[a|0]|w[a+1|0]<<8}function ZF(a,b){if(b>>>0>357913941){nd(8513);L()}return Mc(B(b,12),4)}function TD(a,b){if(b>>>0>214748364){nd(8513);L()}return Mc(B(b,20),4)}function T4(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){ua();L()}}function Rw(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function Ac(a,b){if(Nb(a)>>>0<=b>>>0){Qx();L()}return v[a>>2]+(b<<2)|0}function yG(a){return(v[a>>2]&-256)==1126902528&v[a+4>>2]==1129074247}function uD(a,b){var c=0;c=gb-16|0;gb=c;bc(a,v[b>>2],pc(b));gb=c+16|0}function tC(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;WL(a,b);gb=c+16|0}function k$(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;sG(a,b);gb=c+16|0}function gP(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function N$(a){a=a|0;if(!a){return 0}return(Vw(a,89420,89564)|0)!=0|0}function Mj(a,b){return(v[a+4>>2]-v[b+4>>2]|0)+(v[a>>2]-v[b>>2]<<3)|0}function KW(a,b){if(b>>>0>715827882){nd(8513);L()}return Mc(B(b,6),1)}function Jh(a,b){a=a|0;b=b|0;var c=0;c=gb-16|0;gb=c;Vf(a,b);gb=c+16|0}function zN(a){if(a>>>0>=82595525){nd(8513);L()}return Mc(B(a,52),4)}function ys(a,b,c,d,e){b=Ea(a|0,b|0,c|0,d|0,e|0)|0;jb=O()|0;return b}function tz(a){var b=0;$S(a);b=v[a>>2];if(b){Wh(v[a+16>>2],b,pk(a))}}function s2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;cg(a,f)}function pm(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function nC(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];Wk(a+8|0,b+8|0)}function cz(a,b,c){b=b-a|0;if(b){sh(c,a,b)}return B((b|0)/6|0,6)+c|0}function ZB(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){ec(a);if(b){cv(b)}}}function UE(a,b){if(b>>>0>2147483647){nd(8513);L()}return Mc(b<<1,2)}function UA(a,b){nc(a);Kb(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function TF(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){Zb(gc(c))}}}function JE(a,b){if(b>>>0>1073741823){nd(8513);L()}return Mc(b<<2,2)}function GB(a,b){jc(a,b);jc(a+4|0,b+4|0);jc(wb(a),wb(b));wb(a);wb(b)}function G1(a){a=a|0;var b=0;b=v[115996]+1|0;v[115996]=b;v[a+4>>2]=b}function AG(a,b,c){a:{if((a|0)==(b|0)){t[a+128|0]=0;break a}FO(b,c)}}function A$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return kb[a|0](b,c,d)|0}function sT(a,b,c,d,e){yc(a,b);yc(a+4|0,c);yc(a+8|0,d);yc(a+12|0,e)}function rW(a){t[a+4|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function pG(a,b,c,d,e,f,g){return La(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function ioa(a,b){a=a|0;b=b|0;Bj(a,zb(v[b>>2]),zb(v[b>>2])+pc(b)|0)}function ey(a){a=a|0;var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b|0}function bP(a,b){var c=0;c=gb-16|0;gb=c;Hr(c,1,b);Bc(a,c);gb=c+16|0}function aC(a,b){if(b){aC(a,v[b>>2]);aC(a,v[b+4>>2]);On(ec(a),b,1)}}function _V(a){if(a>>>0>=1073741824){nd(8513);L()}return Mc(a<<2,1)}function Q_(a){a=a|0;var b=0;b=gb-16|0;gb=b;cc(a);MF(a,1);gb=b+16|0}function Kz(a){if(a>>>0>=1073741824){nd(8513);L()}return Mc(a<<2,4)}function IU(a){a=a|0;v[a>>2]=18824;gc(a+28|0);gc(a+12|0);return a|0}function BP(a,b){v[a+852>>2]=v[a+852>>2]+b;t[a+851|0]=w[a+851|0]|32}function yl(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(b){Zb(Uf(b))}}}function vG(a){if(a>>>0>=268435456){nd(8513);L()}return Mc(a<<4,4)}function v1(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function sH(a,b,c){a=a|0;b=b|0;c=c|0;return $p(0,a,b,c?c:463712)|0}function qja(a,b){a=a|0;b=b|0;if(!v[22640]){v[22641]=b;v[22640]=a}}function nT(a,b){EB(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function lS(a){if(a>>>0>=134217728){nd(8513);L()}return Mc(a<<5,4)}function go(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<1)|0}function c7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;eK(a,b,c,d,e)}function Tc(a,b,c){a=a|0;b=b|0;c=c|0;return _c(a,B(Hi(a),b)+c|0)|0}function QW(a){if(a>>>0>1073741823){nd(8513);L()}return Mc(a<<2,1)}function KR(a){if(a>>>0>=536870912){nd(8513);L()}return Mc(a<<3,8)}function y_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+12>>2]](a)|0}function x_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+16>>2]](a)|0}function vi(a,b){var c=0,d=0;c=a,d=tx(v[b>>2]),v[c>>2]=d;return a}function uU(a){a=a+34|0;a=mqa(w[a|0]|w[a+1|0]<<8,0,80,0);return a}function mp(a){a=a|0;return v[a+20>>2]+(v[a+8>>2]-v[a+24>>2]|0)|0}function jy(a){a=w[a+1|0];return(a&6)==6?384:1152>>>((a&14)==2)|0}function eE(a){if(v[a>>2]){PD(a,v[a>>2]);QD(wb(a),v[a>>2],am(a))}}function Nc(a,b,c){a=a|0;b=b|0;c=c|0;if(_E(c)){Zb(a);return}Zb(a)}function Hj(a){a=v[a+656>>2];if(!a){return 0}return v[a+44>>2]!=0}function GX(a){jb=0;a=a+47|0;a=(w[a|0]|w[a+1|0]<<8)-98|0;return a}function GJ(a){a=a|0;return+(+v[v[a+32>>2]+1074456>>2]*.00390625)}function z_(a){a=a|0;a=v[a+4>>2];return kb[v[v[a>>2]+8>>2]](a)|0}function qM(a){a=a|0;v[a>>2]=51540;Lc(a+4256|0);hf(a);return a|0}function jR(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function hS(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){Zb(c)}}}function hM(a){a=a|0;v[a>>2]=52144;Lc(a+4208|0);hf(a);return a|0}function g0(a){a=a|0;var b=0,c=0;b=a,c=xe(),v[b>>2]=c;return a|0}function ed(a,b){return((a^-2147483648)>>>b)-(-2147483648>>>b)|0}function du(a){vb(a+48|0);vb(a+36|0);vb(a+24|0);vb(a+12|0);vb(a)}function bba(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function Ny(a){a=a|0;v[a>>2]=51280;Lc(a+4260|0);hf(a);return a|0}function LM(a){a=a|0;v[a>>2]=50260;gc(a+4208|0);hf(a);return a|0}function BM(a){a=a|0;v[a>>2]=51048;Lc(a+4208|0);hf(a);return a|0}function At(a,b,c){a=v[a>>2];return(a|0)>=x[b>>1]&(a|0)<=x[c>>1]}function $M(a){a=a|0;v[a>>2]=50024;Lc(a+4208|0);hf(a);return a|0}function zu(a){Yu(a);if(v[a>>2]){oS(a);Tk(wb(a),v[a>>2],$h(a))}}function wx(a,b){a=a|0;b=b|0;return(Sh(a)|0)!=0|(a|32)-97>>>0<6}function vM(a){a=a|0;return C(C(C(z[a+4228>>2]*C(198))+C(-99)))}function tE(a){if(!yd(a,28770,25)){return w[a+34|0]<65}return 0}function rn(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+28>>2]](a,b)|0}function rF(a,b,c){gj(a,b);v[a+8>>2]=0;gj(a+12|0,c);pe(c);pe(b)}function ox(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+12>>2]](a,b)|0}function ig(a,b,c,d){v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function hm(a){a=a|0;a=v[a>>2];return kb[v[v[a>>2]+24>>2]](a)|0}function bi(a){tk(a);if(v[a>>2]){Dq(a);vC(wb(a),v[a>>2],ye(a))}}function an(a){lT(a);if(v[a>>2]){kT(a);iB(wb(a),v[a>>2],Wi(a))}}function aA(a){dY(a);if(v[a>>2]){rY(a);cY(wb(a),v[a>>2],on(a))}}function _z(a){PO(a);if(v[a>>2]){OO(a);Nz(wb(a),v[a>>2],mk(a))}}function _ea(a,b){a=a|0;b=b|0;a=_X(a,b);if(!a){xv(b)}return a|0}function Uz(a){AF(a);if(v[a>>2]){UF(a);es(wb(a),v[a>>2],Yk(a))}}function Ti(a,b,c){a=a|0;b=b|0;c=c|0;return ap(Wl(a),Wl(b),c)|0}function Rq(a){zR(a);if(v[a>>2]){oR(a);AA(wb(a),v[a>>2],pg(a))}}function RR(a,b){b=1/(564505.8718779281/b+1);OR(a,b,0,0,b+-1,0)}function Qs(a,b){a=a|0;b=b|0;return kb[v[v[a>>2]+44>>2]](a,b)|0}function OV(a,b,c,d){Je(a,b);u[a+22>>1]=d;u[a+20>>1]=c;return a}function Lt(a){TM(a);if(v[a>>2]){XM(a);SM(wb(a),v[a>>2],Cl(a))}}function Lk(a){Fp(a);if(v[a>>2]){qw(a);WD(wb(a),v[a>>2],Lg(a))}}function Jga(a,b){a=a|0;b=b|0;a=pW(a,b);if(!a){oW(b)}return a|0}function GR(a){Qp(a);if(v[a>>2]){vR(a);im(wb(a),v[a>>2],qg(a))}}function E$(a,b){a=a|0;b=b|0;a=kb[a|0](b)|0;ma(jb|0);return a|0}function $o(a){tk(a);if(v[a>>2]){Dq(a);fw(wb(a),v[a>>2],ye(a))}}function xt(a){a=a|0;v[a>>2]=77092;vb(a+32|0);um(a);return a|0}function uw(a,b){jF(a,b);v[a+8>>2]=v[b+8>>2];jF(a+12|0,b+12|0)}function uL(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function uC(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,4896);gb=c+16|0}function rv(a){a=a|0;a=w[a|0];return ve(a)^1|(a-49&255)>>>0<36}function iC(a,b){a=a|0;b=b|0;a=SV(a,b);if(!a){Ik(b)}return a|0}function eF(a,b){a=a|0;b=b|0;a=dF(a,b);if(!a){tw(b)}return a|0}function cj(a){hA(a);if(v[a>>2]){fw(v[a+16>>2],v[a>>2],pk(a))}}function Zg(a){hA(a);if(v[a>>2]){Wh(v[a+16>>2],v[a>>2],pk(a))}}function Yr(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function Xb(a){return a<<8&16711680|a<<24|(a>>>8&65280|a>>>24)}function Wk(a,b){bk(a,b);v[a+8>>2]=v[b+8>>2];bk(a+12|0,b+12|0)}function VD(a){TE(a);if(v[a>>2]){WD(v[a+16>>2],v[a>>2],ow(a))}}function Rf(a,b){return kb[v[v[a>>2]+32>>2]](a,v[a+12>>2],b)|0}function RW(a){hA(a);if(v[a>>2]){vC(v[a+16>>2],v[a>>2],pk(a))}}function Nl(a,b){a=t[lc(a+58|0,b)|0];return((a|0)>-1?a:-1)&255}function NB(a,b){a=a|0;b=b|0;a=UX(a,b);if(!a){XC(b)}return a|0}function Kw(a,b){a=a|0;b=b|0;a=HF(a,b);if(!a){Aw(b)}return a|0}function Hh(a,b){a=a|0;b=b|0;a=as(a,b);if(!a){ak(b)}return a|0}function HD(a,b){a=a|0;b=b|0;a=Nv(a,b);if(!a){Ov(b)}return a|0}function Gh(a){TE(a);if(v[a>>2]){pw(v[a+16>>2],v[a>>2],ow(a))}}function Fw(a,b){a=a|0;b=b|0;a=xF(a,b);if(!a){wF(b)}return a|0}function F$(a,b){a=a|0;b=+b;a=kb[a|0](b)|0;ma(jb|0);return a|0}function Av(a,b,c){a=w[a|0];return a>>>0>=w[b|0]&a>>>0<=w[c|0]}function Ar(a,b){a=a|0;b=b|0;a=VX(a,b);if(!a){WX(b)}return a|0}function $r(a){a=a|0;a=v[a>>2];return kb[v[v[a>>2]+8>>2]](a)|0}function xea(a,b,c){a=a|0;b=b|0;c=c|0;return mv(a,b,c,1490)|0}function wR(a,b){return v[a>>2]==v[b>>2]&v[a+4>>2]==v[b+4>>2]}function qO(a){a=a|0;v[a+12>>2]=1065353216;pO(a,4);return a|0}function pha(a,b,c){a=a|0;b=b|0;c=c|0;return mv(a,b,c,1105)|0}function oG(a,b,c){b=Ia(1997,a|0,b|0,c|0)|0;jb=O()|0;return b}function le(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];return a}function i_(a,b){a=a|0;b=b|0;Ls(a,b);v[a>>2]=89076;return a|0}function dna(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,yI(c,Jb(b),Ab(b)))}function cC(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function bt(a,b){b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return a}function bN(a,b){a=a|0;b=b|0;Ls(a,b);v[a>>2]=88940;return a|0}function Um(a,b,c){u[a>>1]=x[b>>1];v[a+4>>2]=v[c>>2];return a}function R8(a,b,c){a=a|0;b=b|0;c=c|0;fO(a,0,Dk(v[b+24>>2]),c)}function Q2(a,b){a=a|0;b=b|0;Ls(a,b);v[a>>2]=89128;return a|0}function Pi(a,b){a=a|0;b=b|0;if(Ae(a)>>>0>b>>>0){t[a+16|0]=b}}function Gr(a,b){b=w[b|0]|w[b+1|0]<<8;t[a|0]=b;t[a+1|0]=b>>>8}function Fu(a,b,c){v[a>>2]=v[b>>2];v[a+4>>2]=v[c>>2];return a}function wc(a,b){var c=0;c=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=c}function vp(a,b,c){if(!b){return 0}return jt(a,Ig(t[c|0]),b)}function nP(a){v[a>>2]=0;nc(a+4|0);Qb(a+16|0,0,144);return a}function ida(a){a=a|0;a=jk(a);if(a){kb[v[v[a>>2]+96>>2]](a)}}function hF(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,36);gb=c+16|0}function foa(a,b,c){a=a|0;b=b|0;c=c|0;return mv(a,b,c,663)|0}function Ty(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function Ns(){var a=0;a=aa(4)|0;km(a);ia(a|0,88880,1928);L()}function NW(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,12);gb=c+16|0}function KJ(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function ti(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,4);gb=c+16|0}function pF(a){var b=0;b=v[a+8>>2];if(b){Tk(a,b,v[a+4>>2])}}function n1(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)>-1?b:c)|0}function mB(a,b){if(b){mB(a,v[b>>2]);mB(a,v[b+4>>2]);vT(b)}}function lB(a,b){if(b){lB(a,v[b>>2]);lB(a,v[b+4>>2]);cv(b)}}function eu(a,b){if(b){eu(a,v[b>>2]);eu(a,v[b+4>>2]);cv(b)}}function bU(a){if(v[a>>2]){_T(a,v[a>>2]);Mu(v[a>>2],qg(a))}}function WA(a){ad(a);v[a+12>>2]=0;u[a+16>>1]=65280;return a}function Qr(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,1);gb=c+16|0}function LI(a,b){if(b>>>0<=9){return KI(a,b)}return at(a,b)}function Dw(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function CF(a){var b=0;b=v[a+8>>2];if(b){On(a,b,v[a+4>>2])}}function Bn(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,2);gb=c+16|0}function BY(a,b){var c=0;c=gb-16|0;gb=c;bc(a,b,8);gb=c+16|0}function $B(a,b){if(b){$B(a,v[b>>2]);$B(a,v[b+4>>2]);cv(b)}}function wG(a){a=v[a>>2]-12|0;if((Dw(a+8|0)|0)<=-1){Zb(a)}}function jB(a){a=a+156|0;return(w[a|0]|w[a+1|0]<<8)==65534}function gg(a,b){a=nqa(v[a>>2],v[a+4>>2],b,b>>31);return a}function gF(a){var b=0;b=gb-16|0;gb=b;Qb(a,0,36);gb=b+16|0}function er(a){var b=0;b=v[a>>2];v[b>>2]=v[b>>2]|v[a+4>>2]}function be(a,b){a=a|0;b=b|0;pd(a,v[b>>2],v[b>>2]+pc(b)|0)}function Zn(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function VK(a){a=a|0;return y[v[a+24>>2]+1074420>>2]/1e4|0}function S4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jb=0;return 0}function Q8(a){a=a|0;vL(a,2,100);Pi(v[a+24>>2]+484360|0,0)}function Mfa(a){a=a|0;Ls(a,18693);v[a>>2]=89020;return a|0}function Ab(a){if(De(a)){return v[a+4>>2]}return w[a+11|0]}function yp(a,b,c){pd(a,v[b>>2]+(c>>>3&536870908)|0,c&31)}function xK(a){var b=0;b=v[a+8>>2];if(b){wK(b,v[a+4>>2])}}function uK(a){var b=0;b=v[a+8>>2];if(b){Qu(b,v[a+4>>2])}}function tq(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function sD(a,b){var c=0;c=gb-16|0;gb=c;ZL(a,b);gb=c+16|0}function rk(a){a=v[a+656>>2];if(!a){return 0}return Fj(a)}function pu(a){if(v[a>>2]){Dq(a);Wh(wb(a),v[a>>2],ye(a))}}function pL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){AL(c)}}function oe(a,b,c){pd(a,v[b>>2]+(c>>>3&536870908)|0,1<<c)}function nv(a){if(v[a>>2]){VW(a);wC(wb(a),v[a>>2],Sj(a))}}function mn(a){if(v[a>>2]){ET(a);al(wb(a),v[a>>2],hg(a))}}function j_(a){a=a|0;QF(a,10705);v[a>>2]=28684;return a|0}function hJ(a){while(1){if((mt(a)|0)!=-1){continue}break}}function ex(a){if(v[a>>2]){Nd(a);AG(Yw(a),v[a>>2],BG(a))}}function cy(a,b){return v[((a>>>24^b)<<2)+459440>>2]^a<<8}function Zr(a){if(v[a>>2]){qw(a);pw(wb(a),v[a>>2],Lg(a))}}function Ug(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<2)|0}function Tg(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<3)|0}function OF(a){var b=0;b=v[a+8>>2];if(b){MF(b,v[a+4>>2])}}function KK(a){a=a|0;return Qi(Rb(v[a+24>>2]+484360|0))|0}function HV(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<1)|0}function Fx(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function EO(a){var b=0;dC(a);b=v[a>>2];if(b){GO(b,pk(a))}}function Ce(a){if(v[a>>2]){Wh(wb(a),v[a>>2],v[wb(a)>>2])}}function BR(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){$O(c)}}function $V(a){var b=0;dC(a);b=v[a>>2];if(b){eC(b,pk(a))}}function zb(a){var b=0;b=gb-16|0;gb=b;gb=b+16|0;return a}function wj(a){return Le(a)|Le(a)<<8|Le(a)<<16|Le(a)<<24}function q6(a,b,c){a=a|0;b=b|0;c=c|0;return Ad(B(b,c))|0}function oI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Bh(a,-1,-1)}function hv(a){$o(a+88|0);$o(a+68|0);$o(a+48|0);return a}function goa(a,b){a=a|0;b=b|0;Tb(a,b?b:18693);return a|0}function a$(a){a=a|0;bN(a,5169);v[a>>2]=27820;return a|0}function Z8(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,yI(c,b,Lf(b)))}function W_(a,b,c){a=a|0;b=b|0;c=c|0;Ew(a,b,v[b+8>>2],c)}function U_(a){a=a|0;QF(a,5915);v[a>>2]=27928;return a|0}function Te(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nf(a,c,d,b)}function Pba(a){a=a|0;eM(a);t[a+4202|0]=1;v[a+4224>>2]=0}function NG(a,b){Kn(v[b>>2]);Jn(v[a>>2]);v[a>>2]=v[b>>2]}function LC(a){a=a|0;if(!w[a|0]){return 1}return ce(a)|0}function Ik(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function Hn(a,b,c){a=nqa(v[a>>2],v[a+4>>2],b,c);return a}function HA(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function GG(a){a=a|0;v[a>>2]=83552;vb(a+12|0);return a|0}function Fpa(a,b,c){a=a|0;b=b|0;c=c|0;return wD(a,b,c)|0}function FG(a){a=a|0;v[a>>2]=83592;vb(a+16|0);return a|0}function Cy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Jy(a,b,c,d)}function xH(a){return(a|0)!=0&(a|0)!=74624&(a|0)!=74648}function ws(a,b,c){return fG(Jb(a),Ab(a),Jb(b),c,Ab(b))}function um(a){a=a|0;v[a>>2]=76788;Vb(a+4|0);return a|0}function uP(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){$O(b)}}function tJ(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function rH(a,b,c,d){a=GI(a,b,c,0,-2147483648);return a}function qv(a,b,c){a=a|0;b=b|0;c=c|0;return jt(a,b,c)|0}function pD(a,b,c){a=a|0;b=b|0;c=c|0;return NY(a,b,c)|0}function nF(a){a=a|0;v[a>>2]=28552;pe(a+4|0);return a|0}function ir(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(c<<2)|0}function cf(a,b,c){a=a|0;b=b|0;c=c|0;Fe(a,b);return a|0}function bq(a){a=a|0;v[a>>2]=76852;Vb(a+4|0);return a|0}function bM(a){return C(C(z[a+4208>>2]*C(1e4))+C(-1e4))}function bG(a,b,c){a=a|0;b=b|0;c=c|0;return qs(a,b,c)|0}function ap(a,b,c){b=b-a|0;if(b){sh(c,a,b)}return b+c|0}function aM(a){return C(C(z[a+4252>>2]*C(19980))+C(20))}function _4(a,b){a=a|0;b=b|0;return VF(a,Jb(b),Ab(b))|0}function Ww(a){a=a|0;v[a>>2]=88900;wG(a+4|0);return a|0}function PG(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Jn(b)}}function Kp(a){var b=0;b=v[a+8>>2];v[a+8>>2]=0;return b}function Kc(a){if(De(a)){a=ck(a)-1|0}else{a=10}return a}function Jd(a,b,c){return a>>>0<b>>>0?b:a>>>0>c>>>0?c:a}function JD(a){if(w[a+1|0]==2){return w[a|0]<3}return 0}function IC(a,b,c){a=a|0;b=b|0;c=c|0;return xD(a,b,c)|0}function Et(a){a=a|0;v[a>>2]=55444;Gt(a+4|0);return a|0}function CU(a){a=a|0;v[a>>2]=18876;gc(a+4|0);return a|0}function Bs(a){a=a|0;v[a>>2]=88920;wG(a+4|0);return a|0}function Aj(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){AL(b)}}function x$(a){a=a|0;a=kb[a|0]()|0;ma(jb|0);return a|0}function tM(a){a=a|0;return Gj(C(z[a+4224>>2]*C(4)))|0}function sw(a,b){a=mqa(v[a>>2],v[a+4>>2],b,0);return a}function qj(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function nh(a){var b=0;b=mt(a);v[a+1396>>2]=0;return b}function lI(a){a=a|0;return Xs(v[v[a>>2]-12>>2]+a|0)|0}function g4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Bj(a,c,d)}function eq(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function d5(a){a=a|0;return hq(v[v[a>>2]-12>>2]+a|0)|0}function cq(a){if(De(a)){a=ck(a)-1|0}else{a=1}return a}function bS(a,b){u[a+20>>1]=x[a+20>>1]&768|b&255;NA(a)}function b5(a){a=a|0;return tf(v[v[a>>2]-12>>2]+a|0)|0}function aQ(a,b){a=a|0;b=b|0;return y[a+12>>2]>b>>>0|0}function aI(a){a=a|0;return Vs(v[v[a>>2]-12>>2]+a|0)|0}function _K(a,b){a=a|0;b=b|0;v[v[a+24>>2]+480272>>2]=b}function Qg(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+20>>2]](a,b)}function Ph(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+24>>2]](a,b)}function Oh(a,b){a=a|0;b=b|0;kb[v[v[b>>2]+28>>2]](a,b)}function Oga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function Nq(a,b){v[a>>2]=b;v[a+4>>2]=b+223232;return a}function Lca(a,b,c){a=a|0;b=b|0;c=c|0;Wd(a,b+4228|0,7)}function Lb(a,b,c){return(a|0)<(b|0)?b:(a|0)>(c|0)?c:a}function G_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Uj(a,d,0)}function E2(a,b){a=a|0;b=b|0;pd(a,bI(v[b>>2]),v[b>>2])}function Cda(a,b,c){a=a|0;b=b|0;c=c|0;Wd(a,b+4260|0,8)}function yca(a){a=a|0;return C(C(z[a+4232>>2]*C(20)))}function wo(a){a=a|0;return kb[v[v[a>>2]+24>>2]](a)|0}function vb(a){if(De(a)){al(a,v[a>>2],ck(a))}return a}function tD(a){var b=0;b=gb-16|0;gb=b;Kk(a);gb=b+16|0}function pda(a){a=a|0;t[a+4202|0]=1;Mt(a);Ry(a);PM(a)}function os(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+36}function oj(a){a=a|0;return kb[v[v[a>>2]+12>>2]](a)|0}function oi(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+24}function nj(a){a=a|0;return kb[v[v[a>>2]+16>>2]](a)|0}function nf(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function jf(a,b,c){a=a|0;b=b|0;c=c|0;Vo(a);return a|0}function ij(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+12}function Wja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function Rn(a,b){return kb[v[v[a>>2]+36>>2]](a,b,0)|0}function Qn(a,b){return kb[v[v[a>>2]+52>>2]](a,b,0)|0}function JK(a){a=a|0;return sq(v[a+24>>2]+484344|0)|0}function Hc(a){if(De(a)){Wh(a,v[a>>2],ck(a))}return a}function $l(a,b){a=a|0;b=b|0;return Oe(a)>>>0>b>>>0|0}function yn(a,b,c){a=a|0;b=b|0;c=c|0;u[b>>1]=x[c>>1]}function wP(a){if(v[a>>2]){Nd(a);tP(v[a>>2],pg(a))}}
function vea(a,b){a=a|0;b=b|0;a=a+24|0;LN(a,b);Oz(a)}function uM(a){a=a|0;return C(C(z[a+4216>>2]*C(10)))}function pq(a,b,c){a=a|0;b=b|0;c=c|0;z[b>>2]=z[c>>2]}function lqa(a){if(a){return 31-E(a-1^a)|0}return 32}function _p(a,b){b=v[b>>2];v[a>>2]=b;Kn(b);return a}
function Wba(a){a=a|0;return C(C(z[a+4232>>2]*C(4)))}function WK(a){a=a|0;return v[v[a+24>>2]+1074416>>2]}function RK(a){a=a|0;return v[v[a+24>>2]+1074424>>2]}function Go(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2]}function xl(a){a=a|0;return x[v[a+24>>2]+480192>>1]}function x6(a,b,c){a=a|0;b=b|0;c=c|0;DJ(a-88|0,b,c)}function uB(a){t[a+6|0]=0;u[a+4>>1]=65535;v[a>>2]=0}function u6(a,b,c){a=a|0;b=b|0;c=c|0;BJ(a-88|0,b,c)}function ts(a,b){a=a|0;b=b|0;return Dp(a,b,Lf(b))|0}function qX(a){a=a|0;return fz(w[a+3|0],w[a+5|0])|0}function po(a,b,c){if(!c){return 0}return yd(a,b,c)}function io(a){a=a|0;return x[v[a+24>>2]+480188>>1]}function hs(a){if(v[a>>2]){Nd(a);yF(v[a>>2],pg(a))}}function gq(a){a=a|0;return x[v[a+24>>2]+480190>>1]}function ct(a){if(!a){return 0}v[115121]=a;return-1}function bp(a){if(v[a>>2]){Nd(a);uW(v[a>>2],tW(a))}}function b9(a){a=a|0;a=v[a+4>>2];return(a?a:2107)|0}function au(a){v[a>>2]=38732;v[a>>2]=18704;return a}function ai(a){if(v[a>>2]){Nd(a);eC(v[a>>2],ye(a))}}function aR(a){if(v[a>>2]){Nd(a);VQ(v[a>>2],sA(a))}}function ZT(a){if(v[a>>2]){Nd(a);Mu(v[a>>2],qg(a))}}function ZK(a){a=a|0;return v[v[a+24>>2]+480272>>2]}function Yja(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,ts(b,c))}function Wd(a,b,c){v[a>>2]=b;v[a+4>>2]=b+c;return a}function Rha(a){a=a|0;Zm(90592);ZA(90584);vb(90572)}function QK(a){a=a|0;return x[v[a+24>>2]+480214>>1]}function PR(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function O5(a,b){a=a|0;b=b|0;return VF(a,b,Lf(b))|0}function Mq(a){a=a|0;return ju(w[a+2|0],w[a+4|0])|0}function Ku(a){if(v[a>>2]){Nd(a);tB(v[a>>2],$h(a))}}function Iu(a){if(v[a>>2]){Nd(a);qB(v[a>>2],rB(a))}}function Ip(a){a=a|0;a=cc(a);kb[v[v[a>>2]>>2]](a)|0}function Hu(a){if(v[a>>2]){Nd(a);sB(v[a>>2],si(a))}}function Gl(a){if(v[a>>2]){Nd(a);GO(v[a>>2],ye(a))}}function Fv(a){if(v[a>>2]){Nd(a);EY(v[a>>2],Lg(a))}}function Eo(a){a=a|0;return ju(w[a+3|0],w[a+5|0])|0}function Db(a,b,c){pd(a,(c>>>3&536870908)+b|0,1<<c)}function Cd(a){if(v[a>>2]){LY(a);kD(v[a>>2],Wi(a))}}function Bea(a,b){a=a|0;b=b|0;dk(a+36|0,b);return 1}function $k(a,b){Je(a,b);Qb(a+20|0,0,1040);return a}function $d(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function zC(a,b,c){Wd(a,v[b+28>>2]+(c<<12)|0,4096)}function z6(a,b,c){a=a|0;b=b|0;c=+c;FJ(a-88|0,b,c)}function w6(a,b){a=a|0;b=b|0;return CJ(a-88|0,b)|0}function t6(a,b){a=a|0;b=b|0;return AJ(a-88|0,b)|0}function pn(a){a=(a|0)<120?a:120;return(a|0)>1?a:1}function hC(a,b,c){u[a>>1]=x[b>>1];t[a+2|0]=w[c|0]}function fp(a){return(v[a+480180>>2]&740327453)!=0}function dl(a,b,c){a=a|0;b=b|0;c=c|0;t[b|0]=w[c|0]}function XP(a){return v[a+16>>2]!=(0-v[a+20>>2]|0)}function Wt(a){a=a|0;Ih(a);v[a+20>>2]=0;return a|0}function Rj(a,b,c){v[a>>2]=v[b>>2];t[a+4|0]=w[c|0]}function RC(a,b,c){return a>>>0<c>>>0&a>>>0>=b>>>0}function Pl(a){a=a+170|0;return w[a|0]|w[a+1|0]<<8}function Ot(a,b,c){a=a|0;b=b|0;c=c|0;Dc(a,RG(b,c))}function Km(a){Dj(a+724|0);Dj(a+732|0);Dj(a+740|0)}function Io(a){a=a+168|0;return w[a|0]|w[a+1|0]<<8}function Ij(a){a=a+158|0;return w[a|0]|w[a+1|0]<<8}function yna(a,b){a=a|0;b=b|0;if(!pW(a,b)){oW(b)}}function tW(a){return(v[wb(a)>>2]-v[a>>2]|0)/33|0}function rg(a,b){return fG(Jb(a),Ab(a),b,0,Lf(b))}function qg(a){return(v[wb(a)>>2]-v[a>>2]|0)/12|0}function pd(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function on(a){return(v[wb(a)>>2]-v[a>>2]|0)/48|0}function nJ(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function mk(a){return(v[wb(a)>>2]-v[a>>2]|0)/52|0}function hma(a,b){a=a|0;b=b|0;if(!Nv(a,b)){Ov(b)}}function gh(a,b){if(De(a)){ee(a,b);return}Ve(a,b)}function bna(a,b){a=a|0;b=b|0;if(!dF(a,b)){tw(b)}}function av(a){return(v[wb(a)>>2]-v[a>>2]|0)/24|0}function am(a){return(v[wb(a)>>2]-v[a>>2]|0)/20|0}function _e(a,b,c){a=a|0;b=b|0;c=c|0;nf(a,c,32,b)}function Yk(a){return(v[wb(a)>>2]-v[a>>2]|0)/36|0}function Wi(a){return(v[wb(a)>>2]-v[a>>2]|0)/28|0}function Vm(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function Vj(a,b,c){a=a|0;b=b|0;c=c|0;nf(a,c,20,b)}function RI(a,b){if(!a){return 0}return sl(a,b,0)}function PC(a,b,c){a=a|0;b=b|0;c=c|0;nf(a,c,40,b)}function Mk(a,b,c){a=a|0;b=b|0;c=c|0;nf(a,c,22,b)}function Lp(a){return(v[cc(a)>>2]-v[a>>2]|0)/12|0}function Kv(a,b,c){a=a|0;b=b|0;c=c|0;nf(a,c,30,b)}function Hr(a,b,c){a=a|0;b=b|0;c=c|0;nf(a,c,64,b)}function Hk(a,b,c){a=a|0;b=b|0;c=c|0;nf(a,c,28,b)}function He(a,b){a=a|0;b=b|0;return(a|0)==(b|0)|0}function Gk(a,b,c){a=a|0;b=b|0;c=c|0;nf(a,c,12,b)}function GY(a){return(v[cc(a)>>2]-v[a>>2]|0)/28|0}function Epa(a,b){a=a|0;b=b|0;if(!_X(a,b)){xv(b)}}function DU(a){return(v[wb(a)>>2]-v[a>>2]|0)/56|0}function Cp(a,b,c){a=a|0;b=b|0;c=c|0;nf(a,c,26,b)}function Cb(a){return(v[a+4>>2]&v[v[a>>2]>>2])!=0}function AW(a,b,c){a=a|0;b=b|0;c=c|0;nf(a,c,16,b)}function $ea(a,b){a=a|0;b=b|0;if(!HF(a,b)){Aw(b)}}function zpa(a,b,c){a=a|0;b=b|0;c=c|0;hc(b,c,48)}function yK(a,b,c){a=Sd(a);v[a+4>>2]=c;v[a>>2]=b}function yA(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0}function y6(a,b){a=a|0;b=b|0;return+EJ(a-88|0,b)}function wy(a,b){v[a>>2]=v[b>>2];Dc(a+4|0,b+4|0)}function uZ(a,b){a=a|0;b=b|0;if(!AD(a,b)){yD(b)}}function uY(a,b){a=iY(a,b);if(!a){ZC(b)}return a}function sy(a,b,c){return ir(a,b,v[a+12>>2]+c|0)}function sA(a){return(v[wb(a)>>2]-v[a>>2]|0)/7|0}function qy(a,b,c){return Ug(a,b,v[a+12>>2]+c|0)}function qr(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function nea(a,b){a=a|0;b=b|0;kE(a,b);return a|0}function mC(a,b){a=a|0;b=b|0;if(!dW(a,b)){bW(b)}}function lz(a){return B(Ij(a),Pl(a))+7>>>3&65535}function ki(a){return(Qf(a)|0)!=(0-Qf(a+12|0)|0)}function gX(a,b){a=a|0;b=b|0;return Rt(a,b,32)|0}function fo(a,b,c){return HV(a,b,v[a+12>>2]+c|0)}function a4(a,b){a=a|0;b=b|0;return kb[b|0](a)|0}function Yba(a){a=a|0;return z[a+4212>>2]<C(1)|0}function YX(a,b){a=a|0;b=b|0;if(!UX(a,b)){XC(b)}}function Vg(a){a=w[a+20|0];return(a|0)==255?-1:a}function VA(a,b,c){t[a|0]=w[b|0];t[a+1|0]=w[c|0]}function Sj(a){return(v[wb(a)>>2]-v[a>>2]|0)/6|0}function Ol(a){a=a|0;Xq(v[a+20>>2]);v[a+20>>2]=0}function NA(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function Ki(a){return v[a+8>>2]!=0|v[a+12>>2]!=0}function KS(a,b){yc(a,v[b>>2]);t[a+4|0]=w[b+4|0]}function Jb(a){if(De(a)){return v[a>>2]}return a}function HR(a){return(v[a+4>>2]-v[a>>2]|0)/872|0}function GD(a,b){a=a|0;b=b|0;if(!xF(a,b)){wF(b)}}function Dr(a,b){a=a|0;b=b|0;if(!as(a,b)){ak(b)}}function CY(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0]}function Aca(a){a=a|0;return z[a+4220>>2]<C(1)|0}function $ja(a){a=a|0;a=gb-a&-16;gb=a;return a|0}function yu(a,b){a=a|0;b=b|0;cg(a,b);return a|0}function sca(a){a=a|0;t[a+4202|0]=1;rM(a);sM(a)}function rx(a,b,c,d){a=GI(a,b,c,-1,-1);return a}function rl(a){a=a|0;return hI(v[a>>2])<<24>>24}function nn(a,b,c){v[a>>2]=b;v[a+4>>2]=(c<<1)+b}function jv(a){return(v[a+4>>2]-v[a>>2]|0)/33|0}function jo(a){return(v[a+4>>2]-v[a>>2]|0)/24|0}function jca(a){a=a|0;t[a+4202|0]=1;nM(a);mM(a)}function hn(a,b,c){b=b-a|0;if(b){sh(c-b|0,a,b)}}function el(a){return kb[v[v[a>>2]+36>>2]](a)|0}function dr(a){return(v[a+4>>2]-v[a>>2]|0)/56|0}function Zk(a){return(v[a+4>>2]-v[a>>2]|0)/36|0}function Ze(a){return(v[a+4>>2]-v[a>>2]|0)/20|0}function Yn(a){return kb[v[v[a>>2]+28>>2]](a)|0}function Wm(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function VU(a,b){a=a|0;b=b|0;return Nk(a,b,8)|0}function Tj(a){return(v[a+4>>2]-v[a>>2]|0)/48|0}function Pf(a,b){a=a|0;b=b|0;return Tc(a,b,0)|0}function Op(a,b){a=a|0;b=b|0;return(b-a|0)/12|0}function Of(a){return(v[a+4>>2]-v[a>>2]|0)/52|0}function Mr(a,b){a=a|0;b=b|0;return Nk(a,b,7)|0}function MV(a){var b=0;b=v[a>>2];Me(a);return b}function Fh(a,b){a=a|0;b=b|0;return Nk(a,b,4)|0}function Fba(a){a=a|0;cM(a);Ly(a);t[a+4202|0]=1}function Ch(a){return(v[a+4>>2]-v[a>>2]|0)/28|0}function Cc(a){return(v[a+4>>2]-v[a>>2]|0)/12|0}function xu(a){return(a>>>0<9?a:a-9|256)&65535}function wl(a){return(v[a+4>>2]+v[a>>2]|0)-1|0}function wA(a){return(v[a+4>>2]-v[a>>2]|0)/7|0}function sf(a,b,c){if(!(w[a|0]&32)){VC(b,c,a)}}function eS(a,b){$R(v[a>>2],b);$R(v[a+4>>2],b)}function dp(a){a=a|0;return(w[a+1|0]==1?1:2)|0}function bc(a,b,c){a=a|0;b=b|0;c=c|0;Wd(a,b,c)}function WR(a){IA(a);Qb(a+27|0,0,255);return a}function UC(a){return v[a>>2]+(v[a+4>>2]<<2)|0}function St(a,b){return(v[a>>2]-v[b>>2]|0)/6|0}function Sn(a,b,c){a=a|0;b=b|0;c=c|0;pd(a,b,c)}function Sl(a,b){return(B(b,104)+a|0)+484380|0}function Qj(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function Ld(a){return v[a+20>>2]!=0&v[a>>2]!=0}function Jp(a){LF(a);v[a+8>>2]=0;v[a>>2]=78796}function I8(a,b){a=a|0;b=b|0;Dc(a,ts(b,14705))}function Hi(a){a=a|0;return x[ro(a)+480188>>1]}function Eg(a){return(v[a+4>>2]-v[a>>2]|0)/6|0}function A4(a,b,c){a=a|0;b=b|0;c=c|0;pd(a,c,b)}function yma(a){a=a|0;PV(a);return v[a+16>>2]}function vK(a){a=a|0;v[a>>2]=55668;return a|0}function tc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function tK(a){a=a|0;v[a>>2]=55812;return a|0}function sm(a,b){a=a|0;b=b|0;return dI(a,b)^1}function sg(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function pqa(a,b,c,d){a=kqa(a,b,c,d);return a}function oF(a){a=a|0;v[a>>2]=28424;return a|0}function mi(a,b){a=a|0;b=b|0;return Mc(b,1)|0}function ll(a,b){a=a|0;b=b|0;return dI(a,b)|0}function lY(a){t[a+12|0]=w[a+12|0]|2;return a}function kt(a,b){a=a|0;b=b|0;return RG(a,b)|0}function kg(a,b){a=a|0;b=b|0;return Xl(a,b)|0}function kI(a){a=a|0;Jx(v[v[a>>2]-12>>2]+a|0)}function ik(a,b){a=a|0;b=b|0;return jI(a,b)^1}function ii(a,b){a=a|0;b=b|0;return ew(a,b)|0}function hk(a,b){a=a|0;b=b|0;return jI(a,b)|0}function fi(a,b){a=a|0;b=b|0;return fU(a,b)|0}function cQ(a,b){if(!(z[a>>2]<=b)){z[a>>2]=b}}function c5(a){a=a|0;WH(v[v[a>>2]-12>>2]+a|0)}function a5(a){a=a|0;VH(v[v[a>>2]-12>>2]+a|0)}function Zj(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function Xl(a,b){a=a|0;b=b|0;return Jk(a,b)^1}function XG(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function TP(a){wP(a+20|0);vP(a+8|0);uP(a+4|0)}function Sd(a){v[a>>2]=0;v[a+4>>2]=0;return a}function Nw(a,b){a=a|0;b=b|0;return ts(a,b)|0}function KF(a){a=a|0;v[a>>2]=27976;return a|0}function JX(a,b){a=a|0;b=b|0;pd(a,b,b- -64|0)}function Fy(a){a=a|0;v[a>>2]=55276;return a|0}function Fj(a){return(w[a+31|0]-1&255)>>>0<17}function Cl(a){return v[wb(a)>>2]-v[a>>2]>>11}function CW(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function BF(a){a=a|0;v[a>>2]=28200;return a|0}function $H(a){a=a|0;Gx(v[v[a>>2]-12>>2]+a|0)}function zca(a){a=a|0;return C(z[a+4212>>2])}function ye(a){return v[wb(a)>>2]-v[a>>2]>>2}function si(a){return v[wb(a)>>2]-v[a>>2]>>4}function sF(a){return v[cc(a)>>2]-v[a>>2]>>3}function rB(a){return v[wb(a)>>2]-v[a>>2]>>8}function qu(a,b,c){a=a|0;b=b|0;c=c|0;HY(b,c)}function pk(a){return v[cc(a)>>2]-v[a>>2]>>2}function pg(a){return v[wb(a)>>2]-v[a>>2]>>3}function ow(a){return v[cc(a)>>2]-v[a>>2]>>1}function oB(a){return v[cc(a)>>2]-v[a>>2]>>5}function nma(a){a=a|0;return Nk(a,11016,2)|0}function nG(a){a=Ga(a|0)|0;jb=O()|0;return a}function jg(a){return v[v[a+8>>2]>>2]==(a|0)}function afa(a){a=a|0;return Nk(a,5752,15)|0}function _w(a){return v[cc(a)>>2]-v[a>>2]>>4}function Xba(a){a=a|0;return C(z[a+4220>>2])}function Uy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function UK(a){a=a|0;return TK(v[a+24>>2])|0}function To(a){a=a|0;eB(a+288|0);Uo(a+800|0)}function TC(a,b,c){a=a|0;b=b|0;c=c|0;Je(b,c)}function My(a){return C(C(a*C(7900))+C(100))}function Mn(a,b,c){a=a|0;b=b|0;c=c|0;Dc(b,c)}function Lg(a){return v[wb(a)>>2]-v[a>>2]>>1}function JF(a,b){a=a|0;b=b|0;return(b|0)<6|0}function Hoa(a){a=a|0;return Nk(a,11991,3)|0}function Gf(a){return v[a+8>>2]-v[a+12>>2]|0}function Ama(a){a=a|0;PV(a);return v[a+4>>2]}function AL(a){if(a){kb[v[v[a>>2]+4>>2]](a)}}function $h(a){return v[wb(a)>>2]-v[a>>2]>>5}function $5(a){a=a|0;return Da(v[a+60>>2])|0}function zda(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function yM(a){a=a|0;kb[v[v[a>>2]+4>>2]](a)}function wM(a){a=a|0;return C(z[a+4208>>2])}function vf(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function qm(a){a=a|0;bI(v[a>>2]);return a|0}function ql(a){a=a|0;Ix(v[a>>2]);return a|0}function kK(a,b){a=a|0;b=b|0;return pc(b)|0}function jK(a,b){a=a|0;b=b|0;return Nb(b)|0}function hg(a){return v[wb(a)>>2]-v[a>>2]|0}function gka(a){a=a|0;return Nk(a,1024,6)|0}function gL(a){t[a+4|0]=0;t[a|0]=0;return a}function dS(a,b){u[a+22>>1]=b&7;NA(a);OA(a)}function cr(a){return jr(v[a>>2],v[a+4>>2])}function _o(a,b){return v[a>>2]<v[b>>2]?b:a}function _ca(a,b,c){a=a|0;b=b|0;c=c|0;Sd(a)}function _5(a,b){a=a|0;b=b|0;return Sh(a)|0}function Xt(a,b,c){b=b-a|0;if(b){sh(c,a,b)}}function Qf(a){return v[a+4>>2]-v[a>>2]>>11}function OL(a){return Xh(C(QL(a)*C(32768)))}function MH(a){GK(a);v[a>>2]=77228;return a}function K_(a,b){a=a|0;b=b|0;EF(Qb(b,0,36))}function Gi(a,b){a=a|0;b=b|0;return C(C(0))}function Bt(a){GK(a);v[a>>2]=77156;return a}function BG(a){return v[a+16>>2]-v[a>>2]>>2}function zw(a){js(a+32|0);yb(a+12|0);vb(a)}function tp(a,b){return v[a>>2]-v[b>>2]>>1}function tH(){return(v[v[22545]>>2]?4:1)|0}function sc(a){return v[a+4>>2]-v[a>>2]>>1}function qf(a){return v[a+4>>2]-v[a>>2]>>4}function qea(a,b){a=a|0;b=b|0;cg(a,b+36|0)}function px(a){a=a|0;return Nh(a,464028)|0}function of(a){return v[a+4>>2]-v[a>>2]>>3}function oD(a){a=a|0;return Nh(a,465776)|0}function o5(a){a=a|0;return Nh(a,463824)|0}function jx(a){a=a|0;return Nh(a,464036)|0}function gv(a,b){return v[a>>2]-v[b>>2]>>2}function gl(a,b){kb[v[v[b>>2]+44>>2]](a,b)}function fl(a,b){kb[v[v[b>>2]+32>>2]](a,b)}function cqa(a,b){a=a|0;b=b|0;dk(a+12|0,b)}function ck(a){return v[a+8>>2]&2147483647}function cS(a,b){t[a+21|0]=b&3;NA(a);OA(a)}function ar(a,b){a=a|0;b=b|0;return b-a>>1}function ah(a){return v[a+4>>2]-v[a>>2]>>8}function XK(a){a=a|0;return+aP(v[a+24>>2])}function UL(a){return C(C(a*C(96))+C(-96))}function Su(a){Ce(a+24|0);gc(a+12|0);gc(a)}function Q6(a,b){a=a|0;b=b|0;$Q(v[a>>2],b)}function P_(a){a=a|0;return v[a+4>>2]!=0|0}function Nb(a){return v[a+4>>2]-v[a>>2]>>2}function NT(a,b){return v[a>>2]+B(b,872)|0}function Hx(a){a=a|0;return Nh(a,463988)|0}function Hm(a){vb(a+36|0);Lc(a+24|0);kn(a)}function Ex(a){a=a|0;return Nh(a,463996)|0}function Es(a,b){kb[v[v[b>>2]+40>>2]](a,b)}function D5(a){a=a|0;return Nh(a,463808)|0}function Bfa(a,b){a=a|0;b=b|0;dk(a+40|0,b)}function Ax(a){a=a|0;return Nh(a,464004)|0}function Ae(a){return v[a+4>>2]-v[a>>2]>>5}function yW(a,b){return v[a>>2]+B(b,33)|0}function xd(a,b){return v[a>>2]+B(b,12)|0}function ro(a){return v[v[a+48>>2]+12>>2]}function rm(a){a=a|0;return cI(v[a>>2])|0}function r6(a,b){a=a|0;b=b|0;yJ(a-88|0,b)}function pc(a){return v[a+4>>2]-v[a>>2]|0}function pS(a){v[a>>2]=v[a>>2]-2;return a}function oy(a){a=a|0;Ct(a+8|0);return a|0}function mf(a){v[a>>2]=v[a>>2]+2;return a}function fy(a){a=a|0;if(a){lJ(a);he(a,a)}}function ei(a){return x[a+480190>>1]<3999}function eO(a,b){Vm(a,A[b>>3],-A[b+8>>3])}function cn(a,b){return v[a>>2]+B(b,56)|0}function aF(a){return(w[a+24|0]&16)>>>4|0}function Xs(a){a=a|0;lh(a+8|0);return a|0}function Xn(a,b,c){Bj(a,b,b+c|0);return a}function Xj(a,b){return v[a>>2]-v[b>>2]|0}function Xg(a){v[a>>2]=v[a>>2]+4;return a}function Vt(a,b){return v[a>>2]+B(b,28)|0}function Vs(a){a=a|0;lh(a+4|0);return a|0}function Ul(a,b){return v[a>>2]+B(b,24)|0}function Uja(a){a=a|0;return $r(a+20|0)|0}function TL(a){a=a|0;Qb(a+4296|0,0,81928)}function T0(a,b){a=a|0;b=b|0;cg(a,b+16|0)}function RG(a,b){return Dp(a,Jb(b),Ab(b))}function Mca(a){a=a|0;t[a+4202|0]=1;CM(a)}function Lj(a,b){return v[a>>2]+B(b,36)|0}function KI(a,b){t[a|0]=b+48;return a+1|0}function IK(a,b){a=a|0;b=b|0;cg(a,b+12|0)}function I6(a,b){a=a|0;b=b|0;NJ(a-88|0,b)}function Hg(a,b){return v[a>>2]+B(b,20)|0}function H6(a,b){a=a|0;b=b|0;MJ(a-88|0,b)}function Gn(a,b){return v[a>>2]+(b<<11)|0}function Fo(a,b,c){return a<b?b:C(F(a,c))}function Fd(a,b){v[a>>2]=v[b>>2];return a}function Ec(a,b){a=a|0;b=b|0;_p(a,b+28|0)}function Dba(a){a=a|0;return v[a+4260>>2]}function $e(a,b){return v[a>>2]+B(b,52)|0}function ze(a,b){return v[a>>2]+(b<<3)|0}function zE(a,b){return v[a>>2]+(b<<5)|0}function yda(a){a=a|0;return w[a+4201|0]}function xm(a){return(a|0)==32|a-9>>>0<5}function xg(a){a=a|0;return SP(w[a|0])|0}function xda(a){a=a|0;return w[a+4202|0]}function wna(a,b){a=a|0;b=b|0;Rt(a,b,17)}function rla(a,b){a=a|0;b=b|0;Ok(a,b,10)}function rc(a,b){return v[a>>2]+(b<<1)|0}function qna(a,b){a=a|0;b=b|0;Ok(a,b,17)}function oL(a){return(Jb(a)+Ab(a)|0)-1|0}function ng(a,b){v[a+8>>2]=b|-2147483648}function gba(a){a=a|0;return(a|0)==277|0}function fj(a){return B(ej(a),bd(a))&255}function _c(a,b){return v[a>>2]+B(b,6)|0}function Vl(a){a=a|0;return v[a>>2]+14|0}function Us(a,b){v[a+24>>2]=v[a+24>>2]+b}function Upa(a,b){a=a|0;b=b|0;Ok(a,b,44)}function Tf(a){a=a|0;return!v[a+16>>2]|0}function R0(a,b){a=a|0;b=b|0;$w(a,83624)}function Ql(a,b){return v[a>>2]+(b<<8)|0}function Qc(a,b){return v[a>>2]+(b<<4)|0}function PF(a,b){jc(a,b);jc(a+4|0,b+4|0)}function P0(a,b){a=a|0;b=b|0;$w(a,83644)}function Mb(a,b){return v[a>>2]+(b<<2)|0}function M6(a){a=a|0;return oy(a-88|0)|0}function LF(a){v[a+4>>2]=0;v[a>>2]=78740}function Jk(a,b){return v[a>>2]==v[b>>2]}function HM(a){return(w[a+24|0]&8)>>>3|0}function Gb(a,b){return v[a>>2]!=v[b>>2]}function G6(a,b){a=a|0;b=+b;LJ(a-88|0,b)}function E6(a,b){a=a|0;b=+b;JJ(a-88|0,b)}function Dj(a){u[a+4>>1]=65535;v[a>>2]=0}function C6(a,b){a=a|0;b=+b;HJ(a-88|0,b)}function $c(a){return v[a>>2]==v[a+4>>2]}function $b(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function zi(a,b,c){Dc(a,b);Dc(a+12|0,c)}function xX(a,b){v[a>>2]=v[a>>2]+B(b,6)}function uF(a,b){bc(a,v[b>>2],of(b)<<3)}function rS(a,b){v[a>>2]=v[a>>2]+(b<<1)}function pZ(a,b){a=a|0;b=b|0;Rt(a,b,11)}function oba(a){a=a|0;return-2013527448}function oY(a,b){a=a|0;b=b|0;return b|0}function mw(a,b){a=a|0;b=b|0;hw(a,b,32)}function jT(a,b){return A[a>>3]<A[b>>3]}function he(a,b){if(!v[a+80>>2]){Zb(b)}}function ela(a,b){a=a|0;b=b|0;Ok(a,b,5)}function cH(a,b){a=a|0;b=b|0;Ge(a,1,45)}function bH(a,b){a=a|0;b=b|0;rI(a,1,45)}function YJ(a){v[a+4>>2]=v[a+4>>2]|8192}function Xq(a){a=a|0;if(a){Zb(a+-64|0)}}function VV(a,b){v[a>>2]=v[a>>2]+(b<<2)}function SE(a,b){a=a|0;b=b|0;Ok(a,b,32)}function S0(a,b){a=a|0;b=b|0;Tb(a,8620)}function Q0(a,b){a=a|0;b=b|0;Tb(a,8737)}function PP(a,b){return(Nl(a,b)|0)!=255}function Ou(a,b){return v[a>>2]<v[b>>2]}function Kj(a,b){return u[a>>1]<u[b>>1]}function Ir(a,b,c){if(b){Qb(a,Ig(c),b)}}function Ib(a){return(a<<8|a>>>8)&65535}function Fn(a,b){return x[a>>1]<x[b>>1]}function Ed(a,b){return y[a>>2]<y[b>>2]}function Dna(a,b){a=a|0;b=b|0;vD(a,b,8)}function $u(a,b){return z[a>>2]<z[b>>2]}function $Y(a,b){a=a|0;b=b|0;Ok(a,b,11)}function xh(a){a=+a;return hr(fe(a))|0}function wS(a,b){v[a+4>>2]=b;v[a>>2]=b}function vba(a){a=a|0;return 302837129}function v_(a){a=a|0;return v[a+16>>2]}function un(a,b){a=a|0;b=b|0;bc(a,b,7)}function rca(a){a=a|0;return-285139079}function qA(a,b,c){return a<b?b:F(a,c)}function ls(a){Zk(a);UF(a);Yk(a);Zk(a)}function lZ(a){a=a|0;return v[a+12>>2]}function kk(a,b){return Jb(a)+(b<<2)|0}function kH(a,b,c){Fe(a,b);Fe(a+4|0,c)}function jq(a,b){a=a|0;b=b|0;wI(a,b,0)}function ica(a){a=a|0;return-284078960}function eba(a,b){a=a|0;b=b|0;return 3}function dda(a){a=a|0;return 542066252}function dba(a,b){a=a|0;b=b|0;return 2}function c8(a){a=a|0;return+A[a+16>>3]}function bd(a){return w[a+34|0]&64?2:1}function bca(a){a=a|0;return-281111764}function aZ(a){a=a|0;return v[a+24>>2]}function Zba(a){a=a|0;return-271958638}function Yi(a){return B(v[a>>2],fj(a))}function Yc(a){v[v[a+8>>2]>>2]=v[a>>2]}function Xr(a){a=a|0;return 2147483647}function QN(a,b){a=a|0;b=b|0;lk(a,0,b)}function QF(a,b){CH(a,b);v[a>>2]=89180}function Oba(a){a=a|0;return-620920304}function Ila(a){a=a|0;return w[a+40|0]}function IE(a){wb(a);return 2147483647}function Gja(a){a=a|0;ZS(a);return a|0}function F6(a){a=a|0;return+KJ(a-88|0)}function Eba(a){a=a|0;return-275227023}function D6(a){a=a|0;return+IJ(a-88|0)}function Bca(a){a=a|0;return-270114148}function BK(a){return a?(a|0)==2?3:2:1}function A6(a){a=a|0;return+GJ(a-88|0)}function yx(a){a=a|0;Bs(a);return a|0}function yka(a){a=a|0;return PT(a)|0}
function wt(a){a=a|0;return v[a+4>>2]}function ux(a){a=a|0;if(xH(a)){Zb(a)}}function np(a,b){u[a+8>>1]=b;return a}function my(a){a=a|0;return v[a+8>>2]}function lw(a){return w[a+21|0]>>>7|0}function lv(a){a=a|0;return Pb(a,1)^1}function lh(a){a=a|0;Dx(a);return a|0}function lH(a,b){return w[a|0]<w[b|0]}function jI(a,b){return UH(a)^UH(b)^1}function gs(a,b){a=a|0;b=b|0;return 1}function ej(a){return t[a+34|0]&1?2:1}function dI(a,b){return TH(a)^TH(b)^1}function _l(a){return(w[a+16|0]&5)!=0}function Zs(a,b){a=a|0;b=b|0;return-1}function YQ(a){a=a|0;wr(a);return a|0}function Wca(a,b){a=a|0;b=b|0;yu(a,b)}function TK(a){return x[a+1074448>>1]}function SH(a){a=a|0;yx(a);return a|0}function Rb(a){return zE(a,w[a+16|0])}function Qe(a,b){v[a+4>>2]=b;return a}function PJ(a){v[a>>2]=59836;return a}function Ona(a){a=a|0;return w[a+8|0]}function OE(a){return w[a+22|0]>>>7|0}function O4(a){a=a|0;return KH(a,0)|0}function N4(a){a=a|0;return KH(a,1)|0}function ML(a,b){a=a|0;b=b|0;return 0}function K4(a){a=a|0;return HH(a,0)|0}function Jj(a,b){return t[a|0]<t[b|0]}function J4(a){a=a|0;return HH(a,1)|0}function Dk(a){return v[a+1298364>>2]}function De(a){return w[a+11|0]>>>7|0}function zn(a,b){sc(a);WE(a,b);uE(a)}function tS(a,b){Ae(a);nS(a,b);mS(a)}function pfa(a){a=a|0;return Ii(a)|0}function nga(a){a=a|0;return hm(a)|0}function kd(a,b){return Gn(a+12|0,b)}function kM(a,b){a=a|0;b=b|0;Vf(a,b)}function jn(a,b){pc(a);gT(a,b);YS(a)}function hj(a){return v[a+4>>2]-36|0}function fh(a,b){a=a|0;b=b|0;YY(a,b)}function eoa(a){a=a|0;return Dk(a)|0}function dj(a,b){Nb(a);TO(a,b);gw(a)}function cG(a,b){a=a|0;b=b|0;Kt(a,b)}function aqa(a){a=a|0;return $r(a)|0}function YM(a,b,c){a=a|0;b=b|0;c=c|0}function YK(a){return v[a+4>>2]-48|0}function WZ(a,b){a=a|0;b=b|0;mq(a,b)}function Vf(a,b){a=a|0;b=b|0;cg(a,b)}function VO(a){return v[a+4>>2]-32|0}function V0(a){a=a|0;return t[a+8|0]}function Uu(a){return v[wb(a)>>2]<<5}function U0(a){a=a|0;return t[a+9|0]}function SP(a){return(a+5&255)>>>0<2}function RL(a){v[a>>2]=0;v[a+4>>2]=0}function Pr(a,b){a=a|0;b=b|0;vw(a,b)}function Nr(a,b){a=a|0;b=b|0;Xv(a,b)}function Nba(a){a=a|0;v[a+4224>>2]=0}function Kn(a){v[a+4>>2]=v[a+4>>2]+1}function KU(a){return v[a+4>>2]-56|0}function HU(a){return v[a+4>>2]-28|0}function HK(a){return v[a+4>>2]-12|0}function FN(a,b){Of(a);MO(a,b);CN(a)}function FC(a,b){Eg(a);UW(a,b);IW(a)}function AV(a,b){if(!oV(a,b)){mV(b)}}function yc(a,b){v[a>>2]=b;return a}function wfa(a,b){a=a|0;b=b|0;Hm(b)}function vfa(a,b){a=a|0;b=b|0;Dg(b)}function uo(a){return v[a+4>>2]-4|0}function uf(a){return v[a+24620>>2]}function uda(a,b){a=a|0;b=b|0;Sy(b)}function rea(a){a=a|0;Rt(a,18693,1)}function p2(){Yd(465248,Td(463792))}function o2(){Yd(465256,Td(463800))}function ny(a){a=a|0;return _l(a)|0}function n7(a){a=a|0;return mK(a)|0}function n2(){Yd(465264,Td(465776))}function m2(){Yd(465280,Td(463988))}function ln(a,b){return B(b,12)+a|0}function l2(){Yd(465288,Td(463996))}function kc(a,b){return v[a>>2]+b|0}function jha(a,b){a=a|0;b=b|0;Xm(b)}function j2(){Yd(465296,Td(464004))}function iu(a){return yo(a)<<24>>24}function i2(){Yd(465312,Td(464012))}function h2(){Yd(465320,Td(464020))}function gc(a){sv(a);mn(a);return a}function g2(){Yd(465328,Td(464028))}function f2(){Yd(465360,Td(464036))}function e_(a){a=a|0;return rf(a)|0}function e2(){Yd(465392,Td(463808))}function d2(){Yd(465400,Td(463816))}function c2(){Yd(465408,Td(463824))}function bm(a,b,c){if(c){sh(a,b,c)}}function b2(){Yd(465416,Td(463832))}function ay(a){return!yd(a,89852,6)}function a2(){Yd(465424,Td(463872))}function _1(){Yd(465440,Td(463888))}function Z_(a){a=a|0;return og(a)|0}function ZE(a){a=a|0;return Kg(a)|0}function Z1(){Yd(465448,Td(463896))}function Yga(a,b){a=a|0;b=b|0;IR(b)}function YY(a,b){RH(a,v[a+16>>2]|b)}function Y1(){Yd(465456,Td(463904))}function X1(){Yd(465464,Td(463912))}function Wb(a){return bh(v[a+4>>2])}function W1(){Yd(465472,Td(463920))}function V_(a){a=a|0;return v[a>>2]}function V1(){Yd(465480,Td(463928))}function U1(){Yd(465488,Td(463840))}function Tja(a,b){a=a|0;b=b|0;Xd(b)}function Tga(a,b){a=a|0;b=b|0;Ce(b)}function T1(){Yd(465504,Td(463848))}function Sr(a){t[a+2|0]=0;u[a>>1]=0}function R1(){Yd(465520,Td(463856))}function QE(a){return w[a+21|0]&127}function Pna(a,b){a=a|0;b=b|0;Ik(b)}function PE(a){return w[a+22|0]&127}function P1(){Yd(465536,Td(463864))}function O1(){Yd(465552,Td(463936))}function Ng(a,b,c){if(c){hc(a,b,c)}}function NV(a,b){return we(a,0-b|0)}function N1(){Yd(465560,Td(463944))}function MZ(a){a=a|0;return hE(a)|0}function MC(a,b){return yX(a,0-b|0)}function M8(a){a=a|0;return ue(a)|0}function Bg(a,b,c){return ap(a,b,c)}function $1(){Yd(465432,Td(463880))}function zZ(a,b){a=a|0;b=b|0;Ih(b)}function yj(a){return $c(a+36|0)^1}function yZ(a,b){a=a|0;b=b|0;yb(b)}function xO(a){pd(a,0,-1);return a}function wB(a,b){a=a|0;b=b|0;Kf(b)}function uh(a,b){Vo(a);bf(a+4|0,b)}function ug(a,b){pd(a,Jb(b),Ab(b))}function ue(a){return v[a>>2]+16|0}function p6(a,b){a=a|0;b=b|0;Zb(b)}function ot(a){a=a|0;t[a+6152|0]=0}function o$(a){a=a|0;ko(a,1,10818)}function lo(a,b){v[a+1298424>>2]=b}function lK(a){return(Vg(a)|0)==-1}function km(a){Bm(a);v[a>>2]=88808}function kh(a,b){v[a>>2]=v[a>>2]|b}function kN(a,b){a=a|0;b=b|0;Vo(b)}function iK(a,b){a=a|0;b=b|0;ty(b)}function hK(a,b){a=a|0;b=b|0;Gl(b)}function ef(a,b){Vo(a);yc(a+4|0,b)}function eG(a,b){a=a|0;b=b|0;vb(b)}function dw(a,b){v[a>>2]=v[a>>2]+b}function aH(a){return Nh(a,463880)}function ZZ(a,b){a=a|0;b=b|0;Sr(b)}function ZG(a){return Nh(a,463896)}function YG(a){return Nh(a,463888)}function Uj(a,b,c){Wd(a,v[b>>2],c)}function Ud(a){LF(a);v[a>>2]=83880}function Ss(a){return He(a,-1)?0:a}function Rl(a,b){yp(a,b,v[b+4>>2])}function L_(a,b){a=a|0;b=b|0;zw(b)}function Kk(a){t[a|0]=0;t[a+1|0]=0}function Kh(a,b){a=a|0;b=b|0;Kb(a)}function Ej(a,b){return(b<<13)+a|0}function Ei(a){a=a|0;t[a+4202|0]=0}function EZ(a,b){a=a|0;b=b|0;Yv(b)}function BS(a,b){t[v[a>>2]]=w[b|0]}function AZ(a,b){a=a|0;b=b|0;Kk(b)}function $G(a){return Nh(a,463872)}function zy(a){return a+1298368|0}function yV(a,b){return Nk(a,b,5)}function xy(a){return Vg(a+120|0)}function xr(a,b){return ne(a,b)^1}function x4(a){a=a|0;return 10526}function vS(a){v[a>>2]=v[a>>2]+32}function tT(a,b){kB(a,b);return a}function sr(a){v[a>>2]=v[a>>2]+12}function sd(a,b){return(b<<1)+a|0}function sV(a,b){return(b<<4)+a|0}function rw(a){return t[a+24|0]&1}function ru(a,b,c){return vA(b,c)}function pp(a){v[a>>2]=v[a>>2]+28}function pU(a,b){return Pv(a,b,4)}function op(a){v[a>>2]=2;return a}function nla(a){a=a|0;iW(a,65535)}function mc(a,b){return Jb(a)+b|0}function jN(a,b,c){return Kj(b,c)}function fP(a){v[a>>2]=v[a>>2]+52}function cla(a){a=a|0;IU(a);Zb(a)}function ci(a,b){return(b<<2)+a|0}function aL(a){v[a>>2]=v[a>>2]+24}function a0(a){a=a|0;return 10412}function Zka(a){a=a|0;CU(a);Zb(a)}function Xi(a,b){Je(a,b);return a}function Wo(a){v[a>>2]=v[a>>2]+16}function Vd(a){return v[ec(a)>>2]}function Ui(a){v[a>>2]=0;return a}function Tw(a,b){return v[a+b>>2]}function Sh(a){return a-48>>>0<10}function Sb(a){return bh(v[a>>2])}function Qm(a){u[a>>1]=0;return a}function QT(a){return v[wb(a)>>2]}function Oe(a){return Of(a)&65535}function ND(a,b){return Pv(a,b,7)}function MD(a){return w[a+1|0]==1}function Ifa(a){a=a|0;yf(a,Qi(a))}function Hq(a){gc(a+4|0);return a}function Eh(a){v[a>>2]=1;return a}function EM(a){return w[a+4232|0]}function Dy(a,b){return jO(a,b)^1}function BC(a,b,c){return Fn(b,c)}function Ao(a){return a+1074328|0}function Ah(a){v[a>>2]=v[a>>2]+20}function zr(a){pc(a);ET(a);YS(a)}function zR(a){pg(a);of(a);pg(a)}function zL(a){a=a|0;Gy(a);Zb(a)}function wL(a,b,c,d){Ey(a,b,c,d)}function v4(a){a=a|0;return 7612}function uu(a){v[a>>2]=v[a>>2]+8}function tk(a){ye(a);Nb(a);ye(a)}function sv(a){hg(a);pc(a);hg(a)}function sn(a){sc(a);qw(a);uE(a)}function rA(a){t[a|0]=0;return a}function q4(a){a=a|0;return 3929}function oU(a){return w[a|0]<129}function nD(a){v[a>>2]=v[a>>2]+2}function lT(a){Wi(a);Ch(a);Wi(a)}function jW(a,b){hc(a,b+4|0,256)}function hB(a,b,c){dT(le(a,b),c)}function fM(a){a=a|0;Ny(a);Zb(a)}function f0(a,b){a=a|0;b=b|0;L()}function eN(a){Qf(a);XM(a);WM(a)}function e9(a){a=a|0;Fy(a);Zb(a)}function dY(a){on(a);Tj(a);on(a)}function cE(a){am(a);Ze(a);am(a)}function cD(a){Tj(a);rY(a);qY(a)}function b0(a){a=a|0;return 7005}function ax(a){si(a);qf(a);si(a)}function Z$(a){a=a|0;return 2812}function Yu(a){$h(a);Ae(a);$h(a)}function Wj(a){v[a>>2]=v[a>>2]+6}function TM(a){Cl(a);Qf(a);Cl(a)}function Qp(a){qg(a);Cc(a);qg(a)}function Qo(a,b){u[a>>1]=x[b>>1]}function PO(a){mk(a);Of(a);mk(a)}function OH(a){v[a+72>>2]=462824}function Np(a){a=a|0;Ww(a);Zb(a)}function NN(a){Eg(a);VW(a);IW(a)}function NH(a){v[a+72>>2]=462908}function Me(a){v[a>>2]=v[a>>2]+1}function LH(a){a=a|0;um(a);Zb(a)}function IH(a){a=a|0;bq(a);Zb(a)}function Fp(a){Lg(a);sc(a);Lg(a)}function Fg(a){v[a>>2]=v[a>>2]+4}function Fe(a,b){v[a>>2]=v[b>>2]}function Er(a){return Qb(a,0,48)}function EC(a){Sj(a);Eg(a);Sj(a)}function Cw(a){a=a|0;Bs(a);Zb(a)}function Cg(a){Nb(a);Dq(a);gw(a)}function Bl(a){a=a|0;hf(a);Zb(a)}function Bd(a){return v[a>>2]!=0}function BL(a,b,c,d){CL(a,b,c,d)}function AF(a){Yk(a);Zk(a);Yk(a)}function $4(a){a=a|0;return 7732}function yb(a){pe(a+12|0);pe(a)}function xx(a,b){return Wg(a,b)}function wO(a,b){return uO(a,b)}function v0(a){a=a|0;vb(464092)}function t0(a){a=a|0;Hc(464108)}function r0(a){a=a|0;vb(464124)}function qp(a,b){return as(a,b)}function pj(a,b){return a>>>b&1}function p0(a){a=a|0;Hc(464140)}function oh(a){return a<<24>>24}function nl(a,b,c){pd(a,b,1<<c)}function nk(a){return!v[a+4>>2]}function n0(a){a=a|0;vb(464156)}function l0(a){a=a|0;Hc(464172)}function kf(a,b){return Jg(a,b)}function jr(a,b){return WV(a,b)}function j0(a){a=a|0;vb(464188)}function iN(a,b){return Kj(a,b)}function h0(a){a=a|0;Hc(464204)}function cm(a,b){return FE(a,b)}function ag(a){return oh(Ig(a))}function _b(a,b){return $e(a,b)}function Yl(a){return Ev(sc(a))}function Yj(a,b,c){nf(a,c,13,b)}function Xm(a){vb(a+12|0);Ue(a)}function Xe(a){a=a|0;return a|0}function Th(a,b){return ci(a,b)}function SU(a,b){return Mj(b,a)}function Rr(a,b){return EE(a,b)}function Rm(a){vb(a+12|0);vb(a)}function Oo(a){return Ym(fe(a))}function Oi(a){return Ae(a)&255}function Nj(a,b){return zE(a,b)}function Md(a,b){return Gn(a,b)}function MW(a,b){pd(a,b,b+16|0)}function L6(a){a=a|0;OJ(a-88|0)}function Jq(a){AR(a+12|0);GR(a)}function Fs(a){a=a|0;return 127}function Ef(a){vb(a+20|0);vb(a)}function Dca(a){a=a|0;Zb(Ny(a))}function Cba(a){a=a|0;return 13}function Bq(a){u[a+480214>>1]=0}function AC(a,b){return Fn(a,b)}function zd(a,b){t[a|0]=w[b|0]}function yy(a,b){return b-a>>3}function y7(a){a=a|0;Zb(Et(a))}function u7(a){a=a|0;Zb(vK(a))}function t1(a){a=a|0;Zb(LG(a))}function r7(a){a=a|0;Zb(tK(a))}function r4(a){a=a|0;Zb(yx(a))}function qca(a){a=a|0;return 6}function qI(a){a=a|0;Zb(lh(a))}function pM(a){a=a|0;Zb(qM(a))}function k1(a){a=a|0;Zb(JG(a))}function ju(a,b){return a<<8|b}function gM(a){a=a|0;Zb(hM(a))}function f5(a){a=a|0;Zb(xt(a))}function dc(a,b){v[a+100>>2]=b}function c9(a){a=a|0;Zb(Gy(a))}function _t(a){return a>>>27^a}function _M(a){a=a|0;Zb($M(a))}function _L(a){a=a|0;Zb($L(a))}function _E(a){return a>>>0>16}function _$(a){a=a|0;Zb(Bs(a))}function XS(a){return a+4896|0}function X4(a){a=a|0;Zb(SH(a))}function X0(a){a=a|0;Zb(GG(a))}function WV(a,b){return b-a>>2}function WH(a){a=a|0;Zb(hq(a))}function W0(a){a=a|0;Zb(FG(a))}function VH(a){a=a|0;Zb(tf(a))}function U4(a){a=a|0;Zb(Dx(a))}function R_(a){a=a|0;Zb(KF(a))}function OJ(a){a=a|0;Zb(oy(a))}function N5(a){a=a|0;Zb(um(a))}function KM(a){a=a|0;Zb(LM(a))}function Jx(a){a=a|0;Zb(Xs(a))}function J5(a){a=a|0;Zb(bq(a))}function J1(a){a=a|0;Zb(OG(a))}function I_(a){a=a|0;Zb(BF(a))}function Gx(a){a=a|0;Zb(Vs(a))}function Gka(a){a=a|0;return 9}function GT(a){vB(Qb(a,0,872))}function FH(){return(db()|0)>0}function DG(a){a=a|0;Zb(Zw(a))}function C_(a){a=a|0;Zb(oF(a))}function A_(a){a=a|0;Zb(nF(a))}function AM(a){a=a|0;Zb(BM(a))}function $$(a){a=a|0;Zb(Ww(a))}function xM(a){a=a|0;return 7}function wr(a){Ui(a);return a}function wp(a){return a>>>0<5}function vk(a){return Bd(a)^1}function ul(a){return a+120|0}function te(a){a=a|0;return 1}function qe(a){a=a|0;return 2}function nc(a){Gg(a);return a}function nI(a){a=a|0;return-1}function mR(){return Mc(36,4)}function lc(a,b){return a+b|0}function lM(a){a=a|0;return 5}function ic(a){a=a|0;return 0}function hi(a){return $c(a)^1}function fU(a,b){return b-a|0}function eh(a){ad(a);return a}function bA(a){kF(a);return a}function af(a,b){u[a+28>>1]=b}function ad(a){mh(a);return a}function ZW(){return Mc(32,4)}function YB(){return Mc(20,4)}function Wv(a){return!v[a>>2]}function WU(a,b){bc(a,b,1108)}function VY(a,b){bc(a,b,1954)}function TS(a,b){Qb(a,0,b<<2)}function Pw(){return lb()<<16}function OW(a){Er(Qb(a,0,48))}function MB(a,b){bc(a,b,1024)}function Ko(a,b){v[a+36>>2]=b}function JU(a,b){nf(a,b,33,1)}function Iv(a){a=a|0;return 4}function I1(){_p(463972,SG())}function Ho(a){nc(a);return a}function Ft(a,b){v[a+32>>2]=b}function Cu(a){return a+256|0}function CR(a){Oj(a);return a}function $F(a){a=a|0;return 3}function $8(){return 19923012}function zq(a,b){z[a+8>>2]=b}function yY(a,b){bc(a,b,610)}function yN(a,b){mk(a);mk(a)}function xz(a,b){t[a+34|0]=b}function xq(a,b){z[a+4>>2]=b}function xU(a,b){bc(a,b,146)}function xE(a,b){bc(a,b,497)}function wz(a,b){t[a+32|0]=b}function wq(a,b){t[a+33|0]=b}function wX(a,b){bc(a,b,218)}function vz(a,b){t[a+35|0]=b}function vR(a){uR(a,v[a>>2])}function uX(a,b){bc(a,b,157)}function tt(a){v[a>>2]=56876}function tU(a,b){bc(a,b,608)}function t7(a){a=a|0;wK(a,1)}function sC(a,b){Sj(a);Sj(a)}function rY(a){hY(a,v[a>>2])}function qw(a){WE(a,v[a>>2])}function qD(a,b){bc(a,b,512)}function q7(a){a=a|0;Qu(a,1)}function pX(a,b){bc(a,b,576)}function p5(a){a=a|0;YY(a,1)}function oS(a){nS(a,v[a>>2])}function nV(a,b){bc(a,b,130)}function kV(a,b){bc(a,b,600)}function ip(a,b){wb(b);wb(a)}function iL(a){v[a>>2]=55524}function fK(a,b,c){oK(a,b,c)}function ee(a,b){v[a+4>>2]=b}function cp(a,b){v[a+8>>2]=b}function cc(a){return a+12|0}function cX(a){QG(a,v[a>>2])}function cV(a,b){bc(a,b,126)}function cT(a,b){bc(a,b,263)}function bY(a,b,c){Zl(a,b,c)}function aU(a,b){bc(a,b,204)}function Zc(a,b){a=a|0;b=b|0}function Yw(a){return a+32|0}function XM(a){UM(a,v[a>>2])}function Wr(a,b){Lg(a);Lg(a)}function Ve(a,b){t[a+11|0]=b}function VW(a){UW(a,v[a>>2])}function Ts(a,b){_p(a,b+4|0)}function TW(a,b){bc(a,b,674)}function SD(a,b){am(a);am(a)}function SA(a,b){$h(a);$h(a)}function QJ(a){v[a>>2]=59812}function Pp(a){return a+20|0}function OO(a){MO(a,v[a>>2])}function OM(a,b,c){oq(a,c,b)}function Nd(a){ee(a,v[a>>2])}function NO(a){return a+48|0}function NC(a,b){nf(a,b,8,2)}function Lw(a,b){qg(a);qg(a)}function Lu(a,b){hg(a);hg(a)}function Lm(a,b){ye(a);ye(a)}function Jr(a,b){bc(a,b,192)}function JM(a,b,c){nq(a,c,b)}function Hw(a,b){TF(a,$d(b))}function GK(a){v[a>>2]=78204}function FA(a,b){BR(a,$d(b))}function ET(a){gT(a,v[a>>2])}function EG(a,b){si(a);si(a)}function Dq(a){TO(a,v[a>>2])}function DW(a,b){bc(a,b,128)}function DM(a,b,c){ap(a,b,c)}function Br(a){v[a>>2]=19304}function Bm(a){v[a>>2]=88828}function zv(a,b){bc(a,b,66)}function zf(a,b){t[a+3|0]=b}function zD(a,b){bc(a,b,17)}function wb(a){return a+8|0}function uv(a,b){bc(a,b,22)}function qV(a,b){bc(a,b,30)}function pla(){return 65534}function oC(a,b){bc(a,b,33)}function md(a){return a+1|0}function jP(a){Qb(a,0,1024)}function fW(a,b){bc(a,b,52)}function ec(a){return a+4|0}function e0(){return 465784}function dd(a){return!Ab(a)}function dD(a,b){bc(a,b,64)}function cW(a,b){bc(a,b,80)}function bC(a,b){bc(a,b,40)}function aka(a){a=a|0;GT(a)}function aj(a){return a+3|0}function aV(a,b){bc(a,b,32)}function aE(a,b){bc(a,b,38)}function a9(){return 393216}function _r(a,b){bc(a,b,36)}function _D(a,b){bc(a,b,41)}function Zv(a,b){bc(a,b,16)}function Z5(){return 460484}function XX(a,b){bc(a,b,12)}function Uo(a){Qb(a,0,4096)}function UY(a){Qb(a,0,1954)}function UR(a,b){bc(a,b,27)}function Sy(a){Qb(a,0,2048)}function Re(a){return a+2|0}function Pfa(a){a=a|0;$z(a)}function OU(a,b){bc(a,b,96)}function ME(a,b){hw(a,b,22)}function Jla(){return gb|0}
function Ig(a){return a&255}function IF(a,b){bc(a,b,24)}function Gq(a){Qb(a,0,8192)}function Fja(a){a=a|0;Uo(a)}function EX(a,b){bc(a,b,98)}function DL(a){return 0-a|0}function DB(a){v[a+12>>2]=0}function CX(a,b){bc(a,b,48)}function CD(a,b){bc(a,b,11)}function Bp(a,b){t[a+1|0]=b}function $O(a){if(a){Zb(a)}}function yq(a,b){z[a>>2]=b}function yk(a,b){yp(a,b,0)}function xY(a){Qb(a,0,610)}function wU(a){Qb(a,0,146)}function wE(a){Qb(a,0,497)}function vd(a){Qp(a);iF(a)}function vc(a){v[a+8>>2]=0}function vP(a){eu(a,Vd(a))}function uE(a){Lg(a);sc(a)}function tX(a){Qb(a,0,157)}function ss(a){a=a|0;us(a)}function sU(a){Qb(a,0,608)}function sR(a){qg(a);Cc(a)}function qY(a){on(a);Tj(a)}function oX(a){Qb(a,0,576)}function nr(a){aC(a,Vd(a))}function nB(a){Qb(a,0,256)}function n5(){return 65535}function mr(a){$B(a,Vd(a))}function mV(a){Qb(a,0,130)}function mS(a){$h(a);Ae(a)}function lO(a){sz(a,Vd(a))}function l4(){return 79304}function kn(a){EC(a);nv(a)}function k4(){return 80080}function j4(){return 81632}function iV(a){Qb(a,0,600)}function gw(a){ye(a);Nb(a)}function fd(a){cE(a);eE(a)}function eB(a){Qb(a,0,512)}function dX(a){t[a+31|0]=0}function bf(a,b){v[a>>2]=b}function bV(a){Qb(a,0,126)}function aX(a){xC(a,Vd(a))}function _n(){Pn(8335);L()}function _f(){nd(8335);L()}function _B(a,b){bc(a,b,4)}function YS(a){hg(a);pc(a)}function YD(a,b){li(a,2,b)}function Wc(a){a=a|0;Zb(a)}function WW(a){yC(a,Vd(a))}function WM(a){Cl(a);Qf(a)}function Vb(a){Jn(v[a>>2])}function Ue(a){Fp(a);Zr(a)}function Sq(a){ax(a);JR(a)}function SW(a){Qb(a,0,192)}function Rc(){nd(4862);L()}function RV(a,b){bc(a,b,2)}function Qx(){Pn(4862);L()}function Qv(a,b){bc(a,b,5)}function Oka(a){a=a|0;gb=a}function Ll(a){uA(a,Vd(a))}function Lc(a){tk(a);pu(a)}function KX(a,b){bc(a,b,6)}function JT(a){lB(a,Vd(a))}function IW(a){Sj(a);Eg(a)}function IT(a){mB(a,Vd(a))}function Hp(a,b){bc(a,b,8)}function CN(a){mk(a);Of(a)}function AR(a){Qq(a,Vd(a))}function $X(a,b){bc(a,b,3)}function $T(a){Qb(a,0,204)}function tw(a){Qb(a,0,36)}function pC(a){Qb(a,0,33)}function eW(a){Qb(a,0,52)}function bW(a){Qb(a,0,80)}function ZD(a){Qb(a,0,41)}function ZC(a){Qb(a,0,66)}function XC(a){Qb(a,0,64)}function Vi(a,b){t[a|0]=b}function NU(a){Qb(a,0,96)}function DX(a){Qb(a,0,98)}function BX(a){Qb(a,0,48)}function B8(){return 2048}function $D(a){Qb(a,0,38)}function zk(a){vb(a+4|0)}function xc(a){gc(a+8|0)}function wh(a){a=a|0;L()}function tR(a){Rq(a+8|0)}function sp(a,b){RH(a,b)}function kB(a,b){yc(a,b)}function jp(a,b){zd(a,b)}function iD(a,b){HY(a,b)}function ZV(a,b){VV(a,b)}function Yv(a){u[a>>1]=0}function Xd(a){yb(a+8|0)}function XW(a,b){bf(a,b)}function Vy(a,b){ni(a,b)}function Vo(a){v[a>>2]=0}function Vk(a,b){ee(a,b)}function Rh(a,b){Qh(a,b)}function PA(a,b){Xf(a,b)}function IR(a){Vm(a,0,0)}function HO(a,b){dw(a,b)}function GO(a,b){FO(a,b)}function Cq(a,b){Fe(a,b)}function Kf(a){t[a|0]=0}function Hha(){ua();L()}function js(a){TF(a,0)}function iq(a){qL(a,0)}function cu(a){iP(a,0)}function bu(a){hP(a,0)}function Zm(a){BR(a,0)}function ZA(a){hS(a,0)}function Gc(a){Ee(a,0)}function Dg(a){bX(a,0)}function CO(a){kO(a,0)}function Bi(a){rL(a,0)}function Ai(a){pL(a,0)}function zG(a){JH(a)}function qR(a){Vu(a)}function lf(a){a=a|0}function iE(a){Xg(a)}function VT(a){ad(a)}function Hb(a){vb(a)}function c0(){L()}
// EMSCRIPTEN_END_FUNCS
e=w;var kb=c([null,Wm,Tb,Ot,cg,LL,ko,e6,O5,TN,_4,a4,$2,YN,Wm,F5,CZ,wn,fh,T4,$,oD,rn,i_,Ww,Nc,He,aZ,vn,Xe,Wc,JF,gs,yfa,fi,Nf,fi,rpa,gp,yr,jf,wB,dh,DC,gB,iv,fC,Fb,Zc,IU,wh,te,te,Ona,Mna,wt,Kna,wla,ola,c0,CU,wh,te,ic,te,Ama,yma,vma,qma,lma,cla,Wla,Zka,Ila,Fla,Xe,wh,$ha,Rha,Kha,Hha,Dha,uha,LA,cha,aha,jia,yha,Iz,W5,Fga,vga,UQ,jf,Go,Pq,Zc,UQ,V5,efa,UN,bN,Kt,mq,S5,Q5,Wm,Kt,mq,mi,Cca,cg,Tb,LL,kM,Ht,wf,wI,jq,Vf,J8,SG,H8,bh,bL,l5,o8,kM,z7,Cy,Cy,kba,cba,l7,c7,Zaa,Raa,V7,U7,V4,F8,Vf,S6,B5,ny,z5,uJ,x5,B6,v6,k5,Wm,v5,t5,j6,kt,h6,d6,TI,Dp,Wm,jf,DC,dl,VG,gB,Sn,Q2,wB,Zc,Zc,O$,M$,L$,C$,t$,s$,vs,Vf,r$,q$,Jh,oi,b$,p$,lG,kG,o$,vs,n$,Nn,Nw,ss,dk,Vc,Df,i$,Nn,os,k$,j$,h$,m$,g$,iG,f$,iG,l$,jG,e$,d$,c$,Jh,gG,jf,Mn,Ln,ij,eG,cG,bG,kt,a$,ia,Op,Np,wt,Xc,Pb,Z_,Fw,Y_,hm,X_,WF,W_,_k,WF,be,gm,fi,U_,Bs,fi,T_,K_,J_,cf,V_,S_,L_,Ih,cf,DF,cf,xw,Sn,Sn,F_,E_,D_,Sn,Cw,wt,KF,R_,Ip,ML,Q_,Wc,P_,te,te,wt,my,O_,N_,M_,BF,I_,Ip,H_,Wc,ic,te,te,ic,ic,G_,oF,C_,Ip,B_,nF,A_,z_,y_,x_,w_,v_,u_,t_,s_,mx,qfa,lfa,ifa,$r,EF,n_,zF,eG,Zc,lF,k_,j_,Cw,jf,jf,ZE,rd,g_,f_,jf,Zc,Zc,Zc,gB,DC,wB,dl,_Z,Pq,d_,Fb,$Z,Qk,ZZ,Zc,ZE,ii,YZ,XZ,WZ,SZ,vE,yn,Zc,NZ,nE,Yb,LZ,td,de,mE,KZ,ac,Jc,JZ,IZ,lE,kE,jE,zg,vg,qh,HZ,aw,gE,GZ,fE,$v,jf,FZ,Go,Rd,Te,Bc,jf,jf,zZ,jf,EZ,DZ,Zc,BZ,vE,AZ,yZ,vZ,uZ,tZ,KD,sZ,Se,rZ,qZ,pZ,oZ,uy,fO,VS,nZ,ke,mZ,_v,HD,Gd,dk,rh,iZ,hZ,Uv,Ie,Bf,RO,gZ,fZ,eZ,GD,dZ,FD,ld,Vv,_m,gp,Cn,bZ,$Y,Vr,Tc,bw,gqa,Mv,fqa,wg,Oc,Ob,Yf,Df,eqa,pD,dqa,Vc,Lv,tha,cqa,bqa,Pi,aqa,SY,Kv,$pa,Jv,_pa,Bea,Pf,Be,Gm,so,fz,Zpa,QY,FM,mD,Hv,Gv,Fk,Df,Ypa,Xpa,SE,OY,qn,Wpa,hh,Vpa,Upa,DY,ij,Tpa,cG,bG,kt,Op,Qpa,Ppa,Opa,tY,Lpa,Kpa,bD,xf,Jpa,Ipa,Hpa,Gpa,Mo,cB,Fpa,Epa,Dpa,Cpa,Nf,ce,gt,aD,Bv,$C,zpa,ypa,Apa,jY,gp,Cn,kY,mp,dl,Zc,Mf,YX,vpa,Hk,spa,qpa,ppa,be,yf,SX,opa,gm,npa,dB,mpa,QX,lpa,kpa,jpa,gpa,Mv,hp,fpa,epa,SY,dpa,Mk,cpa,bpa,apa,$oa,xn,gr,_oa,Zoa,OY,qn,Yoa,JX,Xoa,IX,QC,TC,SC,IX,Zy,xha,Vj,rv,iz,uq,Ut,T5,LC,Ooa,qX,Fh,Loa,Koa,zfa,Hoa,Nfa,qv,Cp,Goa,Foa,Eoa,Dr,KE,Doa,Bu,To,Coa,Boa,Noa,kX,a_,Aoa,Po,LE,pv,zoa,Df,yoa,Jc,xoa,woa,jX,voa,VZ,uoa,toa,soa,roa,iX,qoa,Pu,poa,Df,ooa,noa,kw,sY,Moa,Df,moa,loa,yr,xp,koa,joa,ioa,QO,JC,hoa,JC,JC,IC,fX,GC,wm,goa,E4,foa,eoa,doa,coa,boa,aoa,$na,Xda,eX,jf,PW,gd,ep,Vna,tC,Nna,Nr,_na,jf,rC,Lna,Zna,Yna,Xna,Xf,Yda,Cfa,Oda,Wna,Ot,Una,Tna,Sna,cf,Vf,Xe,Zc,Rna,Zc,Zc,Qna,Pq,Pna,rr,Gna,Fna,Ena,_e,Dna,Cna,Bna,Ana,zna,yna,AW,zW,xna,wna,vna,una,tna,sna,rna,qna,wW,gn,kW,mC,nna,lC,mna,pr,IS,Dr,lna,kna,jna,ina,PC,LS,Xl,Vl,kC,hna,MZ,gna,fna,iW,hW,iC,ena,Ge,dna,Ot,Dr,cna,Dr,bna,Pr,ana,Df,tY,ev,TV,Zma,Yma,be,gm,Xma,Wma,XB,Vma,bv,Uma,Tma,Sma,Rma,Qma,Pma,oE,Oma,Nma,Cha,Mma,Lma,Kma,Jma,Eja,Qga,Oga,Ima,k6,CC,l6,Hma,Gma,ey,fy,xfa,Fma,Df,hX,gX,NS,Ema,Dma,Uv,KV,lr,Cma,Bma,Jh,oi,zma,Dv,_u,Bj,Hh,NB,nma,mma,wma,lv,Zc,ima,hma,DD,gma,SO,fma,ema,DN,ep,dma,eV,cma,bma,fm,em,Xu,pA,ama,_la,No,Zla,$l,Yla,Xla,JB,up,xw,Rla,HB,Pla,Ola,mw,Ur,Nla,Ol,Mla,qn,Hh,Hla,Gla,cf,Ela,Dla,TU,cf,Tr,Cla,lC,zla,Gk,wk,Xu,yla,Fea,KV,lr,ev,ula,tla,bD,VU,HB,Vv,sla,rla,qla,n5,pla,nla,mla,Tu,lla,Tu,kla,ks,jla,qn,b_,fla,dla,NB,gla,ela,AU,zU,$ka,mC,_ka,Wka,Vka,ZS,eV,kX,Rga,hR,Ska,Uv,Mka,Lka,GD,gU,Kka,Jka,Ika,Hka,fn,eU,Fka,Eka,Dka,YT,yka,xka,wka,vka,uka,tka,ska,bn,Dja,ST,rka,qka,pka,oka,nka,mka,lka,zha,Zt,Ega,Nga,Lga,kka,Gea,be,jka,lC,ika,hka,gka,lv,QB,fka,MT,xh,eka,dka,xT,cka,bka,ar,aka,DT,ev,zT,Yja,Xja,UU,Vja,Tja,Aha,Qja,Pja,Zea,Oja,Nja,Mja,XN,Lja,Yea,ZN,Kja,Jja,Ija,u$,sG,Bha,Zu,Df,Gfa,Ffa,fT,eT,jf,Zc,fB,Cja,Bja,Aja,zja,yja,xja,wja,vja,uja,tja,sja,rja,pja,oja,nja,mja,lja,kja,jja,ija,hja,gja,fja,eja,dja,cja,bja,aja,$ia,_ia,Zia,Yia,Xia,Wia,Via,Uia,Tia,Sia,Ria,Qia,Pia,Oia,Nia,Mia,Lia,Kia,Jia,Iia,Hia,Gia,Fia,Eia,Dia,Cia,Bia,Aia,zia,yia,xia,wia,via,uia,tia,sia,ria,qia,pia,oia,nia,mia,lia,kia,iia,hia,gia,fia,eia,dia,cia,bia,aia,_ha,Zha,Yha,Xha,Wha,Vha,Uha,Tha,Sha,Qha,Pha,Oha,Nha,Mha,Lha,Jha,Iha,Fha,Yq,Gha,qS,bj,XD,uS,vha,iha,sha,rha,qha,pha,oha,sS,nha,mha,lha,kha,yu,hha,jha,_R,fha,eha,Xv,SR,rfa,dha,bha,vq,qz,oz,nz,GA,$ga,LR,_ga,Zga,jf,Yga,Zc,Jo,sq,ER,Wga,Vga,Hi,Uga,Pf,Sga,Tga,Xe,Zc,ot,m6,Tm,Pga,Dfa,Ti,Eha,Zh,gR,Uja,_h,cfa,Mga,Ar,Kga,Mv,Jga,Hh,Fw,Iga,Hga,Gga,tga,qn,Dga,Mv,Cga,Bga,Fw,pga,qn,xga,wga,YQ,cf,gG,Mn,Ln,kt,Jh,qu,_Q,jf,Xe,WQ,jf,dp,oga,h_,Pe,cZ,SQ,nga,Bpa,RQ,QQ,PQ,OQ,NQ,MQ,LQ,KQ,JQ,IQ,HQ,GQ,FQ,EQ,DQ,CQ,BQ,AQ,zQ,yQ,xQ,wQ,vQ,uQ,tQ,sQ,rQ,qQ,pQ,oQ,nQ,mQ,lQ,kQ,jQ,iQ,hQ,gQ,fQ,eQ,mga,lga,kga,jga,iga,hga,gga,fga,ega,dga,cga,bga,aga,$fa,_fa,Zfa,Yfa,Xga,aQ,Ez,tu,xR,Xfa,Wfa,Dz,xg,Eo,Mq,Vfa,$P,Ro,mA,kA,Om,Gz,UO,Fz,Do,ku,WP,Ufa,jA,Mm,YA,VP,_A,MA,wu,Mi,Tfa,oP,wha,Gja,AS,Rfa,qO,Qfa,Fja,Pfa,rf,Ofa,Mfa,$_,r_,m_,p_,Kfa,l_,q_,__,o_,$m,Jfa,JS,Eq,Ifa,Zca,Hfa,eP,Xz,hfa,gha,Efa,hea,lea,Bfa,jea,gea,cf,cf,ts,Afa,MS,wfa,vfa,LO,Sja,Rja,Joa,Ioa,Yka,Xka,Rka,Qka,pna,ona,Vla,Ula,Ina,Hna,iqa,hqa,Woa,Voa,xZ,wZ,kZ,jZ,Lla,Kla,bla,ala,_ja,Zja,Npa,Mpa,xpa,wpa,RZ,QZ,PZ,OZ,xla,vla,ila,hla,kma,jma,Jna,CW,Soa,Roa,Qoa,Poa,Spa,Rpa,ipa,hpa,Bla,Ala,Xea,Wea,Jea,Iea,pma,oma,Aka,zka,Tla,Sla,Uoa,Toa,Uka,Tka,Pka,Nka,upa,tpa,xma,sma,rma,UZ,TZ,_Y,jqa,$ma,_ma,uma,tma,wh,tfa,sfa,pP,Zc,Vf,fB,pfa,qs,nfa,ofa,$Q,kfa,mfa,jfa,Wt,gfa,yga,Sm,Aga,zga,ffa,dfa,Mr,rga,sga,bfa,Eea,c_,afa,eF,Kw,kz,HD,$ea,Zz,_ea,uga,Vea,Uea,bD,Tea,Hr,HB,Sea,Rea,Qea,NB,Pea,Hh,Oea,Nea,Mea,Lea,Kea,qn,xJ,o6,n6,Hea,Xq,Dea,Aea,mv,yea,xea,wea,HC,vea,Tf,Qh,tm,uea,KN,tea,oea,sea,Cea,rea,mea,pea,zea,nea,az,vN,jf,Zda,Pq,lN,iea,bz,pq,eea,dea,cea,bea,aea,sN,kea,rq,Xf,rN,_da,jl,Qh,kN,Wda,Vda,Uda,Tda,Sda,Rda,Sf,Qda,Pda,$da,fea,Mda,Lda,Vh,Kda,Jda,VM,wda,Pm,Pq,qN,vda,lN,uda,Zc,kN,Zc,$M,_M,_M,ZM,ic,lf,ic,ic,ic,Zc,Iv,Eda,Fda,Hda,Gda,Ida,Gi,gs,gs,Uy,YM,Uy,Uy,Wja,lf,CW,Ada,zda,yda,xda,Dda,Ei,aN,cda,ic,ic,te,Ty,qe,qe,te,Cda,Bda,Zc,lf,Zc,lf,sda,eda,LM,KM,KM,dda,ic,lf,ic,ic,ic,Zc,Gka,QM,qda,gda,fda,rda,Gi,oda,nda,mda,lda,kda,jda,ida,hda,pda,Ei,PM,ic,ic,te,qe,qe,te,NM,MM,$ca,GM,hf,wh,ada,Py,bda,ic,_ca,YM,Yca,Vf,uN,Xca,Wca,Vca,Uca,yu,Jca,xca,pca,hca,aca,Vba,Lba,Bba,uba,Nda,tda,Tca,Sca,un,JO,BM,AM,AM,ZM,ic,lf,ic,ic,ic,Zc,$F,Nca,Oca,Qca,Pca,Rca,Gi,Mca,Ei,CM,ic,ic,te,qe,qe,te,Lca,Kca,zM,Ny,Dca,yM,Bca,ic,lf,ic,ic,ic,Zc,xM,Gca,Hca,Ica,Gi,Fca,Ei,Eca,ic,ic,te,qe,qe,Zc,lf,wM,Aca,zca,vM,yca,uM,tM,wca,qM,pM,pM,rca,ic,lf,ic,ic,ic,Zc,qca,tca,uca,vca,Gi,sca,Ei,rM,ic,ic,te,qe,qe,oca,Bl,Bl,ica,ic,lf,ic,ic,ic,Zc,lM,lca,mca,nca,Gi,jca,Ei,mM,ic,ic,te,qe,qe,gca,hM,gM,gM,bca,ic,lf,ic,ic,ic,Zc,lM,dca,eca,fca,Gi,cca,Ei,iM,ic,ic,te,qe,qe,$ba,fM,fM,Zba,xM,_ba,wM,Yba,Xba,vM,Wba,uM,tM,Uba,Bl,Bl,Oba,ic,lf,ic,ic,ic,Zc,qe,Rba,Sba,Tba,Gi,Pba,Ei,Nba,ic,ic,te,qe,qe,Kba,Mba,$L,_L,_L,Eba,ic,lf,ic,ic,Dba,Zc,Cba,Gba,Hba,Jba,Gi,Fba,Ei,Ly,ic,ic,te,qe,qe,Zc,lf,Aba,Bl,Bl,vba,ic,lf,ic,ic,ic,Zc,$F,xba,yba,zba,Gi,wba,Ei,XL,ic,ic,te,qe,qe,tba,Bl,Bl,oba,ic,lf,ic,ic,ic,Zc,Iv,qba,rba,sba,Gi,pba,Ei,TL,ic,ic,te,qe,qe,a9,mba,g9,T8,$8,_8,E8,Nw,dL,It,IL,A8,aba,HL,B8,cL,w8,v8,Xe,Yaa,Xaa,IL,u8,s8,EL,Uaa,Gy,$K,my,_K,ZK,f8,b8,c8,d8,Ky,r8,Daa,vL,q8,p8,n8,m8,l8,k8,j8,i8,h8,g8,a8,Ky,W7,XK,WK,VK,UK,SK,RK,QK,PK,OK,NK,MK,LK,T7,io,KK,JK,xl,gq,S7,CH,R7,P7,O7,N7,M7,FK,EK,zt,L7,K7,I7,H7,G7,F7,E7,D7,C7,B7,L8,mL,lL,kL,jL,O6,N6,EL,Ky,y9,x9,w9,v9,u9,t9,s9,r9,q9,p9,o9,n9,m9,l9,k9,j9,i9,h9,ua,f9,Fy,e9,d9,zL,b9,zL,c9,lq,Z8,qga,zl,rs,QN,Dl,X8,W8,p7,U8,lk,UN,mu,P8,Sfa,K8,sI,I8,E5,kca,A7,Ot,Qba,Iba,Lfa,O8,Y8,S8,mz,kg,M8,ufa,D8,tL,sL,cL,z8,C8,jV,y8,x8,cf,N8,G8,Q8,bc,t8,e8,_O,$7,_7,Z7,P6,Sz,Tz,R8,WO,Y7,X7,mo,IK,qea,Q7,Qi,J7,Tc,XO,hz,Hja,gz,v7,s7,$la,Qla,o7,n7,m7,nK,k7,gK,ut,gK,ut,ba,Q6,wh,Et,y7,V8,Xe,wh,Xe,Wc,x7,w7,wh,vK,u7,Ip,t7,tK,r7,Ip,q7,kK,jK,kK,jK,Zc,vt,Zc,vt,iK,hK,iK,hK,Wc,j7,Xe,Wc,i7,h7,Wc,dK,cK,wh,g7,bK,f7,bK,e7,$J,d7,$J,Wc,b7,a7,Wc,_J,ZJ,qt,qt,qt,qt,$6,ry,ry,ry,Wc,_6,Z6,Wc,XJ,WJ,Y6,VJ,X6,VJ,W6,TJ,V6,TJ,Wc,U6,T6,Wc,SJ,RJ,pt,pt,pt,pt,R6,py,py,py,Zc,vt,Zc,vt,oy,OJ,K6,J6,NJ,MJ,LJ,KJ,JJ,IJ,HJ,GJ,FJ,EJ,DJ,CJ,BJ,AJ,zJ,yJ,M6,L6,I6,H6,G6,F6,E6,D6,C6,A6,z6,y6,x6,w6,u6,t6,s6,r6,Xe,wh,Xe,wh,q6,p6,i6,g6,$5,f6,c6,b6,a6,Y5,X5,Ms,U5,JI,II,HI,Li,TI,Dp,wo,Ec,D5,C5,A5,y5,w5,u5,s5,Ix,r5,Cka,Bka,KY,q5,wo,p5,o5,m5,_H,Xe,um,N5,Zc,Wm,pI,oI,ic,ic,M5,nI,L5,Zs,K5,Zs,bq,J5,Zc,Wm,pI,oI,ic,ic,I5,nI,H5,Zs,G5,Zs,Xs,Jx,lI,kI,Xs,Jx,lI,kI,Vs,Gx,aI,$H,Vs,Gx,aI,$H,xt,f5,g5,e5,j5,i5,h5,lh,qI,lh,qI,hq,WH,d5,c5,tf,VH,b5,a5,lf,W4,Y4,SH,Xe,Wc,$4,A4,z4,y4,Z4,X4,Dx,U4,P5,ic,S4,R4,Q4,yt,yt,Ex,Ax,Ws,fI,LH,P4,O4,N4,M4,IH,L4,K4,J4,I4,LH,H4,GH,G4,F4,IH,D4,GH,C4,B4,Xe,wh,wh,e_,s4,o4,DH,yx,Wc,x4,w4,Wc,v4,t4,u4,r4,Wc,q4,p4,n4,ic,ic,ic,px,Ph,Oh,Ks,Zb,Ns,ik,hk,rl,ox,ql,_3,nj,Qg,Y3,W3,oH,oH,S3,Q3,nH,oj,O3,M3,xe,K3,m4,tx,Hx,jx,Ph,Oh,Js,sm,ll,rm,rn,qm,nj,Qg,mH,oj,w3,r3,q3,i4,wx,_5,ZH,l3,Qs,vn,g3,Tn,sx,lf,O2,Gs,N2,M2,L2,K2,I2,G2,F2,ml,E2,D2,B2,R5,z2,y2,v2,u2,q2,p2,o2,n2,m2,l2,k2,j2,i2,h2,g2,f2,e2,d2,c2,b2,a2,$1,_1,Z1,Y1,X1,W1,V1,U1,T1,S1,R1,Q1,P1,O1,N1,M1,G1,K1,g0,L1,I1,H1,F1,l4,j4,k4,ux,vH,sl,uH,$p,f1,e1,zI,tH,sH,N0,M0,K0,J0,H0,G0,E0,D0,B0,A0,y0,x0,v0,$w,t0,r0,p0,n0,l0,j0,h0,OG,J1,yM,LG,t1,s1,r1,q1,p1,oY,o1,n1,m1,JG,k1,j1,i1,h1,g1,ic,d1,c1,GG,X0,V0,U0,IK,S0,Q0,FG,W0,my,lZ,T0,R0,P0,Xe,Wc,Wc,E1,D1,C1,B1,A1,z1,y1,x1,oY,w1,v1,u1,Wc,KG,KG,cx,te,te,l1,te,Wc,b1,a1,cx,ic,ic,$0,Iv,Wc,_0,Z0,cx,ic,ic,Y0,Iv,Xe,Wc,h4,g4,f4,Xe,Wc,e4,d4,c4,Wc,b4,$3,Z3,X3,V3,U3,T3,R3,P3,N3,L3,Wc,J3,I3,H3,G3,F3,E3,D3,C3,B3,A3,z3,Wc,y3,x3,v3,u3,t3,s3,p3,o3,Wc,n3,m3,k3,j3,i3,h3,f3,e3,Xe,Wc,qe,d3,c3,b3,a3,_2,Z2,O0,I0,C0,o0,k0,w0,s0,Xe,Wc,qe,Y2,X2,W2,V2,U2,T2,L0,F0,z0,m0,i0,u0,q0,Zw,DG,S2,Zw,DG,R2,Wc,Fs,Fs,Kh,Kh,Kh,cH,ic,hl,hl,Wc,Fs,Fs,Kh,Kh,Kh,cH,ic,hl,hl,Wc,Xr,Xr,Kh,Kh,Kh,bH,ic,hl,hl,Wc,Xr,Xr,Kh,Kh,Kh,bH,ic,hl,hl,Wc,P2,J2,Wc,H2,C2,Wc,A2,x2,Wc,w2,t2,Wc,XG,s2,Zc,Wc,XG,r2,Zc,d0,e0,f0,Wc,a0,Wc,b0,$$,_$,Np,Np,Np,Np,Cw,Wc,Z$,Xe,Wc,lf,lf,uG,Q$,T$,Y$,Wc,R$,U$,X$,Wc,S$,V$,W$]);function lb(){return s.byteLength/65536|0}function qb(rb){rb=rb|0;var mb=lb()|0;var nb=mb+rb|0;if(mb<nb&&nb<65536){var ob=new ArrayBuffer(B(nb,65536));var pb=new Int8Array(ob);pb.set(t);t=new Int8Array(ob);u=new Int16Array(ob);v=new Int32Array(ob);w=new Uint8Array(ob);x=new Uint16Array(ob);y=new Uint32Array(ob);z=new Float32Array(ob);A=new Float64Array(ob);s=ob;r.buffer=s;e=w}return mb}return{"va":ZY,"wa":nba,"xa":lba,"ya":Wc,"za":Zb,"Aa":jba,"Ba":iba,"Ca":hba,"Da":It,"Ea":Zc,"Fa":gba,"Ga":fba,"Ha":eba,"Ia":gs,"Ja":dba,"Ka":ML,"La":bba,"Ma":Xe,"Na":KL,"Oa":JL,"Pa":KL,"Qa":$aa,"Ra":K$,"Sa":J$,"Ta":I$,"Ua":_aa,"Va":GL,"Wa":Waa,"Xa":FL,"Ya":Vaa,"Za":Taa,"_a":Saa,"$a":Qaa,"ab":Paa,"bb":Oaa,"cb":Naa,"db":Maa,"eb":Laa,"fb":Kaa,"gb":Jaa,"hb":Iaa,"ib":Haa,"jb":Gaa,"kb":Faa,"lb":Eaa,"mb":Caa,"nb":Baa,"ob":Aaa,"pb":zaa,"qb":yaa,"rb":xaa,"sb":waa,"tb":vaa,"ub":uaa,"vb":taa,"wb":saa,"xb":raa,"yb":qaa,"zb":paa,"Ab":oaa,"Bb":naa,"Cb":maa,"Db":laa,"Eb":kaa,"Fb":jaa,"Gb":iaa,"Hb":haa,"Ib":gaa,"Jb":faa,"Kb":eaa,"Lb":daa,"Mb":caa,"Nb":baa,"Ob":aaa,"Pb":$9,"Qb":_9,"Rb":Z9,"Sb":Y9,"Tb":X9,"Ub":W9,"Vb":V9,"Wb":U9,"Xb":T9,"Yb":S9,"Zb":R9,"_b":Q9,"$b":P9,"ac":O9,"bc":N9,"cc":M9,"dc":L9,"ec":K9,"fc":H$,"gc":J9,"hc":I9,"ic":H9,"jc":G9,"kc":G$,"lc":F9,"mc":E9,"nc":D9,"oc":C9,"pc":B9,"qc":A9,"rc":z9,"sc":Ad,"tc":Z5,"uc":Jla,"vc":Oka,"wc":$ja,"xc":qja,"yc":P$,"zc":N$,"Ac":kb,"Bc":y$,"Cc":F$,"Dc":E$,"Ec":D$,"Fc":B$,"Gc":A$,"Hc":z$,"Ic":y$,"Jc":x$,"Kc":w$,"Lc":v$}}return sb(ub)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


